import VueI18n from 'vue-i18n';
import Vue from 'vue';

const http = {
  get: (url, requestOptions) => {
    return (requestOptions ? fetch(url, requestOptions) : fetch(url)).then(response => response.json());
  },
  post: (url, body) => {
    return fetch(url, {
      method: 'POST',
      body: JSON.stringify(body)
    }).then(response => response.json());
  }
};

const appSettings = {
  apiBaseUrl: "https://api.okendo.io/v1",
  dynamicTranscodedMediaBaseUrl: "https://d3g5hqndtiniji.cloudfront.net",
  appBaseUrl: "https://reviews.okendo.io",
  recorderPlusBaseUrl: "https://okendo.reviews"
};

var HtmlUtils = {
  addOrUpdateTargetBlock(blockType, blockId, html, elementUpdateMode = 'innerHTML', elementKey = 'head') {
    if (!html) {
      return;
    }

    const HTMLTargetElement = document.querySelector(elementKey);
    const existingElement = HTMLTargetElement.querySelector(`#${blockId}`);

    if (existingElement) {
      existingElement[elementUpdateMode] = html;
    } else {
      const blockElement = document.createElement(blockType);
      blockElement.id = blockId;
      HTMLTargetElement.prepend(blockElement);
      blockElement[elementUpdateMode] = html;
    }
  },

  getFocusableElements(target, includeNegatives) {
    if (target) {
      const targets = ['button', 'a', 'input', 'select', 'textarea', '[tabindex]'];
      const queryTargets = includeNegatives ? targets : targets.map(target => `${target}:not([tabindex="-1"])`);
      return Array.from(target.querySelectorAll(queryTargets.join(',')));
    }
  },

  getFirstFocusable(target) {
    if (target) {
      const focusableElements = this.getFocusableElements(target);

      if (focusableElements === null || focusableElements === void 0 ? void 0 : focusableElements.length) {
        return focusableElements[0];
      }
    }
  }

};

let widgetConfigPromise;
const kOkendoConfigErrorMesssage = 'Could not retrieve Okendo Reviews & UGC configuration';
async function getSubscriberConfig() {
  if (widgetConfigPromise) {
    return await widgetConfigPromise;
  } // either get config from head (provided by shopify metafield)


  const widgetHeaderSettingsElement = document.getElementById('oke-reviews-settings');

  if (widgetHeaderSettingsElement) {
    widgetConfigPromise = Promise.resolve(JSON.parse(widgetHeaderSettingsElement.innerText));
  } else {
    // ... or retrieve from public API
    const subscriberIdElement = document.querySelector('meta[name="oke:subscriber_id"]');
    const subscriberId = subscriberIdElement === null || subscriberIdElement === void 0 ? void 0 : subscriberIdElement.content;

    if (!subscriberId) {
      return;
    }

    const setHeaderConfigFromApi = async () => {
      try {
        const [headerContent, htmlUtils] = await Promise.all([http.get(`${appSettings.apiBaseUrl}/stores/${subscriberId}/widget_plus_settings`), HtmlUtils]);
        htmlUtils.addOrUpdateTargetBlock('style', 'oke-css-vars', headerContent.cssVariables, 'outerHTML');
        htmlUtils.addOrUpdateTargetBlock('style', 'oke-reviews-custom-css', headerContent.customCss, 'outerHTML');
        htmlUtils.addOrUpdateTargetBlock('svg', 'oke-star-symbols', headerContent.starSymbols, 'outerHTML', 'body');
        return headerContent.reviewsHeaderConfig;
      } catch (_a) {
        console.error(kOkendoConfigErrorMesssage);
      }
    };

    widgetConfigPromise = setHeaderConfigFromApi();
  }

  return await widgetConfigPromise;
}
async function getWidgetSettingsFromSubscriberOrDefault(subscriberConfig) {
  let {
    widgetSettings
  } = subscriberConfig;

  if (!widgetSettings) {
    const {
      default: defaultSettings
    } = await Promise.resolve().then(function () { return DefaultSettings; });
    widgetSettings = defaultSettings;
  }

  return widgetSettings;
}

function OkendoVueI18nPlugin(Vue) {
  Vue.use(VueI18n); // eslint-disable-next-line no-prototype-builtins

  if (!Vue.prototype.hasOwnProperty('$i18n')) {
    Object.defineProperty(Vue.prototype, '$i18n', {
      get() {
        var _a;

        return (_a = this.$root) === null || _a === void 0 ? void 0 : _a._i18n;
      }

    });
  }
}

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

/**
  * vue-class-component v7.2.3
  * (c) 2015-present Evan You
  * @license MIT
  */

function _typeof(obj) {
  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _defineProperty$1(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _toConsumableArray$1(arr) {
  return _arrayWithoutHoles$1(arr) || _iterableToArray$1(arr) || _nonIterableSpread$1();
}

function _arrayWithoutHoles$1(arr) {
  if (Array.isArray(arr)) {
    for (var i = 0, arr2 = new Array(arr.length); i < arr.length; i++) arr2[i] = arr[i];

    return arr2;
  }
}

function _iterableToArray$1(iter) {
  if (Symbol.iterator in Object(iter) || Object.prototype.toString.call(iter) === "[object Arguments]") return Array.from(iter);
}

function _nonIterableSpread$1() {
  throw new TypeError("Invalid attempt to spread non-iterable instance");
}

// The rational behind the verbose Reflect-feature check below is the fact that there are polyfills
// which add an implementation for Reflect.defineMetadata but not for Reflect.getOwnMetadataKeys.
// Without this check consumers will encounter hard to track down runtime errors.
function reflectionIsSupported() {
  return typeof Reflect !== 'undefined' && Reflect.defineMetadata && Reflect.getOwnMetadataKeys;
}
function copyReflectionMetadata(to, from) {
  forwardMetadata(to, from);
  Object.getOwnPropertyNames(from.prototype).forEach(function (key) {
    forwardMetadata(to.prototype, from.prototype, key);
  });
  Object.getOwnPropertyNames(from).forEach(function (key) {
    forwardMetadata(to, from, key);
  });
}

function forwardMetadata(to, from, propertyKey) {
  var metaKeys = propertyKey ? Reflect.getOwnMetadataKeys(from, propertyKey) : Reflect.getOwnMetadataKeys(from);
  metaKeys.forEach(function (metaKey) {
    var metadata = propertyKey ? Reflect.getOwnMetadata(metaKey, from, propertyKey) : Reflect.getOwnMetadata(metaKey, from);

    if (propertyKey) {
      Reflect.defineMetadata(metaKey, metadata, to, propertyKey);
    } else {
      Reflect.defineMetadata(metaKey, metadata, to);
    }
  });
}

var fakeArray = {
  __proto__: []
};
var hasProto = fakeArray instanceof Array;
function createDecorator(factory) {
  return function (target, key, index) {
    var Ctor = typeof target === 'function' ? target : target.constructor;

    if (!Ctor.__decorators__) {
      Ctor.__decorators__ = [];
    }

    if (typeof index !== 'number') {
      index = undefined;
    }

    Ctor.__decorators__.push(function (options) {
      return factory(options, key, index);
    });
  };
}
function mixins() {
  for (var _len = arguments.length, Ctors = new Array(_len), _key = 0; _key < _len; _key++) {
    Ctors[_key] = arguments[_key];
  }

  return Vue.extend({
    mixins: Ctors
  });
}
function isPrimitive(value) {
  var type = _typeof(value);

  return value == null || type !== 'object' && type !== 'function';
}

function collectDataFromConstructor(vm, Component) {
  // override _init to prevent to init as Vue instance
  var originalInit = Component.prototype._init;

  Component.prototype._init = function () {
    var _this = this;

    // proxy to actual vm
    var keys = Object.getOwnPropertyNames(vm); // 2.2.0 compat (props are no longer exposed as self properties)

    if (vm.$options.props) {
      for (var key in vm.$options.props) {
        if (!vm.hasOwnProperty(key)) {
          keys.push(key);
        }
      }
    }

    keys.forEach(function (key) {
      if (key.charAt(0) !== '_') {
        Object.defineProperty(_this, key, {
          get: function get() {
            return vm[key];
          },
          set: function set(value) {
            vm[key] = value;
          },
          configurable: true
        });
      }
    });
  }; // should be acquired class property values


  var data = new Component(); // restore original _init to avoid memory leak (#209)

  Component.prototype._init = originalInit; // create plain data object

  var plainData = {};
  Object.keys(data).forEach(function (key) {
    if (data[key] !== undefined) {
      plainData[key] = data[key];
    }
  });

  return plainData;
}

var $internalHooks = ['data', 'beforeCreate', 'created', 'beforeMount', 'mounted', 'beforeDestroy', 'destroyed', 'beforeUpdate', 'updated', 'activated', 'deactivated', 'render', 'errorCaptured', 'serverPrefetch' // 2.6
];
function componentFactory(Component) {
  var options = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  options.name = options.name || Component._componentTag || Component.name; // prototype props.

  var proto = Component.prototype;
  Object.getOwnPropertyNames(proto).forEach(function (key) {
    if (key === 'constructor') {
      return;
    } // hooks


    if ($internalHooks.indexOf(key) > -1) {
      options[key] = proto[key];
      return;
    }

    var descriptor = Object.getOwnPropertyDescriptor(proto, key);

    if (descriptor.value !== void 0) {
      // methods
      if (typeof descriptor.value === 'function') {
        (options.methods || (options.methods = {}))[key] = descriptor.value;
      } else {
        // typescript decorated data
        (options.mixins || (options.mixins = [])).push({
          data: function data() {
            return _defineProperty$1({}, key, descriptor.value);
          }
        });
      }
    } else if (descriptor.get || descriptor.set) {
      // computed properties
      (options.computed || (options.computed = {}))[key] = {
        get: descriptor.get,
        set: descriptor.set
      };
    }
  });
  (options.mixins || (options.mixins = [])).push({
    data: function data() {
      return collectDataFromConstructor(this, Component);
    }
  }); // decorate options

  var decorators = Component.__decorators__;

  if (decorators) {
    decorators.forEach(function (fn) {
      return fn(options);
    });
    delete Component.__decorators__;
  } // find super


  var superProto = Object.getPrototypeOf(Component.prototype);
  var Super = superProto instanceof Vue ? superProto.constructor : Vue;
  var Extended = Super.extend(options);
  forwardStaticMembers(Extended, Component, Super);

  if (reflectionIsSupported()) {
    copyReflectionMetadata(Extended, Component);
  }

  return Extended;
}
var shouldIgnore = {
  prototype: true,
  arguments: true,
  callee: true,
  caller: true
};

function forwardStaticMembers(Extended, Original, Super) {
  // We have to use getOwnPropertyNames since Babel registers methods as non-enumerable
  Object.getOwnPropertyNames(Original).forEach(function (key) {
    // Skip the properties that should not be overwritten
    if (shouldIgnore[key]) {
      return;
    } // Some browsers does not allow reconfigure built-in properties


    var extendedDescriptor = Object.getOwnPropertyDescriptor(Extended, key);

    if (extendedDescriptor && !extendedDescriptor.configurable) {
      return;
    }

    var descriptor = Object.getOwnPropertyDescriptor(Original, key); // If the user agent does not support `__proto__` or its family (IE <= 10),
    // the sub class properties may be inherited properties from the super class in TypeScript.
    // We need to exclude such properties to prevent to overwrite
    // the component options object which stored on the extended constructor (See #192).
    // If the value is a referenced value (object or function),
    // we can check equality of them and exclude it if they have the same reference.
    // If it is a primitive value, it will be forwarded for safety.

    if (!hasProto) {
      // Only `cid` is explicitly exluded from property forwarding
      // because we cannot detect whether it is a inherited property or not
      // on the no `__proto__` environment even though the property is reserved.
      if (key === 'cid') {
        return;
      }

      var superDescriptor = Object.getOwnPropertyDescriptor(Super, key);

      if (!isPrimitive(descriptor.value) && superDescriptor && superDescriptor.value === descriptor.value) {
        return;
      }
    } // Warn if the users manually declare reserved properties

    Object.defineProperty(Extended, key, descriptor);
  });
}

function Component(options) {
  if (typeof options === 'function') {
    return componentFactory(options);
  }

  return function (Component) {
    return componentFactory(Component, options);
  };
}

Component.registerHooks = function registerHooks(keys) {
  $internalHooks.push.apply($internalHooks, _toConsumableArray$1(keys));
};

/** vue-property-decorator verson 8.4.2 MIT LICENSE copyright 2019 kaorun343 */
/** @see {@link https://github.com/vuejs/vue-class-component/blob/master/src/reflect.ts} */
var reflectMetadataIsSupported = typeof Reflect !== 'undefined' && typeof Reflect.getMetadata !== 'undefined';
function applyMetadata(options, target, key) {
    if (reflectMetadataIsSupported) {
        if (!Array.isArray(options) &&
            typeof options !== 'function' &&
            typeof options.type === 'undefined') {
            var type = Reflect.getMetadata('design:type', target, key);
            if (type !== Object) {
                options.type = type;
            }
        }
    }
}
/**
 * decorator of a prop
 * @param  options the options for the prop
 * @return PropertyDecorator | void
 */
function Prop(options) {
    if (options === void 0) { options = {}; }
    return function (target, key) {
        applyMetadata(options, target, key);
        createDecorator(function (componentOptions, k) {
            (componentOptions.props || (componentOptions.props = {}))[k] = options;
        })(target, key);
    };
}
/**
 * decorator of a watch function
 * @param  path the path or the expression to observe
 * @param  WatchOption
 * @return MethodDecorator
 */
function Watch(path, options) {
    if (options === void 0) { options = {}; }
    var _a = options.deep, deep = _a === void 0 ? false : _a, _b = options.immediate, immediate = _b === void 0 ? false : _b;
    return createDecorator(function (componentOptions, handler) {
        if (typeof componentOptions.watch !== 'object') {
            componentOptions.watch = Object.create(null);
        }
        var watch = componentOptions.watch;
        if (typeof watch[path] === 'object' && !Array.isArray(watch[path])) {
            watch[path] = [watch[path]];
        }
        else if (typeof watch[path] === 'undefined') {
            watch[path] = [];
        }
        watch[path].push({ handler: handler, deep: deep, immediate: immediate });
    });
}

// Default widget settings used by the widget-plus, metafields and reviews admin projects
// Only commit changes intended to be the new default settings, do not commit changes made for testing
const kDefaultStarBackgroundColor = '#E5E5E5';
const kDefaultStarForegroundColor = '#FFCF2A';
const kDefaultStarBorderColor = '#2C3E50';
const kDefaultStarInterspace = 2;
const kDefaultStarShape = {
  type: 'default'
};
const kBadgeDarkBackgroundColor = '#272D45';
const kBadgeLightBackgroundColor = '#F4F4F6';
const kBadgeLightBorderColor = '#DBDDE4';
const defaultSettings = {
  global: {
    recorderPlusEnabled: true,
    hideOkendoBranding: false,
    showIncentiveIndicator: false,
    searchEnginePaginationEnabled: false,
    dateSettings: {
      format: {
        type: 'relative'
      }
    },
    stars: {
      backgroundColor: kDefaultStarBackgroundColor,
      borderColor: kDefaultStarBorderColor,
      foregroundColor: kDefaultStarForegroundColor,
      interspace: kDefaultStarInterspace,
      shape: kDefaultStarShape,
      showBorder: false
    }
  },
  reviewsWidget: {
    tabs: {
      reviews: true,
      questions: false
    },
    showWhenEmpty: true,
    style: {
      highlightColor: '#0E7A82',
      productImageSize: {
        value: 48,
        unit: 'px'
      },
      shadingColor: '#F7F7F8',
      showDates: true,
      spaceAbove: {
        value: 20,
        unit: 'px'
      },
      spaceBelow: {
        value: 20,
        unit: 'px'
      },
      button: {
        backgroundColor: '#F7F7F8',
        backgroundColorHover: '#F4F4F6',
        backgroundColorActive: '#676986',
        textColor: '#272D45',
        textColorHover: '#272D45',
        textColorActive: '#FFFFFF',
        borderRadius: {
          value: 4,
          unit: 'px'
        },
        borderColor: '#DBDDE4',
        borderColorHover: '#DBDDE4',
        borderColorActive: '#676986',
        borderWidth: {
          value: 1,
          unit: 'px'
        }
      },
      filters: {
        backgroundColor: '#FFFFFF',
        backgroundColorActive: '#676986',
        borderColor: '#DBDDE4',
        borderColorActive: '#676986',
        textColor: '#2C3E50',
        textColorActive: '#FFFFFF',
        borderRadius: {
          value: 100,
          unit: 'px'
        },
        searchHighlightColor: '#B2F9E9'
      },
      border: {
        color: '#E5E5EB',
        width: {
          value: 1,
          unit: 'px'
        }
      },
      text: {
        primaryColor: '#2C3E50',
        secondaryColor: '#676986',
        fontSizeSmall: {
          value: 12,
          unit: 'px'
        },
        fontSizeRegular: {
          value: 14,
          unit: 'px'
        },
        fontSizeLarge: {
          value: 20,
          unit: 'px'
        }
      },
      avatar: {
        enabled: true,
        size: {
          value: 48,
          unit: 'px'
        },
        backgroundColor: '#E5E5EB',
        placeholderTextColor: '#2C3E50'
      },
      attributeBar: {
        style: 'default',
        borderColor: '#9A9DB1',
        shadingColor: '#9A9DB1',
        backgroundColor: '#D3D4DD',
        markerColor: '#00CAAA'
      },
      stars: {
        height: {
          value: 18,
          unit: 'px'
        }
      }
    },
    header: {
      columnDistribution: 'space-between',
      verticalAlignment: 'top',
      blocks: [{
        textAlignment: 'left',
        columnWidth: 'one-third',
        modules: [{
          name: 'rating-average',
          layout: 'one-line'
        }, {
          name: 'rating-breakdown',
          backgroundColor: '#F4F4F6',
          shadingColor: '#9A9DB1',
          stretchMode: 'contain'
        }]
      }, {
        textAlignment: 'left',
        columnWidth: 'two-thirds',
        modules: [{
          name: 'recommended'
        }, {
          name: 'media-carousel',
          imageGap: {
            value: 4,
            unit: 'px'
          },
          imageHeight: {
            value: 120,
            unit: 'px'
          }
        }]
      }]
    },
    reviews: {
      controls: {
        filterMode: 'closed',
        writeReviewButtonEnabled: true,
        defaultSort: 'has_media desc',
        freeTextSearchEnabled: false
      },
      list: {
        initialPageSize: 5,
        loadMorePageSize: 5,
        layout: {
          name: 'default',
          borderStyle: 'full',
          collapseReviewerDetails: false,
          showAttributeBars: false,
          showProductDetails: 'only-when-grouped'
        },
        media: {
          layout: 'featured',
          size: {
            value: 200,
            unit: 'px'
          },
          imageGap: {
            value: 4,
            unit: 'px'
          }
        },
        truncation: {
          bodyMaxLines: 4,
          enabled: true,
          truncateAll: false
        }
      }
    }
  },
  starRatings: {
    showWhenEmpty: false,
    clickBehavior: 'scroll-to-widget',
    scrollTargetId: undefined,
    style: {
      text: {
        content: 'review-count',
        style: 'number-and-text',
        brackets: false
      },
      spaceAbove: {
        value: 0,
        unit: 'px'
      },
      spaceBelow: {
        value: 0,
        unit: 'px'
      },
      height: {
        value: 18,
        unit: 'px'
      }
    }
  },
  questions: {
    initialPageSize: 6,
    loadMorePageSize: 6
  },
  homepageCarousel: {
    autoPlay: false,
    defaultSort: 'rating desc',
    totalSlides: 12,
    slidesPerPage: {
      medium: 2,
      large: 3
    },
    scrollBehaviour: 'slide',
    truncation: {
      bodyMaxLines: 4,
      enabled: true,
      truncateAll: false
    },
    style: {
      layout: {
        name: 'default',
        reviewDetailsPosition: 'below',
        showAttributeBars: false,
        showProductDetails: 'only-when-grouped',
        showProductName: false
      },
      highlightColor: '#0E7A82',
      productImageSize: {
        value: 48,
        unit: 'px'
      },
      spaceAbove: {
        value: 20,
        unit: 'px'
      },
      spaceBelow: {
        value: 20,
        unit: 'px'
      },
      showDates: true,
      arrows: {
        enabled: true,
        color: '#676986',
        size: {
          value: 24,
          unit: 'px'
        }
      },
      avatar: {
        enabled: true,
        size: {
          value: 48,
          unit: 'px'
        },
        backgroundColor: '#E5E5EB',
        placeholderTextColor: '#2C3E50'
      },
      border: {
        color: '#E5E5EB',
        width: {
          value: 1,
          unit: 'px'
        }
      },
      media: {
        enabled: true,
        size: {
          value: 80,
          unit: 'px'
        },
        imageGap: {
          value: 4,
          unit: 'px'
        }
      },
      stars: {
        height: {
          value: 18,
          unit: 'px'
        }
      },
      text: {
        primaryColor: '#2C3E50',
        secondaryColor: '#676986',
        fontSizeSmall: {
          value: 12,
          unit: 'px'
        },
        fontSizeRegular: {
          value: 14,
          unit: 'px'
        }
      }
    }
  },
  reviewsTab: {
    enabled: true,
    position: 'top-left',
    positionSmall: 'top-left',
    backgroundColor: '#676986',
    textColor: '#FFFFFF'
  },
  mediaGrid: {
    gridStyleDesktop: {
      layout: 'default-desktop'
    },
    gridStyleMobile: {
      layout: 'default-mobile'
    },
    gapSize: {
      value: 10,
      unit: 'px'
    },
    infiniteScroll: false,
    showMoreArrow: {
      enabled: true,
      backgroundColor: '#f4f4f6',
      arrowColor: '#676986'
    },
    linkText: 'Read More'
  },
  mediaCarousel: {
    autoPlay: false,
    linkText: 'Read More',
    minimumImages: 1,
    slideSize: 'medium',
    arrowPosition: 'outside'
  },
  reviewsBadge: {
    colorScheme: 'dark',
    layout: 'large'
  },
  customCss: ''
};

var DefaultSettings = /*#__PURE__*/Object.freeze({
    __proto__: null,
    kDefaultStarBackgroundColor: kDefaultStarBackgroundColor,
    kDefaultStarForegroundColor: kDefaultStarForegroundColor,
    kDefaultStarBorderColor: kDefaultStarBorderColor,
    kDefaultStarInterspace: kDefaultStarInterspace,
    kDefaultStarShape: kDefaultStarShape,
    kBadgeDarkBackgroundColor: kBadgeDarkBackgroundColor,
    kBadgeLightBackgroundColor: kBadgeLightBackgroundColor,
    kBadgeLightBorderColor: kBadgeLightBorderColor,
    'default': defaultSettings
});

const sharedSettings = {
  subscriberId: undefined,
  analyticsSettings: undefined,
  features: undefined,
  isTestModeEnabled: false,
  productLabel: undefined,
  widgetSettings: defaultSettings
};
var SharedSettings = Vue.observable(sharedSettings);

var SharedSettings$1 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': SharedSettings
});

var OkendoUtils = {
  getPrettyNumber(number, letterAbbreviation = false) {
    if (typeof number !== 'undefined') {
      if (number.toString().includes(',') || number.toString().includes('.')) {
        // Number is already formatted (e.g. from metafield)
        return number.toString();
      }

      const parsedNumber = typeof number === 'string' ? parseInt(number, 10) : number;

      if (letterAbbreviation) {
        const formatNumber = (number, divisor, letter) => {
          return (number / divisor).toLocaleString(undefined, {
            maximumFractionDigits: number / divisor > 100 ? 0 : 1
          }) + letter;
        };

        if (parsedNumber > 1000000000) {
          return formatNumber(parsedNumber, 1000000000, 'B');
        } else if (parsedNumber > 1000000) {
          return formatNumber(parsedNumber, 1000000, 'M');
        } else if (parsedNumber > 1000) {
          return formatNumber(parsedNumber, 1000, 'k');
        } else {
          return parsedNumber.toString();
        }
      } else {
        return parsedNumber.toLocaleString();
      }
    }
  },

  getCombinedUnitMeasure(measure) {
    if (measure) {
      return `${measure.value}${measure.unit}`;
    }
  },

  getAverageRatingDisplayText(reviewAggregate) {
    return reviewAggregate.ratingAndReviewCount && reviewAggregate.ratingAndReviewValuesTotal ? (reviewAggregate.ratingAndReviewValuesTotal / reviewAggregate.ratingAndReviewCount).toFixed(1) : '0';
  },

  toPixels(measure) {
    switch (measure.unit) {
      case 'em':
        return Math.floor(measure.value * 14);
      // Replace with font size setting value when added

      case 'rem':
        return Math.floor(measure.value * parseFloat(getComputedStyle(document.documentElement).fontSize));

      case 'px':
      default:
        return Math.floor(measure.value);
    }
  },

  getWidgetSize(widgetElement) {
    var _a;

    const widgetWidth = (_a = widgetElement === null || widgetElement === void 0 ? void 0 : widgetElement.clientWidth) !== null && _a !== void 0 ? _a : 0;
    return widgetWidth > 960 ? 'large' : widgetWidth > 640 ? 'medium' : 'small';
  },

  sendWidgetRenderedEvent(widget, id) {
    document.dispatchEvent(new CustomEvent('oke-rendered', {
      detail: {
        widget,
        id
      }
    }));
  },

  convertMediaToMediaReviews(productReviewMedia) {
    return productReviewMedia.map(baseMedia => this.convertMediaToMediaReview(baseMedia));
  },

  convertMediaToMediaReview(productReviewMedia) {
    var _a, _b, _c, _d;

    return {
      id: productReviewMedia.streamId,
      type: productReviewMedia.type,
      dynamicImageKey: productReviewMedia.dynamicImageKey,
      fullSizeUrl: (_b = (_a = productReviewMedia.imageUrls) === null || _a === void 0 ? void 0 : _a.fullSizeUrl) !== null && _b !== void 0 ? _b : (_c = productReviewMedia.videoUrls) === null || _c === void 0 ? void 0 : _c.fullSizeUrl,
      videoPosterUrl: (_d = productReviewMedia.videoUrls) === null || _d === void 0 ? void 0 : _d.videoPosterUrl,
      source: 'okendo-media',
      dateCreated: productReviewMedia.dateCreated,
      parentId: productReviewMedia.reviewId,
      productId: productReviewMedia.productId
    };
  },

  convertReviewToMediaReview(review) {
    var _a, _b;

    if (!((_a = review === null || review === void 0 ? void 0 : review.media) === null || _a === void 0 ? void 0 : _a.length)) {
      return;
    }

    const baseMedia = review.media[0];
    return {
      id: baseMedia.streamId,
      type: baseMedia.type,
      dynamicImageKey: baseMedia.type === 'image' ? baseMedia.dynamicKey : undefined,
      fullSizeUrl: (_b = baseMedia.fullSizeUrl) !== null && _b !== void 0 ? _b : '',
      videoPosterUrl: baseMedia.type === 'video' ? baseMedia.videoPosterUrl : undefined,
      source: 'okendo-review',
      dateCreated: review.dateCreated,
      reviewer: review.reviewer,
      parentId: review.reviewId,
      body: review.body,
      title: review.title,
      rating: review.rating,
      helpfulCount: review.helpfulCount,
      unhelpfulCount: review.unhelpfulCount,
      isRecommended: review.isRecommended,
      productHandle: review.productHandle,
      productId: review.productId,
      productImageUrl: review.productImageUrl,
      productName: review.productName,
      productUrl: review.productUrl,
      variantId: review.variantId
    };
  },

  convertReviewsToMediaReviews(reviews) {
    var _a, _b, _c;

    const media = [];

    for (const review of reviews) {
      for (const baseMedia of (_a = review.media) !== null && _a !== void 0 ? _a : []) {
        media.push({
          id: baseMedia.streamId,
          type: baseMedia.type,
          dynamicImageKey: baseMedia.dynamicKey,
          fullSizeUrl: (_b = baseMedia.fullSizeUrl) !== null && _b !== void 0 ? _b : '',
          videoPosterUrl: (_c = baseMedia.videoPosterUrl) !== null && _c !== void 0 ? _c : '',
          source: 'okendo-review',
          dateCreated: review.dateCreated,
          reviewer: review.reviewer,
          parentId: review.reviewId,
          body: review.body,
          title: review.title,
          rating: review.rating,
          helpfulCount: review.helpfulCount,
          unhelpfulCount: review.unhelpfulCount,
          isRecommended: review.isRecommended,
          productHandle: review.productHandle,
          productId: review.productId,
          productImageUrl: review.productImageUrl,
          productName: review.productName,
          productUrl: review.productUrl,
          variantId: review.variantId
        });
      }
    }

    return media;
  },

  getWidgetMode(productId, groupId) {
    return productId ? 'product' : groupId ? 'group' : 'all';
  },

  getWidgetRenderMode() {
    if (window === null || window === void 0 ? void 0 : window.okeShowPreviewData) {
      return 'sample-data';
    } else if (SharedSettings.isTestModeEnabled) {
      return 'empty';
    }

    return 'normal';
  },

  merge(source, target) {
    for (const [key, sourceValue] of Object.entries(source)) {
      const targetValue = target[key];

      if (targetValue instanceof Object && !Array.isArray(targetValue) && sourceValue instanceof Object && !Array.isArray(sourceValue)) {
        this.merge(sourceValue, targetValue);
      } else {
        target[key] = sourceValue;
      }
    }
  },

  defaultsDeep(source, target) {
    for (const [key, sourceValue] of Object.entries(source)) {
      if (sourceValue === null || sourceValue === undefined) {
        continue;
      }

      const targetValue = target[key];

      if (targetValue instanceof Object && !Array.isArray(targetValue) && sourceValue instanceof Object && !Array.isArray(sourceValue)) {
        this.merge(sourceValue, targetValue);
      } else {
        target[key] = sourceValue;
      }
    }
  },

  debounce(func, wait) {
    let timer;
    return () => {
      if (timer) {
        clearTimeout(timer);
      }

      timer = window.setTimeout(() => {
        func.apply(this);
      }, wait);
    };
  },

  setDocumentOverflow(overflowClassOperation = 'add') {
    document.documentElement.classList[overflowClassOperation]('is-oke-modalOpen');
    document.body.classList[overflowClassOperation]('is-oke-modalOpen');
  },

  stringOrNullToBoolOrUndefined(val) {
    return val !== null ? val.toLowerCase() === 'true' : undefined;
  },

  /** Check header modules to find the maxiumum number of aggregate images needed */
  getHeaderImagesCountToLoad(headerBlocks) {
    const mediaGridModules = [];
    const mediaCarouselModules = [];
    const initialCarouselImages = 16;

    if (headerBlocks.length) {
      for (const block of headerBlocks) {
        mediaGridModules.push(...block.modules.filter(module => module.name === 'media-grid'));
        mediaCarouselModules.push(...block.modules.filter(module => module.name === 'media-carousel'));
      }
    }

    const maxGridImages = mediaGridModules.reduce((acc, curr) => Math.max(curr.columns * curr.rows, acc), 0);
    const maxCarouselImages = mediaCarouselModules.length ? initialCarouselImages : 0;
    return Math.max(maxGridImages, maxCarouselImages);
  }

};

var StringUtils = {
  addParagraphTags(text) {
    if (text.startsWith('<p>')) {
      return text;
    } else {
      let encodedParagraphs = '<p>';
      encodedParagraphs += text.replace(/(?:\r\n|\r|\n)+/g, '</p><p>');
      encodedParagraphs += '</p>';
      return encodedParagraphs;
    }
  },

  toTitleCase(string) {
    return string.replace(/\w\S*/g, text => text.charAt(0).toUpperCase() + text.substr(1).toLowerCase());
  },

  titleToSnakeCase(string) {
    // Keeps only alphanumeric chars, '_' and '-'. Then replaces '_', and '-' and whitespace with '_'.
    return string.replace(/[^a-zA-Z0-9_\- ]/g, '').replace(/[_\- ]+/g, '_').toLowerCase();
  },

  kebabToCamelCase(item) {
    // Doesn't deal with special characters and is expecting clean kebab case eg: camel-case
    if (!item) return '';
    const camelText = item.split('-');
    return camelText.map((text, index) => {
      return index ? this.capitalize(text) : text.toLowerCase();
    }).join('');
  },

  capitalize(text) {
    return text.charAt(0).toUpperCase() + text.slice(1);
  },

  toComaEscapedEncodedString(string) {
    return encodeURIComponent(string.replace(/,/g, '\\,'));
  }

};

const apiBaseUrl = appSettings.apiBaseUrl;
const dynamicTranscodedMediaBaseUrl = appSettings.dynamicTranscodedMediaBaseUrl;
const appBaseUrl = appSettings.appBaseUrl;
const recorderPlusBaseUrl = appSettings.recorderPlusBaseUrl;
const emptyReviewAggregate = {
  ratingAndReviewCount: 0,
  ratingAndReviewCountByLevel: {},
  ratingAndReviewValuesTotal: 0
};

const getLocaleQueryString = () => {
  const currentLocale = Vue.$localeStore.currentLocale;
  return currentLocale ? `&locale=${currentLocale.code}${currentLocale.variant ? `&variant=${currentLocale.variant}` : ''}` : '';
};

const aggregateErrorHandler = (error, emptyResponse) => {
  return typeof error === 'undefined' || error === 404 ? Promise.resolve(emptyResponse) // Product probably doesn't exist, swallow error and do nothing
  : Promise.reject(error);
};

const handleGetSampleDataOrEmpty = async (requestUrl, emptyResponse, errorHandler) => {
  const widgetRenderMode = OkendoUtils.getWidgetRenderMode();

  if (widgetRenderMode === 'empty') {
    return Promise.resolve(emptyResponse);
  } else {
    const getOptions = widgetRenderMode === 'sample-data' ? {
      headers: {
        'x-okendo-force-sample-data': 'true'
      }
    } : undefined;

    try {
      return http.get(requestUrl, getOptions);
    } catch (error) {
      if (errorHandler) {
        return errorHandler(error, emptyResponse);
      } else {
        throw error;
      }
    }
  }
};

var OkendoApi = {
  get subscriberId() {
    return SharedSettings.subscriberId;
  },

  get storeBaseUrl() {
    if (this.subscriberId) {
      return `${apiBaseUrl}/stores/${this.subscriberId}`;
    } else {
      console.warn('No subscriber Id set');
    }
  },

  filtersToQueryString(filters) {
    if (!(filters === null || filters === void 0 ? void 0 : filters.length)) {
      return '';
    }

    const filtersQueryString = filters === null || filters === void 0 ? void 0 : filters.map(filter => {
      const prefix = filter.target === 'shopper' ? 'shopperAttributes' : 'generalAttributes';
      const filterTitle = StringUtils.toComaEscapedEncodedString(filter.title);
      const filterOptions = filter.options.map(option => StringUtils.toComaEscapedEncodedString(option)).join(',');
      return `${prefix}=${filterTitle},${filterOptions}`;
    }).join('&');
    return `&${filtersQueryString}`;
  },

  ratingFiltersToQueryString(ratings) {
    return (ratings === null || ratings === void 0 ? void 0 : ratings.length) ? `&${ratings.map(rating => `ratings=${rating}`).join('&')}` : '';
  },

  freeTextSearchQueryString(text) {
    return text ? `&text=${encodeURIComponent(text.replace(/[^a-zA-Z0-9 ]/g, ''))}` : '';
  },

  apiBaseUrl() {
    return apiBaseUrl;
  },

  dynamicTranscodedMediaBaseUrl() {
    return dynamicTranscodedMediaBaseUrl;
  },

  writeReviewUrl(productId) {
    var _a;

    return ((_a = SharedSettings.features) === null || _a === void 0 ? void 0 : _a.recorderPlusEnabled) ? `${recorderPlusBaseUrl}/?subscriberId=${this.subscriberId}&productId=${productId}${getLocaleQueryString()}` : `${appBaseUrl}/stores/${this.subscriberId}/review?productId=${productId}${getLocaleQueryString()}`;
  },

  askQuestionUrl(productId) {
    var _a;

    return ((_a = SharedSettings.features) === null || _a === void 0 ? void 0 : _a.recorderQandaPlusEnabled) ? `${recorderPlusBaseUrl}/questions?subscriberId=${this.subscriberId}&productId=${productId}${getLocaleQueryString()}` : `${appBaseUrl}/stores/${this.subscriberId}/question?productId=${productId}`;
  },

  poweredByUrl() {
    return `https://okendo.io?utm_source=${this.subscriberId}&utm_medium=widget&utm_campaign=poweredby`;
  },

  getMore(nextUrl, limit) {
    const loadMoreUrl = limit ? nextUrl.replace(/limit=[0-9]*/i, `limit=${limit}`) : nextUrl;
    return http.get(`${apiBaseUrl}${loadMoreUrl}`);
  },

  postHelpfulVoteReview(reviewId, voteType) {
    return http.post(`${this.storeBaseUrl}/reviews/${reviewId}/vote`, {
      voteType
    });
  },

  getReview(reviewId) {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/reviews/${reviewId}`, undefined);
  },

  getReviewsProduct(productId, limit = 5, orderBy = 'date desc', filters, ratings, freeTextSearchQuery) {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/reviews?limit=${limit}&orderBy=${orderBy}${this.filtersToQueryString(filters)}${this.ratingFiltersToQueryString(ratings)}${this.freeTextSearchQueryString(freeTextSearchQuery)}`, {
      reviews: [],
      areReviewsGrouped: false
    });
  },

  getReviewsAll(limit = 5, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/reviews?limit=${limit}&orderBy=${orderBy}`, {
      reviews: []
    });
  },

  getReviewsGroup(groupId, limit = 5, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/collections/${groupId}/reviews?limit=${limit}&orderBy=${orderBy}`, {
      reviews: []
    });
  },

  getReviews(productId, groupId, limit = 5, orderBy = 'date desc', filters, ratings, freeTextSearchQuery) {
    const widgetMode = OkendoUtils.getWidgetMode(productId, groupId);

    switch (widgetMode) {
      case 'product':
        return this.getReviewsProduct(productId, limit, orderBy, filters, ratings, freeTextSearchQuery);

      case 'group':
        return this.getReviewsGroup(groupId, limit, orderBy);

      default:
        return this.getReviewsAll(limit, orderBy);
    }
  },

  getMultiSourceMedia(productId, groupId, limit = 5) {
    const url = new URL(`${this.storeBaseUrl}/multi_source_media`);

    if (productId) {
      url.searchParams.set('productId', productId);
    } else if (groupId) {
      url.searchParams.set('groupId', groupId);
    }

    url.searchParams.set('limit', limit.toString());
    return handleGetSampleDataOrEmpty(url.href, {
      media: []
    });
  },

  async getReviewAggregateProduct(productId) {
    const result = await handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/review_aggregate`, undefined, aggregateErrorHandler);
    return result !== null && result !== void 0 ? result : {
      reviewAggregate: emptyReviewAggregate
    };
  },

  async getReviewAggregateAll() {
    const result = await handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/review_aggregate`, undefined, aggregateErrorHandler);
    return result !== null && result !== void 0 ? result : {
      reviewAggregate: emptyReviewAggregate
    };
  },

  async getReviewAggregateGroup(groupId) {
    const result = await handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/collections/${groupId}/review_aggregate`, undefined, aggregateErrorHandler);
    return result !== null && result !== void 0 ? result : {
      reviewAggregate: emptyReviewAggregate
    };
  },

  getMediaProduct(productId, limit = 6, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/review_media?limit=${limit}&orderBy=${orderBy}`, {
      media: []
    });
  },

  getMediaAll(limit = 6, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/review_media?limit=${limit}&orderBy=${orderBy}`, {
      media: []
    });
  },

  getMediaGroup(groupdId, limit = 6, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/collections/${groupdId}/review_media?limit=${limit}&orderBy=${orderBy}`, {
      media: []
    });
  },

  getQuestionsProduct(productId, limit = 5, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/questions?limit=${limit}&orderBy=${orderBy}`, {
      questions: []
    });
  },

  getQuestionAggregateProduct(productId) {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/question_aggregate`, undefined);
  },

  getQuestionsAggregateCollection(collectionId) {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/collections/${collectionId}/question_aggregate`, undefined);
  },

  getQuestionsCollection(collectionId, limit = 5, orderBy = 'date desc') {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/collections/${collectionId}/questions?limit=${limit}&orderBy=${orderBy}`, {
      questions: []
    });
  },

  getFiltersProduct(productId) {
    return handleGetSampleDataOrEmpty(`${this.storeBaseUrl}/products/${productId}/attributes`, {
      productAttributes: []
    });
  },

  postHelpfulVoteQuestion(questionId, voteType) {
    return http.post(`${this.storeBaseUrl}/questions/${questionId}/vote`, {
      voteType
    });
  },

  postHelpfulVoteAnswer(questionId, answerId, voteType) {
    return http.post(`${this.storeBaseUrl}/questions/${questionId}/answers/${answerId}/vote`, {
      voteType
    });
  }

};

// Simplified version of https://github.com/Yuliang-Lee/vue2-smooth-scroll/blob/666587c5d662c43110e54dfd059cb22cf1e32b4f/src/index.js
// requestAnimationFrame to be called by the browser before every repaint
let requestAnimationFrame; // Get the top position of an element in the document

const getTop = (element, start) => {
  // return value of html.getBoundingClientRect().top ... IE : 0, other browsers : -pageYOffset
  if (element.nodeName === 'HTML') return -start;
  const elementTop = element.getBoundingClientRect().top;
  const scrollMarginTop = parseInt((window.getComputedStyle(element).scrollMarginTop || 0).toString(), 10);
  return elementTop + start - scrollMarginTop;
};
/**
 * ease in out function
 * @see https://gist.github.com/gre/1650294
**/


function easeInOutCubic(t) {
  return t < 0.5 ? 4 * t * t * t : (t - 1) * (2 * t - 2) * (2 * t - 2) + 1;
}

var ScrollUtil = {
  smoothScrollTo(scrollTo, offset = -48) {
    const duration = 500;

    if (!requestAnimationFrame) {
      requestAnimationFrame = window.requestAnimationFrame || function (fn) {
        window.setTimeout(fn, 16);
      };
    }

    const startPoint = window.pageYOffset; // Get the top position of an element in the document
    // return value of html.getBoundingClientRect().top ... IE : 0, other browsers : -pageYOffset

    let end = getTop(scrollTo, startPoint); // Ajusts offset from the end

    end += offset;
    const clock = Date.now();
    const easeFn = easeInOutCubic;

    const step = () => {
      // the time elapsed from the beginning of the scroll
      const elapsed = Date.now() - clock; // calculate the scroll position we should be in

      let position = end;

      if (elapsed < duration) {
        position = startPoint + (end - startPoint) * easeFn(elapsed / duration);
        requestAnimationFrame(step);
      }

      window.scrollTo(0, position);
    };

    step();
  },

  bindScrollEventForElements(sourceElements) {
    sourceElements.forEach(sourceElement => {
      const targetSelector = sourceElement.getAttribute('data-oke-scroll-target');

      if (!targetSelector) {
        return;
      }

      const targetElement = document.querySelector(targetSelector);

      if (targetElement) {
        sourceElement.addEventListener('click', () => this.smoothScrollTo(targetElement));
        sourceElement.style.cursor = 'pointer';
      }
    });
  }

};

var StarRatingUtils = {
  widgetSelector: '[data-oke-widget]',

  async areStarRatingsClickable(starRatingSettingOverride) {
    const clickTargetSelector = await this.getClickTargetSelector(starRatingSettingOverride);
    return !!clickTargetSelector && !!document.querySelector(clickTargetSelector);
  },

  async getClickTargetSelector(starRatingSettingOverride) {
    let starRatingSettings; // On initial load we use the widgetConfig from the header settings so we don't import our core bundle which includes Vue.

    if (starRatingSettingOverride) {
      starRatingSettings = starRatingSettingOverride;
    } else {
      const {
        default: SharedSettings
      } = await Promise.resolve().then(function () { return SharedSettings$1; });
      starRatingSettings = SharedSettings.widgetSettings.starRatings;
    }

    if (starRatingSettings.clickBehavior === 'none') {
      return;
    } else if (starRatingSettings.clickBehavior === 'scroll-to-id' && starRatingSettings.scrollTargetId && !!document.querySelector(`#${starRatingSettings.scrollTargetId}`)) {
      return `#${starRatingSettings.scrollTargetId}`;
    }

    return this.widgetSelector;
  },

  async scrollToElement(sourceElement) {
    var _a;

    const targetElementSelector = await this.getClickTargetSelector();

    if (sourceElement && targetElementSelector) {
      // Scroll to first child if exists or parent as a fallback
      let targetElement = document.querySelector(targetElementSelector);

      if (targetElement && targetElement.firstElementChild) {
        targetElement = targetElement.firstElementChild;
      }

      const scrollDisabled = sourceElement.dataset.okeScrollDisabled === 'true';

      if (targetElement && ((_a = sourceElement.firstElementChild) === null || _a === void 0 ? void 0 : _a.classList.contains('oke-is-clickable')) && !scrollDisabled) {
        ScrollUtil.smoothScrollTo(targetElement);
      }
    }
  }

};

let OkendoStarRating = class OkendoStarRating extends Vue {
  constructor() {
    super(...arguments);
    this.version = "0.59.7";
    this.averageRating = '0';
    this.isClickable = false;
    this.reviewCount = 0;
  }

  created() {
    var _a, _b;

    const renderMode = OkendoUtils.getWidgetRenderMode();
    this.widgetMode = OkendoUtils.getWidgetMode(this.productId, this.groupId);

    if (renderMode === 'normal' && this.initialData) {
      this.averageRating = (_a = this.initialData.averageRating) !== null && _a !== void 0 ? _a : this.averageRating;
      this.reviewCount = (_b = this.initialData.reviewCount) !== null && _b !== void 0 ? _b : this.reviewCount;
      this.sendWidgetRenderedEvent();
    } else {
      this.loadAggregateData();
    }
  }

  sendWidgetRenderedEvent() {
    this.$nextTick(() => {
      OkendoUtils.sendWidgetRenderedEvent('star-rating', this.widgetId);
    });
  }

  async mounted() {
    this.isClickable = await StarRatingUtils.areStarRatingsClickable();
  }

  get starRatingSettings() {
    return SharedSettings.widgetSettings.starRatings;
  }

  get textStyle() {
    return this.starRatingSettings.style.text;
  }

  get starHeight() {
    return OkendoUtils.toPixels(this.starRatingSettings.style.height);
  }

  get starInterspace() {
    var _a, _b;

    return (_b = (_a = this.starRatingSettings.style.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.interspace) !== null && _b !== void 0 ? _b : SharedSettings.widgetSettings.global.stars.interspace;
  }

  get prettyNumber() {
    return this.textStyle.content === 'average-rating' || this.textStyle.content === 'average-and-count' ? this.averageRating : OkendoUtils.getPrettyNumber(this.reviewCount);
  }

  get reviewTotal() {
    return this.textStyle.content === 'average-and-count' ? ` (${OkendoUtils.getPrettyNumber(this.reviewCount)} ${this.$tc('Review', this.reviewCount)})` : undefined;
  }

  get showReviewCountBrackets() {
    return this.textStyle.content !== 'average-and-count' && this.textStyle.brackets;
  }

  get labelText() {
    if (this.textStyle.style === 'number-and-text') {
      const label = this.textStyle.content === 'average-rating' || this.textStyle.content === 'average-and-count' ? this.$tc('Stars') : this.$tc('Review', this.reviewCount);
      return ` ${label}`;
    } else if (this.textStyle.content === 'average-and-count' && this.textStyle.style === 'number-out-of-5-stars') {
      return ` ${this.$tc('out of 5 Stars')}`;
    }
  }

  get showWhenEmpty() {
    return this.starRatingSettings.showWhenEmpty;
  }

  get metafieldJsonData() {
    const initialData = {
      averageRating: this.averageRating,
      reviewCount: this.reviewCount
    };
    return JSON.stringify(initialData);
  }

  async loadAggregateData() {
    if (this.widgetMode !== 'all' || this.starRatingDataAttributeSettings.isInAllReviewsMode) {
      const reviewAggregateResponse = await this.loadReviewAggregate();

      if (reviewAggregateResponse) {
        this.reviewCount = reviewAggregateResponse.reviewAggregate.ratingAndReviewCount;
        this.averageRating = OkendoUtils.getAverageRatingDisplayText(reviewAggregateResponse.reviewAggregate);
        this.sendWidgetRenderedEvent();
      }
    }
  }

  async loadReviewAggregate() {
    switch (this.widgetMode) {
      case 'product':
        return await OkendoApi.getReviewAggregateProduct(this.productId);

      case 'group':
        return await OkendoApi.getReviewAggregateGroup(this.groupId);

      case 'all':
        return await OkendoApi.getReviewAggregateAll();
    }
  }

  onClick() {
    this.$nextTick(() => {
      StarRatingUtils.scrollToElement(this.$el);
    });
  }

};

__decorate([Prop()], OkendoStarRating.prototype, "groupId", void 0);

__decorate([Prop()], OkendoStarRating.prototype, "productId", void 0);

__decorate([Prop()], OkendoStarRating.prototype, "starRatingDataAttributeSettings", void 0);

__decorate([Prop()], OkendoStarRating.prototype, "initialData", void 0);

__decorate([Prop()], OkendoStarRating.prototype, "widgetId", void 0);

OkendoStarRating = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], OkendoStarRating);
var script$13 = OkendoStarRating;

function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
    if (typeof shadowMode !== 'boolean') {
        createInjectorSSR = createInjector;
        createInjector = shadowMode;
        shadowMode = false;
    }
    // Vue.extend constructor export interop.
    const options = typeof script === 'function' ? script.options : script;
    // render functions
    if (template && template.render) {
        options.render = template.render;
        options.staticRenderFns = template.staticRenderFns;
        options._compiled = true;
        // functional template
        if (isFunctionalTemplate) {
            options.functional = true;
        }
    }
    // scopedId
    if (scopeId) {
        options._scopeId = scopeId;
    }
    let hook;
    if (moduleIdentifier) {
        // server build
        hook = function (context) {
            // 2.3 injection
            context =
                context || // cached call
                    (this.$vnode && this.$vnode.ssrContext) || // stateful
                    (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
            // 2.2 with runInNewContext: true
            if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                context = __VUE_SSR_CONTEXT__;
            }
            // inject component styles
            if (style) {
                style.call(this, createInjectorSSR(context));
            }
            // register component module identifier for async chunk inference
            if (context && context._registeredComponents) {
                context._registeredComponents.add(moduleIdentifier);
            }
        };
        // used by ssr in case component is cached and beforeCreate
        // never gets called
        options._ssrRegister = hook;
    }
    else if (style) {
        hook = shadowMode
            ? function (context) {
                style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
            }
            : function (context) {
                style.call(this, createInjector(context));
            };
    }
    if (hook) {
        if (options.functional) {
            // register for functional component in vue file
            const originalRender = options.render;
            options.render = function renderWithStyleInjection(h, context) {
                hook.call(context);
                return originalRender(h, context);
            };
        }
        else {
            // inject component registration as beforeCreate hook
            const existing = options.beforeCreate;
            options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
        }
    }
    return script;
}

/* script */
const __vue_script__$16 = script$13;
/* template */

var __vue_render__$16 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews oke-sr",
    attrs: {
      "data-oke-reviews-version": _vm.version,
      "data-oke-container": ""
    }
  }, [_vm.reviewCount > 0 || _vm.showWhenEmpty ? _c('div', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Star Rating Summary Click'
      },
      expression: "{ action: 'Star Rating Summary Click' }",
      arg: "click"
    }],
    class: {
      'oke-is-clickable': _vm.isClickable
    },
    attrs: {
      "tabIndex": _vm.isClickable ? 0 : undefined,
      "role": _vm.isClickable ? 'button' : undefined
    },
    on: {
      "click": function ($event) {
        _vm.isClickable ? _vm.onClick() : undefined;
      },
      "keydown": [function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) {
          return null;
        }

        _vm.isClickable ? _vm.onClick() : undefined;
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) {
          return null;
        }

        _vm.isClickable ? _vm.onClick() : undefined;
      }]
    }
  }, [_c('div', {
    staticClass: "oke-sr-rating"
  }, [_vm._v("\n            " + _vm._s(_vm.averageRating) + "\n        ")]), _vm._v(" "), _c('div', {
    staticClass: "oke-sr-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.averageRating,
      "height": _vm.starHeight,
      "interspace": _vm.starInterspace
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-sr-count",
    class: {
      'oke-sr-count--brackets': _vm.showReviewCountBrackets
    }
  }, [_c('span', {
    staticClass: "oke-sr-count-number"
  }, [_vm._v(_vm._s(_vm.prettyNumber))]), _vm._v(" "), _vm.labelText ? [_c('span', {
    staticClass: "oke-sr-label-text"
  }, [_vm._v(_vm._s(_vm.labelText))])] : _vm._e(), _vm._v(" "), _vm.reviewTotal ? [_c('span', {
    staticClass: "oke-sr-total-text"
  }, [_vm._v(_vm._s(_vm.reviewTotal))])] : _vm._e()], 2), _vm._v(" "), _vm.isClickable ? _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc('Click to scroll to reviews')))]) : _vm._e()]) : _vm._e(), _vm._v(" "), _vm.metafieldJsonData ? _c('script', {
    attrs: {
      "type": "application/json",
      "data-oke-metafield-data": ""
    }
  }, [_vm._v("\n        " + _vm._s(_vm.metafieldJsonData) + "\n    ")]) : _vm._e()]);
};

var __vue_staticRenderFns__$16 = [];
/* style */

const __vue_inject_styles__$16 = undefined;
/* scoped */

const __vue_scope_id__$16 = undefined;
/* module identifier */

const __vue_module_identifier__$16 = undefined;
/* functional template */

const __vue_is_functional_template__$16 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$16 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$16,
  staticRenderFns: __vue_staticRenderFns__$16
}, __vue_inject_styles__$16, __vue_script__$16, __vue_scope_id__$16, __vue_is_functional_template__$16, __vue_module_identifier__$16, false, undefined, undefined, undefined);

let WidgetBase = class WidgetBase extends Vue {
  constructor() {
    super(...arguments);
    this.version = "0.59.7";
    this.widgetWidth = 0;
    this.widgetSize = 'small';
  }

  mounted() {
    var _a;

    this.widgetParentContainerElement = (_a = this.widgetSnippetElement) !== null && _a !== void 0 ? _a : this.$el.parentElement;

    if (!this.widgetParentContainerElement) {
      return;
    } // Temporarily set parent widget container to 100% to let the browser have a width in flex containers.


    this.widgetParentContainerElement.style.width = '100%';

    if (this.isWidgetVisible()) {
      this.onWidgetMounted();
    } else {
      // Setup a resize observer to check for visiblity changes
      const visibilityResizeObserver = new ResizeObserver(() => {
        if (this.widgetParentContainerElement && this.isWidgetVisible()) {
          this.onWidgetMounted();
          visibilityResizeObserver.disconnect();
        }
      });
      visibilityResizeObserver.observe(this.widgetParentContainerElement);
    }
  }

  destroyed() {
    this.removeResizeListener();
    this.removeKeyboardHelper();
  }

  onWidgetMounted() {
    this.widgetWidth = this.widgetParentContainerElement.getBoundingClientRect().width;
    this.setWidgetSize(this.widgetWidth);
    this.addKeyboardHelper();
    this.addResizeListener();

    if (this.widgetParentContainerElement) {
      this.widgetParentContainerElement.style.width = '';

      if (this.widgetParentContainerElement.getAttribute('style') === '') {
        this.widgetParentContainerElement.removeAttribute('style');
      }
    }
  }

  isWidgetVisible() {
    if (!this.widgetParentContainerElement) {
      return false;
    }

    return !!(this.widgetParentContainerElement.offsetWidth || this.widgetParentContainerElement.offsetHeight || this.widgetParentContainerElement.getClientRects().length);
  }

  getWidgetSizes() {
    const widgetElement = this.$el.firstElementChild; // We only care about width so don't do anything unless the width has changed
    // This is useful because the ResizeObserver will fire when load more items is used

    if (widgetElement && this.widgetWidth !== widgetElement.clientWidth) {
      this.widgetWidth = widgetElement.clientWidth;
      this.setWidgetSize(this.widgetWidth);
    }
  }

  setWidgetSize(width) {
    this.widgetSize = width > 960 ? 'large' : width > 640 ? 'medium' : 'small';
  }

  addResizeListener() {
    this.getWidgetSizes();
    this.$nextTick(() => {
      this.resizeObserver = new ResizeObserver(() => {
        OkendoUtils.debounce(this.getWidgetSizes, 100)();

        if (!this.isWidgetVisible() && this.widgetParentContainerElement) {
          const visibilityResizeObserver = new ResizeObserver(() => {
            if (this.widgetParentContainerElement && this.isWidgetVisible()) {
              this.widgetWidth = this.widgetParentContainerElement.getBoundingClientRect().width;
              this.setWidgetSize(this.widgetWidth);
              visibilityResizeObserver.disconnect();
            }
          });
          visibilityResizeObserver.observe(this.widgetParentContainerElement);
        }
      });
      this.resizeObserver.observe(this.$el);
    });
  }

  removeResizeListener() {
    if (this.resizeObserver) {
      this.resizeObserver.disconnect();
    }
  }

  addKeyboardHelper() {
    const handleTabbing = event => {
      if (event.key === 'Tab') {
        document.body.classList.add('is-oke-keyboardUser');
        window.removeEventListener('keydown', handleTabbing);
      }
    };

    window.addEventListener('keydown', handleTabbing);
  }

  removeKeyboardHelper() {
    window.removeEventListener('keydown', this.addKeyboardHelper);
  }

};

__decorate([Prop()], WidgetBase.prototype, "widgetId", void 0);

__decorate([Prop()], WidgetBase.prototype, "initialData", void 0);

__decorate([Prop()], WidgetBase.prototype, "widgetSnippetElement", void 0);

WidgetBase = __decorate([Component], WidgetBase);
var WidgetBase$1 = WidgetBase;

let OkendoQuestionsWidget = class OkendoQuestionsWidget extends mixins(WidgetBase$1) {
  onQuestionsLoaded() {
    OkendoUtils.sendWidgetRenderedEvent('questions', this.widgetId);
  }

};

__decorate([Prop()], OkendoQuestionsWidget.prototype, "widgetId", void 0);

__decorate([Prop()], OkendoQuestionsWidget.prototype, "initialData", void 0);

__decorate([Prop()], OkendoQuestionsWidget.prototype, "productId", void 0);

__decorate([Prop()], OkendoQuestionsWidget.prototype, "groupId", void 0);

__decorate([Prop()], OkendoQuestionsWidget.prototype, "askQuestionProductId", void 0);

OkendoQuestionsWidget = __decorate([Component({
  components: {
    Questions: async () => (await Promise.resolve().then(function () { return Questions; })).default
  }
})], OkendoQuestionsWidget);
var script$12 = OkendoQuestionsWidget;

/* script */
const __vue_script__$15 = script$12;
/* template */

var __vue_render__$15 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "questionsWidget",
    staticClass: "okeReviews",
    class: {
      'oke-is-small': _vm.widgetSize === 'small',
      'oke-is-medium': _vm.widgetSize === 'medium',
      'oke-is-large': _vm.widgetSize === 'large'
    },
    attrs: {
      "data-oke-reviews-version": _vm.version,
      "data-oke-container": ""
    }
  }, [_c('div', {
    staticClass: "oke-qw"
  }, [_c('questions', {
    attrs: {
      "initialData": _vm.initialData,
      "productId": _vm.productId,
      "groupId": _vm.groupId,
      "askQuestionProductId": _vm.askQuestionProductId
    },
    on: {
      "load": function ($event) {
        return _vm.onQuestionsLoaded();
      }
    }
  })], 1)]);
};

var __vue_staticRenderFns__$15 = [];
/* style */

const __vue_inject_styles__$15 = undefined;
/* scoped */

const __vue_scope_id__$15 = undefined;
/* module identifier */

const __vue_module_identifier__$15 = undefined;
/* functional template */

const __vue_is_functional_template__$15 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$15 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$15,
  staticRenderFns: __vue_staticRenderFns__$15
}, __vue_inject_styles__$15, __vue_script__$15, __vue_scope_id__$15, __vue_is_functional_template__$15, __vue_module_identifier__$15, false, undefined, undefined, undefined);

var AnalyticsUtils = {
  bindGAEventToElement(element, eventType, action, label, eventValue, eventParameters) {
    if (eventType === 'click') {
      element.addEventListener('click', event => {
        event.stopPropagation();
        this.sendGAEvent(action, label, eventValue, eventParameters);
      }, {
        capture: false,
        passive: true
      });
    } else if (eventType === 'change') {
      element.addEventListener('change', event => {
        const value = event.target.value;
        this.sendGAEvent(`${action}${value ? ` - ${value}` : ''}`, label, eventValue, eventParameters);
      }, {
        capture: false,
        passive: true
      });
    }
  },

  sendGAEvent(eventName, eventLabel, eventValue, eventParameters = {}) {
    var _a;

    eventLabel = eventLabel !== null && eventLabel !== void 0 ? eventLabel : SharedSettings.productLabel;
    const requiredParameters = {
      event_value: eventValue,
      product_label: SharedSettings.productLabel
    };

    if (eventParameters) {
      OkendoUtils.merge(eventParameters, requiredParameters);
    }

    switch ((_a = SharedSettings.analyticsSettings) === null || _a === void 0 ? void 0 : _a.provider) {
      case 'ua':
        this.sendUAEvent(eventName, eventLabel, eventValue);
        break;

      case 'gtm':
        this.sendGTMEvent(eventName, eventLabel, requiredParameters);
        break;

      case 'gtag':
        this.sendGTagEvent(eventName, eventLabel, requiredParameters);
        break;
    }
  },

  sendUAEvent(action, label, value) {
    const gaObject = window.ga;

    if (gaObject) {
      gaObject('send', 'event', 'Okendo', StringUtils.toTitleCase(action), label, value);
    }
  },

  sendGTMEvent(eventName, eventLabel, eventParameters) {
    const dataLayer = window.dataLayer;

    if (dataLayer && dataLayer.find(x => x.event === 'gtm.js')) {
      this.resetDataLayer();
      dataLayer.push({
        event: `okendo_${StringUtils.titleToSnakeCase(eventName)}`,
        event_category: 'Okendo',
        event_label: eventLabel,
        ...eventParameters
      });
    }
  },

  sendGTagEvent(eventName, eventLabel, eventParameters) {
    const gtag = window.gtag;

    if (window.dataLayer && gtag) {
      gtag('event', `okendo_${StringUtils.titleToSnakeCase(eventName)}`, {
        event_category: 'Okendo',
        event_label: eventLabel,
        ...eventParameters
      });
    }
  },

  resetDataLayer() {
    if (window.dataLayer) {
      window.dataLayer.push(function () {
        this.reset();
      });
    }
  }

};

var translationsCommon = {};

var localeUtils = {};

(function (exports) {
	Object.defineProperty(exports, "__esModule", { value: true });
	exports.localesMatch = exports.isValidLocaleCodeOrAlias = exports.isValidLocaleCode = exports.getLocaleTranslationFilename = exports.getSubscriberLocaleTranslationFilename = exports.getSubscriberLocaleWithFallback = exports.getLocaleWithFallback = exports.getAllLocales = exports.getLocale = exports.localeAliases = exports.allLocales = exports.english = void 0;
	exports.english = { code: 'en' };
	exports.allLocales = {
	    da: 'Danish',
	    de: {
	        defaultVariant: 'formal',
	        variants: {
	            formal: { name: 'German (formal)' },
	            informal: { name: 'German (informal)' }
	        }
	    },
	    el: 'Greek',
	    en: 'English',
	    es: 'Spanish',
	    fr: 'French',
	    id: 'Indonesian',
	    it: 'Italian',
	    ja: 'Japanese',
	    ko: 'Korean',
	    nl: 'Dutch',
	    no: 'Norwegian',
	    pl: 'Polish',
	    pt: 'Portuguese',
	    ru: 'Russian',
	    sv: 'Swedish',
	    th: 'Thai',
	    vi: 'Vietnamese',
	    'zh-TW': 'Chinese (Traditional)'
	};
	exports.localeAliases = {
	    nb: 'no'
	};
	function getLocale(localeCode, variant) {
	    if (localeCode === undefined) {
	        return;
	    }
	    const localeCodeOrAlias = isValidLocaleCode(localeCode) ? localeCode : exports.localeAliases[localeCode];
	    const locale = exports.allLocales[localeCodeOrAlias];
	    if (!locale) {
	        return;
	    }
	    if (typeof locale === 'string') {
	        // If the store has requested a variant and we don't know about it, still return the default locale.
	        return { code: localeCodeOrAlias };
	    }
	    else if ('variants' in locale) {
	        if (variant) {
	            const matchingVariant = locale.variants[variant];
	            if (matchingVariant) {
	                return { code: localeCodeOrAlias, variant };
	            }
	        }
	        // If there is no matching variant, still return the default.
	        return { code: localeCodeOrAlias, variant: locale.defaultVariant };
	    }
	}
	exports.getLocale = getLocale;
	function getAllLocales() {
	    const result = [];
	    for (const [localeCode, info] of Object.entries(exports.allLocales)) {
	        if (typeof info === 'string') {
	            result.push({ name: info, code: localeCode });
	        }
	        else if ('variants' in info) {
	            for (const [variantCode, { name: variantName }] of Object.entries(info.variants)) {
	                result.push({ name: variantName, code: localeCode, variant: variantCode });
	            }
	        }
	    }
	    return result.sort((a, b) => a.name.localeCompare(b.name));
	}
	exports.getAllLocales = getAllLocales;
	function getLocaleWithFallback(localeAndVariant, localeCode, fallback = exports.english) {
	    var _a, _b;
	    return (_b = (_a = getLocale(localeAndVariant === null || localeAndVariant === void 0 ? void 0 : localeAndVariant.code, localeAndVariant === null || localeAndVariant === void 0 ? void 0 : localeAndVariant.variant)) !== null && _a !== void 0 ? _a : getLocale(localeCode)) !== null && _b !== void 0 ? _b : fallback;
	}
	exports.getLocaleWithFallback = getLocaleWithFallback;
	/**
	 *  Gets the subscriber locale in the following order:
	 *  1. localeAndVariant
	 *  2. locale - using deprecated locale code only to form a Subscriber.Locale object
	 *  3. fallback - Defaults to English
	 */
	function getSubscriberLocaleWithFallback(subscriber, fallback = exports.english) {
	    return getLocaleWithFallback(subscriber.localeAndVariant, subscriber.locale, fallback);
	}
	exports.getSubscriberLocaleWithFallback = getSubscriberLocaleWithFallback;
	function getSubscriberLocaleTranslationFilename(subscriber) {
	    const subscriberLocale = getSubscriberLocaleWithFallback(subscriber);
	    return formatFilename(subscriberLocale);
	}
	exports.getSubscriberLocaleTranslationFilename = getSubscriberLocaleTranslationFilename;
	function getLocaleTranslationFilename(localeCode, variant) {
	    const locale = getLocale(localeCode, variant);
	    if (!locale) {
	        return;
	    }
	    return formatFilename(locale);
	}
	exports.getLocaleTranslationFilename = getLocaleTranslationFilename;
	function isValidLocaleCode(localeCode) {
	    return !!localeCode && Object.entries(exports.allLocales).some(([localeCodeKey]) => localeCodeKey.toLowerCase() === localeCode.toLowerCase());
	}
	exports.isValidLocaleCode = isValidLocaleCode;
	function isValidLocaleCodeOrAlias(localeCode) {
	    return !!localeCode && (isValidLocaleCode(localeCode) || localeCode.toLowerCase() in exports.localeAliases);
	}
	exports.isValidLocaleCodeOrAlias = isValidLocaleCodeOrAlias;
	function localesMatch(locale, localeToCompare) {
	    var _a, _b;
	    return (locale === null || locale === void 0 ? void 0 : locale.code.toLowerCase()) === (localeToCompare === null || localeToCompare === void 0 ? void 0 : localeToCompare.code.toLowerCase()) && ((_a = locale === null || locale === void 0 ? void 0 : locale.variant) === null || _a === void 0 ? void 0 : _a.toLowerCase()) === ((_b = localeToCompare === null || localeToCompare === void 0 ? void 0 : localeToCompare.variant) === null || _b === void 0 ? void 0 : _b.toLowerCase());
	}
	exports.localesMatch = localesMatch;
	function formatFilename(locale) {
	    return `${locale.code.toLowerCase()}${(locale.variant ? `-${locale.variant.toLowerCase()}` : '')}`;
	}
} (localeUtils));

(function (exports) {
	Object.defineProperty(exports, "__esModule", { value: true });
	exports.localesMatch = exports.isValidLocaleCodeOrAlias = exports.isValidLocaleCode = exports.getSubscriberLocaleTranslationFilename = exports.getSubscriberLocaleWithFallback = exports.getLocaleWithFallback = exports.getLocaleTranslationFilename = exports.getLocale = exports.english = exports.getAllLocales = void 0;
	var localeUtils_1 = localeUtils;
	Object.defineProperty(exports, "getAllLocales", { enumerable: true, get: function () { return localeUtils_1.getAllLocales; } });
	Object.defineProperty(exports, "english", { enumerable: true, get: function () { return localeUtils_1.english; } });
	Object.defineProperty(exports, "getLocale", { enumerable: true, get: function () { return localeUtils_1.getLocale; } });
	Object.defineProperty(exports, "getLocaleTranslationFilename", { enumerable: true, get: function () { return localeUtils_1.getLocaleTranslationFilename; } });
	Object.defineProperty(exports, "getLocaleWithFallback", { enumerable: true, get: function () { return localeUtils_1.getLocaleWithFallback; } });
	Object.defineProperty(exports, "getSubscriberLocaleWithFallback", { enumerable: true, get: function () { return localeUtils_1.getSubscriberLocaleWithFallback; } });
	Object.defineProperty(exports, "getSubscriberLocaleTranslationFilename", { enumerable: true, get: function () { return localeUtils_1.getSubscriberLocaleTranslationFilename; } });
	Object.defineProperty(exports, "isValidLocaleCode", { enumerable: true, get: function () { return localeUtils_1.isValidLocaleCode; } });
	Object.defineProperty(exports, "isValidLocaleCodeOrAlias", { enumerable: true, get: function () { return localeUtils_1.isValidLocaleCodeOrAlias; } });
	Object.defineProperty(exports, "localesMatch", { enumerable: true, get: function () { return localeUtils_1.localesMatch; } });
} (translationsCommon));

var LocaleState = {
  install: Vue => {
    const localeStore = Vue.observable({
      currentLocale: translationsCommon.english
    });
    const actions = {
      setLocale(locale) {
        if (locale) {
          localeStore.currentLocale = locale;
        }
      }

    };
    Vue.$localeStore = localeStore;
    Vue.$localeStoreActions = actions;
  }
};

const en = require('./locales/en').default;

Vue.use(LocaleState);
Vue.use(VueI18n);
const i18n = new VueI18n({
  locale: 'en',
  fallbackLocale: 'en',
  messages: {
    en
  }
});

const loadedLocaleFileNames = ['en'];
async function setLocale(localeCode, variant, _rootI18n) {
  let rootI18n;

  if (_rootI18n) {
    rootI18n = _rootI18n;
  }

  const _i18n = rootI18n !== null && rootI18n !== void 0 ? rootI18n : i18n;

  const locale = translationsCommon.getLocale(localeCode, variant);

  if (!locale) {
    console.warn(`Okendo Reviews & UGC - Locale not present for requested locale code.`);
  }

  const currentLocale = Vue.$localeStore.currentLocale;
  const localeVariantChanged = (locale === null || locale === void 0 ? void 0 : locale.variant) !== (currentLocale === null || currentLocale === void 0 ? void 0 : currentLocale.variant);

  if ((locale === null || locale === void 0 ? void 0 : locale.code) && ((locale === null || locale === void 0 ? void 0 : locale.code) !== _i18n.locale || localeVariantChanged)) {
    const localeFileName = translationsCommon.getLocaleTranslationFilename(locale === null || locale === void 0 ? void 0 : locale.code, locale === null || locale === void 0 ? void 0 : locale.variant); // If the variant has changed we need to manually update the localeMessage on i18n because setLocaleMessage uses the locale code without variant.

    if (!rootI18n && localeFileName && (!loadedLocaleFileNames.includes(localeFileName) || localeVariantChanged)) {
      await loadLocaleMessagesAsync(localeFileName, locale === null || locale === void 0 ? void 0 : locale.code, _i18n);
    }

    if (rootI18n && (locale === null || locale === void 0 ? void 0 : locale.code) === 'en') {
      // default widget library locale to `en`
      _i18n.setLocaleMessage(locale.code, require('./locales/en.js').default);
    }

    _i18n.locale = locale === null || locale === void 0 ? void 0 : locale.code;
    Vue.$localeStoreActions.setLocale(locale);
    return locale;
  }
}

async function loadLocaleMessagesAsync(localeTranslationFileCode, localeCode, i18nInstance) {
  try {
    const messages = await import(
    /* webpackChunkName: "locale-[request]" */
    `./locales/${localeTranslationFileCode}.js`);
    i18nInstance.setLocaleMessage(localeCode, messages.default);

    if (!loadedLocaleFileNames.includes(localeTranslationFileCode)) {
      loadedLocaleFileNames.push(localeTranslationFileCode);
    }
  } catch (er) {
    console.error(er);
  }
}

const modalContainerId = 'oke-modalContainer';
const modalContainerInnerId = 'oke-modalContainer-inner';
const modalHistory = [];
let modalInstance;
let modalContainer;
let restoringModalFromHistory = false;
var ModalService = {
  openMediaModal(propsData) {
    const component = async () => (await Promise.resolve().then(function () { return MediaModal; })).default;

    this.openModal(component, 'mediaModal', propsData);
  },

  openAllReviewsModal(propsData) {
    const component = async () => (await Promise.resolve().then(function () { return AllReviewsModal; })).default;

    this.openModal(component, 'allReviewsModal', propsData);
  },

  openModal(component, historyKey, propsData) {
    if (!restoringModalFromHistory) {
      modalHistory.push({
        key: historyKey,
        propsData
      });
    }

    this.closeCurrentModalInstance();

    if (!document.getElementById(modalContainerId)) {
      // Add div to html body to hold modal
      modalContainer = document.createElement('div');
      modalContainer.id = modalContainerId;
      const modalContainerInner = document.createElement('div');
      modalContainerInner.id = modalContainerInnerId;
      modalContainer.appendChild(modalContainerInner);
      document.body.appendChild(modalContainer);
      modalInstance = new Vue({
        el: `#${modalContainerInnerId}`,
        i18n,
        render: h => h(component, {
          props: { ...propsData
          }
        }),
        created: () => {
          var _a, _b;

          setLocale((_a = Vue.$localeStore.currentLocale) === null || _a === void 0 ? void 0 : _a.code, (_b = Vue.$localeStore.currentLocale) === null || _b === void 0 ? void 0 : _b.variant);
        }
      });
    }

    restoringModalFromHistory = false;
  },

  closeModal() {
    modalHistory.pop();
    this.closeCurrentModalInstance();

    if (modalHistory.length) {
      this.restoreLastModalInHistory();
    }
  },

  closeCurrentModalInstance() {
    modalInstance === null || modalInstance === void 0 ? void 0 : modalInstance.$destroy();
    modalContainer === null || modalContainer === void 0 ? void 0 : modalContainer.remove();
  },

  restoreLastModalInHistory() {
    const lastModalInHistory = modalHistory[modalHistory.length - 1];
    restoringModalFromHistory = true;

    switch (lastModalInHistory.key) {
      case 'mediaModal':
        this.openMediaModal(lastModalInHistory.propsData);
        break;

      case 'allReviewsModal':
        this.openAllReviewsModal();
        break;
    }
  },

  bindOpenReviewsModalEventForElements(sourceElements) {
    sourceElements.forEach(sourceElement => {
      var _a, _b;

      if (sourceElement) {
        const groupId = (_a = sourceElement.getAttribute('data-oke-reviews-group-id')) !== null && _a !== void 0 ? _a : undefined;
        const productId = (_b = sourceElement.getAttribute('data-oke-reviews-product-id')) !== null && _b !== void 0 ? _b : undefined;

        const eventHandler = () => this.openAllReviewsModal({
          groupId,
          productId
        });

        sourceElement.addEventListener('click', eventHandler);
        sourceElement.addEventListener('keydown', event => {
          if (event.key === 'Space' || event.key === 'Enter') {
            event.preventDefault();
            eventHandler();
          }
        });
        sourceElement.style.cursor = 'pointer';
      }
    });
  }

};

let OkendoReviewCarousel = class OkendoReviewCarousel extends mixins(WidgetBase$1) {
  constructor() {
    super(...arguments);
    this.reviews = [];
    this.slidesPerPage = 3;
    this.currentPage = 0;
    this.carouselOptions = {
      itemsToSlide: this.scrollBehaviour,
      initialSlide: 0,
      infiniteScroll: true,
      fluidSlide: true,
      wheelControl: false,
      playSpeed: 2500
    };
  }

  async created() {
    this.insertOrUpdateCSSVariables();

    if (this.initialData) {
      this.reviews = this.initialData.reviews;
      OkendoUtils.sendWidgetRenderedEvent('homepage-carousel', this.widgetId);
    } else {
      await this.loadReviews();
      OkendoUtils.sendWidgetRenderedEvent('homepage-carousel', this.widgetId);
    }
  }

  mounted() {
    this.setSlidesPerPage(this.widgetSize);
  }

  onPropertyChanged(newSize) {
    this.setSlidesPerPage(newSize);
  }

  onWidgetWidthChange() {
    var _a;

    (_a = this.getCarouselByRef()) === null || _a === void 0 ? void 0 : _a.update();
  }

  get isAutoPlayEnabled() {
    if (this.carouselDataAttributeSettings.autoplay) {
      return this.carouselDataAttributeSettings.autoplay;
    }

    if (this.reviewsSettings.autoPlay) {
      return this.reviewsSettings.autoPlay;
    }

    return false;
  }

  get initialAggregateData() {
    var _a;

    return (_a = this.initialData) === null || _a === void 0 ? void 0 : _a.aggregateRating;
  }

  get reviewsSettings() {
    var _a, _b;

    const subscriberSettings = { ...SharedSettings.widgetSettings.homepageCarousel,
      style: { ...SharedSettings.widgetSettings.homepageCarousel.style,
        layout: { ...SharedSettings.widgetSettings.homepageCarousel.style.layout
        }
      }
    };
    const forcedLayoutSettings = (_b = (_a = this.carouselDataAttributeSettings) === null || _a === void 0 ? void 0 : _a.style) === null || _b === void 0 ? void 0 : _b.layout;

    if (forcedLayoutSettings) {
      OkendoUtils.defaultsDeep(forcedLayoutSettings, subscriberSettings.style.layout);
    }

    return subscriberSettings;
  }

  get scrollBehaviour() {
    return this.reviewsSettings.scrollBehaviour === 'page' ? this.slidesPerPage : 1;
  }

  get arrowSettings() {
    return this.reviewsSettings.style.arrows;
  }

  get individualReviewSettings() {
    var _a, _b;

    const styleSettings = this.reviewsSettings.style;
    return {
      media: styleSettings.media,
      layout: styleSettings.layout,
      showAvatars: styleSettings.avatar.enabled,
      showDates: styleSettings.showDates,
      showMedia: styleSettings.media.enabled,
      stars: {
        height: styleSettings.stars.height,
        interspace: (_b = (_a = styleSettings.stars.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.interspace) !== null && _b !== void 0 ? _b : SharedSettings.widgetSettings.global.stars.interspace
      },
      truncationSettings: this.reviewsSettings.truncation
    };
  }

  get translatedInstructions() {
    return this.$tc('Press left and right arrows to navigate.');
  }

  get homepageCarouselComponent() {
    switch (this.reviewsSettings.style.layout.name) {
      case 'featured':
        return 'ReviewCardFeaturedMedia';

      case 'testimonial':
        return 'TestimonialCard';

      case 'minimal-centered':
        return 'ReviewCardMinimalCentered';

      case 'default':
      default:
        return 'ReviewCard';
    }
  }

  get badgeDataAttributeSettings() {
    return {
      layout: 'minimal',
      url: this.carouselDataAttributeSettings.headerUrl,
      stars: this.reviewsSettings.style.stars.globalOverrideSettings ? this.reviewsSettings.style.stars : { ...this.reviewsSettings.style.stars,
        globalOverrideSettings: SharedSettings.widgetSettings.global.stars
      }
    };
  }

  getCarouselByRef() {
    return this.$refs.okeReviewsCarousel;
  }

  onSliderSlide(event) {
    var _a;

    if (this.reviews.length <= this.slidesPerPage) {
      (_a = this.getCarouselByRef()) === null || _a === void 0 ? void 0 : _a.slideTo(0);
    }

    if (event.currentSlide !== this.currentPage) {
      AnalyticsUtils.sendGAEvent('Homepage Carousel Scroll');
      this.currentPage = event.currentSlide;
    }
  }

  onReviewCardMediaClick(initialIndex, initialMedia) {
    var _a;

    if (!((_a = this.getCarouselByRef()) === null || _a === void 0 ? void 0 : _a.isSliding)) {
      ModalService.openMediaModal({
        initialMedia,
        mediaContext: 'review',
        initialIndex,
        widgetMode: this.widgetMode
      });
    }
  }

  nextSlide() {
    var _a;

    (_a = this.getCarouselByRef()) === null || _a === void 0 ? void 0 : _a.slideNext();
  }

  prevSlide() {
    var _a;

    (_a = this.getCarouselByRef()) === null || _a === void 0 ? void 0 : _a.slidePrev();
  }

  getTabIndexForSlide(index) {
    return index >= this.currentPage && index < this.currentPage + this.slidesPerPage ? 0 : -1;
  }

  async loadReviews() {
    const limit = this.reviewsSettings.totalSlides;
    const sortOrder = this.reviewsSettings.defaultSort;
    const {
      reviews
    } = await OkendoApi.getReviews(this.productId, this.groupId, limit, sortOrder);
    this.reviews = reviews;
  }

  insertOrUpdateCSSVariables() {
    const carouselStyles = this.reviewsSettings.style;
    const carouselVars = `.oke-reviewCarousel {
            --oke-spaceAbove: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.spaceAbove) || 0};
            --oke-spaceBelow: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.spaceBelow) || 0};
            --oke-highlightColor: ${carouselStyles.highlightColor};
            --oke-productImageSize: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.productImageSize)};

            --oke-border-color: ${carouselStyles.border.color};
            --oke-border-width: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.border.width)};

            --oke-text-primaryColor: ${carouselStyles.text.primaryColor};
            --oke-text-secondaryColor: ${carouselStyles.text.secondaryColor};
            --oke-text-small: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.text.fontSizeSmall)};
            --oke-text-regular: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.text.fontSizeRegular)};

            --oke-avatar-size: ${OkendoUtils.getCombinedUnitMeasure(carouselStyles.avatar.size)};
            --oke-avatar-backgroundColor: ${carouselStyles.avatar.backgroundColor};
            --oke-avatar-placeholderTextColor: ${carouselStyles.avatar.placeholderTextColor};
        }`;
    HtmlUtils.addOrUpdateTargetBlock('style', 'oke-carousel-vars', carouselVars);
  }

  setSlidesPerPage(size) {
    this.slidesPerPage = size === 'small' ? 1 : this.reviewsSettings.slidesPerPage[size];
    const homepageCarousel = this.getCarouselByRef();

    if (homepageCarousel) {
      homepageCarousel.displayConfig.itemsToShow = this.slidesPerPage;
    }
  }

};

__decorate([Prop()], OkendoReviewCarousel.prototype, "productId", void 0);

__decorate([Prop()], OkendoReviewCarousel.prototype, "groupId", void 0);

__decorate([Prop({
  default: 'all'
})], OkendoReviewCarousel.prototype, "widgetMode", void 0);

__decorate([Prop()], OkendoReviewCarousel.prototype, "initialData", void 0);

__decorate([Prop()], OkendoReviewCarousel.prototype, "carouselDataAttributeSettings", void 0);

__decorate([Watch('widgetSize')], OkendoReviewCarousel.prototype, "onPropertyChanged", null);

__decorate([Watch('widgetWidth')], OkendoReviewCarousel.prototype, "onWidgetWidthChange", null);

OkendoReviewCarousel = __decorate([Component({
  components: {
    Hooper: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Hooper,
    Slide: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Slide,
    OkendoReviewsBadge: async () => (await Promise.resolve().then(function () { return OkendoReviewsBadge; })).default,
    PoweredBy: async () => (await Promise.resolve().then(function () { return PoweredBy; })).default,
    PrevNextButton: async () => (await Promise.resolve().then(function () { return PrevNextButton; })).default,
    ReviewCard: async () => (await Promise.resolve().then(function () { return ReviewCard$2; })).default,
    ReviewCardFeaturedMedia: async () => (await Promise.resolve().then(function () { return ReviewCardFeaturedMedia; })).default,
    TestimonialCard: async () => (await Promise.resolve().then(function () { return TestimonialCard; })).default,
    ReviewCardMinimalCentered: async () => (await Promise.resolve().then(function () { return ReviewCardMinimalCentered; })).default
  }
})], OkendoReviewCarousel);
var script$11 = OkendoReviewCarousel;

/* script */
const __vue_script__$14 = script$11;
/* template */

var __vue_render__$14 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    directives: [{
      name: "onScreenTracking",
      rawName: "v-onScreenTracking",
      value: {
        widgetType: 'Homepage Carousel',
        widgetId: _vm.widgetId,
        threshold: 0.8
      },
      expression: "{ widgetType: 'Homepage Carousel', widgetId, threshold: 0.8 }"
    }],
    staticClass: "okeReviews",
    attrs: {
      "data-oke-reviews-version": _vm.version,
      "data-oke-container": ""
    }
  }, [_c('div', {
    ref: "okendoCarousel",
    staticClass: "oke-reviewCarousel",
    class: {
      'oke-is-small': _vm.widgetSize === 'small',
      'oke-is-medium': _vm.widgetSize === 'medium',
      'oke-is-large': _vm.widgetSize === 'large'
    },
    attrs: {
      "role": "region",
      "aria-label": _vm.$t('Review Carousel')
    }
  }, [!_vm.carouselDataAttributeSettings.hideHeader ? [_c('div', {
    staticClass: "oke-reviewCarousel-header"
  }, [_c('h2', {
    staticClass: "oke-reviewCarousel-header-title"
  }, [_vm._v(_vm._s(_vm.carouselDataAttributeSettings.headerText))]), _vm._v(" "), _c('okendo-reviews-badge', {
    attrs: {
      "badgeDataAttributeSettings": _vm.badgeDataAttributeSettings,
      "groupId": _vm.groupId,
      "initialData": _vm.initialAggregateData,
      "productId": _vm.productId
    }
  })], 1)] : _vm._e(), _vm._v(" "), _vm.reviews.length ? [_c('div', {
    staticClass: "oke-reviewCarousel-slider"
  }, [_vm.arrowSettings.enabled && _vm.reviews.length > _vm.slidesPerPage ? _c('prev-next-button', {
    attrs: {
      "isDisabled": _vm.currentPage === 0 && !_vm.carouselOptions.infiniteScroll || _vm.reviews.length <= _vm.slidesPerPage,
      "arrowSize": _vm.arrowSettings.size,
      "arrowColor": _vm.arrowSettings.color,
      "arrowDirection": "left",
      "buttonClass": "oke-reviewCarousel-prev"
    },
    on: {
      "click": _vm.prevSlide
    }
  }) : _vm._e(), _vm._v(" "), _c('hooper', {
    ref: "okeReviewsCarousel",
    staticClass: "oke-reviewCarousel-reviews",
    attrs: {
      "autoPlay": _vm.isAutoPlayEnabled,
      "settings": _vm.carouselOptions,
      "instructionsText": _vm.translatedInstructions,
      "itemsToShow": _vm.slidesPerPage,
      "role": _vm.$t('group')
    },
    on: {
      "slide": _vm.onSliderSlide
    }
  }, _vm._l(_vm.reviews, function (review, index) {
    return _c('slide', {
      key: review.reviewId,
      ref: "reviewCards",
      refInFor: true,
      staticClass: "oke-reviewCarousel-reviews-review",
      class: {
        'oke-reviewCarousel-reviews-review--testimonial': _vm.individualReviewSettings.layout.name === 'testimonial'
      },
      style: {
        width: 100 / _vm.slidesPerPage + '%'
      },
      attrs: {
        "aria-label": _vm.$t('Slide {0}', [index + 1]),
        "tabindex": _vm.getTabIndexForSlide(index)
      }
    }, [_c(_vm.homepageCarouselComponent, {
      tag: "component",
      attrs: {
        "review": review,
        "reviewSettings": _vm.individualReviewSettings,
        "widgetSize": _vm.widgetSize,
        "widgetMode": _vm.widgetMode
      },
      on: {
        "reviewCardMediaClick": _vm.onReviewCardMediaClick
      }
    })], 1);
  }), 1), _vm._v(" "), _vm.arrowSettings.enabled && _vm.reviews.length > _vm.slidesPerPage ? _c('prev-next-button', {
    attrs: {
      "isDisabled": _vm.currentPage >= _vm.reviews.length - _vm.slidesPerPage && !_vm.carouselOptions.infiniteScroll || _vm.reviews.length <= _vm.slidesPerPage,
      "arrowSize": _vm.arrowSettings.size,
      "arrowColor": _vm.arrowSettings.color,
      "arrowDirection": "right",
      "buttonClass": "oke-reviewCarousel-next"
    },
    on: {
      "click": _vm.nextSlide
    }
  }) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-a11yText",
    attrs: {
      "aria-live": "polite"
    }
  }, [_vm._v("\n                    " + _vm._s(_vm.$t('Viewing Slides {0} to {1} of {2}', [_vm.currentPage + 1, _vm.currentPage + _vm.slidesPerPage, _vm.reviews.length])) + "\n                ")])], 1)] : _vm._e()], 2)]);
};

var __vue_staticRenderFns__$14 = [];
/* style */

const __vue_inject_styles__$14 = undefined;
/* scoped */

const __vue_scope_id__$14 = undefined;
/* module identifier */

const __vue_module_identifier__$14 = undefined;
/* functional template */

const __vue_is_functional_template__$14 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$14 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$14,
  staticRenderFns: __vue_staticRenderFns__$14
}, __vue_inject_styles__$14, __vue_script__$14, __vue_scope_id__$14, __vue_is_functional_template__$14, __vue_module_identifier__$14, false, undefined, undefined, undefined);

let OkendoReviewsBadge$1 = class OkendoReviewsBadge extends Vue {
  constructor() {
    super(...arguments);
    this.averageRating = '0';
    this.reviewCount = 0;
  }

  created() {
    if (this.initialData) {
      this.averageRating = this.initialData.averageRating;
      this.reviewCount = this.initialData.reviewCount;
      OkendoUtils.sendWidgetRenderedEvent('badge', this.widgetId);
    } else {
      this.loadAggregateData();
    }
  }

  get badgeSettings() {
    var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;

    const {
      reviewsBadge: {
        stars
      },
      global
    } = SharedSettings.widgetSettings;
    const subscriberSettings = { ...SharedSettings.widgetSettings.reviewsBadge,
      stars: {
        globalOverrideSettings: {
          foregroundColor: (_b = (_a = stars === null || stars === void 0 ? void 0 : stars.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.foregroundColor) !== null && _b !== void 0 ? _b : global.stars.foregroundColor,
          backgroundColor: (_d = (_c = stars === null || stars === void 0 ? void 0 : stars.globalOverrideSettings) === null || _c === void 0 ? void 0 : _c.backgroundColor) !== null && _d !== void 0 ? _d : global.stars.backgroundColor,
          showBorder: (_f = (_e = stars === null || stars === void 0 ? void 0 : stars.globalOverrideSettings) === null || _e === void 0 ? void 0 : _e.showBorder) !== null && _f !== void 0 ? _f : global.stars.showBorder,
          borderColor: (_h = (_g = stars === null || stars === void 0 ? void 0 : stars.globalOverrideSettings) === null || _g === void 0 ? void 0 : _g.borderColor) !== null && _h !== void 0 ? _h : global.stars.borderColor,
          interspace: (_k = (_j = stars === null || stars === void 0 ? void 0 : stars.globalOverrideSettings) === null || _j === void 0 ? void 0 : _j.interspace) !== null && _k !== void 0 ? _k : global.stars.interspace
        },
        height: ((_l = stars === null || stars === void 0 ? void 0 : stars.height) === null || _l === void 0 ? void 0 : _l.value) && ((_m = stars === null || stars === void 0 ? void 0 : stars.height) === null || _m === void 0 ? void 0 : _m.unit) ? {
          value: stars.height.value,
          unit: stars.height.unit
        } : undefined
      }
    };

    if (this.badgeDataAttributeSettings) {
      OkendoUtils.defaultsDeep({ ...this.badgeDataAttributeSettings
      }, subscriberSettings);
    }

    return subscriberSettings;
  }

  get badgeLayout() {
    return this.badgeSettings.layout;
  }

  get url() {
    var _a;

    return ((_a = this.badgeSettings.url) === null || _a === void 0 ? void 0 : _a.length) ? this.badgeSettings.url : undefined; // '' will result in href(unknown) in DOM
  }

  get okendoBrandingEnabled() {
    return !SharedSettings.widgetSettings.global.hideOkendoBranding;
  }

  get starForegroundColor() {
    var _a, _b, _c;

    return (_c = (_b = (_a = this.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.foregroundColor) !== null && _c !== void 0 ? _c : kDefaultStarForegroundColor;
  }

  get starBackgroundColor() {
    var _a, _b, _c;

    return (_c = (_b = (_a = this.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.backgroundColor) !== null && _c !== void 0 ? _c : kDefaultStarBackgroundColor;
  }

  get starBorderColor() {
    var _a, _b, _c, _d, _e;

    return ((_b = (_a = this.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.showBorder) ? (_e = (_d = (_c = this.stars) === null || _c === void 0 ? void 0 : _c.globalOverrideSettings) === null || _d === void 0 ? void 0 : _d.borderColor) !== null && _e !== void 0 ? _e : kDefaultStarBorderColor : 'transparent';
  }

  get starBorderWidth() {
    var _a, _b;

    return ((_b = (_a = this.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.showBorder) ? 1 : 0;
  }

  get badgeComponent() {
    switch (this.badgeLayout) {
      case 'large':
        return 'large-badge';

      case 'small':
        return 'small-badge';

      case 'minimal':
        return 'minimal-badge';
    }
  }

  get stars() {
    return this.badgeSettings.stars;
  }

  async loadAggregateData() {
    let loadAggregatePromise;

    if (this.productId) {
      loadAggregatePromise = OkendoApi.getReviewAggregateProduct(this.productId);
    } else if (this.groupId) {
      loadAggregatePromise = OkendoApi.getReviewAggregateGroup(this.groupId);
    } else {
      loadAggregatePromise = OkendoApi.getReviewAggregateAll();
    }

    const {
      reviewAggregate
    } = await loadAggregatePromise;
    this.reviewCount = reviewAggregate.ratingAndReviewCount;
    this.averageRating = OkendoUtils.getAverageRatingDisplayText(reviewAggregate);
    OkendoUtils.sendWidgetRenderedEvent('badge', this.widgetId);
  }

};

__decorate([Prop()], OkendoReviewsBadge$1.prototype, "widgetId", void 0);

__decorate([Prop()], OkendoReviewsBadge$1.prototype, "productId", void 0);

__decorate([Prop()], OkendoReviewsBadge$1.prototype, "groupId", void 0);

__decorate([Prop()], OkendoReviewsBadge$1.prototype, "initialData", void 0);

__decorate([Prop()], OkendoReviewsBadge$1.prototype, "badgeDataAttributeSettings", void 0);

OkendoReviewsBadge$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default,
    LargeBadge: async () => (await Promise.resolve().then(function () { return LargeBadge; })).default,
    SmallBadge: async () => (await Promise.resolve().then(function () { return SmallBadge; })).default,
    MinimalBadge: async () => (await Promise.resolve().then(function () { return MinimalBadge; })).default,
    PoweredBy: async () => (await Promise.resolve().then(function () { return PoweredBy; })).default
  }
})], OkendoReviewsBadge$1);
var script$10 = OkendoReviewsBadge$1;

/* script */
const __vue_script__$13 = script$10;
/* template */

var __vue_render__$13 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews",
    style: {
      '--oke-stars-foregroundColor': _vm.starForegroundColor,
      '--oke-stars-backgroundColor': _vm.starBackgroundColor,
      '--oke-stars-borderWidth': _vm.starBorderWidth,
      '--oke-stars-borderColor': _vm.starBorderColor
    },
    attrs: {
      "data-oke-container": ""
    }
  }, [_vm.reviewCount > 0 ? _c(_vm.url ? 'a' : 'div', {
    tag: "component",
    staticClass: "oke-ratingsBadge",
    class: "oke-ratingsBadge--" + _vm.badgeLayout,
    attrs: {
      "href": _vm.url
    }
  }, [_c('div', {
    attrs: {
      "aria-hidden": "true"
    }
  }, [_c(_vm.badgeComponent, {
    tag: "component",
    attrs: {
      "badgeSettings": _vm.badgeSettings,
      "reviewCount": _vm.reviewCount,
      "averageRating": _vm.averageRating
    }
  })], 1), _vm._v(" "), _vm.badgeLayout !== 'minimal' && _vm.okendoBrandingEnabled ? _c('powered-by', {
    staticClass: "oke-ratingsBadge-poweredBy",
    attrs: {
      "height": "12"
    }
  }) : _vm._e(), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("\n            " + _vm._s(_vm.$t('{0} verified reviews with an average of {1} stars out of 5 by Okendo Reviews', [_vm.reviewCount, _vm.averageRating])) + "\n        ")])], 1) : _vm._e()], 1);
};

var __vue_staticRenderFns__$13 = [];
/* style */

const __vue_inject_styles__$13 = undefined;
/* scoped */

const __vue_scope_id__$13 = undefined;
/* module identifier */

const __vue_module_identifier__$13 = undefined;
/* functional template */

const __vue_is_functional_template__$13 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$13 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$13,
  staticRenderFns: __vue_staticRenderFns__$13
}, __vue_inject_styles__$13, __vue_script__$13, __vue_scope_id__$13, __vue_is_functional_template__$13, __vue_module_identifier__$13, false, undefined, undefined, undefined);

var OkendoReviewsBadge = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$13
});

let MediaWidgetBase = class MediaWidgetBase extends Vue {
  constructor() {
    super(...arguments);
    this.reviews = [];
    this.isLoading = false;
  }

  get canLoadMore() {
    return !!this.nextUrl && !this.isLoading;
  }

  async loadMoreMedia(limit) {
    this.isLoading = true;
    const loadReviewsPromise = this.nextUrl ? OkendoApi.getMore(this.nextUrl, limit) : Promise.resolve({
      media: []
    });
    await this.loadMedia(loadReviewsPromise);
  }

  async loadInitialMedia(limit) {
    this.widgetMode = OkendoUtils.getWidgetMode(this.productId, this.groupId);
    const reviewsPromise = OkendoApi.getMultiSourceMedia(this.productId, this.groupId, limit);
    return this.loadMedia(reviewsPromise);
  }

  async loadMedia(reviewPromise) {
    try {
      const reviewResponse = await reviewPromise;
      const {
        media,
        nextUrl
      } = reviewResponse;
      this.nextUrl = nextUrl;
      this.reviews = [...this.reviews, ...media];
    } catch (_a) {
      console.log('Error occurred loading reviews, please try again');
    } finally {
      this.isLoading = false;
    }
  }

};

__decorate([Prop()], MediaWidgetBase.prototype, "groupId", void 0);

__decorate([Prop()], MediaWidgetBase.prototype, "productId", void 0);

MediaWidgetBase = __decorate([Component], MediaWidgetBase);
var MediaWidgetBase$1 = MediaWidgetBase;

let OkendoMediaGrid = class OkendoMediaGrid extends mixins(WidgetBase$1, MediaWidgetBase$1) {
  constructor() {
    super(...arguments);
    this.limit = 25;
    this.numberVisible = 0;
    this.extraItemsIndexStart = 0;
    this.showRemainingItemsAsSingle = false;
    this.amountToHide = 0;
    this.reviewsToShow = [];
    this.containerSize = 0;
    this.layoutLength = 0;
    this.gridStyleParams = {
      'default-desktop': {
        initialLimit: 14,
        loadMoreLimit: 7,
        columns: 5
      },
      'large-centered': {
        initialLimit: 10,
        loadMoreLimit: 5,
        columns: 4
      },
      'x-large': {
        initialLimit: 14,
        loadMoreLimit: 7,
        columns: 6
      },
      'two-heroes': {
        initialLimit: 10,
        loadMoreLimit: 2,
        loadMoreLimitAlt: 8,
        columns: 4
      },
      'custom-desktop': {
        initialLimit: this.mediaGridSettings.gridStyleDesktop.rows * this.mediaGridSettings.gridStyleDesktop.columns,
        loadMoreLimit: this.mediaGridSettings.gridStyleDesktop.rows * this.mediaGridSettings.gridStyleDesktop.columns,
        columns: this.mediaGridSettings.gridStyleDesktop.columns
      },
      'default-mobile': {
        initialLimit: 9,
        loadMoreLimit: 3,
        loadMoreLimitAlt: 6,
        columns: 3
      },
      'alternate-mobile': {
        initialLimit: 6,
        loadMoreLimit: 3,
        columns: 3
      },
      'hero-three-mobile': {
        initialLimit: 10,
        loadMoreLimit: 1,
        loadMoreLimitAlt: 9,
        columns: 3
      },
      'custom-mobile': {
        initialLimit: this.mediaGridSettings.gridStyleMobile.rows * this.mediaGridSettings.gridStyleMobile.columns,
        loadMoreLimit: this.mediaGridSettings.gridStyleMobile.rows * this.mediaGridSettings.gridStyleMobile.columns,
        columns: this.mediaGridSettings.gridStyleMobile.columns
      }
    };
  }

  created() {
    this.resetLayout();
  }

  mounted() {
    this.setLoadLimit();
    this.refreshContainerSizeFromClient();

    if (this.initialData) {
      this.reviews = this.initialData.reviews;
      this.nextUrl = this.initialData.nextUrl;
      OkendoUtils.sendWidgetRenderedEvent('media-grid', this.widgetId);
    } else {
      this.loadReviews();
    }

    if (this.mediaGridSettings.infiniteScroll) {
      this.$nextTick(() => {
        document.addEventListener('scroll', this.onScroll);
        this.onScroll();
      });
    }
  }

  onPropertyChanged(newSize, oldSize) {
    if (oldSize !== 'small' && newSize === 'small' || newSize !== 'small' && oldSize === 'small') {
      this.resetLayout();
    }

    this.widgetSize = newSize;
  }

  onPropertyWidthChanged(newSize, oldSize) {
    if (newSize > oldSize) {
      this.refreshContainerSizeFromClient();
      this.reviewsToShow = this.reviews.map((review, index) => ({ ...review,
        width: this.getGridItemMediaImageSize(index)
      }));
    }
  }

  onPropertyReviewsChanged(newReviews, currentReviews) {
    if (newReviews.length > currentReviews.length) {
      const newReviewsToShow = newReviews.slice(currentReviews.length).map((review, index) => ({ ...review,
        width: this.getGridItemMediaImageSize(index)
      }));
      this.reviewsToShow = [...this.reviewsToShow, ...newReviewsToShow];
    }
  }

  get mediaGridSettings() {
    return SharedSettings.widgetSettings.mediaGrid;
  }

  get gapSize() {
    return OkendoUtils.toPixels(this.mediaGridSettings.gapSize);
  }

  refreshContainerSizeFromClient() {
    this.containerSize = this.$refs.mediaGridContainer.clientWidth;
  }

  get renderedColumns() {
    return this.widgetSize === 'small' ? this.gridStyleParams[this.mediaGridSettings.gridStyleMobile.layout].columns : this.gridStyleParams[this.mediaGridSettings.gridStyleDesktop.layout].columns;
  }

  get customGridStyle() {
    if (this.widgetSize === 'small') {
      if (this.mediaGridSettings.gridStyleMobile.layout === 'custom-mobile') {
        return {
          'grid-template-columns': `repeat(${this.mediaGridSettings.gridStyleMobile.columns}, 1fr)`
        };
      }
    } else {
      if (this.mediaGridSettings.gridStyleDesktop.layout === 'custom-desktop') {
        return {
          'grid-template-columns': `repeat(${this.mediaGridSettings.gridStyleDesktop.columns}, 1fr)`
        };
      }
    }
  }

  get gridLayout() {
    return this.widgetSize === 'small' ? this.mediaGridSettings.gridStyleMobile.layout : this.mediaGridSettings.gridStyleDesktop.layout;
  }

  get lastRowClass() {
    return this.showRemainingItemsAsSingle && !this.isLoading ? `oke-mediaGrid-container--last-${this.numberVisible - this.extraItemsIndexStart}` : '';
  }

  showArrow() {
    var _a;

    const hasNextUrl = this.nextUrl !== undefined;
    const areMoreReviewAvailable = this.reviews.length > this.numberVisible;
    const isShowMoreArrowEnabled = ((_a = this.mediaGridSettings.showMoreArrow) === null || _a === void 0 ? void 0 : _a.enabled) === true;
    return isShowMoreArrowEnabled && (hasNextUrl || areMoreReviewAvailable);
  }

  destroyed() {
    document.removeEventListener('scroll', this.onScroll);
  }

  setLoadLimit() {
    this.layoutLength = this.widgetSize === 'small' ? this.gridStyleParams[this.mediaGridSettings.gridStyleMobile.layout].initialLimit : this.gridStyleParams[this.mediaGridSettings.gridStyleDesktop.layout].initialLimit;
    this.limit = this.layoutLength * 2 + 1;
  }

  resetLayout() {
    this.currentLayoutParams = this.widgetSize === 'small' ? this.gridStyleParams[this.mediaGridSettings.gridStyleMobile.layout] : this.gridStyleParams[this.mediaGridSettings.gridStyleDesktop.layout];
    this.numberVisible = this.currentLayoutParams.initialLimit;
    this.showRemainingItemsAsSingle = false;
    this.setLoadLimit();
  }

  onScroll() {
    const mediaContainer = this.$refs.mediaGridContainer;
    const bottomOfElement = mediaContainer.getBoundingClientRect().bottom;

    if (bottomOfElement < window.innerHeight && this.canLoadMore) {
      this.loadMoreMedia().then(() => {
        OkendoUtils.sendWidgetRenderedEvent('media-grid');
      });
    }
  }

  clickShowMore() {
    // Already have enough reviews pre-loaded, don't need to load more
    this.extraItemsIndexStart = this.numberVisible;

    if (this.reviews.length - this.numberVisible > this.amountToAdd()) {
      this.numberVisible += this.amountToAdd();
    } else if (this.canLoadMore) {
      this.loadMoreMedia().then(() => {
        OkendoUtils.sendWidgetRenderedEvent('media-grid');

        if (this.reviews.length - this.numberVisible >= this.amountToAdd()) {
          this.numberVisible += this.amountToAdd();
        } else {
          this.showRemainingItemsAsSingle = true;
          this.numberVisible += this.reviews.length - this.numberVisible;
        }
      });
    } else {
      this.showRemainingItemsAsSingle = this.reviews.length - this.numberVisible !== this.amountToAdd();
      this.numberVisible += this.reviews.length - this.numberVisible;
    }
  }

  amountToAdd() {
    if (this.currentLayoutParams.loadMoreLimitAlt) {
      if (this.numberVisible % this.currentLayoutParams.initialLimit === 0) {
        return this.currentLayoutParams.loadMoreLimit;
      }

      return this.currentLayoutParams.loadMoreLimitAlt;
    }

    return this.currentLayoutParams.loadMoreLimit;
  }

  onMediaClick(index) {
    ModalService.openMediaModal({
      initialMedia: this.reviews,
      initialNextUrl: this.nextUrl,
      mediaContext: 'aggregate',
      initialIndex: index,
      widgetMode: 'all'
    });
  }

  loadReviews() {
    this.loadInitialMedia(this.limit).then(() => {
      OkendoUtils.sendWidgetRenderedEvent('media-grid', this.widgetId);
      this.showRemainingItemsAsSingle = this.layoutLength > this.reviews.length;
    });
  }

  getGridItemMediaImageSize(index) {
    if (this.showRemainingItemsAsSingle && index > this.reviews.length - this.extraItemsIndexStart) {
      return this.getGridItemSize();
    }

    const itemWidth = this.gridItemWidth(index);

    if (itemWidth > 1) {
      const extraToAdd = (itemWidth - 1) * this.gapSize;
      return itemWidth * this.getGridItemSize() + extraToAdd;
    }

    return this.getGridItemSize();
  }

  getGridItemSize() {
    return (this.containerSize - this.gapSize * (this.renderedColumns - 1)) / this.renderedColumns;
  }

  gridItemWidth(index) {
    const gridStyle = this.widgetSize === 'small' ? this.mediaGridSettings.gridStyleMobile.layout : this.mediaGridSettings.gridStyleDesktop.layout;
    const defaultSize = 1;

    switch (gridStyle) {
      case 'default-desktop':
        return index % 14 === 0 || (index + 4) % 14 === 0 ? 2 : defaultSize;

      case 'large-centered':
        return (index + 4) % 5 === 0 || index === 1 ? 2 : defaultSize;

      case 'x-large':
        return index % 14 === 0 || (index + 5) % 14 === 0 ? 3 : defaultSize;

      case 'two-heroes':
        return index === 0 || index === 1 || index % 10 === 0 || (index - 1) % 10 === 0 ? 2 : defaultSize;

      case 'default-mobile':
        return index === 0 || index % 9 === 0 ? 2 : defaultSize;

      case 'alternate-mobile':
        return index % 6 === 0 || (index - 4) % 6 === 0 ? 2 : defaultSize;

      case 'hero-three-mobile':
        return index % 10 === 0 ? 3 : defaultSize;

      default:
        return defaultSize;
    }
  }

};

__decorate([Prop()], OkendoMediaGrid.prototype, "initialData", void 0);

__decorate([Watch('widgetSize')], OkendoMediaGrid.prototype, "onPropertyChanged", null);

__decorate([Watch('widgetWidth')], OkendoMediaGrid.prototype, "onPropertyWidthChanged", null);

__decorate([Watch('reviews')], OkendoMediaGrid.prototype, "onPropertyReviewsChanged", null);

OkendoMediaGrid = __decorate([Component({
  components: {
    MediaOverlay: () => Promise.resolve().then(function () { return MediaOverlay; }),
    MediaThumbnail: () => Promise.resolve().then(function () { return MediaThumbnail; })
  }
})], OkendoMediaGrid);
var script$$ = OkendoMediaGrid;

/* script */
const __vue_script__$12 = script$$;
/* template */

var __vue_render__$12 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews oke-mediaGrid",
    attrs: {
      "data-oke-container": ""
    }
  }, [_c('div', {
    ref: "mediaGridContainer",
    staticClass: "oke-mediaGrid-container",
    class: ["oke-mediaGrid-container--" + _vm.gridLayout, _vm.lastRowClass],
    style: Object.assign({}, {
      'grid-row-gap': _vm.gapSize + "px",
      'grid-column-gap': _vm.gapSize + "px"
    }, _vm.customGridStyle)
  }, _vm._l(_vm.reviewsToShow.slice(0, this.numberVisible), function (item, index) {
    return _c('button', {
      key: item.id + "-" + index,
      staticClass: "oke-mediaGrid-item",
      on: {
        "click": function ($event) {
          return _vm.onMediaClick(index);
        },
        "keyup": function ($event) {
          if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) {
            return null;
          }

          return _vm.onMediaClick(index);
        }
      }
    }, [_c('media-thumbnail', {
      staticClass: "oke-mediaGrid-thumbnail",
      attrs: {
        "mediaItem": item,
        "transcodedWidth": item.width,
        "transcodedHeight": item.width,
        "mediaContext": 'aggregate'
      }
    }), _vm._v(" "), _vm.widgetSize !== 'small' ? _c('media-overlay', {
      staticClass: "oke-mediaGrid-overlay",
      attrs: {
        "overlayHeight": item.width,
        "linkText": _vm.mediaGridSettings.linkText,
        "overlayItem": item
      }
    }) : _vm._e()], 1);
  }), 0), _vm._v(" "), _vm.reviews.length && _vm.showArrow() ? _c('button', {
    staticClass: "oke-mediaGrid-loadMore",
    class: {
      'oke-is-loading': _vm.isLoading
    },
    style: {
      'backgroundColor': _vm.mediaGridSettings.showMoreArrow.backgroundColor,
      'color': _vm.mediaGridSettings.showMoreArrow.arrowColor
    },
    attrs: {
      "title": _vm.$tc('Show More'),
      "aria-busy": _vm.isLoading
    },
    on: {
      "click": function ($event) {
        return _vm.clickShowMore();
      }
    }
  }, [_c('span', {
    staticClass: "oke-mediaGrid-loadMore-chevron oke-icon oke-icon--chevron-down"
  }), _vm._v(" "), _c('span', {
    staticClass: "oke-mediaGrid-loadMore-loading oke-icon oke-icon--loading"
  })]) : _vm._e()]);
};

var __vue_staticRenderFns__$12 = [];
/* style */

const __vue_inject_styles__$12 = undefined;
/* scoped */

const __vue_scope_id__$12 = undefined;
/* module identifier */

const __vue_module_identifier__$12 = undefined;
/* functional template */

const __vue_is_functional_template__$12 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$12 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$12,
  staticRenderFns: __vue_staticRenderFns__$12
}, __vue_inject_styles__$12, __vue_script__$12, __vue_scope_id__$12, __vue_is_functional_template__$12, __vue_module_identifier__$12, false, undefined, undefined, undefined);

/**
  * Hopper 0.7.0
  * (c) 2022
    * @license MIT
    */

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);

    if (enumerableOnly) {
      symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });
    }

    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function getInRange(value, min, max) {
  return Math.max(Math.min(value, max), min);
}
function now() {
  return Date.now();
}
function Timer(callback, defaultTime) {
  this.create = function () {
    return window.setTimeout(callback, defaultTime);
  };

  this.stop = function () {
    if (this.timer) {
      window.clearTimeout(this.timer);
      this.timer = null;
    }
  };

  this.start = function () {
    if (!this.timer) {
      this.timer = this.create();
    }
  };

  this.set = function (newTime) {
    var timeout = newTime || defaultTime;
    this.timer = window.setTimeout(callback, timeout);
  };

  this.timer = this.create();
}
function camelCaseToString(camelCase) {
  camelCase = camelCase.replace(/([A-Z]+)/g, ' $1');
  return camelCase.charAt(0).toUpperCase() + camelCase.slice(1);
}
function normalizeSlideIndex(index, slidesCount, itemsToShow, infiniteScroll) {
  var realIndex;

  if (index < 0) {
    realIndex = infiniteScroll ? (index + slidesCount) % slidesCount - (itemsToShow - 1) : (index + slidesCount) % slidesCount;
  } else {
    realIndex = infiniteScroll ? index % (slidesCount - itemsToShow + 1) : index % slidesCount;
  } // Test for NaN


  if (realIndex !== realIndex) {
    return 0;
  }

  return realIndex;
} // IE11 :)

function assignPoly(target) {
  if (target === undefined || target === null) {
    throw new TypeError('Cannot convert first argument to object');
  }

  var to = Object(target);

  for (var i = 1; i < arguments.length; i++) {
    var nextSource = arguments[i];

    if (nextSource === undefined || nextSource === null) {
      continue;
    }

    nextSource = Object(nextSource);
    var keysArray = Object.keys(Object(nextSource));

    for (var nextIndex = 0, len = keysArray.length; nextIndex < len; nextIndex++) {
      var nextKey = keysArray[nextIndex];
      var desc = Object.getOwnPropertyDescriptor(nextSource, nextKey);

      if (desc !== undefined && desc.enumerable) {
        to[nextKey] = nextSource[nextKey];
      }
    }
  }

  return to;
}

var assign = Object.assign || assignPoly;

function signPoly(value) {
  if (value < 0) {
    return -1;
  }

  return value > 0 ? 1 : 0;
}

var sign = Math.sign || signPoly;
function normalizeChildren(context) {
  var slotProps = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

  if (context.$scopedSlots.default) {
    return context.$scopedSlots.default(slotProps) || [];
  }

  return context.$slots.default || [];
}

var EMITTER = new Vue();
var Carousel = {
  name: 'Hooper',
  provide: function provide() {
    return {
      $hooper: this
    };
  },
  props: {
    // count of items to showed per view
    itemsToShow: {
      default: 1,
      type: Number
    },
    // count of items to slide when use navigation buttons
    itemsToSlide: {
      default: 1,
      type: Number
    },
    // index number of initial slide
    initialSlide: {
      default: 0,
      type: Number
    },
    // control infinite scrolling mode
    infiniteScroll: {
      default: false,
      type: Boolean
    },
    // control center mode
    centerMode: {
      default: false,
      type: Boolean
    },
    // vertical sliding mode
    vertical: {
      default: false,
      type: Boolean
    },
    // enable rtl mode
    rtl: {
      default: null,
      type: Boolean
    },
    // enable auto sliding to carousel
    autoPlay: {
      default: false,
      type: Boolean
    },
    // speed of auto play to trigger slide
    playSpeed: {
      default: 2000,
      type: Number
    },
    // toggle mouse dragging
    mouseDrag: {
      default: true,
      type: Boolean
    },
    // toggle touch dragging
    touchDrag: {
      default: true,
      type: Boolean
    },
    // toggle mouse wheel sliding
    wheelControl: {
      default: true,
      type: Boolean
    },
    // toggle keyboard control
    keysControl: {
      default: true,
      type: Boolean
    },
    // enable any move to commit a slide
    shortDrag: {
      default: true,
      type: Boolean
    },
    // sliding transition time in ms
    transition: {
      default: 300,
      type: Number
    },
    // pause autoPlay on mousehover
    hoverPause: {
      default: true,
      type: Boolean
    },
    // remove empty space around slides
    trimWhiteSpace: {
      default: false,
      type: Boolean
    },
    // enable rapid transistion of slides
    fluidSlide: {
      default: false,
      type: Boolean
    },
    // screen reader instructions
    instructionsText: {
      default: null,
      type: String
    },
    // an object to pass all settings
    settings: {
      default: function _default() {
        return {};
      },
      type: Object
    },
    group: {
      type: String,
      default: null
    }
  },
  data: function data() {
    return {
      isDragging: false,
      isSliding: false,
      isTouch: false,
      isHover: false,
      isFocus: false,
      initialized: false,
      slideWidth: 0,
      slideHeight: 0,
      slidesCount: 0,
      trimStart: 0,
      trimEnd: 1,
      currentSlide: null,
      timer: null,
      defaults: {},
      breakpoints: {},
      delta: {
        x: 0,
        y: 0
      },
      displayConfig: {}
    };
  },
  computed: {
    slideBounds: function slideBounds() {
      var displayConfig = this.displayConfig,
          currentSlide = this.currentSlide; // Because the "isActive" depends on the slides shown, not the number of slidable ones.
      // but upper and lower bounds for Next,Prev depend on whatever is smaller.

      var siblings = displayConfig.itemsToShow;
      var lower = displayConfig.centerMode ? Math.ceil(currentSlide - siblings / 2) : currentSlide;
      var upper = displayConfig.centerMode ? Math.floor(currentSlide + siblings / 2) : Math.floor(currentSlide + siblings - 1);
      return {
        lower: lower,
        upper: upper
      };
    },
    trackTransform: function trackTransform() {
      var _this$displayConfig = this.displayConfig,
          vertical = _this$displayConfig.vertical,
          rtl = _this$displayConfig.rtl,
          centerMode = _this$displayConfig.centerMode;
      var direction = rtl ? -1 : 1;
      var slideLength = vertical ? this.slideHeight : this.slideWidth;
      var containerLength = vertical ? this.containerHeight : this.containerWidth;
      var dragDelta = vertical ? this.delta.y : this.delta.x;
      var centeringSpace = centerMode ? (containerLength - slideLength) / 2 : 0; // calculate track translate

      var translate = dragDelta + direction * (centeringSpace - this.currentSlide * slideLength);

      if (vertical) {
        return "transform: translate(0, ".concat(translate, "px);");
      }

      return "transform: translate(".concat(translate, "px, 0);");
    },
    trackTransition: function trackTransition() {
      if (this.initialized && this.isSliding) {
        return "transition: ".concat(this.displayConfig.transition, "ms");
      }

      return '';
    }
  },
  watch: {
    group: function group(val, oldVal) {
      if (val === oldVal) {
        return;
      }

      EMITTER.$off("slideGroup:".concat(oldVal), this._groupSlideHandler);
      this.addGroupListeners();
    },
    autoPlay: function autoPlay(val, oldVal) {
      if (val === oldVal) {
        return;
      }

      this.restartTimer();
    },
    instructionsText: function instructionsText(val, oldVal) {
      if (val === oldVal) {
        return;
      }

      this.displayConfig.instructionsText = val;
    }
  },
  methods: {
    // controlling methods
    slideTo: function slideTo(slideIndex) {
      var isSource = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : true;

      if (!this.displayConfig.fluidSlide && this.isSliding || slideIndex === this.currentSlide) {
        return;
      }

      this.isSliding = true;
      var _this$displayConfig2 = this.displayConfig,
          infiniteScroll = _this$displayConfig2.infiniteScroll,
          itemsToShow = _this$displayConfig2.itemsToShow;
      var previousSlide = this.currentSlide;
      var index = infiniteScroll ? slideIndex : getInRange(slideIndex, this.trimStart, this.slidesCount - this.trimEnd);
      this.$emit('beforeSlide', {
        currentSlide: this.currentSlide,
        slideTo: index
      }); // Notify others if in a group and is the slide event initiator.

      if (this.group && isSource) {
        EMITTER.$emit("slideGroup:".concat(this.group), slideIndex);
      }

      this.currentSlide = index;
      this.currentSlide = normalizeSlideIndex(index, this.slidesCount, itemsToShow, infiniteScroll);
      this.$emit('slide', {
        currentSlide: this.currentSlide,
        slideFrom: previousSlide
      });
    },
    slideNext: function slideNext() {
      this.slideTo(this.currentSlide + this.displayConfig.itemsToSlide);
    },
    slidePrev: function slidePrev() {
      this.slideTo(this.currentSlide - this.displayConfig.itemsToSlide);
    },
    initEvents: function initEvents() {
      // get the element direction if not explicitly set
      if (this.defaults.rtl === null) {
        this.defaults.rtl = getComputedStyle(this.$el).direction === 'rtl';
      }

      if (this.$props.autoPlay) {
        this.initAutoPlay();
      }

      if (this.displayConfig.mouseDrag) {
        this.$refs.list.addEventListener('mousedown', this.onDragStart);
      }

      if (this.displayConfig.touchDrag) {
        this.$refs.list.addEventListener('touchstart', this.onDragStart, {
          passive: true
        });
      }

      if (this.displayConfig.keysControl) {
        this.$el.addEventListener('keydown', this.onKeypress);
      }

      if (this.displayConfig.wheelControl) {
        this.lastScrollTime = now();
        this.$el.addEventListener('wheel', this.onWheel, {
          passive: false
        });
      }

      window.addEventListener('resize', this.update);
    },
    getCurrentSlideTimeout: function getCurrentSlideTimeout() {
      var _children$curIdx$comp, _children$curIdx;

      var curIdx = normalizeSlideIndex(this.currentSlide, this.slidesCount, this.displayConfig.itemsToShow, this.displayConfig.infiniteScroll);
      var children = normalizeChildren(this);
      return (_children$curIdx$comp = (_children$curIdx = children[curIdx]) === null || _children$curIdx === void 0 ? void 0 : _children$curIdx.componentOptions.propsData.duration) !== null && _children$curIdx$comp !== void 0 ? _children$curIdx$comp : this.displayConfig.playSpeed;
    },
    // switched to using a timeout which defaults to the prop set on this component, but can be overridden on a per slide basis.
    initAutoPlay: function initAutoPlay() {
      var _this = this;

      this.timer = new Timer(function () {
        if (_this.isSliding || _this.isDragging || _this.isHover && _this.displayConfig.hoverPause || _this.isFocus || !_this.$props.autoPlay) {
          _this.timer.set(_this.getCurrentSlideTimeout());

          return;
        }

        if (_this.currentSlide === _this.slidesCount - 1 && !_this.displayConfig.infiniteScroll) {
          _this.slideTo(0);

          _this.timer.set(_this.getCurrentSlideTimeout());

          return;
        }

        _this.slideNext();

        _this.timer.set(_this.getCurrentSlideTimeout());
      }, this.getCurrentSlideTimeout());
    },
    initDefaults: function initDefaults() {
      this.breakpoints = this.settings.breakpoints;
      this.defaults = assign({}, this.$props, this.settings);
      this.displayConfig = assign({}, this.defaults);
    },
    // updating methods
    update: function update() {
      if (this.breakpoints) {
        this.updateConfig();
      }

      this.updateWidth();
      this.updateTrim();
      this.$emit('updated', {
        containerWidth: this.containerWidth,
        containerHeight: this.containerHeight,
        slideWidth: this.slideWidth,
        slideHeight: this.slideHeight,
        settings: this.displayConfig
      });
    },
    updateTrim: function updateTrim() {
      var _this$displayConfig3 = this.displayConfig,
          trimWhiteSpace = _this$displayConfig3.trimWhiteSpace,
          itemsToShow = _this$displayConfig3.itemsToShow,
          centerMode = _this$displayConfig3.centerMode,
          infiniteScroll = _this$displayConfig3.infiniteScroll;

      if (!trimWhiteSpace || infiniteScroll) {
        this.trimStart = 0;
        this.trimEnd = 1;
        return;
      }

      this.trimStart = centerMode ? Math.floor((itemsToShow - 1) / 2) : 0;
      this.trimEnd = centerMode ? Math.ceil(itemsToShow / 2) : itemsToShow;
    },
    updateWidth: function updateWidth() {
      var rect = this.$el.getBoundingClientRect();
      this.containerWidth = rect.width;
      this.containerHeight = rect.height;

      if (this.displayConfig.vertical) {
        this.slideHeight = this.containerHeight / this.displayConfig.itemsToShow;
        return;
      }

      this.slideWidth = this.containerWidth / this.displayConfig.itemsToShow;
    },
    updateConfig: function updateConfig() {
      var _this2 = this;

      var breakpoints = Object.keys(this.breakpoints).sort(function (a, b) {
        return b - a;
      });
      var matched;
      breakpoints.some(function (breakpoint) {
        matched = window.matchMedia("(min-width: ".concat(breakpoint, "px)")).matches;

        if (matched) {
          _this2.displayConfig = assign({}, _this2.displayConfig, _this2.defaults, _this2.breakpoints[breakpoint]);
          return true;
        }
      });

      if (!matched) {
        this.displayConfig = assign(this.displayConfig, this.defaults);
      }
    },
    restartTimer: function restartTimer() {
      var _this3 = this;

      this.$nextTick(function () {
        if (_this3.timer === null && _this3.$props.autoPlay) {
          _this3.initAutoPlay();

          return;
        }

        if (_this3.timer) {
          _this3.timer.stop();

          if (_this3.$props.autoPlay) {
            _this3.timer.set(_this3.getCurrentSlideTimeout());

            _this3.timer.start();
          }
        }
      });
    },
    restart: function restart() {
      var _this4 = this;

      this.$nextTick(function () {
        _this4.update();
      });
    },
    // events handlers
    onDragStart: function onDragStart(event) {
      this.isTouch = event.type === 'touchstart';

      if (!this.isTouch && event.button !== 0) {
        return;
      }

      this.startPosition = {
        x: 0,
        y: 0
      };
      this.endPosition = {
        x: 0,
        y: 0
      };
      this.isDragging = true;
      this.startPosition.x = this.isTouch ? event.touches[0].clientX : event.clientX;
      this.startPosition.y = this.isTouch ? event.touches[0].clientY : event.clientY;
      document.addEventListener(this.isTouch ? 'touchmove' : 'mousemove', this.onDrag);
      document.addEventListener(this.isTouch ? 'touchend' : 'mouseup', this.onDragEnd);
    },
    isInvalidDirection: function isInvalidDirection(deltaX, deltaY) {
      if (!this.displayConfig.vertical) {
        return Math.abs(deltaX) <= Math.abs(deltaY);
      }

      if (this.displayConfig.vertical) {
        return Math.abs(deltaY) <= Math.abs(deltaX);
      }

      return false;
    },
    onDrag: function onDrag(event) {
      if (this.isSliding) {
        return;
      }

      this.endPosition.x = this.isTouch ? event.touches[0].clientX : event.clientX;
      this.endPosition.y = this.isTouch ? event.touches[0].clientY : event.clientY;
      var deltaX = this.endPosition.x - this.startPosition.x;
      var deltaY = this.endPosition.y - this.startPosition.y; // Maybe scrolling.

      if (this.isInvalidDirection(deltaX, deltaY)) {
        return;
      }

      this.delta.y = deltaY;
      this.delta.x = deltaX;

      if (!this.isTouch) {
        event.preventDefault();
      }
    },
    onDragEnd: function onDragEnd() {
      var tolerance = this.displayConfig.shortDrag ? 0.5 : 0.15;
      this.isDragging = false;

      if (this.displayConfig.vertical) {
        var draggedSlides = Math.round(Math.abs(this.delta.y / this.slideHeight) + tolerance);
        this.slideTo(this.currentSlide - sign(this.delta.y) * draggedSlides);
      }

      if (!this.displayConfig.vertical) {
        var direction = (this.displayConfig.rtl ? -1 : 1) * sign(this.delta.x);

        var _draggedSlides = Math.round(Math.abs(this.delta.x / this.slideWidth) + tolerance);

        this.slideTo(this.currentSlide - direction * _draggedSlides);
      }

      this.delta.x = 0;
      this.delta.y = 0;
      document.removeEventListener(this.isTouch ? 'touchmove' : 'mousemove', this.onDrag);
      document.removeEventListener(this.isTouch ? 'touchend' : 'mouseup', this.onDragEnd);
      this.restartTimer();
    },
    onTransitionend: function onTransitionend(e) {
      if (e.propertyName === 'transform') {
        this.isSliding = false;
        this.$emit('afterSlide', {
          currentSlide: this.currentSlide
        });
      }
    },
    onKeypress: function onKeypress(event) {
      var key = event.key;

      if (key.startsWith('Arrow')) {
        event.preventDefault();
      }

      if (this.displayConfig.vertical) {
        if (key === 'ArrowUp') {
          this.slidePrev();
        }

        if (key === 'ArrowDown') {
          this.slideNext();
        }

        return;
      }

      if (this.displayConfig.rtl) {
        if (key === 'ArrowRight') {
          this.slidePrev();
        }

        if (key === 'ArrowLeft') {
          this.slideNext();
        }

        return;
      }

      if (key === 'ArrowRight') {
        this.slideNext();
      }

      if (key === 'ArrowLeft') {
        this.slidePrev();
      }
    },
    onWheel: function onWheel(event) {
      event.preventDefault();

      if (now() - this.lastScrollTime < 200) {
        return;
      } // get wheel direction


      this.lastScrollTime = now();
      var value = event.wheelDelta || -event.deltaY;
      var delta = sign(value);

      if (delta === -1) {
        if (this.currentSlide !== this.slidesCount - 1 && !this.displayConfig.infiniteScroll || this.displayConfig.infiniteScroll) {
          this.slideNext();
        }
      }

      if (delta === 1) {
        if (this.currentSlide !== 0 && !this.displayConfig.infiniteScroll || this.displayConfig.infiniteScroll) {
          this.slidePrev();
        }
      }
    },
    addGroupListeners: function addGroupListeners() {
      var _this5 = this;

      if (!this.group) {
        return;
      }

      this._groupSlideHandler = function (slideIndex) {
        // set the isSource to false to prevent infinite emitting loop.
        _this5.slideTo(slideIndex, false);
      };

      EMITTER.$on("slideGroup:".concat(this.group), this._groupSlideHandler);
    }
  },
  created: function created() {
    this.initDefaults();
  },
  mounted: function mounted() {
    var _this6 = this;

    this.initEvents();
    this.addGroupListeners();
    this.$nextTick(function () {
      _this6.update();

      _this6.slideTo(_this6.displayConfig.initialSlide || 0);

      setTimeout(function () {
        _this6.$emit('loaded');

        _this6.initialized = true;
        _this6.isSliding = false;
      }, _this6.transition);
    });
  },
  beforeDestroy: function beforeDestroy() {
    window.removeEventListener('resize', this.update);

    if (this.group) {
      EMITTER.$off("slideGroup:".concat(this.group), this._groupSlideHandler);
    }

    if (this.timer) {
      this.timer.stop();
    }
  },
  render: function render(h) {
    var _this7 = this;

    var body = renderBody.call(this, h);
    return h('section', {
      class: {
        hooper: true,
        'is-vertical': this.displayConfig.vertical,
        'is-rtl': this.displayConfig.rtl
      },
      attrs: {
        tabindex: '0'
      },
      on: {
        focusin: function focusin() {
          return _this7.isFocus = true;
        },
        focusout: function focusout() {
          return _this7.isFocus = false;
        },
        mouseover: function mouseover() {
          return _this7.isHover = true;
        },
        mouseleave: function mouseleave() {
          return _this7.isHover = false;
        }
      }
    }, body);
  }
};
/**
 * Produces the VNodes for the Slides.
 * requires {this} to be bound to hooper.
 * So use with .call or .bind
 */

function renderSlides(h) {
  var children = normalizeChildren(this);
  var childrenCount = children.length;
  var idx = 0;
  var slides = [];

  for (var i = 0; i < childrenCount; i++) {
    var child = children[i];
    var ctor = child.componentOptions && child.componentOptions.Ctor;

    if (!ctor || ctor.options.name !== 'HooperSlide') {
      continue;
    } // give slide an index behind the scenes


    child.componentOptions.propsData.index = idx;
    child.data.key = idx;
    child.key = idx;
    child.data.props = _objectSpread2(_objectSpread2({}, child.data.props || {}), {}, {
      index: idx++
    });
    slides.push(child);
  } // update hooper's information of the slide count.


  this.slidesCount = slides.length;
  return h('ul', {
    class: {
      'hooper-track': true,
      'is-dragging': this.isDragging
    },
    style: this.trackTransform + this.trackTransition,
    ref: 'track',
    on: {
      transitionend: this.onTransitionend
    }
  }, slides);
}
/**
 * Builds the VNodes for the hooper body.
 * Which is the slides, addons if available, and a11y stuff.
 * REQUIRES {this} to be bound to the hooper instance.
 * use with .call or .bind
 */


function renderBody(h) {
  var slides = renderSlides.call(this, h);
  var addons = this.$slots['hooper-addons'] || [];
  var instructions = h('span', {
    class: 'hooper-sr-only',
    attrs: {
      'aria-live': 'polite'
    }
  }, this.displayConfig.instructionsText);
  var a11y = h('div', {
    class: 'hooper-liveregion hooper-sr-only',
    attrs: {
      'aria-live': 'polite',
      'aria-atomic': 'true'
    }
  });
  var children = [slides].concat(_toConsumableArray(addons), [instructions, a11y]);
  return [h('div', {
    class: 'hooper-list',
    ref: 'list'
  }, children)];
}

var Slide = {
  name: 'HooperSlide',
  inject: ['$hooper'],
  props: {
    isClone: {
      type: Boolean,
      default: false
    },
    index: {
      type: Number,
      required: true
    },
    duration: {
      type: Number,
      default: null
    }
  },
  computed: {
    style: function style() {
      var _ref = this.$hooper || {},
          displayConfig = _ref.displayConfig,
          slideHeight = _ref.slideHeight,
          slideWidth = _ref.slideWidth;

      if (displayConfig.vertical) {
        return "height: ".concat(slideHeight, "px");
      }

      return "width: ".concat(slideWidth, "px");
    },
    isActive: function isActive() {
      var _this$$hooper$slideBo = this.$hooper.slideBounds,
          upper = _this$$hooper$slideBo.upper,
          lower = _this$$hooper$slideBo.lower;
      return this.index >= lower && this.index <= upper;
    },
    isPrev: function isPrev() {
      var lower = this.$hooper.slideBounds.lower;
      var itemsToSlide = this.$hooper.displayConfig.itemsToSlide;
      return this.index < lower && this.index >= lower - itemsToSlide;
    },
    isNext: function isNext() {
      var upper = this.$hooper.slideBounds.upper;
      var itemsToSlide = this.$hooper.displayConfig.itemsToSlide;
      return this.index > upper && this.index <= upper + itemsToSlide;
    },
    isCurrent: function isCurrent() {
      return this.index === this.$hooper.currentSlide;
    }
  },
  render: function render(h) {
    var classes = {
      'hooper-slide': true,
      'is-clone': this.isClone,
      'is-active': this.isActive,
      'is-prev': this.isPrev,
      'is-next': this.isNext,
      'is-current': this.isCurrent
    };
    var children = normalizeChildren(this);
    return h('li', {
      class: classes,
      style: this.style,
      attrs: {
        tabindex: !this.isActive ? -1 : 0
      }
    }, children);
  }
};

var Mixin = {
  inject: ['$hooper']
};

var icons = {
  arrowUp: 'M7.41 15.41L12 10.83l4.59 4.58L18 14l-6-6-6 6z',
  arrowDown: 'M7.41 8.59L12 13.17l4.59-4.58L18 10l-6 6-6-6 1.41-1.41z',
  arrowRight: 'M8.59 16.59L13.17 12 8.59 7.41 10 6l6 6-6 6-1.41-1.41z',
  arrowLeft: 'M15.41 16.59L10.83 12l4.58-4.59L14 6l-6 6 6 6 1.41-1.41z'
};
var Icon = {
  name: 'HooperIcon',
  functional: true,
  inheritAttrs: true,
  props: {
    name: {
      type: String,
      required: true,
      validator: function validator(val) {
        return val in icons;
      }
    }
  },
  render: function render(createElement, _ref) {
    var props = _ref.props;
    var icon = icons[props.name];
    var children = [];
    children.push(createElement('title', camelCaseToString(props.name)));
    children.push(createElement('path', {
      attrs: {
        d: 'M0 0h24v24H0z',
        fill: 'none'
      }
    }));
    children.push(createElement('path', {
      attrs: {
        d: icon
      }
    }));
    return createElement('svg', {
      attrs: {
        class: "icon icon-".concat(props.name),
        viewBox: '0 0 24 24',
        width: '24px',
        height: '24px'
      }
    }, children);
  }
};

var Progress = {
  inject: ['$hooper'],
  name: 'HooperProgress',
  computed: {
    currentSlide: function currentSlide() {
      return normalizeSlideIndex(this.$hooper.currentSlide, this.$hooper.slidesCount);
    },
    progress: function progress() {
      var range = this.$hooper.slidesCount - this.$hooper.trimStart - this.$hooper.trimEnd;
      return (this.currentSlide - this.$hooper.trimStart) * 100 / range;
    }
  },
  render: function render(h) {
    return h('div', {
      class: 'hooper-progress'
    }, [h('div', {
      class: 'hooper-progress-inner',
      style: "width: ".concat(this.progress, "%")
    })]);
  }
};

function renderFraction(h, current, totalCount) {
  return [h('span', current + 1), h('span', '/'), h('span', totalCount)];
}

function renderIndicator(h, index, isCurrent, onClick) {
  return h('li', [h('button', {
    class: {
      'hooper-indicator': true,
      'is-active': isCurrent
    },
    on: {
      click: onClick
    },
    attrs: {
      type: 'button'
    }
  }, [h('span', {
    class: 'hooper-sr-only'
  }, "item ".concat(index))])]);
}

function renderDefault(h, current, totalCount, slideToIndex) {
  var children = [];

  var _loop = function _loop(i) {
    children.push(renderIndicator(h, i, i === current, function () {
      return slideToIndex(i);
    }));
  };

  for (var i = 0; i < totalCount; i++) {
    _loop(i);
  }

  return [h('ol', {
    class: 'hooper-indicators'
  }, children)];
}

var Pagination = {
  inject: ['$hooper'],
  name: 'HooperPagination',
  props: {
    mode: {
      default: 'indicator',
      type: String
    }
  },
  computed: {
    currentSlide: function currentSlide() {
      return normalizeSlideIndex(this.$hooper.currentSlide, this.$hooper.slidesCount);
    },
    slides: function slides() {
      var slides = this.$hooper.slides.map(function (_, index) {
        return index;
      });
      return slides.slice(this.$hooper.trimStart, this.$hooper.slidesCount - this.$hooper.trimEnd + 1);
    }
  },
  render: function render(h) {
    var _this = this;

    var totalCount = this.$hooper.slidesCount;
    var children = this.mode === 'indicator' ? renderDefault(h, this.currentSlide, totalCount, function (index) {
      return _this.$hooper.slideTo(index);
    }) : renderFraction(h, this.currentSlide, totalCount);
    return h('div', {
      class: {
        'hooper-pagination': true,
        'is-vertical': this.$hooper.displayConfig.vertical
      }
    }, children);
  }
};

function iconName(isVertical, isRTL, isPrev) {
  if (isPrev) {
    return isVertical ? 'arrowUp' : isRTL ? 'arrowRight' : 'arrowLeft';
  }

  return isVertical ? 'arrowDown' : isRTL ? 'arrowLeft' : 'arrowRight';
}

function renderButton(h, disabled, slot, isPrev, _ref, onClick) {
  var _class;

  var isVertical = _ref.isVertical,
      isRTL = _ref.isRTL;
  var children = slot && slot.length ? slot : [h(Icon, {
    props: {
      name: iconName(isVertical, isRTL, isPrev)
    }
  })];
  return h('button', {
    class: (_class = {}, _defineProperty(_class, "hooper-".concat(isPrev ? 'prev' : 'next'), true), _defineProperty(_class, 'is-disabled', disabled), _class),
    attrs: {
      type: 'button'
    },
    on: {
      click: onClick
    }
  }, children);
}

var Navigation = {
  inject: ['$hooper'],
  name: 'HooperNavigation',
  computed: {
    isPrevDisabled: function isPrevDisabled() {
      if (this.$hooper.displayConfig.infiniteScroll) {
        return false;
      }

      return this.$hooper.currentSlide === 0;
    },
    isNextDisabled: function isNextDisabled() {
      if (this.$hooper.displayConfig.infiniteScroll) {
        return false;
      }

      if (this.$hooper.displayConfig.trimWhiteSpace) {
        return this.$hooper.currentSlide === this.$hooper.slidesCount - Math.min(this.$hooper.displayConfig.itemsToShow, this.$hooper.slidesCount);
      }

      return this.$hooper.currentSlide === this.$hooper.slidesCount - 1;
    }
  },
  methods: {
    slideNext: function slideNext() {
      this.$hooper.slideNext();
      this.$hooper.restartTimer();
    },
    slidePrev: function slidePrev() {
      this.$hooper.slidePrev();
      this.$hooper.restartTimer();
    }
  },
  render: function render(h) {
    var _this = this;

    var displayConfig = {
      isRTL: this.$hooper.displayConfig.rtl,
      isVertical: this.$hooper.displayConfig.vertical
    };
    var children = [renderButton(h, this.isPrevDisabled, this.$slots['hooper-prev'], true, displayConfig, function () {
      return _this.slidePrev();
    }), renderButton(h, this.isNextDisabled, this.$slots['hooper-next'], false, displayConfig, function () {
      return _this.slideNext();
    })];
    return h('div', {
      class: {
        'hooper-navigation': true,
        'is-vertical': this.$hooper.displayConfig.vertical,
        'is-rtl': this.$hooper.displayConfig.rtl
      }
    }, children);
  }
};

var hooper_esm = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': Carousel,
    Hooper: Carousel,
    Icon: Icon,
    Navigation: Navigation,
    Pagination: Pagination,
    Progress: Progress,
    Slide: Slide,
    addonMixin: Mixin
});

let MediaCarousel$2 = class MediaCarousel extends mixins(WidgetBase$1, MediaWidgetBase$1) {
  constructor() {
    super(...arguments);
    this.slidesPerPage = 10;
    this.hasEnoughReviews = true;
    this.currentSlide = 0;
    this.carouselOptions = {
      itemsToShow: this.slidesPerPage,
      itemsToSlide: 1,
      initialSlide: 0,
      infiniteScroll: false,
      fluidSlide: true,
      wheelControl: false
    };
    this.limit = 10;
    this.loadMoreThreshold = 10;
  }

  created() {
    if (this.initialData) {
      this.reviews = this.initialData.reviews.slice(0, this.limit);
      this.nextUrl = this.initialData.nextUrl;
      OkendoUtils.sendWidgetRenderedEvent('media-carousel', this.widgetId);
    } else {
      this.loadInitialMedia(this.limit * 2).then(() => {
        this.hasEnoughReviews = this.mediaCarouselSettings.minimumImages < this.reviews.length;
        OkendoUtils.sendWidgetRenderedEvent('media-carousel', this.widgetId);
      });
    }
  }

  mounted() {
    this.setSlidesPerPage(this.$refs.okeMediaCarouselContainer.clientWidth);
  }

  onWidgetWidthChange(newSize) {
    this.setSlidesPerPage(newSize);
  }

  get isNextArrowDisabled() {
    if (this.reviews.length <= this.slidesPerPage) {
      return true;
    }

    const moreToLoad = !!this.nextUrl;
    const enabled = this.currentSlide < this.reviews.length - this.slidesPerPage || this.carouselOptions.infiniteScroll || moreToLoad;
    return !enabled;
  }

  get isCloseToSliderEnd() {
    return this.currentSlide >= this.reviews.length - this.loadMoreThreshold;
  }

  get carouselHeight() {
    switch (this.mediaCarouselSettings.slideSize) {
      case 'x-small':
        return 140;

      case 'small':
        return 160;

      case 'medium':
        return 200;

      case 'large':
        return 240;

      case 'x-large':
        return 340;

      default:
        return 200;
    }
  }

  get mediaCarouselSettings() {
    return SharedSettings.widgetSettings.mediaCarousel;
  }

  setSlidesPerPage(size) {
    const itemsCount = size / this.carouselHeight;
    this.slidesPerPage = itemsCount;
    this.limit = Math.ceil(this.slidesPerPage);
    this.$refs.okeMediaCarousel.displayConfig.itemsToShow = this.slidesPerPage;
    this.$refs.okeMediaCarousel.update();
  }

  onSliderSlide(event) {
    if (event.currentSlide !== this.currentSlide) {
      AnalyticsUtils.sendGAEvent('Media Carousel Scroll');
      this.currentSlide = event.currentSlide;

      if (this.isCloseToSliderEnd && this.canLoadMore && !this.initialData) {
        this.loadMoreMedia(this.limit).then(() => {
          this.hasEnoughReviews = this.mediaCarouselSettings.minimumImages < this.reviews.length;
        });
      }
    }
  }

  onMediaClick(index) {
    if (!this.$refs.okeMediaCarousel.isSliding) {
      const mediaType = this.reviews[index].type;
      AnalyticsUtils.sendGAEvent(`Media Carousel ${mediaType === 'image' ? 'Photo' : StringUtils.toTitleCase(mediaType)} Click`);
      ModalService.openMediaModal({
        initialMedia: this.reviews,
        initialNextUrl: this.nextUrl,
        mediaContext: 'aggregate',
        initialIndex: index,
        widgetMode: 'all'
      });
    }
  }

  nextSlide() {
    this.$refs.okeMediaCarousel.slideNext();
  }

  prevSlide() {
    this.$refs.okeMediaCarousel.slidePrev();
  }

};

__decorate([Prop()], MediaCarousel$2.prototype, "initialData", void 0);

__decorate([Watch('widgetWidth')], MediaCarousel$2.prototype, "onWidgetWidthChange", null);

MediaCarousel$2 = __decorate([Component({
  components: {
    MediaThumbnail: () => Promise.resolve().then(function () { return MediaThumbnail; }),
    MediaOverlay: () => Promise.resolve().then(function () { return MediaOverlay; }),
    Hooper: Carousel,
    Slide
  }
})], MediaCarousel$2);
var script$_ = MediaCarousel$2;

/* script */
const __vue_script__$11 = script$_;
/* template */

var __vue_render__$11 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews",
    attrs: {
      "data-oke-container": ""
    }
  }, [_vm.hasEnoughReviews ? _c('div', {
    ref: "okeMediaCarouselContainer",
    staticClass: "oke-mediaCarousel",
    class: "oke-mediaCarousel-" + _vm.mediaCarouselSettings.arrowPosition,
    style: {
      height: _vm.carouselHeight + 'px'
    },
    attrs: {
      "tabindex": "0",
      "role": "region"
    },
    on: {
      "keydown": [function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) {
          return null;
        }

        return _vm.onMediaClick(_vm.currentSlide);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) {
          return null;
        }

        return _vm.onMediaClick(_vm.currentSlide);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "right", 39, $event.key, ["Right", "ArrowRight"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 2) {
          return null;
        }

        return _vm.nextSlide.apply(null, arguments);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "left", 37, $event.key, ["Left", "ArrowLeft"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 0) {
          return null;
        }

        return _vm.prevSlide.apply(null, arguments);
      }]
    }
  }, [_c('div', [_c('button', {
    staticClass: "oke-mediaCarousel-button-prev",
    attrs: {
      "disabled": _vm.currentSlide === 0,
      "type": "button",
      "title": "Previous Slide",
      "tabindex": "-1"
    },
    on: {
      "click": _vm.prevSlide
    }
  }), _vm._v(" "), _c('hooper', {
    ref: "okeMediaCarousel",
    staticClass: "oke-mediaCarousel-container",
    attrs: {
      "settings": _vm.carouselOptions,
      "height": 'auto',
      "autoPlay": _vm.mediaCarouselSettings.autoPlay,
      "playSpeed": 1000,
      "role": _vm.$t('group')
    },
    on: {
      "slide": _vm.onSliderSlide
    }
  }, _vm._l(_vm.reviews, function (item, index) {
    return _c('slide', {
      key: item.reviewId,
      staticClass: "oke-mediaCarousel-slide",
      style: {
        'width': _vm.carouselHeight + "px",
        'height': _vm.carouselHeight + "px"
      },
      attrs: {
        "aria-label": _vm.$t('Slide {0}', [index + 1])
      }
    }, [_c('media-thumbnail', {
      attrs: {
        "mediaItem": item,
        "transcodedHeight": _vm.carouselHeight,
        "transcodedWidth": _vm.carouselHeight,
        "linked": true,
        "mediaContext": "aggregate"
      },
      on: {
        "mediaThumbnailClick": function ($event) {
          return _vm.onMediaClick(index);
        }
      }
    }), _vm._v(" "), _vm.widgetSize !== 'small' ? _c('media-overlay', {
      staticClass: "oke-mediaCarousel-slide-overlay",
      attrs: {
        "overlayHeight": _vm.carouselHeight,
        "linkText": _vm.mediaCarouselSettings.linkText,
        "overlayItem": item
      },
      on: {
        "mediaClicked": function ($event) {
          return _vm.onMediaClick(index);
        }
      }
    }) : _vm._e()], 1);
  }), 1), _vm._v(" "), _c('button', {
    staticClass: "oke-mediaCarousel-button-next",
    class: {
      'oke-is-loading': _vm.isLoading
    },
    attrs: {
      "disabled": _vm.isNextArrowDisabled,
      "aria-busy": _vm.isLoading,
      "type": "button",
      "title": _vm.$tc('Next Slide'),
      "tabindex": "-1"
    },
    on: {
      "click": _vm.nextSlide
    }
  })], 1), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("\n            " + _vm._s(_vm.$tc('Customer-uploaded media carousel. Press left and right arrows to navigate. Press space or enter to open more details.')) + "\n        ")]), _vm._v(" "), _c('div', {
    staticClass: "oke-a11yText",
    attrs: {
      "aria-live": "polite"
    }
  }, [_vm._v("\n            " + _vm._s(_vm.$t('Slide {0} selected', [_vm.currentSlide + 1])) + "\n        ")])]) : _vm._e()]);
};

var __vue_staticRenderFns__$11 = [];
/* style */

const __vue_inject_styles__$11 = undefined;
/* scoped */

const __vue_scope_id__$11 = undefined;
/* module identifier */

const __vue_module_identifier__$11 = undefined;
/* functional template */

const __vue_is_functional_template__$11 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$11 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$11,
  staticRenderFns: __vue_staticRenderFns__$11
}, __vue_inject_styles__$11, __vue_script__$11, __vue_scope_id__$11, __vue_is_functional_template__$11, __vue_module_identifier__$11, false, undefined, undefined, undefined);

var SEOUtils = {
  getCrawlablePaginationInfo(nextUrlKey, paginationPageNumKey) {
    if (!window.location.search) {
      return;
    } // Can't use Object.fromEntries to shorthand assign as we're targeting ES2018


    const params = new URLSearchParams(window.location.search);
    const queryParamOkeReviewsNextUrl = params.get(nextUrlKey);
    const queryParamOkeReviewsPageNum = params.get(paginationPageNumKey);

    if (!queryParamOkeReviewsNextUrl || !queryParamOkeReviewsPageNum || isNaN(parseInt(queryParamOkeReviewsPageNum))) {
      return;
    }

    const decodedQueryParam = decodeURIComponent(queryParamOkeReviewsNextUrl);

    if (decodedQueryParam.includes(`${SharedSettings.subscriberId}`) && decodedQueryParam.includes('lastEvaluated')) {
      return {
        nextUrl: decodedQueryParam,
        initialPageNumber: parseInt(queryParamOkeReviewsPageNum)
      };
    }
  }

};

let OkendoWidget$1 = class OkendoWidget extends mixins(WidgetBase$1) {
  constructor() {
    super(...arguments);
    this.reviews = [];
    this.reviewsNextUrl = null;
    this.media = [];
    this.mediaNextUrl = null;
    this.reviewCount = 0;
    this.questionCount = 0;
    this.productAttributes = [];
    this.widgetSearchEngineInitialPageNumber = 1;
    this.activeTab = 'reviews';
    this.tabs = ['reviews'];
    this.questionsState = 'unopened';
    this.viewState = 'loading';
  }

  created() {
    this.widgetMode = OkendoUtils.getWidgetMode(this.productId, this.groupId);

    if (this.reviewsWidgetSettings.tabs.questions && this.widgetMode !== 'all') {
      this.tabs.push('questions');
    }

    this.getCrawlablePaginationInfo();

    if (this.initialData && !this.widgetSearchEngineNextUrl) {
      const {
        reviews,
        reviewsNextUrl,
        reviewAggregate,
        media,
        mediaNextUrl,
        questionCount,
        productAttributes,
        areReviewsGrouped
      } = this.initialData;
      this.reviews = reviews || [];
      this.reviewsNextUrl = reviewsNextUrl !== null && reviewsNextUrl !== void 0 ? reviewsNextUrl : null;
      this.reviewAggregate = reviewAggregate;
      this.media = media;
      this.mediaNextUrl = mediaNextUrl !== null && mediaNextUrl !== void 0 ? mediaNextUrl : null;
      this.reviewCount = (reviewAggregate === null || reviewAggregate === void 0 ? void 0 : reviewAggregate.ratingAndReviewCount) || 0;
      this.questionCount = questionCount || 0;
      this.productAttributes = productAttributes || [];
      this.widgetMode = areReviewsGrouped ? 'group' : this.widgetMode;
      this.setSharedProductName();
      this.viewState = this.reviewCount || this.questionCount ? 'content' : 'empty';
    } else {
      this.loadWidgetData();
    }
  }

  mounted() {
    if (this.initialData) {
      this.sendWidgetRenderedEvent();
    }
  }

  sendWidgetRenderedEvent() {
    this.$nextTick(() => {
      OkendoUtils.sendWidgetRenderedEvent('reviews-widget', this.widgetId);
    });
  }

  get showOkendoWidget() {
    return this.viewState === 'content' || this.viewState === 'empty' && this.showWhenEmpty;
  }

  get okendoBrandingEnabled() {
    return !SharedSettings.widgetSettings.global.hideOkendoBranding;
  }

  get reviewsWidgetSettings() {
    return SharedSettings.widgetSettings.reviewsWidget;
  }

  get showWhenEmpty() {
    return this.reviewsWidgetSettings.showWhenEmpty;
  }

  get questionsEnabled() {
    return this.reviewsWidgetSettings.tabs.questions;
  }

  get metafieldJsonData() {
    var _a, _b;

    if (this.widgetMode !== 'all') {
      const initialData = {
        reviews: this.reviews,
        reviewsNextUrl: (_a = this.reviewsNextUrl) !== null && _a !== void 0 ? _a : undefined,
        areReviewsGrouped: this.widgetMode === 'group',
        media: this.media,
        mediaNextUrl: (_b = this.mediaNextUrl) !== null && _b !== void 0 ? _b : undefined,
        reviewAggregate: this.reviewAggregate,
        questionCount: this.questionCount,
        productAttributes: this.productAttributes
      };
      return JSON.stringify(initialData);
    }
  }

  get allowSearchEnginePagination() {
    var _a;

    return !this.disableSearchEnginePagination && !!((_a = SharedSettings.widgetSettings.global) === null || _a === void 0 ? void 0 : _a.searchEnginePaginationEnabled);
  }

  onTabChange(newTab) {
    if (newTab === 'questions' && this.questionsState === 'unopened') {
      this.questionsState = this.questionCount ? 'loading' : 'loaded';
    }

    this.activeTab = newTab;
  }

  onQuestionsLoaded() {
    this.questionsState = 'loaded';
  }

  async loadWidgetData() {
    var _a, _b, _c, _d, _e;

    this.viewState = 'loading';
    const imagesToLoad = this.headerImagesToLoad();
    const loadReviewAggregate = this.loadReviewAggregate();
    const loadMediaAggregate = imagesToLoad ? this.loadMediaAggregate(imagesToLoad) : Promise.resolve(undefined);
    const loadReviews = this.widgetSearchEngineNextUrl ? OkendoApi.getMore(this.widgetSearchEngineNextUrl) : this.loadReviews(this.reviewsWidgetSettings.reviews.list.initialPageSize || 5, this.reviewsWidgetSettings.reviews.controls.defaultSort);
    const questionAggregate = this.questionsEnabled ? this.loadQuestionAggregate() : Promise.resolve(undefined);
    const filterMode = this.reviewsWidgetSettings.reviews.controls.filterMode;
    const productAttributes = this.widgetMode === 'product' && (filterMode === 'open' || filterMode === 'open-always') ? OkendoApi.getFiltersProduct(this.productId) : Promise.resolve(undefined);

    try {
      const [reviewResponse, aggregateResponse, mediaResponse, questionResponse, productAttributesResponse] = await Promise.all([loadReviews, loadReviewAggregate, loadMediaAggregate, questionAggregate, productAttributes]);
      this.reviews = reviewResponse.reviews;
      this.reviewsNextUrl = (_a = reviewResponse === null || reviewResponse === void 0 ? void 0 : reviewResponse.nextUrl) !== null && _a !== void 0 ? _a : null;
      this.media = (_b = mediaResponse === null || mediaResponse === void 0 ? void 0 : mediaResponse.media) !== null && _b !== void 0 ? _b : [];
      this.mediaNextUrl = (_c = mediaResponse === null || mediaResponse === void 0 ? void 0 : mediaResponse.nextUrl) !== null && _c !== void 0 ? _c : null;
      this.reviewAggregate = aggregateResponse.reviewAggregate;
      this.reviewCount = this.reviewAggregate.ratingAndReviewCount;
      this.questionCount = (_d = questionResponse === null || questionResponse === void 0 ? void 0 : questionResponse.questionAggregate.approvedQuestionCount) !== null && _d !== void 0 ? _d : 0;
      this.productAttributes = (_e = productAttributesResponse === null || productAttributesResponse === void 0 ? void 0 : productAttributesResponse.productAttributes) !== null && _e !== void 0 ? _e : [];
      this.widgetMode = 'areReviewsGrouped' in reviewResponse && reviewResponse.areReviewsGrouped ? 'group' : this.widgetMode;
      this.viewState = this.reviewCount || this.questionCount ? 'content' : 'empty';
      this.setSharedProductName();
    } catch (_f) {
      this.viewState = 'error';
    } finally {
      this.sendWidgetRenderedEvent();
    }
  }

  getCrawlablePaginationInfo() {
    this.widgetSearchEngineNextUrl = undefined;

    if (this.allowSearchEnginePagination && SharedSettings.widgetSettings.reviewsWidget.reviews.list.layout.name !== 'carousel') {
      const {
        nextUrl: widgetSearchEngineNextUrl,
        initialPageNumber: widgetInitialPageNum
      } = SEOUtils.getCrawlablePaginationInfo('okeReviewsNextUrl', 'okeReviewsPageNum') || {};

      if (widgetSearchEngineNextUrl && widgetInitialPageNum) {
        this.widgetSearchEngineNextUrl = widgetSearchEngineNextUrl;
        this.widgetSearchEngineInitialPageNumber = widgetInitialPageNum;
      }
    }
  }

  loadQuestionAggregate() {
    switch (this.widgetMode) {
      case 'product':
        return OkendoApi.getQuestionAggregateProduct(this.productId);

      case 'group':
        return OkendoApi.getQuestionsAggregateCollection(this.groupId);

      default:
        return Promise.resolve(undefined);
    }
  }

  async loadReviewAggregate() {
    switch (this.widgetMode) {
      case 'product':
        return await OkendoApi.getReviewAggregateProduct(this.productId);

      case 'group':
        return await OkendoApi.getReviewAggregateGroup(this.groupId);

      default:
        return await OkendoApi.getReviewAggregateAll();
    }
  }

  loadReviews(limit, sort) {
    return OkendoApi.getReviews(this.productId, this.groupId, limit, sort);
  }

  loadMediaAggregate(limit) {
    switch (this.widgetMode) {
      case 'product':
        return OkendoApi.getMediaProduct(this.productId, limit);

      case 'group':
        return OkendoApi.getMediaGroup(this.groupId, limit);

      default:
        return OkendoApi.getMediaAll(limit);
    }
  }

  setSharedProductName() {
    var _a;

    SharedSettings.productLabel = this.widgetMode === 'all' ? this.$tc('All Products') : (_a = this.reviewAggregate) === null || _a === void 0 ? void 0 : _a.productName;
  }

  headerImagesToLoad() {
    return OkendoUtils.getHeaderImagesCountToLoad(this.reviewsWidgetSettings.header.blocks);
  }

};

__decorate([Prop()], OkendoWidget$1.prototype, "groupId", void 0);

__decorate([Prop()], OkendoWidget$1.prototype, "productId", void 0);

__decorate([Prop()], OkendoWidget$1.prototype, "writeReviewProductId", void 0);

__decorate([Prop()], OkendoWidget$1.prototype, "askQuestionProductId", void 0);

__decorate([Prop()], OkendoWidget$1.prototype, "locale", void 0);

__decorate([Prop()], OkendoWidget$1.prototype, "initialData", void 0);

__decorate([Prop({
  default: () => false
})], OkendoWidget$1.prototype, "disableSearchEnginePagination", void 0);

OkendoWidget$1 = __decorate([Component({
  components: {
    Reviews: async () => (await Promise.resolve().then(function () { return Reviews; })).default,
    WidgetNavBar: async () => (await Promise.resolve().then(function () { return WidgetNavBar; })).default,
    WidgetHeader: async () => (await Promise.resolve().then(function () { return WidgetHeader; })).default,
    PoweredBy: async () => (await Promise.resolve().then(function () { return PoweredBy; })).default,
    State: async () => (await Promise.resolve().then(function () { return State; })).default,
    Questions: async () => (await Promise.resolve().then(function () { return Questions; })).default
  }
})], OkendoWidget$1);
var script$Z = OkendoWidget$1;

/* script */
const __vue_script__$10 = script$Z;
/* template */

var __vue_render__$10 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    directives: [{
      name: "onScreenTracking",
      rawName: "v-onScreenTracking",
      value: {
        widgetType: 'Reviews Widget',
        widgetId: _vm.widgetId,
        rootMargin: '-30% 0% -40% 0%'
      },
      expression: "{ widgetType: 'Reviews Widget', widgetId, rootMargin: '-30% 0% -40% 0%' }"
    }],
    staticClass: "okeReviews oke-w",
    attrs: {
      "data-oke-reviews-version": _vm.version,
      "data-oke-container": ""
    }
  }, [_c('div', {
    ref: "okendoWidget",
    staticClass: "js-oke-widgetSize",
    class: {
      'oke-is-small': _vm.widgetSize === 'small',
      'oke-is-medium': _vm.widgetSize === 'medium',
      'oke-is-large': _vm.widgetSize === 'large'
    }
  }, [_vm.showOkendoWidget ? [_vm.reviewAggregate && _vm.reviewCount && _vm.viewState !== 'empty' ? _c('widget-header', {
    attrs: {
      "reviewAggregate": _vm.reviewAggregate,
      "media": _vm.media,
      "mediaNextUrl": _vm.mediaNextUrl,
      "widgetMode": _vm.widgetMode
    }
  }) : _vm._e(), _vm._v(" "), _vm.tabs.length > 1 || _vm.okendoBrandingEnabled ? _c('div', {
    staticClass: "oke-w-controls"
  }, [_c('div', {
    staticClass: "oke-w-controls-nav"
  }, [_vm.tabs.length > 1 ? _c('widget-nav-bar', {
    attrs: {
      "activeTab": _vm.activeTab,
      "tabs": _vm.tabs,
      "reviewCount": _vm.reviewCount,
      "questionCount": _vm.questionCount,
      "widgetId": _vm.widgetId
    },
    on: {
      "tabChange": function ($event) {
        return _vm.onTabChange($event);
      }
    }
  }) : _vm._e(), _vm._v(" "), _vm.okendoBrandingEnabled ? _c('powered-by') : _vm._e()], 1)]) : _vm._e(), _vm._v(" "), _vm._l(_vm.tabs, function (tab) {
    return _c('div', {
      key: tab,
      staticClass: "oke-w-main"
    }, [_c('div', {
      staticClass: "oke-w-panel",
      attrs: {
        "hidden": _vm.activeTab !== tab,
        "id": tab + "-panel-" + _vm.widgetId,
        "aria-labelledby": _vm.questionsEnabled ? tab + "-tab-" + _vm.widgetId : undefined,
        "role": "tabpanel"
      }
    }, [tab === 'reviews' ? _c('div', {
      staticClass: "oke-w-reviewsTab"
    }, [_c('reviews', {
      attrs: {
        "allowSearchEnginePagination": _vm.allowSearchEnginePagination,
        "groupId": _vm.groupId,
        "hasInitialSearchEnginePaginationUrl": !!_vm.widgetSearchEngineNextUrl,
        "initialNextUrl": _vm.reviewsNextUrl,
        "initialPageNumber": _vm.widgetSearchEngineInitialPageNumber,
        "initialReviewCount": _vm.reviewCount,
        "initialReviews": _vm.reviews,
        "productAttributes": _vm.productAttributes,
        "productId": _vm.productId,
        "widgetId": _vm.widgetId,
        "widgetMode": _vm.widgetMode,
        "widgetSize": _vm.widgetSize,
        "widgetWidth": _vm.widgetWidth,
        "writeReviewProductId": _vm.writeReviewProductId
      }
    })], 1) : _vm._e(), _vm._v(" "), _vm.questionsEnabled && tab === 'questions' && _vm.questionsState !== 'unopened' ? _c('div', {
      staticClass: "oke-w-questionsTab"
    }, [_c('questions', {
      attrs: {
        "hidden": _vm.questionsState === 'loading',
        "productId": _vm.productId,
        "groupId": _vm.groupId,
        "askQuestionProductId": _vm.askQuestionProductId,
        "showStateTopBorderOnEmpty": false
      },
      on: {
        "load": function ($event) {
          return _vm.onQuestionsLoaded();
        }
      }
    }), _vm._v(" "), _c('div', {
      staticClass: "oke-w-questions-loading"
    }, [_vm.questionsState === 'loading' ? _c('state', {
      attrs: {
        "state": "loading",
        "contentType": "questions"
      }
    }) : _vm._e()], 1)], 1) : _vm._e()])]);
  })] : _vm.viewState !== 'empty' ? _c('state', {
    attrs: {
      "state": _vm.viewState,
      "productId": _vm.productId,
      "contentType": "reviews"
    },
    on: {
      "retry": function ($event) {
        return _vm.loadWidgetData();
      }
    }
  }) : _vm._e()], 2), _vm._v(" "), _vm.metafieldJsonData ? _c('script', {
    attrs: {
      "type": "application/json",
      "data-oke-metafield-data": ""
    }
  }, [_vm._v("\n        " + _vm._s(_vm.metafieldJsonData) + "\n    ")]) : _vm._e()]);
};

var __vue_staticRenderFns__$10 = [];
/* style */

const __vue_inject_styles__$10 = undefined;
/* scoped */

const __vue_scope_id__$10 = undefined;
/* module identifier */

const __vue_module_identifier__$10 = undefined;
/* functional template */

const __vue_is_functional_template__$10 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$10 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$10,
  staticRenderFns: __vue_staticRenderFns__$10
}, __vue_inject_styles__$10, __vue_script__$10, __vue_scope_id__$10, __vue_is_functional_template__$10, __vue_module_identifier__$10, false, undefined, undefined, undefined);

var OkendoWidget = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$10
});

const starSymbolsId = 'oke-star-symbols';
const cssVariablesId = 'oke-css-vars';
const customCssId = 'oke-reviews-custom-css';

function getCssVariablesSnippet(widgetSettings) {
  var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m, _o, _p, _q, _r, _s, _t, _u, _v, _w, _x, _y, _z, _0, _1, _2, _3, _4, _5, _6, _7, _8, _9, _10, _11, _12;

  if (!widgetSettings.reviewsWidget) {
    widgetSettings.reviewsWidget = { ...defaultSettings.reviewsWidget
    };
  }

  if (!widgetSettings.starRatings) {
    widgetSettings.starRatings = { ...defaultSettings.starRatings
    };
  }

  const widgetStyles = widgetSettings.reviewsWidget.style;
  const starRatingStyles = widgetSettings.starRatings.style;
  return `<style id="${cssVariablesId}">
        :root {
            --oke-widget-spaceAbove: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.spaceAbove) || 0};
            --oke-widget-spaceBelow: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.spaceBelow) || 0};
            --oke-starRating-spaceAbove: ${OkendoUtils.getCombinedUnitMeasure(starRatingStyles.spaceAbove) || 0};
            --oke-starRating-spaceBelow: ${OkendoUtils.getCombinedUnitMeasure(starRatingStyles.spaceBelow) || 0};

            --oke-button-backgroundColor: ${widgetStyles.button.backgroundColor};
            --oke-button-backgroundColorHover: ${widgetStyles.button.backgroundColorHover};
            --oke-button-backgroundColorActive: ${widgetStyles.button.backgroundColorActive};
            --oke-button-textColor: ${widgetStyles.button.textColor};
            --oke-button-textColorHover: ${widgetStyles.button.textColorHover};
            --oke-button-textColorActive: ${widgetStyles.button.textColorActive};
            --oke-button-borderColor: ${widgetStyles.button.borderColor};
            --oke-button-borderColorHover: ${widgetStyles.button.borderColorHover};
            --oke-button-borderColorActive: ${widgetStyles.button.borderColorActive};
            --oke-button-borderRadius: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.button.borderRadius)};
            --oke-button-borderWidth: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.button.borderWidth)};

            --oke-border-color: ${widgetStyles.border.color};
            --oke-border-width: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.border.width)};

            --oke-text-primaryColor: ${widgetStyles.text.primaryColor};
            --oke-text-secondaryColor: ${widgetStyles.text.secondaryColor};
            --oke-text-small: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.text.fontSizeSmall)};
            --oke-text-regular: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.text.fontSizeRegular)};
            --oke-text-large: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.text.fontSizeLarge)};

            --oke-avatar-size: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.avatar.size)};
            --oke-avatar-backgroundColor: ${widgetStyles.avatar.backgroundColor};
            --oke-avatar-placeholderTextColor: ${widgetStyles.avatar.placeholderTextColor};

            --oke-highlightColor: ${widgetStyles.highlightColor};
            --oke-shadingColor: ${widgetStyles.shadingColor};
            --oke-productImageSize: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.productImageSize)};

            --oke-attributeBar-shadingColor: ${widgetStyles.attributeBar.shadingColor};
            --oke-attributeBar-borderColor: ${widgetStyles.attributeBar.borderColor};
            --oke-attributeBar-backgroundColor: ${widgetStyles.attributeBar.backgroundColor};
            --oke-attributeBar-markerColor: ${widgetStyles.attributeBar.markerColor};

            --oke-filter-backgroundColor: ${widgetStyles.filters.backgroundColor};
            --oke-filter-backgroundColorActive: ${widgetStyles.filters.backgroundColorActive};
            --oke-filter-borderColor: ${widgetStyles.filters.borderColor};
            --oke-filter-borderColorActive: ${widgetStyles.filters.borderColorActive};
            --oke-filter-textColor: ${widgetStyles.filters.textColor};
            --oke-filter-textColorActive: ${widgetStyles.filters.textColorActive};
            --oke-filter-borderRadius: ${OkendoUtils.getCombinedUnitMeasure(widgetStyles.filters.borderRadius)};
            --oke-filter-searchHighlightColor: ${widgetStyles.filters.searchHighlightColor};

            --oke-mediaGrid-chevronColor: ${((_b = (_a = widgetSettings.mediaGrid) === null || _a === void 0 ? void 0 : _a.showMoreArrow) === null || _b === void 0 ? void 0 : _b.arrowColor) ? (_c = defaultSettings.mediaGrid.showMoreArrow) === null || _c === void 0 ? void 0 : _c.arrowColor : ''};
            --oke-stars-foregroundColor: ${(_f = (_e = (_d = widgetSettings.global) === null || _d === void 0 ? void 0 : _d.stars) === null || _e === void 0 ? void 0 : _e.foregroundColor) !== null && _f !== void 0 ? _f : kDefaultStarForegroundColor};
            --oke-stars-backgroundColor: ${(_j = (_h = (_g = widgetSettings.global) === null || _g === void 0 ? void 0 : _g.stars) === null || _h === void 0 ? void 0 : _h.backgroundColor) !== null && _j !== void 0 ? _j : kDefaultStarBackgroundColor};
            ${((_l = (_k = widgetSettings.global) === null || _k === void 0 ? void 0 : _k.stars) === null || _l === void 0 ? void 0 : _l.showBorder) ? `--oke-stars-borderWidth: 1; --oke-stars-borderColor: ${widgetSettings.global.stars.borderColor};` : '--oke-stars-borderWidth: 0;'}
        }
        ${((_m = widgetSettings.homepageCarousel) === null || _m === void 0 ? void 0 : _m.style.stars.globalOverrideSettings) ? `.oke-reviewCarousel {
            --oke-stars-foregroundColor: ${(_q = (_p = (_o = widgetSettings.homepageCarousel) === null || _o === void 0 ? void 0 : _o.style.stars.globalOverrideSettings) === null || _p === void 0 ? void 0 : _p.foregroundColor) !== null && _q !== void 0 ? _q : kDefaultStarForegroundColor};
            --oke-stars-backgroundColor: ${(_s = (_r = widgetSettings.homepageCarousel) === null || _r === void 0 ? void 0 : _r.style.stars.globalOverrideSettings) === null || _s === void 0 ? void 0 : _s.backgroundColor};
            ${((_u = (_t = widgetSettings.homepageCarousel) === null || _t === void 0 ? void 0 : _t.style.stars.globalOverrideSettings) === null || _u === void 0 ? void 0 : _u.showBorder) ? `--oke-stars-borderWidth: 1; --oke-stars-borderColor: ${(_w = (_v = widgetSettings.homepageCarousel) === null || _v === void 0 ? void 0 : _v.style.stars.globalOverrideSettings) === null || _w === void 0 ? void 0 : _w.borderColor};` : '--oke-stars-borderWidth: 0;'}
        }` : ''}
        ${((_x = widgetSettings.reviewsWidget) === null || _x === void 0 ? void 0 : _x.style.stars.globalOverrideSettings) ? `.oke-w, .oke-modal {
            --oke-stars-foregroundColor: ${(_z = (_y = widgetSettings.reviewsWidget.style.stars.globalOverrideSettings) === null || _y === void 0 ? void 0 : _y.foregroundColor) !== null && _z !== void 0 ? _z : kDefaultStarForegroundColor};
            --oke-stars-backgroundColor: ${(_0 = widgetSettings.reviewsWidget.style.stars.globalOverrideSettings) === null || _0 === void 0 ? void 0 : _0.backgroundColor};
            ${((_2 = (_1 = widgetSettings.reviewsWidget) === null || _1 === void 0 ? void 0 : _1.style.stars.globalOverrideSettings) === null || _2 === void 0 ? void 0 : _2.showBorder) ? `--oke-stars-borderWidth: 1; --oke-stars-borderColor: ${(_4 = (_3 = widgetSettings.reviewsWidget) === null || _3 === void 0 ? void 0 : _3.style.stars.globalOverrideSettings) === null || _4 === void 0 ? void 0 : _4.borderColor};` : '--oke-stars-borderWidth: 0;'}
        }` : ''}
        ${((_5 = widgetSettings.starRatings) === null || _5 === void 0 ? void 0 : _5.style.globalOverrideSettings) ? `.oke-sr {
            --oke-stars-foregroundColor: ${(_7 = (_6 = widgetSettings.starRatings.style.globalOverrideSettings) === null || _6 === void 0 ? void 0 : _6.foregroundColor) !== null && _7 !== void 0 ? _7 : kDefaultStarForegroundColor};
            --oke-stars-backgroundColor: ${(_8 = widgetSettings.starRatings.style.globalOverrideSettings) === null || _8 === void 0 ? void 0 : _8.backgroundColor};
            ${((_10 = (_9 = widgetSettings.starRatings) === null || _9 === void 0 ? void 0 : _9.style.globalOverrideSettings) === null || _10 === void 0 ? void 0 : _10.showBorder) ? `--oke-stars-borderWidth: 1; --oke-stars-borderColor: ${(_12 = (_11 = widgetSettings.starRatings) === null || _11 === void 0 ? void 0 : _11.style.globalOverrideSettings) === null || _12 === void 0 ? void 0 : _12.borderColor};` : '--oke-stars-borderWidth: 0;'}
        }` : ''}
    </style>`;
}

function getHeaderContent(subscriber, widgetSettings, starSvgString) {
  var _a;

  const customCss = getCustomCss(widgetSettings.customCss);
  delete widgetSettings.customCss;
  return {
    reviewsHeaderConfig: getReviewsHeaderConfig(subscriber, widgetSettings),
    cssVariables: getCssVariablesSnippet(widgetSettings),
    starSymbols: getStarSymbolSnippet((_a = widgetSettings.global) === null || _a === void 0 ? void 0 : _a.stars.shape, starSvgString),
    customCss
  };
}

function getStarSymbolSnippet(starShape = kDefaultStarShape, starSvgString) {
  if (starShape.type === 'custom') {
    return starSvgString ? getCustomStarSymbolSnippet(starShape, starSvgString) : getStandardStarSymbolSnippet(kDefaultStarShape);
  }

  return getStandardStarSymbolSnippet(starShape);
}

function getCustomCss(css) {
  if (css) {
    return `<style id="${customCssId}">${css}</style>`;
  }
}

function getReviewsHeaderConfig(subscriber, widgetSettings) {
  const {
    analyticsSettings,
    features,
    locale,
    localeAndVariant,
    matchCustomerLocale,
    isTestModeEnabled
  } = subscriber;
  return {
    subscriberId: subscriber.subscriberId,
    analyticsSettings,
    isTestModeEnabled: isTestModeEnabled || undefined,
    locale,
    localeAndVariant,
    matchCustomerLocale,
    widgetSettings,
    ...getWidgetPlusFeatures(features)
  };
}

function getCustomStarSymbolSnippet(starShape, starSvgString) {
  const viewBoxRemovedSvgString = starSvgString.replace(/ viewBox="([^"]+)"/, '');
  const filledStarSvg = starShape.useAssetColors ? viewBoxRemovedSvgString : replaceSvgFillAttributes(viewBoxRemovedSvgString, 'var(--oke-stars-foregroundColor)');
  const emptyStarSvg = replaceSvgFillAttributes(viewBoxRemovedSvgString, 'var(--oke-stars-backgroundColor)');
  return mapStarSvgToSymbolSnippet(emptyStarSvg, filledStarSvg);
}

function getStandardStarSymbolSnippet(starShape) {
  let emptyStarSvg = '<path id="star-default--empty" fill="var(--oke-stars-backgroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M3.34 13.86c-.48.3-.76.1-.63-.44l1.08-4.56L.26 5.82c-.42-.36-.32-.7.24-.74l4.63-.37L6.92.39c.2-.52.55-.52.76 0l1.8 4.32 4.62.37c.56.05.67.37.24.74l-3.53 3.04 1.08 4.56c.13.54-.14.74-.63.44L7.3 11.43l-3.96 2.43z"/>';
  let filledStarSvg = '<path id="star-default--filled" fill="var(--oke-stars-foregroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M3.34 13.86c-.48.3-.76.1-.63-.44l1.08-4.56L.26 5.82c-.42-.36-.32-.7.24-.74l4.63-.37L6.92.39c.2-.52.55-.52.76 0l1.8 4.32 4.62.37c.56.05.67.37.24.74l-3.53 3.04 1.08 4.56c.13.54-.14.74-.63.44L7.3 11.43l-3.96 2.43z"/>';

  switch (starShape.type) {
    case 'circle':
      emptyStarSvg = '<circle id="star-circle--empty" fill="var(--oke-stars-backgroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" cx="6" cy="6" r="6" />';
      filledStarSvg = '<circle id="star-circle--filled" fill="var(--oke-stars-foregroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" cx="6" cy="6" r="6" />';
      break;

    case 'heart':
      emptyStarSvg = '<path id="star-heart--empty" fill="var(--oke-stars-backgroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M8 14.68L6.84 13.624C2.72 9.888 0 7.424 0 4.4C0 1.936 1.936 0 4.4 0C5.792 0 7.128 0.648 8 1.672C8.872 0.648 10.208 0 11.6 0C14.064 0 16 1.936 16 4.4C16 7.424 13.28 9.888 9.16 13.632L8 14.68Z"/>';
      filledStarSvg = '<path id="star-heart--filled" fill="var(--oke-stars-foregroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M8 14.68L6.84 13.624C2.72 9.888 0 7.424 0 4.4C0 1.936 1.936 0 4.4 0C5.792 0 7.128 0.648 8 1.672C8.872 0.648 10.208 0 11.6 0C14.064 0 16 1.936 16 4.4C16 7.424 13.28 9.888 9.16 13.632L8 14.68Z"/>';
      break;

    case 'thin':
      emptyStarSvg = '<path id="star-thin--empty" fill="var(--oke-stars-backgroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M9.944 6.4L8 0L6.056 6.4H0L4.944 9.928L3.064 16L8 12.248L12.944 16L11.064 9.928L16 6.4H9.944Z"/>';
      filledStarSvg = '<path id="star-thin--filled" fill="var(--oke-stars-foregroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M9.944 6.4L8 0L6.056 6.4H0L4.944 9.928L3.064 16L8 12.248L12.944 16L11.064 9.928L16 6.4H9.944Z"/>';
      break;

    case 'rounded':
      emptyStarSvg = '<path id="star-rounded--empty" fill="var(--oke-stars-backgroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M16.6744 7.11837C16.9845 6.8136 17.0731 6.45442 16.9402 6.04082C16.8073 5.62721 16.5193 5.38776 16.0762 5.32245L11.4906 4.66939L9.46364 0.587755C9.26427 0.195916 8.94306 0 8.5 0C8.05694 0 7.73573 0.195916 7.53636 0.587755L5.50938 4.66939L0.923769 5.32245C0.480712 5.38776 0.19273 5.62721 0.0598129 6.04082C-0.0731041 6.45442 0.0155059 6.8136 0.325646 7.11837L3.64855 10.2857L2.85106 14.7918C2.7846 15.2054 2.92859 15.5429 3.28303 15.8041C3.46026 15.9347 3.67071 16 3.91439 16C4.09161 16 4.25775 15.9565 4.41282 15.8694L8.5 13.7469L12.5872 15.8694C12.7422 15.9565 12.9084 16 13.0856 16C13.3293 16 13.5397 15.9347 13.717 15.8041C14.0714 15.5429 14.2154 15.2054 14.1489 14.7918L13.3514 10.2857L16.6744 7.11837Z"/>';
      filledStarSvg = '<path id="star-rounded--filled" fill="var(--oke-stars-foregroundColor)" stroke="var(--oke-stars-borderColor)" stroke-width="var(--oke-stars-borderWidth)" d="M16.6744 7.11837C16.9845 6.8136 17.0731 6.45442 16.9402 6.04082C16.8073 5.62721 16.5193 5.38776 16.0762 5.32245L11.4906 4.66939L9.46364 0.587755C9.26427 0.195916 8.94306 0 8.5 0C8.05694 0 7.73573 0.195916 7.53636 0.587755L5.50938 4.66939L0.923769 5.32245C0.480712 5.38776 0.19273 5.62721 0.0598129 6.04082C-0.0731041 6.45442 0.0155059 6.8136 0.325646 7.11837L3.64855 10.2857L2.85106 14.7918C2.7846 15.2054 2.92859 15.5429 3.28303 15.8041C3.46026 15.9347 3.67071 16 3.91439 16C4.09161 16 4.25775 15.9565 4.41282 15.8694L8.5 13.7469L12.5872 15.8694C12.7422 15.9565 12.9084 16 13.0856 16C13.3293 16 13.5397 15.9347 13.717 15.8041C14.0714 15.5429 14.2154 15.2054 14.1489 14.7918L13.3514 10.2857L16.6744 7.11837Z"/>';
      break;
  }

  return mapStarSvgToSymbolSnippet(emptyStarSvg, filledStarSvg);
}

function replaceSvgFillAttributes(starSvg, replaceValue) {
  let result = starSvg;

  if (/fill/.test(result)) {
    result = result.replace(/fill="\S*"/g, `fill="${replaceValue}"`).replace(/fill:\S+;*/g, `fill:${replaceValue};`);
  }

  return result;
}

function mapStarSvgToSymbolSnippet(emptyStarSvg, filledStarSvg) {
  return `<svg id="${starSymbolsId}" style="display:none!important" data-oke-id="${starSymbolsId}"><symbol id="oke-star-empty" style="overflow:visible;">${emptyStarSvg}</symbol><symbol id="oke-star-filled" style="overflow:visible;">${filledStarSvg}</symbol></svg>`;
}

function getWidgetPlusFeatures(features) {
  const recorderPlusEnabled = (features === null || features === void 0 ? void 0 : features.recorderPlus) ? {
    recorderPlusEnabled: true
  } : {};
  const recorderQandaPlusEnabled = (features === null || features === void 0 ? void 0 : features.recorderQandaPlus) ? {
    recorderQandaPlusEnabled: true
  } : {};
  const attributeFiltersEnabled = (features === null || features === void 0 ? void 0 : features.widgetFilters) ? {
    attributeFiltersEnabled: true
  } : {};
  return (features === null || features === void 0 ? void 0 : features.recorderPlus) || (features === null || features === void 0 ? void 0 : features.widgetFilters) ? {
    features: { ...recorderPlusEnabled,
      ...recorderQandaPlusEnabled,
      ...attributeFiltersEnabled
    }
  } : {};
}

var HeaderSettingsService = {
  cssVariablesId,
  customCssId,
  starSymbolsId,
  getCssVariablesSnippet,
  getCustomStarSymbolSnippet,
  getHeaderContent,
  getReviewsHeaderConfig,
  getStandardStarSymbolSnippet,
  getWidgetPlusFeatures
};

function getCustomerLocaleFromShopify(options) {
  var _a;

  if (options === null || options === void 0 ? void 0 : options.matchCustomerLocale) {
    return translationsCommon.getLocale((_a = window.Shopify) === null || _a === void 0 ? void 0 : _a.locale);
  }
}

var CypressLazyLoadDirective = {
  inserted: (imageElement, binding) => {
    if ((imageElement === null || imageElement === void 0 ? void 0 : imageElement.nodeName) === 'IMG') {
      imageElement.src = binding.value;
    }
  }
};

// v-ga:[click|change]="{ action: 'string', label: 'string' }"

var GoogleAnalyticsDirective = {
  inserted: (element, binding) => {
    var _a;

    if (!binding.value) {
      return;
    }

    const eventType = (_a = binding.arg) !== null && _a !== void 0 ? _a : 'click';
    const message = binding.value;
    const action = message.action;
    const label = message.label;
    const value = message.value;
    const eventParameters = message.eventParameters;
    AnalyticsUtils.bindGAEventToElement(element, eventType, action, label, value, eventParameters);
  }
};

var img$3 = "data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' width='130' height='160' viewBox='-52 -63 130 160'%3e %3cpath d='M26 30v2H16v-2h8v-8h2v8zM2 32H0V0h18v2h2v2h-2v4h4V6h2v2h2v8h-2v-6h-8V2H2v28h8v2H2zM20 4h2v2h-2V4z' fill='%23D3D4DD'/%3e %3cpath d='M24 18h-2v2h-2v2h-2v2h-2v2h-2v2h-2v2H4V4h10v8h10v6zm0 6v6h-6v-2h2v-2h2v-2h2z' fill='%23E5E5EB'/%3e%3c/svg%3e";

class LazySrcElementState {
  constructor(imageElement, imageSrc) {
    this.imageElement = imageElement;
    this.imageSrc = imageSrc;
    this.isLoaded = false;
    this.onImageErrorFunc = this.onImageError.bind(this);
    this.showImageFunc = this.showImage.bind(this);
    this.hideImage();
    this.createObserver();
  }

  debounceValueUpdate(imageSrc) {
    if (this.timer) {
      clearTimeout(this.timer);
    }

    this.timer = window.setTimeout(() => {
      this.imageSrc = imageSrc; // If image was previously loaded we need to re-load it in with the new url.

      if (this.isLoaded) {
        this.loadImage();
      }

      this.timer = undefined;
    }, 200);
  }

  hideImage() {
    this.imageElement.style.opacity = '0';
    this.imageElement.style.transition = 'all 0.1s ease-out';
  }

  showImage() {
    this.imageElement.style.opacity = '1';
    this.removeEventListeners();
  }

  onImageError() {
    this.imageElement.src = img$3;
    this.imageElement.classList.add('oke-is-error');
  }

  loadImage() {
    const imageSrc = this.imageSrc;
    this.imageElement.addEventListener('load', this.showImageFunc);
    this.imageElement.addEventListener('error', this.onImageErrorFunc);

    if (imageSrc) {
      this.imageElement.src = imageSrc;
    } else {
      this.onImageError();
    }

    this.isLoaded = true;
  }

  removeEventListeners() {
    this.imageElement.removeEventListener('load', this.showImageFunc);
    this.imageElement.removeEventListener('error', this.onImageErrorFunc);
  }

  createObserver() {
    const observer = new IntersectionObserver((entries, observer) => {
      for (const entry of entries) {
        if (entry.isIntersecting) {
          this.loadImage();
          observer.disconnect();
        }
      }
    });
    observer.observe(this.imageElement);
  }

}

var LazyLoadDirective = (() => {
  const directiveState = new WeakMap();
  return {
    inserted: (imageElement, binding) => {
      if ((imageElement === null || imageElement === void 0 ? void 0 : imageElement.nodeName) === 'IMG') {
        const state = new LazySrcElementState(imageElement, binding.value);
        directiveState.set(imageElement, state);
      }
    },
    componentUpdated: (element, binding) => {
      const state = directiveState.get(element);

      if (!state) {
        return;
      }

      if (binding.oldValue !== binding.value && binding.value) {
        state.debounceValueUpdate(binding.value);
      }
    }
  };
})();

// This sets the image element opacity to 0 which will hide the alt text
// Because we don't use the directive binding value, the url is never set in the img tag
// This means the browser won't load an image when the metafield is rendered on the merchant's store
var MetafieldsLazyLoadDirective = {
  inserted: imageElement => {
    if ((imageElement === null || imageElement === void 0 ? void 0 : imageElement.nodeName) === 'IMG') {
      imageElement.style.opacity = '0';
    }
  }
};

var NoOpDirective = {
  // eslint-disable-next-line @typescript-eslint/no-unused-vars
  inserted: (element, binding) => {// Do Nothing
  }
};

class OnScreenTracker {
  constructor() {
    this.trackableWidgets = new Map();
    this.kTimerIntervalMilliseconds = 5000;
    document.addEventListener('visibilitychange', this.handleVisibilityChange.bind(this), false);
  }

  createObserver(widgetElement, trackableWidget) {
    if (!widgetElement || !trackableWidget.widgetId || !trackableWidget.widgetType) {
      return;
    }

    const observerOptions = {
      root: null,
      rootMargin: trackableWidget.rootMargin,
      threshold: trackableWidget.threshold ? [trackableWidget.threshold] : undefined
    };
    const intersectionObserver = new IntersectionObserver(this.intersectionCallback.bind(this), observerOptions);
    intersectionObserver.observe(widgetElement);
    trackableWidget.observer = intersectionObserver;
    this.trackableWidgets.set(widgetElement, trackableWidget);
  }

  destroyObserver(widgetElement) {
    var _a;

    const trackableWidget = this.trackableWidgets.get(widgetElement);

    if (!trackableWidget) {
      return;
    }

    trackableWidget.isIntersecting = false;
    this.clearInterval(trackableWidget);
    (_a = trackableWidget.observer) === null || _a === void 0 ? void 0 : _a.disconnect();
    this.trackableWidgets.delete(widgetElement);

    if (this.trackableWidgets.size === 0) {
      document.removeEventListener('visibilitychange', this.handleVisibilityChange.bind(this), false);
    }
  }

  handleVisibilityChange() {
    this.trackableWidgets.forEach(trackableWidget => {
      if (document.hidden) {
        this.clearInterval(trackableWidget);
      } else if (trackableWidget.isIntersecting) {
        trackableWidget.intervalId = this.setInterval(trackableWidget.widgetType);
      }
    });
  }

  intersectionCallback(entries) {
    entries.forEach(entry => {
      var _a, _b, _c;

      const widgetElement = entry.target;
      const trackableWidget = this.trackableWidgets.get(widgetElement);

      if (!trackableWidget) {
        return;
      }

      const widgetStyle = (_a = widgetElement.parentElement) === null || _a === void 0 ? void 0 : _a.style;
      const isWidgetOpaque = !(widgetStyle === null || widgetStyle === void 0 ? void 0 : widgetStyle.opacity) || (widgetStyle === null || widgetStyle === void 0 ? void 0 : widgetStyle.opacity) && +(widgetStyle === null || widgetStyle === void 0 ? void 0 : widgetStyle.opacity) > 0;
      const isWidgetVisible = ((_b = widgetElement.parentElement) === null || _b === void 0 ? void 0 : _b.style.visibility) !== 'hidden';

      if (entry.isIntersecting && entry.intersectionRatio >= ((_c = trackableWidget.threshold) !== null && _c !== void 0 ? _c : 0) && isWidgetVisible && isWidgetOpaque) {
        trackableWidget.isIntersecting = true;
        trackableWidget.intervalId = this.setInterval(trackableWidget.widgetType);
      } else if (!entry.isIntersecting) {
        trackableWidget.isIntersecting = false;
        this.clearInterval(trackableWidget);
      }
    });
  }

  sendAnalyticsEvent(widgetType) {
    AnalyticsUtils.sendGAEvent(`${widgetType} On Screen Timer`, undefined, this.kTimerIntervalMilliseconds, {
      timer_interval_msec: this.kTimerIntervalMilliseconds
    });
  }

  setInterval(widgetType) {
    return window.setInterval(() => this.sendAnalyticsEvent(widgetType), this.kTimerIntervalMilliseconds);
  }

  clearInterval(trackableWidget) {
    if (trackableWidget.intervalId) {
      window.clearInterval(trackableWidget.intervalId);
      trackableWidget.intervalId = undefined;
    }
  }

}

var OnScreenTrackingDirective = (() => {
  const tracker = new OnScreenTracker();
  return {
    inserted: (widgetElement, binding) => {
      const analyticsSettings = SharedSettings.analyticsSettings;

      if ((analyticsSettings === null || analyticsSettings === void 0 ? void 0 : analyticsSettings.provider) === 'none' || !(analyticsSettings === null || analyticsSettings === void 0 ? void 0 : analyticsSettings.isWidgetOnScreenTrackingEnabled) || !binding.value) {
        return;
      }

      const trackableWidget = binding.value;
      tracker.createObserver(widgetElement, trackableWidget);
    },
    unbind: widgetElement => {
      tracker.destroyObserver(widgetElement);
    }
  };
})();

function registerCustomDirectives(widgetRenderMode, isInThemeCustomizer) {
  const useNoOpDirective = widgetRenderMode === 'cypress' || widgetRenderMode === 'prerender';
  Vue.directive('ga', useNoOpDirective || isInThemeCustomizer ? NoOpDirective : GoogleAnalyticsDirective);
  Vue.directive('onScreenTracking', useNoOpDirective || isInThemeCustomizer ? NoOpDirective : OnScreenTrackingDirective);

  if (widgetRenderMode === 'cypress') {
    Vue.directive('lazySrc', CypressLazyLoadDirective);
  } else {
    Vue.directive('lazySrc', useNoOpDirective ? MetafieldsLazyLoadDirective : LazyLoadDirective);
  }
}

class InitialiseWidgetsBase {
  setGlobalWidgetSettingsAndDirectives(settings, options, subscriberId, features, analyticsSettings) {
    if (!settings) {
      settings = defaultSettings;
    }

    this.setWidgetSettings(settings, options, features, analyticsSettings);
    const defaultLocale = this.getDefaultWidgetLocale(options);
    this.setWidgetLocale(defaultLocale.code, defaultLocale.variant, options === null || options === void 0 ? void 0 : options.i18n);
    this.setSubscriberId(subscriberId);
    const isInThemeCustomizer = window.okeInShopifyThemeCustomizer;
    registerCustomDirectives(options === null || options === void 0 ? void 0 : options.widgetRenderMode, isInThemeCustomizer);
  }

  setWidgetSettings(settings, options, features, analyticsSettings) {
    var _a;

    const widgetSettings = (_a = SharedSettings.widgetSettings) !== null && _a !== void 0 ? _a : defaultSettings;

    if (settings) {
      OkendoUtils.merge(settings, widgetSettings);
    }

    SharedSettings.widgetSettings = widgetSettings;

    if (options) {
      SharedSettings.isTestModeEnabled = (options === null || options === void 0 ? void 0 : options.isTestModeEnabled) || false;
    }

    if (features) {
      SharedSettings.features = features;
    }

    if (analyticsSettings) {
      SharedSettings.analyticsSettings = analyticsSettings;
    }
    /**
     * The following functions service programatically initializing the widget via okeWidgetApi, used for reviews-admin preview (scripts/iframeWidgetPreviewer/index.ts line 92) and metafield renderer (see metafield-utils/WidgetMetafieldRenderer.ts).
     * Admin preview especially needs to override existing CSS variable and star symbol snippets in order to support live setting reload.
     * TODO: Use a setting flag in WidgetHeaderInitialisationOptions to control whether these function should be called to avoid doubling up.
     */


    this.writeCSSVariables(widgetSettings);
    this.writeStarSymbols(widgetSettings);
  }

  setWidgetLocale(value = 'en', variant, rootI18n) {
    setLocale(value, variant, rootI18n).then(locale => {
      if (locale) {
        Vue.$localeStoreActions.setLocale(locale);
      }
    });
  }

  setSubscriberId(subscriberId) {
    SharedSettings.subscriberId = subscriberId;
  }

  getDefaultWidgetLocale(options) {
    if (!options) {
      return translationsCommon.english;
    }

    const settingsLocale = translationsCommon.getLocaleWithFallback(options === null || options === void 0 ? void 0 : options.localeAndVariant, options === null || options === void 0 ? void 0 : options.locale);
    const shopifyLocale = getCustomerLocaleFromShopify(options); // If the Shopify locale code is the same as the settings locale code, use the settings locale so we get the Merchant's selected variant if present.

    return shopifyLocale && shopifyLocale.code !== settingsLocale.code ? shopifyLocale : settingsLocale;
  }

  writeStarSymbols(widgetSettings) {
    var _a, _b;

    const starShape = (_b = (_a = widgetSettings.global) === null || _a === void 0 ? void 0 : _a.stars.shape) !== null && _b !== void 0 ? _b : kDefaultStarShape;

    if (starShape.type !== 'custom') {
      const starSymbolSnippet = HeaderSettingsService.getStandardStarSymbolSnippet(starShape);
      HtmlUtils.addOrUpdateTargetBlock('svg', HeaderSettingsService.starSymbolsId, starSymbolSnippet, 'outerHTML', 'body');
      return;
    }

    fetch(starShape.assetUrl).then(res => {
      if (res.ok) {
        res.text().then(svgString => {
          const starSymbolSnippet = HeaderSettingsService.getCustomStarSymbolSnippet(starShape, svgString);
          HtmlUtils.addOrUpdateTargetBlock('svg', HeaderSettingsService.starSymbolsId, starSymbolSnippet, 'outerHTML', 'body');
        });
      } else {
        SharedSettings.widgetSettings.global.stars.shape = kDefaultStarShape;
        const starSymbolSnippet = HeaderSettingsService.getStandardStarSymbolSnippet(kDefaultStarShape);
        HtmlUtils.addOrUpdateTargetBlock('svg', HeaderSettingsService.starSymbolsId, starSymbolSnippet, 'outerHTML', 'body');
      }
    });
  }

  writeCSSVariables(widgetSettings) {
    const cssVariablesId = HeaderSettingsService.cssVariablesId;
    const cssVariableContent = HeaderSettingsService.getCssVariablesSnippet(widgetSettings);
    HtmlUtils.addOrUpdateTargetBlock('style', cssVariablesId, cssVariableContent, 'outerHTML');
  }

}

async function okendoConfigure(i18n) {
  if (!i18n) {
    console.warn('No `i18n` instance provided to okendoConfigure()');
    return;
  }

  const subscriberConfig = await getSubscriberConfig();
  let subscriberSettings;

  if (subscriberConfig) {
    subscriberSettings = await getWidgetSettingsFromSubscriberOrDefault(subscriberConfig);
    const {
      locale,
      matchCustomerLocale,
      subscriberId,
      features
    } = subscriberConfig;
    const sharedWidgetInitialisation = new InitialiseWidgetsBase();
    sharedWidgetInitialisation.setGlobalWidgetSettingsAndDirectives(subscriberSettings, {
      locale,
      matchCustomerLocale,
      isWidgetLibrary: true,
      i18n
    }, subscriberId, features);
  }

  return {
    subscriberConfig,
    subscriberSettings
  };
}

var components = /*#__PURE__*/Object.freeze({
    __proto__: null,
    okendoConfigure: okendoConfigure,
    OkendoVueI18nPlugin: OkendoVueI18nPlugin,
    OkendoHomepageCarousel: __vue_component__$14,
    OkendoMediaCarousel: __vue_component__$11,
    OkendoMediaGrid: __vue_component__$12,
    OkendoQuestionsWidget: __vue_component__$15,
    OkendoReviewsBadge: __vue_component__$13,
    OkendoStarRating: __vue_component__$16,
    OkendoWidget: __vue_component__$10
});

// Import vue components

const install = function install(Vue) {
  Object.entries(components).forEach(([componentName, component]) => {
    Vue.component(componentName, component);
  });
}; // Create module definition for Vue.use()

let Stars$1 = class Stars extends Vue {
  get foregroundWidth() {
    const singleStarPercent = this.onScreenStarWidth / this.onScreenSvgWidth * 100;
    const singleInterspacePercent = this.interspace / this.onScreenSvgWidth * 100;
    const interspacesCovered = this.rating < 5 ? Math.floor(this.rating) : 4;
    return `${singleStarPercent * this.rating + singleInterspacePercent * interspacesCovered}%`;
  } // Star positions within the unscaled svg, uses original stars with interspace scaled down with scalingFactor


  get starSvgPositions() {
    return [0, 1, 2, 3, 4].map(n => (this.starShape.width + this.interspace / this.scalingFactor) * n);
  } // Unscaled svg viewBox, uses original stars with interspace scaled down with scalingFactor


  get viewBox() {
    return `0 0 ${this.onScreenSvgWidth / this.scalingFactor} ${this.starShape.height}`;
  } // Scaled svg width to calculate foregroundWidth, uses scaled stars with "onscreen" interspace


  get onScreenSvgWidth() {
    return this.singleStar ? this.onScreenStarWidth : this.onScreenStarWidth * 5 + this.interspace * 4;
  }

  get onScreenStarWidth() {
    return this.starShape.width * this.scalingFactor;
  }

  get scalingFactor() {
    return this.height / this.starShape.height;
  }

  get starShape() {
    var _a, _b, _c;

    switch ((_c = (_b = (_a = SharedSettings.widgetSettings.global) === null || _a === void 0 ? void 0 : _a.stars) === null || _b === void 0 ? void 0 : _b.shape) === null || _c === void 0 ? void 0 : _c.type) {
      case 'circle':
        return {
          width: 12,
          height: 12
        };

      case 'custom':
        return {
          width: SharedSettings.widgetSettings.global.stars.shape.width,
          height: SharedSettings.widgetSettings.global.stars.shape.height
        };

      case 'heart':
        return {
          width: 16,
          height: 15
        };

      case 'thin':
        return {
          width: 16,
          height: 16
        };

      case 'rounded':
        return {
          width: 17,
          height: 16
        };

      case 'default':
      default:
        return {
          width: 14.6,
          height: 14
        };
    }
  }

};

__decorate([Prop()], Stars$1.prototype, "rating", void 0);

__decorate([Prop({
  default: () => 18
})], Stars$1.prototype, "height", void 0);

__decorate([Prop({
  default: () => 2
})], Stars$1.prototype, "interspace", void 0);

__decorate([Prop({
  default: () => false
})], Stars$1.prototype, "singleStar", void 0);

Stars$1 = __decorate([Component], Stars$1);
var script$Y = Stars$1;

/* script */
const __vue_script__$$ = script$Y;
/* template */

var __vue_render__$$ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-stars"
  }, [_vm.singleStar ? [_c('svg', {
    staticStyle: {
      "overflow": "visible"
    },
    attrs: {
      "height": _vm.height,
      "viewBox": _vm.viewBox,
      "aria-hidden": "true"
    }
  }, [_c('use', {
    attrs: {
      "href": "#oke-star-filled"
    }
  })])] : _vm._e(), _vm._v(" "), !_vm.singleStar ? [_c('div', {
    staticClass: "oke-stars-background"
  }, [_c('svg', {
    attrs: {
      "height": _vm.height,
      "viewBox": _vm.viewBox,
      "aria-hidden": "true"
    }
  }, _vm._l(_vm.starSvgPositions, function (position) {
    return _c('use', {
      key: position,
      attrs: {
        "x": position,
        "href": "#oke-star-empty"
      }
    });
  }), 0)]), _vm._v(" "), _c('div', {
    staticClass: "oke-stars-foreground",
    style: {
      width: _vm.foregroundWidth
    }
  }, [_c('svg', {
    attrs: {
      "height": _vm.height,
      "viewBox": _vm.viewBox,
      "aria-hidden": "true"
    }
  }, _vm._l(_vm.starSvgPositions, function (position) {
    return _c('use', {
      key: position,
      attrs: {
        "x": position,
        "href": "#oke-star-filled"
      }
    });
  }), 0)])] : _vm._e(), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("Rated " + _vm._s(_vm.rating) + " stars")])], 2);
};

var __vue_staticRenderFns__$$ = [];
/* style */

const __vue_inject_styles__$$ = undefined;
/* scoped */

const __vue_scope_id__$$ = undefined;
/* module identifier */

const __vue_module_identifier__$$ = undefined;
/* functional template */

const __vue_is_functional_template__$$ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$$ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$$,
  staticRenderFns: __vue_staticRenderFns__$$
}, __vue_inject_styles__$$, __vue_script__$$, __vue_scope_id__$$, __vue_is_functional_template__$$, __vue_module_identifier__$$, false, undefined, undefined, undefined);

var Stars = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$$
});

let Questions$1 = class Questions extends Vue {
  constructor() {
    super(...arguments);
    this.isLoadingMore = false;
    this.nextUrl = '';
    this.questions = [];
    this.selectedSortOption = 'date desc';
    this.viewState = 'loading';
  }

  created() {
    if (this.initialData) {
      this.questions = this.initialData.questions;
      this.nextUrl = this.initialData.nextUrl;
      this.$emit('load');
    } else {
      this.loadQuestions(this.questionsSettings.initialPageSize, this.selectedSortOption);
    }
  }

  get questionsSettings() {
    return SharedSettings.widgetSettings.questions;
  }

  async loadQuestions(limit, sort) {
    if (this.productId || this.groupId) {
      this.viewState = 'loading';
      const topAlert = this.$refs.topAlert;
      topAlert === null || topAlert === void 0 ? void 0 : topAlert.show(this.$tc('Loading Questions...'));

      try {
        const {
          questions,
          nextUrl
        } = this.productId ? await OkendoApi.getQuestionsProduct(this.productId, limit, sort) : await OkendoApi.getQuestionsCollection(this.groupId, limit, sort);
        this.questions = questions;
        this.nextUrl = nextUrl;
        this.viewState = questions.length ? 'content' : 'empty';
      } catch (_a) {
        this.viewState = 'error';
      } finally {
        topAlert === null || topAlert === void 0 ? void 0 : topAlert.hide();
        this.$emit('load');
      }
    }
  }

  async showMoreQuestions() {
    if (this.nextUrl) {
      this.isLoadingMore = true;

      try {
        const {
          questions,
          nextUrl
        } = await OkendoApi.getMore(this.nextUrl, this.questionsSettings.loadMorePageSize);
        this.questions.push(...questions);
        this.nextUrl = nextUrl;
      } catch (_a) {
        this.$refs.bottomAlert.show(this.$tc('Unexpected error occurred, please try again'), 2000);
      } finally {
        this.isLoadingMore = false;
      }
    }
  }

  onSortChange(newSort) {
    this.selectedSortOption = newSort;
    this.loadQuestions(this.questionsSettings.initialPageSize, this.selectedSortOption);
  }

};

__decorate([Prop()], Questions$1.prototype, "initialData", void 0);

__decorate([Prop()], Questions$1.prototype, "groupId", void 0);

__decorate([Prop()], Questions$1.prototype, "productId", void 0);

__decorate([Prop()], Questions$1.prototype, "askQuestionProductId", void 0);

__decorate([Prop()], Questions$1.prototype, "size", void 0);

__decorate([Prop({
  default: () => true
})], Questions$1.prototype, "showStateTopBorderOnEmpty", void 0);

Questions$1 = __decorate([Component({
  components: {
    ShowMore: async () => (await Promise.resolve().then(function () { return ShowMore; })).default,
    QuestionsHeader: async () => (
    /* webpackChunkName: "modules/questions" */
    await Promise.resolve().then(function () { return QuestionsHeader; })).default,
    Alert: async () => (await Promise.resolve().then(function () { return Alert; })).default,
    QuestionsList: async () => (await Promise.resolve().then(function () { return QuestionsList; })).default,
    State: async () => (await Promise.resolve().then(function () { return State; })).default
  }
})], Questions$1);
var script$X = Questions$1;

/* script */
const __vue_script__$_ = script$X;
/* template */

var __vue_render__$_ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-questions"
  }, [_vm.viewState === 'content' || _vm.questions.length && _vm.viewState === 'loading' ? _c('questions-header', {
    attrs: {
      "sortDisabled": _vm.viewState !== 'content',
      "productId": _vm.productId || _vm.askQuestionProductId,
      "selectedSortOption": _vm.selectedSortOption,
      "widgetSize": _vm.size
    },
    on: {
      "sortChange": function ($event) {
        return _vm.onSortChange($event);
      }
    }
  }) : _vm._e(), _vm._v(" "), _vm.viewState === 'content' || _vm.questions.length && _vm.viewState === 'loading' ? _c('div', {
    staticClass: "oke-questions-main"
  }, [_c('questions-list', {
    attrs: {
      "isLoading": _vm.viewState === 'loading',
      "questions": _vm.questions
    }
  }), _vm._v(" "), _vm.questions && _vm.questions.length ? _c('div', {
    staticClass: "oke-questions-main-alerts"
  }, [_c('alert', {
    ref: "bottomAlert",
    attrs: {
      "position": "bottom"
    }
  }), _vm._v(" "), _c('alert', {
    ref: "topAlert",
    attrs: {
      "position": "top"
    }
  })], 1) : _vm._e()], 1) : _c('state', {
    attrs: {
      "state": _vm.viewState,
      "productId": _vm.productId || _vm.askQuestionProductId,
      "topBorder": _vm.showStateTopBorderOnEmpty,
      "contentType": "questions"
    },
    on: {
      "retry": function ($event) {
        return _vm.loadQuestions(_vm.questionsSettings.initialPageSize, _vm.selectedSortOption);
      }
    }
  }), _vm._v(" "), _vm.nextUrl && _vm.viewState === 'content' ? _c('div', {
    staticClass: "oke-questions-footer"
  }, [_c('show-more', {
    attrs: {
      "nextUrl": _vm.nextUrl,
      "isLoading": _vm.isLoadingMore,
      "contentType": "questions"
    },
    on: {
      "click": function ($event) {
        return _vm.showMoreQuestions();
      }
    }
  })], 1) : _vm._e()], 1);
};

var __vue_staticRenderFns__$_ = [];
/* style */

const __vue_inject_styles__$_ = undefined;
/* scoped */

const __vue_scope_id__$_ = undefined;
/* module identifier */

const __vue_module_identifier__$_ = undefined;
/* functional template */

const __vue_is_functional_template__$_ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$_ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$_,
  staticRenderFns: __vue_staticRenderFns__$_
}, __vue_inject_styles__$_, __vue_script__$_, __vue_scope_id__$_, __vue_is_functional_template__$_, __vue_module_identifier__$_, false, undefined, undefined, undefined);

var Questions = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$_
});

let ModalMixin = class ModalMixin extends Vue {
  onModalClose() {
    ModalService.closeModal();
  }

  setUpTabTrapping() {
    this.$nextTick(() => {
      this.keyboardHandler = event => {
        const focusableElements = HtmlUtils.getFocusableElements(this.$refs.modalContent);
        const firstFocus = focusableElements === null || focusableElements === void 0 ? void 0 : focusableElements[0];
        const lastFocus = focusableElements === null || focusableElements === void 0 ? void 0 : focusableElements[focusableElements.length - 1];

        if (event.keyCode === 9) {
          // Tab
          if (event.shiftKey && document.activeElement === firstFocus) {
            event.preventDefault();
            firstFocus.focus();
          } else if (!event.shiftKey && document.activeElement === lastFocus) {
            event.preventDefault();
            lastFocus.focus();
          }
        } else if (event.keyCode === 27) {
          // Escape
          this.onModalClose();
        }
      };

      document.addEventListener('keydown', this.keyboardHandler);
    });
  }

};
ModalMixin = __decorate([Component], ModalMixin);
var ModalMixin$1 = ModalMixin;

const kPixelThreshold = 200;
var ImageUtils = {
  getTranscodedImageUrl(dynamicKey, width, height) {
    if (dynamicKey) {
      const mediaBaseUrl = OkendoApi.dynamicTranscodedMediaBaseUrl();
      const pixelRatio = Math.round(window.devicePixelRatio) || 1;

      if (!width && !height || width && width < 0 || height && height < 0) {
        return `${mediaBaseUrl}/images/${dynamicKey}.jpg?d=1600x1600`;
      } else {
        if (width && height && width !== height) {
          const isWidthLarger = Math.max(width, height) === width;
          const originalAspectRatio = width / height;

          if (isWidthLarger) {
            width = Math.ceil(width / kPixelThreshold) * kPixelThreshold;
            height = width / originalAspectRatio;
          } else {
            height = Math.ceil(height / kPixelThreshold) * kPixelThreshold;
            width = height * originalAspectRatio;
          }
        } else {
          width = width ? Math.ceil(width / kPixelThreshold) * kPixelThreshold : undefined;
          height = height ? Math.ceil(height / kPixelThreshold) * kPixelThreshold : undefined;
        }

        return `${mediaBaseUrl}/images/${dynamicKey}.jpg?d=${width ? Math.floor(width * pixelRatio) : ''}x${height ? Math.floor(height * pixelRatio) : ''}${width && height ? '&crop=center' : ''}`;
      }
    }
  },

  getAvatarUrl(reviewer) {
    var _a;

    const kAvatarImageDimensions2x = 96;

    if ((_a = reviewer.customAvatar) === null || _a === void 0 ? void 0 : _a.dynamicKey) {
      return this.getTranscodedImageUrl(reviewer.customAvatar.dynamicKey, kAvatarImageDimensions2x, kAvatarImageDimensions2x);
    }

    return reviewer.avatarUrl;
  },

  isMultiSourceMediaArray(mediaItems) {
    return mediaItems && mediaItems[0] && 'source' in mediaItems[0];
  }

};

let MediaModal$1 = class MediaModal extends mixins(ModalMixin$1) {
  constructor() {
    super(...arguments);
    this.media = [];
    this.activeSlideIndex = -1;
    this.viewState = 'loading';
    this.isLoadingMore = false;
    this.isSliderGalleryInitialised = false;
    this.galleryImageHeight = 600;
    this.navigationImageHeight = 120;
    this.carouselGalleryOptions = {
      itemsToShow: 1,
      itemsToSlide: 1,
      initialSlide: this.initialIndex,
      infiniteScroll: false,
      wheelControl: false,
      fluidSlide: true
    };
    this.carouselNavOptions = {
      itemsToSlide: 1,
      initialSlide: this.initialIndex,
      centerMode: true,
      infiniteScroll: false,
      keysControl: false,
      fluidSlide: true,
      breakpoints: {
        960: {
          itemsToShow: 8
        },
        640: {
          itemsToShow: 6
        },
        0: {
          itemsToShow: 4
        }
      }
    };
    this.nextUrl = this.initialNextUrl;
    this.loadMoreThreshold = 6;
    this.reviewCache = {};
    this.initialLoad = true;
  }

  created() {
    this.media = [...this.initialMedia];

    if (this.mediaContext === 'aggregate') {
      this.updateReview(this.initialIndex);
    } else {
      const indexToLoad = this.initialIndex >= 0 && this.initialIndex < this.media.length ? this.initialIndex : 0;
      this.currentActiveReview = this.media[indexToLoad];
      this.reviewCache[this.media[indexToLoad].parentId] = this.media[indexToLoad];
      this.viewState = 'content';
    }
  }

  mounted() {
    OkendoUtils.setDocumentOverflow();
    this.previousFocus = document.activeElement;
    this.setUpTabTrapping();
    this.$refs.mediaGalleryReview.focus();
  }

  destroyed() {
    var _a;

    OkendoUtils.setDocumentOverflow('remove');
    (_a = this.previousFocus) === null || _a === void 0 ? void 0 : _a.focus();
    document.removeEventListener('keydown', this.keyboardHandler);
  }

  onPropertyChanged(newIndex, oldIndex) {
    var _a;

    if (newIndex !== oldIndex) {
      this.carouselGallery.slideTo(newIndex);
      (_a = this.carouselNav) === null || _a === void 0 ? void 0 : _a.slideTo(newIndex);
    }

    if (!this.initialLoad) {
      this.updateReview(newIndex);
    }

    if (newIndex >= this.totalSlides - this.loadMoreThreshold - 1) {
      this.loadMoreMedia();
    }

    this.initialLoad = false;
  }

  get totalSlides() {
    var _a;

    return ((_a = this.media) === null || _a === void 0 ? void 0 : _a.length) || 0;
  }

  get contentReady() {
    return this.viewState === 'content';
  }

  preventIfSliding(e) {
    if (this.carouselGallery.isSliding) {
      e.preventDefault();
    }
  }

  nextSlide() {
    this.activeSlideIndex = this.activeSlideIndex === this.totalSlides - 1 ? 0 : this.activeSlideIndex + 1;
  }

  prevSlide() {
    this.activeSlideIndex = this.activeSlideIndex === 0 ? this.totalSlides - 1 : this.activeSlideIndex - 1;
  }

  focusSlideThumbnail(index) {
    var _a;

    const thumbnails = this.$refs.mediaThumbnail;
    (_a = thumbnails[index]) === null || _a === void 0 ? void 0 : _a.focus();
  }

  onSliderGalleryInit(data) {
    if (data) {
      this.isSliderGalleryInitialised = true;
    }
  }

  onSliderSlide(data) {
    this.activeSlideIndex = data.currentSlide;
  }

  onSliderThumbnailClick(index) {
    var _a;

    if (!((_a = this.carouselNav) === null || _a === void 0 ? void 0 : _a.isSliding)) {
      this.activeSlideIndex = index;
    }
  }

  async updateReview(mediaIndex) {
    var _a;

    const reviewId = (_a = this.media[mediaIndex]) === null || _a === void 0 ? void 0 : _a.parentId;

    if (reviewId) {
      const mediaReview = this.media.find(media => media.parentId === reviewId);

      if (mediaReview && mediaReview.source !== 'okendo-media') {
        this.currentActiveReview = mediaReview;
        this.viewState = 'content';
      } else if (this.reviewCache[reviewId]) {
        this.currentActiveReview = this.reviewCache[reviewId];
      } else {
        this.viewState = 'loading';

        try {
          const response = await OkendoApi.getReview(reviewId);
          this.currentActiveReview = OkendoUtils.convertReviewToMediaReview(response === null || response === void 0 ? void 0 : response.review);
          this.reviewCache[reviewId] = this.currentActiveReview;
          this.viewState = 'content';
        } catch (_b) {
          this.viewState = 'error';
        }
      }
    }
  }

  get carouselGallery() {
    return this.$refs.carouselGallery;
  }

  get carouselNav() {
    return this.$refs.carouselNav;
  }

  async loadMoreMedia() {
    if (this.nextUrl && !this.isLoadingMore) {
      this.isLoadingMore = true;

      try {
        const {
          media,
          nextUrl
        } = await OkendoApi.getMore(this.nextUrl);

        if (ImageUtils.isMultiSourceMediaArray(media)) {
          this.media.push(...media);
        } else {
          this.media.push(...OkendoUtils.convertMediaToMediaReviews(media));
        }

        this.nextUrl = nextUrl;
      } finally {
        this.isLoadingMore = false;
      }
    }
  }

};

__decorate([Prop()], MediaModal$1.prototype, "initialMedia", void 0);

__decorate([Prop({
  default: () => 0
})], MediaModal$1.prototype, "initialIndex", void 0);

__decorate([Prop()], MediaModal$1.prototype, "mediaContext", void 0);

__decorate([Prop()], MediaModal$1.prototype, "initialNextUrl", void 0);

__decorate([Prop()], MediaModal$1.prototype, "widgetMode", void 0);

__decorate([Watch('activeSlideIndex')], MediaModal$1.prototype, "onPropertyChanged", null);

MediaModal$1 = __decorate([Component({
  components: {
    ReviewSimple: async () => (await Promise.resolve().then(function () { return ReviewSimple; })).default,
    MediaThumbnail: async () => (await Promise.resolve().then(function () { return MediaThumbnail; })).default,
    FullVideo: async () => (await Promise.resolve().then(function () { return FullVideo; })).default,
    Hooper: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Hooper,
    Slide: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Slide
  }
})], MediaModal$1);
var script$W = MediaModal$1;

/* script */
const __vue_script__$Z = script$W;
/* template */

var __vue_render__$Z = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews",
    attrs: {
      "data-oke-container": ""
    }
  }, [_c('div', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Media Dialog Close'
      },
      expression: "{ action: 'Media Dialog Close' }",
      arg: "click"
    }],
    staticClass: "oke-modal",
    on: {
      "click": function ($event) {
        return _vm.onModalClose();
      },
      "keyup": [function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "right", 39, $event.key, ["Right", "ArrowRight"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 2) {
          return null;
        }

        return _vm.nextSlide.apply(null, arguments);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "left", 37, $event.key, ["Left", "ArrowLeft"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 0) {
          return null;
        }

        return _vm.prevSlide.apply(null, arguments);
      }]
    }
  }, [_c('div', {
    ref: "modalContent",
    staticClass: "oke-modal-content",
    attrs: {
      "role": "dialog",
      "aria-modal": "true",
      "aria-labelledby": "oke-modal-title"
    },
    on: {
      "click": function ($event) {
        $event.stopPropagation();
      }
    }
  }, [_c('h1', {
    staticClass: "oke-a11yText",
    attrs: {
      "id": "oke-modal-title"
    }
  }, [_vm._v(_vm._s(_vm.$tc('User Media and Reviews Gallery')))]), _vm._v(" "), _c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Media Dialog Close'
      },
      expression: "{ action: 'Media Dialog Close' }",
      arg: "click"
    }],
    staticClass: "oke-modal-close",
    attrs: {
      "title": _vm.$tc('Close Dialog'),
      "aria-label": _vm.$tc('Close Dialog')
    },
    on: {
      "click": function ($event) {
        return _vm.onModalClose();
      }
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-mediaGallery"
  }, [_c('div', {
    staticClass: "oke-mediaGallery-slider",
    class: {
      'is-oke-loading': !_vm.isSliderGalleryInitialised
    }
  }, [_c('hooper', {
    ref: "carouselGallery",
    attrs: {
      "settings": _vm.carouselGalleryOptions
    },
    on: {
      "updated": _vm.onSliderGalleryInit,
      "slide": _vm.onSliderSlide
    }
  }, _vm._l(_vm.media, function (mediaItem, index) {
    return _c('slide', {
      key: mediaItem.id,
      attrs: {
        "index": index,
        "aria-label": _vm.$t('Slide {0}', [index + 1]),
        "role": _vm.$t('group')
      }
    }, [_c('div', {
      attrs: {
        "role": "tabpanel",
        "aria-hidden": _vm.activeSlideIndex !== index,
        "id": "media-tabpanel-" + index,
        "aria-labelledby": "media-tab-" + index
      },
      on: {
        "click": _vm.preventIfSliding
      }
    }, [mediaItem.type === 'image' ? _c('media-thumbnail', {
      staticClass: "oke-mediaGallery-slider-image",
      attrs: {
        "mediaItem": mediaItem,
        "transcodedHeight": _vm.galleryImageHeight,
        "mediaContext": _vm.mediaContext,
        "id": "media-tab-" + index
      }
    }) : _vm._e(), _vm._v(" "), mediaItem.type === 'video' ? _c('full-video', {
      attrs: {
        "mediaItem": mediaItem,
        "scaleToFill": true,
        "tabbable": _vm.activeSlideIndex === index,
        "videoClass": "oke-mediaGallery-slider-image",
        "id": "media-tab-" + index
      }
    }) : _vm._e()], 1)]);
  }), 1)], 1), _vm._v(" "), _c('div', {
    ref: "mediaGalleryReview",
    staticClass: "oke-mediaGallery-review",
    class: {
      'is-oke-loading': _vm.viewState === 'loading'
    },
    attrs: {
      "tabindex": "0"
    }
  }, [_vm.contentReady && _vm.currentActiveReview ? _c('review-simple', {
    attrs: {
      "review": _vm.currentActiveReview,
      "widgetMode": _vm.widgetMode,
      "showHelpfulVoting": _vm.currentActiveReview.source !== 'foursixty',
      "hideStars": _vm.currentActiveReview.source === 'foursixty',
      "showPostedOnIg": _vm.currentActiveReview.source === 'foursixty'
    }
  }) : _vm.viewState === 'error' ? _c('div', {
    staticClass: "oke-mediaGallery-review-error",
    attrs: {
      "role": "alert"
    }
  }, [_c('p', [_vm._v(_vm._s(_vm.$tc('Error Loading Review')))]), _vm._v(" "), _c('button', {
    staticClass: "oke-button",
    on: {
      "click": function ($event) {
        return _vm.updateReview(_vm.activeSlideIndex);
      }
    }
  }, [_vm._v("\n                            " + _vm._s(_vm.$tc('Try Again')) + "\n                        ")])]) : _vm._e()], 1), _vm._v(" "), _vm.media.length > 1 ? _c('div', {
    ref: "mediaNavigation",
    staticClass: "oke-mediaGallery-nav"
  }, [_c('button', {
    staticClass: "oke-mediaGallery-nav-prev",
    attrs: {
      "disabled": _vm.activeSlideIndex === 0,
      "type": "button",
      "title": _vm.$tc('Previous Slide')
    },
    on: {
      "click": _vm.prevSlide
    }
  }), _vm._v(" "), _c('hooper', {
    ref: "carouselNav",
    staticClass: "oke-mediaGallery-nav-slider",
    attrs: {
      "settings": _vm.carouselNavOptions
    },
    on: {
      "slide": _vm.onSliderSlide
    }
  }, [_vm._l(_vm.media, function (mediaItem, index) {
    return _c('slide', {
      key: mediaItem.id,
      attrs: {
        "index": index,
        "aria-label": _vm.$t('Slide {0}', [index + 1]),
        "role": _vm.$t('group')
      }
    }, [_c('button', {
      ref: "mediaThumbnail",
      refInFor: true,
      staticClass: "oke-mediaGallery-nav-button",
      class: {
        'is-oke-selected': _vm.activeSlideIndex === index
      },
      attrs: {
        "tabindex": _vm.activeSlideIndex === index ? 0 : -1,
        "aria-selected": _vm.activeSlideIndex === index,
        "id": "media-tab-" + index,
        "aria-controls": "media-tabpanel-" + index,
        "role": "tab",
        "type": "button"
      },
      on: {
        "click": function ($event) {
          return _vm.onSliderThumbnailClick(index);
        }
      }
    }, [_c('media-thumbnail', {
      staticClass: "oke-mediaGallery-nav-button-image",
      attrs: {
        "mediaItem": mediaItem,
        "alt": _vm.$t('Slide {0}', [_vm.activeSlideIndex]),
        "mediaContext": _vm.mediaContext,
        "transcodedHeight": 120
      }
    })], 1)]);
  }), _vm._v(" "), _vm.isLoadingMore ? _c('slide', {
    style: {
      width: 'auto'
    },
    attrs: {
      "aria-label": _vm.$t('Slide {0}', [_vm.activeSlideIndex]),
      "role": _vm.$t('group')
    }
  }, [_c('div', {
    staticClass: "oke-mediaGallery-nav-loading"
  })]) : _vm._e()], 2), _vm._v(" "), _c('button', {
    staticClass: "oke-mediaGallery-nav-next",
    attrs: {
      "disabled": _vm.activeSlideIndex === _vm.totalSlides - 1,
      "type": "button",
      "title": _vm.$tc('Next Slide')
    },
    on: {
      "click": _vm.nextSlide
    }
  })], 1) : _vm._e()])])])]);
};

var __vue_staticRenderFns__$Z = [];
/* style */

const __vue_inject_styles__$Z = undefined;
/* scoped */

const __vue_scope_id__$Z = undefined;
/* module identifier */

const __vue_module_identifier__$Z = undefined;
/* functional template */

const __vue_is_functional_template__$Z = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$Z = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$Z,
  staticRenderFns: __vue_staticRenderFns__$Z
}, __vue_inject_styles__$Z, __vue_script__$Z, __vue_scope_id__$Z, __vue_is_functional_template__$Z, __vue_module_identifier__$Z, false, undefined, undefined, undefined);

var MediaModal = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$Z
});

// Unique ID creation requires a high quality random # generator. In the browser we therefore
// require the crypto API and do not support built-in fallback to lower quality random number
// generators (like Math.random()).
var getRandomValues;
var rnds8 = new Uint8Array(16);
function rng() {
  // lazy load so that environments that need to polyfill have a chance to do so
  if (!getRandomValues) {
    // getRandomValues needs to be invoked in a context where "this" is a Crypto implementation. Also,
    // find the complete implementation of crypto (msCrypto) on IE11.
    getRandomValues = typeof crypto !== 'undefined' && crypto.getRandomValues && crypto.getRandomValues.bind(crypto) || typeof msCrypto !== 'undefined' && typeof msCrypto.getRandomValues === 'function' && msCrypto.getRandomValues.bind(msCrypto);

    if (!getRandomValues) {
      throw new Error('crypto.getRandomValues() not supported. See https://github.com/uuidjs/uuid#getrandomvalues-not-supported');
    }
  }

  return getRandomValues(rnds8);
}

var REGEX = /^(?:[0-9a-f]{8}-[0-9a-f]{4}-[1-5][0-9a-f]{3}-[89ab][0-9a-f]{3}-[0-9a-f]{12}|00000000-0000-0000-0000-000000000000)$/i;

function validate(uuid) {
  return typeof uuid === 'string' && REGEX.test(uuid);
}

/**
 * Convert array of 16 byte values to UUID string format of the form:
 * XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX
 */

var byteToHex = [];

for (var i = 0; i < 256; ++i) {
  byteToHex.push((i + 0x100).toString(16).substr(1));
}

function stringify(arr) {
  var offset = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;
  // Note: Be careful editing this code!  It's been tuned for performance
  // and works in ways you may not expect. See https://github.com/uuidjs/uuid/pull/434
  var uuid = (byteToHex[arr[offset + 0]] + byteToHex[arr[offset + 1]] + byteToHex[arr[offset + 2]] + byteToHex[arr[offset + 3]] + '-' + byteToHex[arr[offset + 4]] + byteToHex[arr[offset + 5]] + '-' + byteToHex[arr[offset + 6]] + byteToHex[arr[offset + 7]] + '-' + byteToHex[arr[offset + 8]] + byteToHex[arr[offset + 9]] + '-' + byteToHex[arr[offset + 10]] + byteToHex[arr[offset + 11]] + byteToHex[arr[offset + 12]] + byteToHex[arr[offset + 13]] + byteToHex[arr[offset + 14]] + byteToHex[arr[offset + 15]]).toLowerCase(); // Consistency check for valid UUID.  If this throws, it's likely due to one
  // of the following:
  // - One or more input array values don't map to a hex octet (leading to
  // "undefined" in the uuid)
  // - Invalid input values for the RFC `version` or `variant` fields

  if (!validate(uuid)) {
    throw TypeError('Stringified UUID is invalid');
  }

  return uuid;
}

function parse(uuid) {
  if (!validate(uuid)) {
    throw TypeError('Invalid UUID');
  }

  var v;
  var arr = new Uint8Array(16); // Parse ########-....-....-....-............

  arr[0] = (v = parseInt(uuid.slice(0, 8), 16)) >>> 24;
  arr[1] = v >>> 16 & 0xff;
  arr[2] = v >>> 8 & 0xff;
  arr[3] = v & 0xff; // Parse ........-####-....-....-............

  arr[4] = (v = parseInt(uuid.slice(9, 13), 16)) >>> 8;
  arr[5] = v & 0xff; // Parse ........-....-####-....-............

  arr[6] = (v = parseInt(uuid.slice(14, 18), 16)) >>> 8;
  arr[7] = v & 0xff; // Parse ........-....-....-####-............

  arr[8] = (v = parseInt(uuid.slice(19, 23), 16)) >>> 8;
  arr[9] = v & 0xff; // Parse ........-....-....-....-############
  // (Use "/" to avoid 32-bit truncation when bit-shifting high-order bytes)

  arr[10] = (v = parseInt(uuid.slice(24, 36), 16)) / 0x10000000000 & 0xff;
  arr[11] = v / 0x100000000 & 0xff;
  arr[12] = v >>> 24 & 0xff;
  arr[13] = v >>> 16 & 0xff;
  arr[14] = v >>> 8 & 0xff;
  arr[15] = v & 0xff;
  return arr;
}

function stringToBytes(str) {
  str = unescape(encodeURIComponent(str)); // UTF8 escape

  var bytes = [];

  for (var i = 0; i < str.length; ++i) {
    bytes.push(str.charCodeAt(i));
  }

  return bytes;
}

var DNS = '6ba7b810-9dad-11d1-80b4-00c04fd430c8';
var URL$1 = '6ba7b811-9dad-11d1-80b4-00c04fd430c8';
function v35 (name, version, hashfunc) {
  function generateUUID(value, namespace, buf, offset) {
    if (typeof value === 'string') {
      value = stringToBytes(value);
    }

    if (typeof namespace === 'string') {
      namespace = parse(namespace);
    }

    if (namespace.length !== 16) {
      throw TypeError('Namespace must be array-like (16 iterable integer values, 0-255)');
    } // Compute hash of namespace and value, Per 4.3
    // Future: Use spread syntax when supported on all platforms, e.g. `bytes =
    // hashfunc([...namespace, ... value])`


    var bytes = new Uint8Array(16 + value.length);
    bytes.set(namespace);
    bytes.set(value, namespace.length);
    bytes = hashfunc(bytes);
    bytes[6] = bytes[6] & 0x0f | version;
    bytes[8] = bytes[8] & 0x3f | 0x80;

    if (buf) {
      offset = offset || 0;

      for (var i = 0; i < 16; ++i) {
        buf[offset + i] = bytes[i];
      }

      return buf;
    }

    return stringify(bytes);
  } // Function#name is not settable on some platforms (#270)


  try {
    generateUUID.name = name; // eslint-disable-next-line no-empty
  } catch (err) {} // For CommonJS default export support


  generateUUID.DNS = DNS;
  generateUUID.URL = URL$1;
  return generateUUID;
}

/*
 * Browser-compatible JavaScript MD5
 *
 * Modification of JavaScript MD5
 * https://github.com/blueimp/JavaScript-MD5
 *
 * Copyright 2011, Sebastian Tschan
 * https://blueimp.net
 *
 * Licensed under the MIT license:
 * https://opensource.org/licenses/MIT
 *
 * Based on
 * A JavaScript implementation of the RSA Data Security, Inc. MD5 Message
 * Digest Algorithm, as defined in RFC 1321.
 * Version 2.2 Copyright (C) Paul Johnston 1999 - 2009
 * Other contributors: Greg Holt, Andrew Kepert, Ydnar, Lostinet
 * Distributed under the BSD License
 * See http://pajhome.org.uk/crypt/md5 for more info.
 */
function md5(bytes) {
  if (typeof bytes === 'string') {
    var msg = unescape(encodeURIComponent(bytes)); // UTF8 escape

    bytes = new Uint8Array(msg.length);

    for (var i = 0; i < msg.length; ++i) {
      bytes[i] = msg.charCodeAt(i);
    }
  }

  return md5ToHexEncodedArray(wordsToMd5(bytesToWords(bytes), bytes.length * 8));
}
/*
 * Convert an array of little-endian words to an array of bytes
 */


function md5ToHexEncodedArray(input) {
  var output = [];
  var length32 = input.length * 32;
  var hexTab = '0123456789abcdef';

  for (var i = 0; i < length32; i += 8) {
    var x = input[i >> 5] >>> i % 32 & 0xff;
    var hex = parseInt(hexTab.charAt(x >>> 4 & 0x0f) + hexTab.charAt(x & 0x0f), 16);
    output.push(hex);
  }

  return output;
}
/**
 * Calculate output length with padding and bit length
 */


function getOutputLength(inputLength8) {
  return (inputLength8 + 64 >>> 9 << 4) + 14 + 1;
}
/*
 * Calculate the MD5 of an array of little-endian words, and a bit length.
 */


function wordsToMd5(x, len) {
  /* append padding */
  x[len >> 5] |= 0x80 << len % 32;
  x[getOutputLength(len) - 1] = len;
  var a = 1732584193;
  var b = -271733879;
  var c = -1732584194;
  var d = 271733878;

  for (var i = 0; i < x.length; i += 16) {
    var olda = a;
    var oldb = b;
    var oldc = c;
    var oldd = d;
    a = md5ff(a, b, c, d, x[i], 7, -680876936);
    d = md5ff(d, a, b, c, x[i + 1], 12, -389564586);
    c = md5ff(c, d, a, b, x[i + 2], 17, 606105819);
    b = md5ff(b, c, d, a, x[i + 3], 22, -1044525330);
    a = md5ff(a, b, c, d, x[i + 4], 7, -176418897);
    d = md5ff(d, a, b, c, x[i + 5], 12, 1200080426);
    c = md5ff(c, d, a, b, x[i + 6], 17, -1473231341);
    b = md5ff(b, c, d, a, x[i + 7], 22, -45705983);
    a = md5ff(a, b, c, d, x[i + 8], 7, 1770035416);
    d = md5ff(d, a, b, c, x[i + 9], 12, -1958414417);
    c = md5ff(c, d, a, b, x[i + 10], 17, -42063);
    b = md5ff(b, c, d, a, x[i + 11], 22, -1990404162);
    a = md5ff(a, b, c, d, x[i + 12], 7, 1804603682);
    d = md5ff(d, a, b, c, x[i + 13], 12, -40341101);
    c = md5ff(c, d, a, b, x[i + 14], 17, -1502002290);
    b = md5ff(b, c, d, a, x[i + 15], 22, 1236535329);
    a = md5gg(a, b, c, d, x[i + 1], 5, -165796510);
    d = md5gg(d, a, b, c, x[i + 6], 9, -1069501632);
    c = md5gg(c, d, a, b, x[i + 11], 14, 643717713);
    b = md5gg(b, c, d, a, x[i], 20, -373897302);
    a = md5gg(a, b, c, d, x[i + 5], 5, -701558691);
    d = md5gg(d, a, b, c, x[i + 10], 9, 38016083);
    c = md5gg(c, d, a, b, x[i + 15], 14, -660478335);
    b = md5gg(b, c, d, a, x[i + 4], 20, -405537848);
    a = md5gg(a, b, c, d, x[i + 9], 5, 568446438);
    d = md5gg(d, a, b, c, x[i + 14], 9, -1019803690);
    c = md5gg(c, d, a, b, x[i + 3], 14, -187363961);
    b = md5gg(b, c, d, a, x[i + 8], 20, 1163531501);
    a = md5gg(a, b, c, d, x[i + 13], 5, -1444681467);
    d = md5gg(d, a, b, c, x[i + 2], 9, -51403784);
    c = md5gg(c, d, a, b, x[i + 7], 14, 1735328473);
    b = md5gg(b, c, d, a, x[i + 12], 20, -1926607734);
    a = md5hh(a, b, c, d, x[i + 5], 4, -378558);
    d = md5hh(d, a, b, c, x[i + 8], 11, -2022574463);
    c = md5hh(c, d, a, b, x[i + 11], 16, 1839030562);
    b = md5hh(b, c, d, a, x[i + 14], 23, -35309556);
    a = md5hh(a, b, c, d, x[i + 1], 4, -1530992060);
    d = md5hh(d, a, b, c, x[i + 4], 11, 1272893353);
    c = md5hh(c, d, a, b, x[i + 7], 16, -155497632);
    b = md5hh(b, c, d, a, x[i + 10], 23, -1094730640);
    a = md5hh(a, b, c, d, x[i + 13], 4, 681279174);
    d = md5hh(d, a, b, c, x[i], 11, -358537222);
    c = md5hh(c, d, a, b, x[i + 3], 16, -722521979);
    b = md5hh(b, c, d, a, x[i + 6], 23, 76029189);
    a = md5hh(a, b, c, d, x[i + 9], 4, -640364487);
    d = md5hh(d, a, b, c, x[i + 12], 11, -421815835);
    c = md5hh(c, d, a, b, x[i + 15], 16, 530742520);
    b = md5hh(b, c, d, a, x[i + 2], 23, -995338651);
    a = md5ii(a, b, c, d, x[i], 6, -198630844);
    d = md5ii(d, a, b, c, x[i + 7], 10, 1126891415);
    c = md5ii(c, d, a, b, x[i + 14], 15, -1416354905);
    b = md5ii(b, c, d, a, x[i + 5], 21, -57434055);
    a = md5ii(a, b, c, d, x[i + 12], 6, 1700485571);
    d = md5ii(d, a, b, c, x[i + 3], 10, -1894986606);
    c = md5ii(c, d, a, b, x[i + 10], 15, -1051523);
    b = md5ii(b, c, d, a, x[i + 1], 21, -2054922799);
    a = md5ii(a, b, c, d, x[i + 8], 6, 1873313359);
    d = md5ii(d, a, b, c, x[i + 15], 10, -30611744);
    c = md5ii(c, d, a, b, x[i + 6], 15, -1560198380);
    b = md5ii(b, c, d, a, x[i + 13], 21, 1309151649);
    a = md5ii(a, b, c, d, x[i + 4], 6, -145523070);
    d = md5ii(d, a, b, c, x[i + 11], 10, -1120210379);
    c = md5ii(c, d, a, b, x[i + 2], 15, 718787259);
    b = md5ii(b, c, d, a, x[i + 9], 21, -343485551);
    a = safeAdd(a, olda);
    b = safeAdd(b, oldb);
    c = safeAdd(c, oldc);
    d = safeAdd(d, oldd);
  }

  return [a, b, c, d];
}
/*
 * Convert an array bytes to an array of little-endian words
 * Characters >255 have their high-byte silently ignored.
 */


function bytesToWords(input) {
  if (input.length === 0) {
    return [];
  }

  var length8 = input.length * 8;
  var output = new Uint32Array(getOutputLength(length8));

  for (var i = 0; i < length8; i += 8) {
    output[i >> 5] |= (input[i / 8] & 0xff) << i % 32;
  }

  return output;
}
/*
 * Add integers, wrapping at 2^32. This uses 16-bit operations internally
 * to work around bugs in some JS interpreters.
 */


function safeAdd(x, y) {
  var lsw = (x & 0xffff) + (y & 0xffff);
  var msw = (x >> 16) + (y >> 16) + (lsw >> 16);
  return msw << 16 | lsw & 0xffff;
}
/*
 * Bitwise rotate a 32-bit number to the left.
 */


function bitRotateLeft(num, cnt) {
  return num << cnt | num >>> 32 - cnt;
}
/*
 * These functions implement the four basic operations the algorithm uses.
 */


function md5cmn(q, a, b, x, s, t) {
  return safeAdd(bitRotateLeft(safeAdd(safeAdd(a, q), safeAdd(x, t)), s), b);
}

function md5ff(a, b, c, d, x, s, t) {
  return md5cmn(b & c | ~b & d, a, b, x, s, t);
}

function md5gg(a, b, c, d, x, s, t) {
  return md5cmn(b & d | c & ~d, a, b, x, s, t);
}

function md5hh(a, b, c, d, x, s, t) {
  return md5cmn(b ^ c ^ d, a, b, x, s, t);
}

function md5ii(a, b, c, d, x, s, t) {
  return md5cmn(c ^ (b | ~d), a, b, x, s, t);
}

v35('v3', 0x30, md5);

function v4(options, buf, offset) {
  options = options || {};
  var rnds = options.random || (options.rng || rng)(); // Per 4.4, set bits for version and `clock_seq_hi_and_reserved`

  rnds[6] = rnds[6] & 0x0f | 0x40;
  rnds[8] = rnds[8] & 0x3f | 0x80; // Copy bytes to buffer, if provided

  if (buf) {
    offset = offset || 0;

    for (var i = 0; i < 16; ++i) {
      buf[offset + i] = rnds[i];
    }

    return buf;
  }

  return stringify(rnds);
}

// Adapted from Chris Veness' SHA1 code at
// http://www.movable-type.co.uk/scripts/sha1.html
function f(s, x, y, z) {
  switch (s) {
    case 0:
      return x & y ^ ~x & z;

    case 1:
      return x ^ y ^ z;

    case 2:
      return x & y ^ x & z ^ y & z;

    case 3:
      return x ^ y ^ z;
  }
}

function ROTL(x, n) {
  return x << n | x >>> 32 - n;
}

function sha1(bytes) {
  var K = [0x5a827999, 0x6ed9eba1, 0x8f1bbcdc, 0xca62c1d6];
  var H = [0x67452301, 0xefcdab89, 0x98badcfe, 0x10325476, 0xc3d2e1f0];

  if (typeof bytes === 'string') {
    var msg = unescape(encodeURIComponent(bytes)); // UTF8 escape

    bytes = [];

    for (var i = 0; i < msg.length; ++i) {
      bytes.push(msg.charCodeAt(i));
    }
  } else if (!Array.isArray(bytes)) {
    // Convert Array-like to Array
    bytes = Array.prototype.slice.call(bytes);
  }

  bytes.push(0x80);
  var l = bytes.length / 4 + 2;
  var N = Math.ceil(l / 16);
  var M = new Array(N);

  for (var _i = 0; _i < N; ++_i) {
    var arr = new Uint32Array(16);

    for (var j = 0; j < 16; ++j) {
      arr[j] = bytes[_i * 64 + j * 4] << 24 | bytes[_i * 64 + j * 4 + 1] << 16 | bytes[_i * 64 + j * 4 + 2] << 8 | bytes[_i * 64 + j * 4 + 3];
    }

    M[_i] = arr;
  }

  M[N - 1][14] = (bytes.length - 1) * 8 / Math.pow(2, 32);
  M[N - 1][14] = Math.floor(M[N - 1][14]);
  M[N - 1][15] = (bytes.length - 1) * 8 & 0xffffffff;

  for (var _i2 = 0; _i2 < N; ++_i2) {
    var W = new Uint32Array(80);

    for (var t = 0; t < 16; ++t) {
      W[t] = M[_i2][t];
    }

    for (var _t = 16; _t < 80; ++_t) {
      W[_t] = ROTL(W[_t - 3] ^ W[_t - 8] ^ W[_t - 14] ^ W[_t - 16], 1);
    }

    var a = H[0];
    var b = H[1];
    var c = H[2];
    var d = H[3];
    var e = H[4];

    for (var _t2 = 0; _t2 < 80; ++_t2) {
      var s = Math.floor(_t2 / 20);
      var T = ROTL(a, 5) + f(s, b, c, d) + e + K[s] + W[_t2] >>> 0;
      e = d;
      d = c;
      c = ROTL(b, 30) >>> 0;
      b = a;
      a = T;
    }

    H[0] = H[0] + a >>> 0;
    H[1] = H[1] + b >>> 0;
    H[2] = H[2] + c >>> 0;
    H[3] = H[3] + d >>> 0;
    H[4] = H[4] + e >>> 0;
  }

  return [H[0] >> 24 & 0xff, H[0] >> 16 & 0xff, H[0] >> 8 & 0xff, H[0] & 0xff, H[1] >> 24 & 0xff, H[1] >> 16 & 0xff, H[1] >> 8 & 0xff, H[1] & 0xff, H[2] >> 24 & 0xff, H[2] >> 16 & 0xff, H[2] >> 8 & 0xff, H[2] & 0xff, H[3] >> 24 & 0xff, H[3] >> 16 & 0xff, H[3] >> 8 & 0xff, H[3] & 0xff, H[4] >> 24 & 0xff, H[4] >> 16 & 0xff, H[4] >> 8 & 0xff, H[4] & 0xff];
}

v35('v5', 0x50, sha1);

let AllReviewsModal$1 = class AllReviewsModal extends mixins(ModalMixin$1) {
  constructor() {
    super(...arguments);
    this.widgetId = v4();
    this.reviewsContainer = null;
  }

  mounted() {
    this.reviewsContainer = this.$refs.allReviewsContainer;
    OkendoUtils.setDocumentOverflow();
    this.previousFocus = document.activeElement;
    this.setUpTabTrapping();
    this.$refs.closeButton.focus(); // Focus on closeButton to trap focus while widget is loading
  }

  destroyed() {
    var _a;

    OkendoUtils.setDocumentOverflow('remove');
    (_a = this.previousFocus) === null || _a === void 0 ? void 0 : _a.focus();
    document.removeEventListener('keydown', this.keyboardHandler);
  }

};

__decorate([Prop()], AllReviewsModal$1.prototype, "groupId", void 0);

__decorate([Prop()], AllReviewsModal$1.prototype, "productId", void 0);

AllReviewsModal$1 = __decorate([Component({
  components: {
    OkendoWidget: async () => (await Promise.resolve().then(function () { return OkendoWidget; })).default
  }
})], AllReviewsModal$1);
var script$V = AllReviewsModal$1;

/* script */
const __vue_script__$Y = script$V;
/* template */

var __vue_render__$Y = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews",
    attrs: {
      "data-oke-container": ""
    }
  }, [_c('div', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'All Reviews Dialog Close'
      },
      expression: "{ action: 'All Reviews Dialog Close' }",
      arg: "click"
    }],
    staticClass: "oke-modal oke-modal--large",
    attrs: {
      "role": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onModalClose();
      }
    }
  }, [_c('div', {
    ref: "modalContent",
    staticClass: "oke-modal-content",
    attrs: {
      "role": "dialog",
      "aria-modal": "true",
      "aria-labelledby": "oke-modal-title"
    },
    on: {
      "click": function ($event) {
        $event.stopPropagation();
      }
    }
  }, [_c('h1', {
    staticClass: "oke-a11yText",
    attrs: {
      "id": "oke-modal-title"
    }
  }, [_vm._v(_vm._s(_vm.$tc('All Reviews')))]), _vm._v(" "), _c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'All Reviews Dialog Close'
      },
      expression: "{ action: 'All Reviews Dialog Close' }",
      arg: "click"
    }],
    ref: "closeButton",
    staticClass: "oke-modal-close",
    attrs: {
      "title": _vm.$tc('Close Dialog'),
      "aria-label": _vm.$tc('Close Dialog')
    },
    on: {
      "click": function ($event) {
        return _vm.onModalClose();
      }
    }
  }), _vm._v(" "), _c('div', {
    ref: "allReviewsContainer",
    staticClass: "oke-allReviews"
  }, [_c('okendo-widget', {
    attrs: {
      "disableSearchEnginePagination": true,
      "groupId": _vm.groupId,
      "productId": _vm.productId,
      "widgetId": _vm.widgetId,
      "widgetSnippetElement": _vm.reviewsContainer
    }
  })], 1)])])]);
};

var __vue_staticRenderFns__$Y = [];
/* style */

const __vue_inject_styles__$Y = undefined;
/* scoped */

const __vue_scope_id__$Y = undefined;
/* module identifier */

const __vue_module_identifier__$Y = undefined;
/* functional template */

const __vue_is_functional_template__$Y = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$Y = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$Y,
  staticRenderFns: __vue_staticRenderFns__$Y
}, __vue_inject_styles__$Y, __vue_script__$Y, __vue_scope_id__$Y, __vue_is_functional_template__$Y, __vue_module_identifier__$Y, false, undefined, undefined, undefined);

var AllReviewsModal = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$Y
});

var img$2 = "data:image/svg+xml,%3csvg id='Layer_1' data-name='Layer 1' xmlns='http://www.w3.org/2000/svg' width='124' height='15' viewBox='0 0 124 15'%3e %3cpath d='M.51%2c11.43V4.33H3.56c.66%2c0%2c1.17%2c.19%2c1.53%2c.58%2c.36%2c.39%2c.54%2c.91%2c.54%2c1.56s-.18%2c1.17-.54%2c1.56c-.36%2c.39-.87%2c.58-1.53%2c.58H1.66v2.83H.51Zm1.15-3.84h1.83c.29%2c0%2c.52-.07%2c.68-.22%2c.16-.16%2c.24-.38%2c.24-.66v-.49c0-.28-.08-.5-.24-.65-.16-.16-.39-.23-.68-.23H1.66v2.26Z' fill='%23747475'/%3e %3cpath d='M8.68%2c11.56c-.37%2c0-.7-.06-1.01-.19-.3-.13-.55-.31-.76-.55-.21-.24-.37-.54-.49-.88-.12-.35-.17-.73-.17-1.15s.06-.8%2c.17-1.14c.12-.35%2c.28-.64%2c.49-.88%2c.21-.24%2c.46-.43%2c.76-.56%2c.31-.13%2c.64-.19%2c1.01-.19s.7%2c.06%2c1%2c.19c.31%2c.13%2c.56%2c.32%2c.77%2c.56%2c.21%2c.24%2c.37%2c.53%2c.49%2c.88%2c.12%2c.34%2c.17%2c.72%2c.17%2c1.14s-.06%2c.8-.17%2c1.15c-.12%2c.34-.28%2c.63-.49%2c.88-.21%2c.24-.47%2c.42-.77%2c.55-.3%2c.13-.63%2c.19-1%2c.19Zm0-.92c.38%2c0%2c.69-.12%2c.92-.35%2c.23-.24%2c.35-.59%2c.35-1.06v-.9c0-.47-.12-.82-.35-1.05-.23-.24-.54-.36-.92-.36s-.69%2c.12-.92%2c.36c-.23%2c.23-.35%2c.58-.35%2c1.05v.9c0%2c.47%2c.12%2c.82%2c.35%2c1.06%2c.23%2c.23%2c.54%2c.35%2c.92%2c.35Z' fill='%23747475'/%3e %3cpath d='M11.75%2c6.14h1.08l.54%2c2.22%2c.48%2c2h.03l.55-2%2c.64-2.22h1l.65%2c2.22%2c.56%2c2h.03l.47-2%2c.55-2.22h1.03l-1.42%2c5.29h-1.25l-.69-2.41-.43-1.49h-.02l-.42%2c1.49-.7%2c2.41h-1.22l-1.44-5.29Z' fill='%23747475'/%3e %3cpath d='M22.42%2c11.56c-.38%2c0-.72-.06-1.02-.19-.3-.13-.55-.31-.76-.55-.21-.24-.37-.54-.49-.88-.11-.35-.16-.73-.16-1.15s.05-.8%2c.16-1.14c.12-.35%2c.28-.64%2c.49-.88%2c.21-.24%2c.46-.43%2c.76-.56%2c.3-.13%2c.64-.19%2c1.02-.19s.73%2c.07%2c1.02%2c.2c.3%2c.14%2c.55%2c.33%2c.74%2c.57%2c.2%2c.24%2c.34%2c.52%2c.44%2c.83%2c.1%2c.32%2c.15%2c.66%2c.15%2c1.03v.42h-3.63v.17c0%2c.41%2c.12%2c.74%2c.36%2c1.01%2c.24%2c.26%2c.59%2c.39%2c1.04%2c.39%2c.33%2c0%2c.6-.07%2c.82-.21s.41-.34%2c.57-.58l.65%2c.64c-.2%2c.33-.48%2c.59-.85%2c.78-.37%2c.19-.81%2c.28-1.3%2c.28Zm0-4.67c-.19%2c0-.37%2c.03-.53%2c.1-.16%2c.07-.29%2c.16-.41%2c.28-.11%2c.12-.19%2c.27-.25%2c.44-.06%2c.17-.09%2c.36-.09%2c.56v.07h2.46v-.1c0-.41-.11-.73-.32-.98-.21-.25-.5-.38-.86-.38Z' fill='%23747475'/%3e %3cpath d='M26%2c11.43V6.14h1.11v1.02h.05c.07-.27%2c.23-.51%2c.47-.71%2c.24-.2%2c.57-.31%2c.99-.31h.3v1.07h-.44c-.44%2c0-.78%2c.07-1.02%2c.21-.23%2c.14-.35%2c.35-.35%2c.63v3.38h-1.11Z' fill='%23747475'/%3e %3cpath d='M31.92%2c11.56c-.38%2c0-.72-.06-1.02-.19-.3-.13-.55-.31-.76-.55-.21-.24-.37-.54-.49-.88-.11-.35-.16-.73-.16-1.15s.05-.8%2c.16-1.14c.12-.35%2c.28-.64%2c.49-.88%2c.21-.24%2c.46-.43%2c.76-.56s.64-.19%2c1.02-.19%2c.73%2c.07%2c1.02%2c.2c.3%2c.14%2c.55%2c.33%2c.74%2c.57%2c.2%2c.24%2c.34%2c.52%2c.44%2c.83%2c.1%2c.32%2c.15%2c.66%2c.15%2c1.03v.42h-3.63v.17c0%2c.41%2c.12%2c.74%2c.36%2c1.01%2c.24%2c.26%2c.59%2c.39%2c1.04%2c.39%2c.33%2c0%2c.6-.07%2c.82-.21s.41-.34%2c.57-.58l.65%2c.64c-.2%2c.33-.48%2c.59-.85%2c.78-.37%2c.19-.81%2c.28-1.3%2c.28Zm0-4.67c-.19%2c0-.37%2c.03-.53%2c.1-.16%2c.07-.29%2c.16-.41%2c.28-.11%2c.12-.19%2c.27-.25%2c.44-.06%2c.17-.09%2c.36-.09%2c.56v.07h2.46v-.1c0-.41-.11-.73-.32-.98-.21-.25-.5-.38-.87-.38Z' fill='%23747475'/%3e %3cpath d='M38.82%2c10.56h-.05c-.12%2c.31-.31%2c.56-.57%2c.73-.26%2c.18-.56%2c.26-.92%2c.26-.67%2c0-1.19-.24-1.56-.72-.37-.49-.55-1.17-.55-2.05s.18-1.55%2c.55-2.04c.37-.49%2c.89-.73%2c1.56-.73%2c.35%2c0%2c.66%2c.09%2c.92%2c.26%2c.26%2c.17%2c.45%2c.41%2c.57%2c.73h.05V3.9h1.11v7.53h-1.11v-.88Zm-1.2%2c.04c.34%2c0%2c.62-.08%2c.85-.24%2c.23-.17%2c.35-.39%2c.35-.66v-1.81c0-.27-.12-.49-.35-.65-.23-.17-.52-.25-.85-.25-.39%2c0-.7%2c.13-.93%2c.38-.23%2c.24-.35%2c.57-.35%2c.98v.92c0%2c.41%2c.12%2c.74%2c.35%2c.99%2c.23%2c.24%2c.54%2c.37%2c.93%2c.37Z' fill='%23747475'/%3e %3cpath d='M43.92%2c3.9h1.11v3.11h.05c.12-.32%2c.3-.56%2c.56-.73%2c.26-.18%2c.57-.26%2c.93-.26%2c.67%2c0%2c1.19%2c.24%2c1.56%2c.73%2c.37%2c.48%2c.55%2c1.16%2c.55%2c2.04s-.18%2c1.56-.55%2c2.05c-.37%2c.48-.89%2c.72-1.56%2c.72-.35%2c0-.66-.09-.93-.26-.26-.18-.44-.42-.56-.73h-.05v.88h-1.11V3.9Zm2.31%2c6.7c.39%2c0%2c.7-.12%2c.93-.37%2c.23-.25%2c.35-.58%2c.35-.99v-.92c0-.41-.12-.73-.35-.98-.23-.25-.54-.38-.93-.38-.34%2c0-.62%2c.08-.85%2c.25-.23%2c.16-.35%2c.38-.35%2c.65v1.81c0%2c.27%2c.12%2c.49%2c.35%2c.66%2c.23%2c.16%2c.52%2c.24%2c.85%2c.24Z' fill='%23747475'/%3e %3cpath d='M53.12%2c6.14h1.07l-2.23%2c6.34c-.06%2c.18-.13%2c.33-.21%2c.45-.07%2c.13-.17%2c.23-.27%2c.31-.1%2c.08-.23%2c.14-.38%2c.17-.15%2c.04-.33%2c.06-.53%2c.06h-.64v-.91h.9l.31-.9-1.92-5.53h1.11l1.06%2c3.11%2c.31%2c1.15h.05l.34-1.15%2c1.06-3.11Z' fill='%23747475'/%3e %3cpath d='M87.52%2c3.03h1.53v5.54l2.51-2.77h1.95l-2.98%2c3.1%2c3.09%2c3.23h-1.99l-2.59-2.86v2.86h-1.53V3.03Z' fill='%23747475'/%3e %3cpath d='M93.81%2c8.91c0-1.96%2c1.41-3.4%2c3.41-3.4s3.39%2c1.44%2c3.39%2c3.4v.55h-5.19c.21%2c.94%2c.91%2c1.44%2c1.81%2c1.44%2c.68%2c0%2c1.18-.2%2c1.5-.61h1.63c-.47%2c1.23-1.63%2c2.03-3.13%2c2.03-2%2c0-3.41-1.44-3.41-3.4Zm5.18-.69c-.24-.86-.94-1.29-1.77-1.29s-1.53%2c.44-1.77%2c1.29h3.54Z' fill='%23747475'/%3e %3cpath d='M101.61%2c8.98c0-2.12%2c1.26-3.34%2c3.13-3.34s3.13%2c1.21%2c3.13%2c3.34v3.16h-1.53v-3.16c0-1.21-.64-1.91-1.6-1.91s-1.6%2c.71-1.6%2c1.91v3.16h-1.53v-3.16Z' fill='%23747475'/%3e %3cpath d='M114.14%2c3.03v5.94h0c0%2c1.12-.74%2c1.91-1.86%2c1.91s-1.87-.8-1.87-1.91c0-1.01%2c.76-1.84%2c1.87-1.84%2c.48%2c0%2c.88%2c.15%2c1.19%2c.4v-1.41c-.4-.27-.9-.41-1.45-.41-1.54%2c0-3.15%2c1.03-3.15%2c3.2%2c0%2c2.01%2c1.41%2c3.4%2c3.42%2c3.4s3.37-1.33%2c3.37-3.39V3.03h-1.53Z' fill='%23747475'/%3e %3cpath d='M120.08%2c5.49c-2%2c0-3.41%2c1.44-3.41%2c3.41s1.41%2c3.41%2c3.41%2c3.41%2c3.41-1.44%2c3.41-3.41-1.41-3.41-3.41-3.41Zm0%2c5.39c-1.09%2c0-1.97-.88-1.97-1.97s.88-1.97%2c1.97-1.97%2c1.97%2c.88%2c1.97%2c1.97-.88%2c1.97-1.97%2c1.97Z' fill='%23747475'/%3e %3cpath d='M81.91%2c3.38c-2.62%2c0-4.46%2c1.89-4.46%2c4.46s1.85%2c4.46%2c4.46%2c4.46%2c4.46-1.89%2c4.46-4.46-1.85-4.46-4.46-4.46Zm0%2c7.39c-1.62%2c0-2.93-1.31-2.93-2.93s1.31-2.93%2c2.93-2.93%2c2.93%2c1.31%2c2.93%2c2.93-1.31%2c2.93-2.93%2c2.93Z' fill='%23747475'/%3e %3cpath d='M59.91%2c.81V14.54h13.73V.81h-13.73Zm3.32%2c2.86h3.55c2.21%2c0%2c4%2c1.79%2c4%2c4s-1.79%2c4-4%2c4-4-1.79-4-4c0-.47%2c.08-.92%2c.23-1.33h.71c-.18%2c.41-.28%2c.86-.28%2c1.33%2c0%2c1.84%2c1.5%2c3.34%2c3.34%2c3.34s3.34-1.5%2c3.34-3.34-1.5-3.34-3.34-3.34h-4.18c.19-.24%2c.4-.46%2c.63-.66Zm-1.09%2c1.34h4.64c1.47%2c0%2c2.67%2c1.19%2c2.67%2c2.67s-1.19%2c2.67-2.67%2c2.67-2.67-1.19-2.67-2.67c0-.49%2c.13-.94%2c.36-1.33h.81c-.32%2c.35-.51%2c.82-.51%2c1.33%2c0%2c1.11%2c.9%2c2.01%2c2.01%2c2.01s2.01-.9%2c2.01-2.01-.9-2.01-2.01-2.01h-4.96c.09-.23%2c.2-.45%2c.32-.66Zm4.64%2c8.02c-2.96%2c0-5.35-2.4-5.35-5.35%2c0-.46%2c.06-.91%2c.17-1.33h.69c-.13%2c.42-.19%2c.87-.19%2c1.33%2c0%2c2.59%2c2.1%2c4.69%2c4.69%2c4.69s4.69-2.1%2c4.69-4.69-2.1-4.69-4.69-4.69c0%2c0-.01%2c0-.02%2c0h-2.56c.76-.42%2c1.64-.66%2c2.58-.66%2c2.96%2c0%2c5.35%2c2.4%2c5.35%2c5.35s-2.4%2c5.35-5.35%2c5.35Z' fill='%23747475'/%3e%3c/svg%3e";

let PoweredBy$1 = class PoweredBy extends Vue {
  get poweredByUrl() {
    return OkendoApi.poweredByUrl();
  }

  get poweredByImage() {
    return img$2;
  }

};

__decorate([Prop({
  default: () => 16
})], PoweredBy$1.prototype, "height", void 0);

PoweredBy$1 = __decorate([Component], PoweredBy$1);
var script$U = PoweredBy$1;

/* script */
const __vue_script__$X = script$U;
/* template */

var __vue_render__$X = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('a', {
    staticClass: "oke-poweredBy",
    attrs: {
      "href": _vm.poweredByUrl,
      "target": "_blank",
      "rel": "noopener noreferrer"
    }
  }, [_c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.poweredByImage,
      expression: "poweredByImage"
    }],
    staticClass: "oke-poweredBy-image",
    attrs: {
      "height": _vm.height + "px",
      "width": _vm.height * 155 / 16 + "px",
      "alt": _vm.$tc('Powered by Okendo')
    }
  }), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc('Open Okendo Reviews in a new window')))])]);
};

var __vue_staticRenderFns__$X = [];
/* style */

const __vue_inject_styles__$X = undefined;
/* scoped */

const __vue_scope_id__$X = undefined;
/* module identifier */

const __vue_module_identifier__$X = undefined;
/* functional template */

const __vue_is_functional_template__$X = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$X = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$X,
  staticRenderFns: __vue_staticRenderFns__$X
}, __vue_inject_styles__$X, __vue_script__$X, __vue_scope_id__$X, __vue_is_functional_template__$X, __vue_module_identifier__$X, false, undefined, undefined, undefined);

var PoweredBy = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$X
});

let ShowMore$2 = class ShowMore extends Vue {
  get arrowSizePx() {
    return OkendoUtils.getCombinedUnitMeasure(this.arrowSize);
  }

  get arrowLabel() {
    return this.arrowDirection === 'right' ? this.$tc('Next') : this.$tc('Previous');
  }

  onClick(event) {
    this.$emit('click', event);
  }

};

__decorate([Prop()], ShowMore$2.prototype, "isDisabled", void 0);

__decorate([Prop()], ShowMore$2.prototype, "arrowDirection", void 0);

__decorate([Prop()], ShowMore$2.prototype, "arrowColor", void 0);

__decorate([Prop({
  default: () => ({
    value: 48,
    unit: 'px'
  })
})], ShowMore$2.prototype, "arrowSize", void 0);

__decorate([Prop()], ShowMore$2.prototype, "buttonClass", void 0);

__decorate([Prop()], ShowMore$2.prototype, "isLoadingMore", void 0);

ShowMore$2 = __decorate([Component], ShowMore$2);
var script$T = ShowMore$2;

/* script */
const __vue_script__$W = script$T;
/* template */

var __vue_render__$W = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('button', {
    staticClass: "oke-prevNextButton",
    class: [{
      'oke-prevNextButton--next': this.arrowDirection === 'right',
      'oke-prevNextButton--prev': this.arrowDirection === 'left',
      'oke-is-loading': _vm.isLoadingMore
    }, _vm.buttonClass],
    attrs: {
      "disabled": _vm.isDisabled,
      "title": _vm.arrowLabel,
      "aria-label": _vm.arrowLabel,
      "type": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onClick($event);
      }
    }
  }, [_c('div', {
    staticClass: "oke-prevNextButton-icon",
    style: {
      width: _vm.arrowSizePx,
      height: _vm.arrowSizePx,
      'font-size': _vm.arrowSizePx,
      color: _vm.arrowColor
    },
    attrs: {
      "role": "presentation"
    }
  })]);
};

var __vue_staticRenderFns__$W = [];
/* style */

const __vue_inject_styles__$W = undefined;
/* scoped */

const __vue_scope_id__$W = undefined;
/* module identifier */

const __vue_module_identifier__$W = undefined;
/* functional template */

const __vue_is_functional_template__$W = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$W = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$W,
  staticRenderFns: __vue_staticRenderFns__$W
}, __vue_inject_styles__$W, __vue_script__$W, __vue_scope_id__$W, __vue_is_functional_template__$W, __vue_module_identifier__$W, false, undefined, undefined, undefined);

var PrevNextButton = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$W
});

function createHandler(divisor) {
    return function(diff, timePeriod) {
        return {
            period: Math.floor(diff / divisor),
            formatString: `{0} ${timePeriod.noun} ${timePeriod.restOfString}`
        };
    };
}

const prettyDateFormatters = [{
    threshold: 1,
    handler: (diff, timePeriod) => {
        return {
            formatString: timePeriod.noun
        };
    },
    timePeriod: {
        noun: "Just now"
    }
}, {
    threshold: 60,
    handler: createHandler(1),
    timePeriod: {
        noun: "second",
        restOfString: "ago"
    }
}, {
    threshold: 3600,
    handler: createHandler(60),
    timePeriod: {
        noun: "minute",
        restOfString: "ago"
    }
}, {
    threshold: 86400,
    handler: createHandler(3600),
    timePeriod: {
        noun: "hour",
        restOfString: "ago"
    }
}, {
    threshold: 172800,
    handler: (diff, timePeriod) => {
        return {
            formatString: timePeriod.noun
        };
    },
    timePeriod: {
        noun: "Yesterday"
    }
}, {
    threshold: 604800,
    handler: createHandler(86400),
    timePeriod: {
        noun: "day",
        restOfString: "ago"
    }
}, {
    threshold: 2592000,
    handler: createHandler(604800),
    timePeriod: {
        noun: "week",
        restOfString: "ago"
    }
}, {
    threshold: 31536000,
    handler: createHandler(2592000),
    timePeriod: {
        noun: "month",
        restOfString: "ago"
    }
}, {
    threshold: Infinity,
    handler: createHandler(31536000),
    timePeriod: {
        noun: "year",
        restOfString: "ago"
    }
}];

function getPrettyDateResult(date) {
    var diff = (((new Date()).getTime() - date.getTime()) / 1000);

    if (diff < 0) {
        return undefined;
    }

    for (var i = 0; i < prettyDateFormatters.length; i++) {
        if (diff < prettyDateFormatters[i].threshold) {
            return prettyDateFormatters[i].handler(diff, prettyDateFormatters[i].timePeriod);
        }
    }

    throw new Error("Exhausted all formatter options, none found."); //should never be reached
}

var prettydate = {
    toFormatComponents: function(date) {
        return getPrettyDateResult(date);
    }
};

const kMonthi18nKeyLookup = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
var DateUtils = {
  formatDate(date, dateFormat) {
    var _a;

    switch (dateFormat.type) {
      case 'hidden':
        return;

      case 'absolute':
        if (!((_a = window.Intl) === null || _a === void 0 ? void 0 : _a.DateTimeFormat)) {
          return this.getPrettyDate(date);
        }

        return this.getAbsoluteDate(date, dateFormat.options);

      case 'relative':
      default:
        return this.getPrettyDate(date);
    }
  },

  getPrettyDate(date) {
    var _a;

    if (date) {
      const prettyDateResult = prettydate.toFormatComponents(new Date(date));

      if (prettyDateResult) {
        const prettyResultPeriod = (_a = prettyDateResult.period) !== null && _a !== void 0 ? _a : 0;
        return i18n.tc(prettyDateResult.formatString, prettyResultPeriod, {
          0: prettyResultPeriod
        });
      }
    }
  },

  getAbsoluteDate(date, options) {
    if (date instanceof Date || (date === null || date === void 0 ? void 0 : date.length)) {
      return new Intl.DateTimeFormat(i18n.locale, options).format(new Date(date));
    }
  },

  getFormattedDateFromAttribute(attribute) {
    var _a, _b;

    const dateComponents = attribute.value;

    if (!dateComponents.day && !dateComponents.month && !dateComponents.year) {
      return;
    }

    if (dateComponents.day && dateComponents.month && dateComponents.year && ((_a = window.Intl) === null || _a === void 0 ? void 0 : _a.DateTimeFormat) !== undefined) {
      // If we have an absolute date format specified from config, use it.
      const settingsDateFormat = SharedSettings.widgetSettings.global.dateSettings.format;
      const dateFormatOption = settingsDateFormat.type === 'absolute' ? settingsDateFormat.options : {
        dateStyle: 'medium'
      };
      return this.getAbsoluteDate(new Date(dateComponents.year, dateComponents.month - 1, dateComponents.day), dateFormatOption);
    } // Fall through so we support day month year if Intl isn't supported


    if (dateComponents.month) {
      return i18n.tc(kMonthi18nKeyLookup[dateComponents.month], undefined, {
        day: dateComponents.day,
        year: (_b = dateComponents.year) === null || _b === void 0 ? void 0 : _b.toString()
      }).trim();
    } else if (dateComponents.year) {
      return dateComponents.year.toString();
    }
  }

};

let ReviewBase = class ReviewBase extends Vue {
  constructor() {
    super(...arguments);
    this.isTruncated = false;
    this.isFullReviewLoading = false; // Used only when generating metafields

    this.isMetafieldTruncated = false;
    this.metafieldReviewBodyMaxChars = 1000;
    this.environment = "production";
  }

  created() {
    var _a;

    if (((_a = this.environment) === null || _a === void 0 ? void 0 : _a.startsWith('metafields')) && this.review.body.length > this.metafieldReviewBodyMaxChars) {
      this.isMetafieldTruncated = true;
      this.review.body = this.review.body.substring(0, this.metafieldReviewBodyMaxChars) + '...';
    }
  }

  get hideAvatars() {
    return !this.reviewSettings.showAvatars;
  }

  get showDates() {
    return this.reviewSettings.showDates;
  }

  get imageGap() {
    return this.reviewSettings.media.imageGap;
  }

  get isAttributesVisible() {
    return !this.attributesNeedTruncation || !this.isTruncated;
  }

  get mediaSize() {
    return this.reviewSettings.media.size;
  }

  get reviewDateCreated() {
    return DateUtils.formatDate(this.review.dateCreated, SharedSettings.widgetSettings.global.dateSettings.format);
  }

  get showMedia() {
    return this.reviewSettings.showMedia;
  }

  get showAttributeBars() {
    return this.reviewSettings.layout.showAttributeBars;
  }

  get showProductInfo() {
    return this.reviewSettings.layout.showProductDetails === 'always' || this.reviewSettings.layout.showProductDetails === 'only-when-grouped' && (this.widgetMode === 'all' || this.widgetMode === 'group');
  }

  get starHeight() {
    return this.reviewSettings.stars.height;
  }

  get starInterspace() {
    return this.reviewSettings.stars.interspace;
  }

  get truncationSettings() {
    return this.reviewSettings.truncationSettings;
  }

  get selectAttributes() {
    var _a, _b;

    return [...((_a = this.review.reviewer.attributes) !== null && _a !== void 0 ? _a : []), ...((_b = this.review.productAttributes) !== null && _b !== void 0 ? _b : [])];
  }

  get showIncentivizedReviewsBadge() {
    return this.review.isIncentivized && SharedSettings.widgetSettings.global.showIncentiveIndicator;
  }

  async onReadMoreClick() {
    var _a;

    if (this.review.isBodyTruncated) {
      // Truncated metafield, load full review from API
      this.isFullReviewLoading = true;

      try {
        const response = await OkendoApi.getReview(this.review.reviewId);
        this.review.body = (_a = response === null || response === void 0 ? void 0 : response.review.body) !== null && _a !== void 0 ? _a : '';
        this.isTruncated = false;
      } catch (_b) {
        this.isTruncated = true;
      } finally {
        this.isFullReviewLoading = false;
      }
    } else {
      this.isTruncated = false;
    }
  }

  setReviewTruncation(reviewBasicContentData) {
    this.isTruncated = reviewBasicContentData.reviewBodyNeedsTruncation || this.replyNeedsTruncation || this.mediaNeedsTruncation || this.attributesNeedTruncation || !!this.review.isBodyTruncated;
  }

  get replyNeedsTruncation() {
    return this.truncationSettings.truncateAll && !!this.review.reply;
  }

  get mediaNeedsTruncation() {
    var _a;

    const hasMedia = !!((_a = this.review.media) === null || _a === void 0 ? void 0 : _a.length);
    return this.truncationSettings.truncateAll && hasMedia && this.showMedia;
  }

  get attributesNeedTruncation() {
    var _a;

    const hasAttributes = !!((_a = this.review.attributesWithRating) === null || _a === void 0 ? void 0 : _a.length);
    return this.truncationSettings.truncateAll && hasAttributes && this.showAttributeBars;
  }

};

__decorate([Prop()], ReviewBase.prototype, "review", void 0);

__decorate([Prop()], ReviewBase.prototype, "widgetMode", void 0);

__decorate([Prop()], ReviewBase.prototype, "widgetSize", void 0);

__decorate([Prop()], ReviewBase.prototype, "reviewSettings", void 0);

__decorate([Prop()], ReviewBase.prototype, "isIncentivised", void 0);

ReviewBase = __decorate([Component({
  components: {
    Avatar: async () => (await Promise.resolve().then(function () { return Avatar; })).default,
    Reviewer: async () => (await Promise.resolve().then(function () { return Reviewer; })).default,
    HelpfulVoting: async () => (await Promise.resolve().then(function () { return HelpfulVoting; })).default,
    SelectAttributes: async () => (await Promise.resolve().then(function () { return SelectAttributes; })).default,
    BarAttributes: async () => (await Promise.resolve().then(function () { return BarAttributes; })).default,
    ReviewerRecommendation: async () => (
    /* webpackChunkName: "modules/review-basic-content" */
    await Promise.resolve().then(function () { return ReviewerRecommendation; })).default,
    ReviewReply: async () => (await Promise.resolve().then(function () { return ReviewReply; })).default,
    MediaStrip: async () => (await Promise.resolve().then(function () { return MediaStrip; })).default,
    ReviewBasicContent: async () => (await Promise.resolve().then(function () { return ReviewBasicContent; })).default,
    MediaCollage: async () => (await Promise.resolve().then(function () { return MediaCollage; })).default,
    Product: async () => (await Promise.resolve().then(function () { return Product; })).default,
    IncentivizedReview: async () => (await Promise.resolve().then(function () { return IncentivizedReview; })).default
  }
})], ReviewBase);
var ReviewBase$1 = ReviewBase;

let ReviewCardBase = class ReviewCardBase extends ReviewBase$1 {
  constructor() {
    super(...arguments);
    this.cardHeight = 0;
    this.cardWidth = 0;
  }

  mounted() {
    this.$nextTick(() => {
      this.resizeObserver = new ResizeObserver(OkendoUtils.debounce(this.onResize, 200));
      this.resizeObserver.observe(this.$refs.reviewCard);
    });
  }

  get isMediaVisible() {
    return (!this.isTruncated || !this.mediaNeedsTruncation) && this.showMedia;
  }

  get isReplyVisible() {
    return (!this.isTruncated || !this.replyNeedsTruncation) && !!this.reviewLayoutSettings.showReply;
  }

  get reviewCardHasExtraContent() {
    return this.reviewCardHasMedia || this.reviewCardHasAttributes || this.reviewCardHasReply;
  }

  get reviewCardHasMedia() {
    var _a;

    return this.showMedia && !!((_a = this.review.media) === null || _a === void 0 ? void 0 : _a.length);
  }

  get reviewCardHasAttributes() {
    var _a;

    return this.showAttributeBars && !!((_a = this.review.attributesWithRating) === null || _a === void 0 ? void 0 : _a.length);
  }

  get reviewCardHasReply() {
    return !!this.reviewLayoutSettings.showReply && !!this.review.reply;
  }

  get reviewLayoutSettings() {
    return this.reviewSettings.layout;
  }

  get showProductInfo() {
    return this.reviewSettings.layout.showProductDetails === 'always' || this.reviewSettings.layout.showProductDetails === 'only-when-grouped' && (this.widgetMode === 'all' || this.widgetMode === 'group');
  }

  get showProductName() {
    return this.showProductInfo && this.reviewLayoutSettings.showProductName;
  }

  onResize() {
    if (this.$refs.reviewCard) {
      const reviewCardHeight = this.$refs.reviewCard.getBoundingClientRect().height;
      const reviewCardWidth = this.$refs.reviewCard.getBoundingClientRect().width;

      if (reviewCardHeight !== this.cardHeight || reviewCardWidth !== this.cardWidth) {
        this.cardHeight = reviewCardHeight;
        this.$nextTick(() => {
          this.$emit('cardUpdated', {
            height: reviewCardHeight,
            width: reviewCardWidth,
            index: this.index
          });
        });
      }
    }
  }

  unmounted() {
    this.resizeObserver.disconnect();
  }

  onMediaClick(clickedIndex) {
    const mediaReviews = OkendoUtils.convertReviewsToMediaReviews([this.review]);
    this.$emit('reviewCardMediaClick', clickedIndex, mediaReviews);
  }

};

__decorate([Prop()], ReviewCardBase.prototype, "reviewSettings", void 0);

__decorate([Prop()], ReviewCardBase.prototype, "index", void 0);

ReviewCardBase = __decorate([Component], ReviewCardBase);
var ReviewCardBase$1 = ReviewCardBase;

class ReviewCard$3 extends mixins(ReviewCardBase$1) {}

/* script */
const __vue_script__$V = ReviewCard$3;
/* template */

var __vue_render__$V = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "reviewCard",
    staticClass: "oke-reviewCard",
    class: ["oke-reviewCard--" + _vm.reviewLayoutSettings.reviewDetailsPosition, {
      'oke-reviewCard--hasContent': _vm.reviewCardHasExtraContent
    }]
  }, [_c('div', {
    staticClass: "oke-reviewCard-head",
    class: "" + (_vm.showProductName ? 'oke-reviewCard-head--hasProductName' : '')
  }, [_c('div', {
    staticClass: "oke-reviewCard-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "layout": _vm.hideAvatars ? 'minimal' : 'side-by-side'
    }
  })], 1), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-reviewCard-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review,
      "layout": !_vm.showProductName ? 'image-only' : ''
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCard-content"
  }, [_c('review-basic-content', {
    attrs: {
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": _vm.showDates,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCard-container"
  }, [_vm.reviewCardHasAttributes ? _c('div', {
    staticClass: "oke-reviewCard-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.reviewCardHasMedia ? _c('div', {
    staticClass: "oke-reviewCard-media",
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "maxMediaCount": 2,
      "mediaContext": "review"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.isReplyVisible && _vm.review.reply ? _c('div', {
    staticClass: "oke-reviewCard-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-helpful"
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)], 1)]);
};

var __vue_staticRenderFns__$V = [];
/* style */

const __vue_inject_styles__$V = undefined;
/* scoped */

const __vue_scope_id__$V = undefined;
/* module identifier */

const __vue_module_identifier__$V = undefined;
/* functional template */

const __vue_is_functional_template__$V = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$V = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$V,
  staticRenderFns: __vue_staticRenderFns__$V
}, __vue_inject_styles__$V, __vue_script__$V, __vue_scope_id__$V, __vue_is_functional_template__$V, __vue_module_identifier__$V, false, undefined, undefined, undefined);

var ReviewCard$2 = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$V
});

let ReviewCardFeaturedMedia$1 = class ReviewCardFeaturedMedia extends mixins(ReviewCardBase$1) {
  constructor() {
    super(...arguments);
    this.imageWidth = 300;
  }

  get imageHeight() {
    return OkendoUtils.toPixels(this.mediaSize);
  }

  get featuredMedia() {
    var _a;

    if (this.review.media) {
      const videos = this.review.media.filter(mediaItem => mediaItem.type === 'video');
      return (_a = videos[0]) !== null && _a !== void 0 ? _a : this.review.media[0];
    }
  }

  get mediaNeedsTruncation() {
    return false;
  }

};

__decorate([Prop({
  default: () => true
})], ReviewCardFeaturedMedia$1.prototype, "shouldStretchVertically", void 0);

__decorate([Prop({
  default: () => false
})], ReviewCardFeaturedMedia$1.prototype, "showFullHeightImages", void 0);

ReviewCardFeaturedMedia$1 = __decorate([Component({
  components: {
    MediaThumbnail: async () => (await Promise.resolve().then(function () { return MediaThumbnail; })).default,
    ShowMoreButton: async () => (await Promise.resolve().then(function () { return ShowMoreButton; })).default
  }
})], ReviewCardFeaturedMedia$1);
var script$S = ReviewCardFeaturedMedia$1;

/* script */
const __vue_script__$U = script$S;
/* template */

var __vue_render__$U = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "reviewCard",
    staticClass: "oke-reviewCardFeaturedMedia",
    class: ["oke-reviewCardFeaturedMedia--" + _vm.reviewLayoutSettings.reviewDetailsPosition, {
      'oke-reviewCardFeaturedMedia--verticalStretch': _vm.shouldStretchVertically
    }]
  }, [_vm.reviewCardHasMedia ? _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-media",
    style: {
      height: _vm.imageHeight + 'px'
    }
  }, [_c('media-thumbnail', {
    attrs: {
      "mediaItem": _vm.featuredMedia,
      "linked": true,
      "transcodedHeight": !_vm.showFullHeightImages ? _vm.imageHeight : undefined,
      "transcodedWidth": _vm.imageWidth,
      "productName": _vm.review.productName,
      "mediaContext": "review"
    },
    on: {
      "mediaThumbnailClick": function ($event) {
        return _vm.onMediaClick(0);
      }
    }
  }), _vm._v(" "), _vm.review.media.length > 1 ? _c('show-more-button', {
    attrs: {
      "moreMediaCount": _vm.review.media.length - 1
    },
    on: {
      "showMoreButtonClick": function ($event) {
        return _vm.onMediaClick(1);
      }
    }
  }) : _vm._e()], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-container"
  }, [_c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-content"
  }, [_c('review-basic-content', {
    attrs: {
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": _vm.showDates,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  }), _vm._v(" "), _vm.reviewCardHasAttributes ? _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.isReplyVisible && _vm.review.reply ? _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-head",
    class: "" + (_vm.showProductName ? 'oke-reviewCardFeaturedMedia-head--hasProductName' : '')
  }, [_c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "layout": _vm.hideAvatars ? 'minimal' : 'side-by-side'
    }
  })], 1), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-reviewCardFeaturedMedia-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review,
      "layout": !_vm.showProductName ? 'image-only' : ''
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)])]);
};

var __vue_staticRenderFns__$U = [];
/* style */

const __vue_inject_styles__$U = undefined;
/* scoped */

const __vue_scope_id__$U = undefined;
/* module identifier */

const __vue_module_identifier__$U = undefined;
/* functional template */

const __vue_is_functional_template__$U = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$U = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$U,
  staticRenderFns: __vue_staticRenderFns__$U
}, __vue_inject_styles__$U, __vue_script__$U, __vue_scope_id__$U, __vue_is_functional_template__$U, __vue_module_identifier__$U, false, undefined, undefined, undefined);

var ReviewCardFeaturedMedia = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$U
});

class ReviewCard$1 extends mixins(ReviewCardBase$1) {
  get testimonialAlignment() {
    var _a;

    return this.reviewLayoutSettings.name === 'testimonial' ? (_a = this.reviewLayoutSettings.testimonialAlignment) !== null && _a !== void 0 ? _a : 'left' : 'left';
  }

}

/* script */
const __vue_script__$T = ReviewCard$1;
/* template */

var __vue_render__$T = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "reviewCard",
    staticClass: "oke-testimonialCard",
    class: "oke-testimonialCard--" + _vm.reviewLayoutSettings.reviewDetailsPosition
  }, [_c('div', {
    staticClass: "oke-testimonialCard-head",
    class: "" + (_vm.showProductName ? 'oke-testimonialCard-head--hasProductName' : '')
  }, [_c('div', {
    staticClass: "oke-testimonialCard-reviewer",
    class: "oke-testimonialCard-reviewer--" + _vm.testimonialAlignment
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "layout": _vm.hideAvatars ? 'minimal' : 'side-by-side'
    }
  }), _vm._v(" "), _vm.showProductName ? _c('p', {
    staticClass: "oke-testimonialCard-productName"
  }, [_vm._v(_vm._s(_vm.review.productName))]) : _vm._e()], 1), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-testimonialCard-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review,
      "showTitle": false,
      "layout": 'image-only'
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-testimonialCard-content"
  }, [_c('review-basic-content', {
    attrs: {
      "alignment": _vm.testimonialAlignment,
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": _vm.showDates,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-testimonialCard-container",
    class: "oke-testimonialCard-container--" + _vm.testimonialAlignment
  }, [_vm.reviewCardHasAttributes ? _c('div', {
    staticClass: "oke-testimonialCard-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating,
      "alignment": _vm.testimonialAlignment
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.reviewCardHasMedia ? _c('div', {
    staticClass: "oke-testimonialCard-media",
    style: {
      'text-align': _vm.testimonialAlignment
    },
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "alignment": _vm.testimonialAlignment,
      "maxMediaCount": 2,
      "mediaContext": "review"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.isReplyVisible && _vm.review.reply ? _c('div', {
    staticClass: "oke-testimonialCard-reply",
    class: "oke-testimonialCard-reply--" + _vm.testimonialAlignment
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-helpful",
    class: "oke-w-review-helpful--" + (_vm.testimonialAlignment === 'left' ? 'rightAlign' : 'centerAlign')
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)], 1)]);
};

var __vue_staticRenderFns__$T = [];
/* style */

const __vue_inject_styles__$T = undefined;
/* scoped */

const __vue_scope_id__$T = undefined;
/* module identifier */

const __vue_module_identifier__$T = undefined;
/* functional template */

const __vue_is_functional_template__$T = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$T = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$T,
  staticRenderFns: __vue_staticRenderFns__$T
}, __vue_inject_styles__$T, __vue_script__$T, __vue_scope_id__$T, __vue_is_functional_template__$T, __vue_module_identifier__$T, false, undefined, undefined, undefined);

var TestimonialCard = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$T
});

class ReviewCard extends mixins(ReviewCardBase$1) {}

/* script */
const __vue_script__$S = ReviewCard;
/* template */

var __vue_render__$S = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "reviewCard",
    staticClass: "oke-reviewCardMinimalCentered"
  }, [_c('div', {
    staticClass: "oke-reviewCardMinimalCentered-head",
    class: "" + (_vm.showProductName ? 'oke-reviewCardMinimalCentered-head--hasProductName' : '')
  }, [_vm.showProductInfo ? _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review,
      "layout": !_vm.showProductName ? 'image-only' : 'stacked',
      "showTitle": false
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-contentContainer"
  }, [_c('div', {
    staticClass: "oke-reviewCardMinimalCentered-content"
  }, [_c('review-basic-content', {
    attrs: {
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": _vm.showDates,
      "starGap": _vm.starGap,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings,
      "alignment": "center"
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _vm.reviewCardHasAttributes ? _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating,
      "alignment": "center"
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.reviewCardHasMedia ? _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-media",
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "maxMediaCount": 2,
      "mediaContext": "review",
      "alignment": "center"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.isReplyVisible && _vm.review.reply ? _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-reviewCardMinimalCentered-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "layout": _vm.hideAvatars ? 'minimal' : 'side-by-side'
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-helpful"
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)], 1)]);
};

var __vue_staticRenderFns__$S = [];
/* style */

const __vue_inject_styles__$S = undefined;
/* scoped */

const __vue_scope_id__$S = undefined;
/* module identifier */

const __vue_module_identifier__$S = undefined;
/* functional template */

const __vue_is_functional_template__$S = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$S = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$S,
  staticRenderFns: __vue_staticRenderFns__$S
}, __vue_inject_styles__$S, __vue_script__$S, __vue_scope_id__$S, __vue_is_functional_template__$S, __vue_module_identifier__$S, false, undefined, undefined, undefined);

var ReviewCardMinimalCentered = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$S
});

let LargeBadge$1 = class LargeBadge extends Vue {
  get badgeColor() {
    var _a;

    return this.badgeSettings.colorScheme === 'custom' ? (_a = this.badgeSettings.backgroundColor) !== null && _a !== void 0 ? _a : kBadgeDarkBackgroundColor : this.badgeSettings.colorScheme === 'dark' ? kBadgeDarkBackgroundColor : kBadgeLightBackgroundColor;
  }

  get textColor() {
    var _a;

    return this.badgeSettings.colorScheme === 'custom' ? (_a = this.badgeSettings.textColor) !== null && _a !== void 0 ? _a : 'white' : this.badgeSettings.colorScheme === 'dark' ? 'white' : kBadgeDarkBackgroundColor;
  }

  get fontSize() {
    return this.reviewCount < 100000 ? '20px' : this.reviewCount < 1000000 ? '18px' : '16px';
  }

  get formattedReviewCount() {
    return this.reviewCount.toLocaleString();
  }

  get strokeColor() {
    var _a;

    return this.badgeSettings.colorScheme === 'custom' ? (_a = this.badgeSettings.borderColor) !== null && _a !== void 0 ? _a : this.badgeColor : this.badgeSettings.colorScheme === 'light' ? kBadgeLightBorderColor : this.badgeColor;
  }

};

__decorate([Prop()], LargeBadge$1.prototype, "badgeSettings", void 0);

__decorate([Prop()], LargeBadge$1.prototype, "reviewCount", void 0);

__decorate([Prop()], LargeBadge$1.prototype, "averageRating", void 0);

LargeBadge$1 = __decorate([Component({
  components: {
    // Stars: () => import(/* webpackChunkName: "modules/okendo-star-rating" */ '@/components/Stars.vue')
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], LargeBadge$1);
var script$R = LargeBadge$1;

/* script */
const __vue_script__$R = script$R;
/* template */

var __vue_render__$R = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-largeBadge"
  }, [_c('span', {
    staticClass: "oke-largeBadge-count",
    style: {
      color: _vm.textColor,
      fontSize: _vm.fontSize
    }
  }, [_vm._v("\n        " + _vm._s(_vm.formattedReviewCount) + "\n    ")]), _vm._v(" "), _c('span', {
    staticClass: "oke-largeBadge-text",
    style: {
      color: _vm.textColor
    }
  }, [_vm._v(_vm._s(_vm.$tc('Verified Reviews')))]), _vm._v(" "), _c('div', {
    staticClass: "oke-largeBadge-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.averageRating,
      "height": 13
    }
  })], 1), _vm._v(" "), _c('svg', {
    staticClass: "oke-largeBadge-svg",
    attrs: {
      "width": "128",
      "height": "103",
      "viewBox": "0 0 128 103",
      "fill": "none",
      "xmlns": "http://www.w3.org/2000/svg"
    }
  }, [_c('g', {
    style: {
      stroke: _vm.strokeColor
    }
  }, [_c('path', {
    attrs: {
      "d": "M3.34843 42.5H17c1.3807 0 2.5 1.1193 2.5 2.5v22.5H3.34843c-1.13501 0-1.85881-1.2118-1.3207-2.2111l4.90194-9.1037c.39843-.7399.39843-1.6305 0-2.3704l-4.90194-9.1037c-.53811-.9993.18569-2.2111 1.3207-2.2111ZM124.652 42.5H111c-1.381 0-2.5 1.1193-2.5 2.5v22.5h16.152c1.135 0 1.858-1.2118 1.32-2.2111l-4.902-9.1037c-.398-.7399-.398-1.6305 0-2.3704l4.902-9.1037c.538-.9993-.185-2.2111-1.32-2.2111Z",
      "fill": "#fff"
    }
  }), _vm._v(" "), _c('path', {
    style: {
      fill: _vm.badgeColor
    },
    attrs: {
      "d": "M27 .5h74c4.142 0 7.5 3.35786 7.5 7.5v67.3841c0 2.8649-1.632 5.4796-4.206 6.7379l-36.9999 18.089c-2.0785 1.016-4.5097 1.016-6.5882 0l-37-18.089C21.1321 80.8637 19.5 78.249 19.5 75.3841V7.99999C19.5 3.85786 22.8579.5 27 .5Z"
    }
  }), _vm._v(" "), _c('rect', {
    attrs: {
      "x": "12.5",
      "y": "38.5",
      "width": "101",
      "height": "25",
      "rx": "2.5",
      "fill": "#fff"
    }
  })])])]);
};

var __vue_staticRenderFns__$R = [];
/* style */

const __vue_inject_styles__$R = undefined;
/* scoped */

const __vue_scope_id__$R = undefined;
/* module identifier */

const __vue_module_identifier__$R = undefined;
/* functional template */

const __vue_is_functional_template__$R = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$R = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$R,
  staticRenderFns: __vue_staticRenderFns__$R
}, __vue_inject_styles__$R, __vue_script__$R, __vue_scope_id__$R, __vue_is_functional_template__$R, __vue_module_identifier__$R, false, undefined, undefined, undefined);

var LargeBadge = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$R
});

let SmallBadge$1 = class SmallBadge extends Vue {
  get border() {
    return this.badgeSettings.colorScheme === 'custom' ? this.badgeSettings.borderColor ? `1px solid ${this.badgeSettings.borderColor}` : undefined : this.badgeSettings.colorScheme === 'light' ? `1px solid ${kBadgeLightBorderColor}` : undefined;
  }

  get badgeColor() {
    var _a;

    return this.badgeSettings.colorScheme === 'custom' ? (_a = this.badgeSettings.backgroundColor) !== null && _a !== void 0 ? _a : kBadgeDarkBackgroundColor : this.badgeSettings.colorScheme === 'dark' ? kBadgeDarkBackgroundColor : kBadgeLightBackgroundColor;
  }

  get formattedReviewCount() {
    return this.reviewCount.toLocaleString();
  }

  get textColor() {
    var _a;

    return this.badgeSettings.colorScheme === 'custom' ? (_a = this.badgeSettings.textColor) !== null && _a !== void 0 ? _a : 'white' : this.badgeSettings.colorScheme === 'dark' ? 'white' : kBadgeDarkBackgroundColor;
  }

  get starHeight() {
    var _a;

    return ((_a = this.badgeSettings.stars) === null || _a === void 0 ? void 0 : _a.height) ? OkendoUtils.toPixels(this.badgeSettings.stars.height) : 16;
  }

  get starInterspace() {
    var _a, _b;

    return (_b = (_a = this.badgeSettings.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.interspace;
  }

};

__decorate([Prop()], SmallBadge$1.prototype, "badgeSettings", void 0);

__decorate([Prop()], SmallBadge$1.prototype, "reviewCount", void 0);

__decorate([Prop()], SmallBadge$1.prototype, "averageRating", void 0);

SmallBadge$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], SmallBadge$1);
var script$Q = SmallBadge$1;

/* script */
const __vue_script__$Q = script$Q;
/* template */

var __vue_render__$Q = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-smallBadge",
    style: {
      backgroundColor: _vm.badgeColor,
      border: _vm.border
    }
  }, [_c('div', {
    staticClass: "oke-smallBadge-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.averageRating,
      "height": _vm.starHeight,
      "interspace": _vm.starInterspace
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-smallBadge-count",
    style: {
      color: _vm.textColor
    }
  }, [_vm._v("\n        " + _vm._s(_vm.formattedReviewCount) + "\n        "), _c('span', [_vm._v(_vm._s(_vm.$tc('Review', _vm.reviewCount)))])])]);
};

var __vue_staticRenderFns__$Q = [];
/* style */

const __vue_inject_styles__$Q = undefined;
/* scoped */

const __vue_scope_id__$Q = undefined;
/* module identifier */

const __vue_module_identifier__$Q = undefined;
/* functional template */

const __vue_is_functional_template__$Q = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$Q = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$Q,
  staticRenderFns: __vue_staticRenderFns__$Q
}, __vue_inject_styles__$Q, __vue_script__$Q, __vue_scope_id__$Q, __vue_is_functional_template__$Q, __vue_module_identifier__$Q, false, undefined, undefined, undefined);

var SmallBadge = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$Q
});

let MinimalBadge$1 = class MinimalBadge extends Vue {
  get formattedReviewCount() {
    return this.reviewCount.toLocaleString();
  }

  get starHeight() {
    var _a;

    return ((_a = this.badgeSettings.stars) === null || _a === void 0 ? void 0 : _a.height) ? OkendoUtils.toPixels(this.badgeSettings.stars.height) : 16;
  }

  get starInterspace() {
    var _a, _b;

    return (_b = (_a = this.badgeSettings.stars) === null || _a === void 0 ? void 0 : _a.globalOverrideSettings) === null || _b === void 0 ? void 0 : _b.interspace;
  }

};

__decorate([Prop()], MinimalBadge$1.prototype, "badgeSettings", void 0);

__decorate([Prop()], MinimalBadge$1.prototype, "reviewCount", void 0);

__decorate([Prop()], MinimalBadge$1.prototype, "averageRating", void 0);

MinimalBadge$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], MinimalBadge$1);
var script$P = MinimalBadge$1;

/* script */
const __vue_script__$P = script$P;
/* template */

var __vue_render__$P = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-minimalBadge"
  }, [_c('div', {
    staticClass: "oke-minimalBadge-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.averageRating,
      "height": _vm.starHeight,
      "interspace": _vm.starInterspace
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-minimalBadge-count"
  }, [_vm._v("\n        " + _vm._s(_vm.formattedReviewCount) + "\n        "), _c('span', [_vm._v(_vm._s(_vm.$tc('Review', _vm.reviewCount)))])])]);
};

var __vue_staticRenderFns__$P = [];
/* style */

const __vue_inject_styles__$P = undefined;
/* scoped */

const __vue_scope_id__$P = undefined;
/* module identifier */

const __vue_module_identifier__$P = undefined;
/* functional template */

const __vue_is_functional_template__$P = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$P = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$P,
  staticRenderFns: __vue_staticRenderFns__$P
}, __vue_inject_styles__$P, __vue_script__$P, __vue_scope_id__$P, __vue_is_functional_template__$P, __vue_module_identifier__$P, false, undefined, undefined, undefined);

var MinimalBadge = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$P
});

let MediaOverlay$1 = class MediaOverlay extends Vue {
  onMediaClick() {
    this.$emit('mediaClicked');
  }

};

__decorate([Prop()], MediaOverlay$1.prototype, "overlayHeight", void 0);

__decorate([Prop()], MediaOverlay$1.prototype, "overlayItem", void 0);

__decorate([Prop()], MediaOverlay$1.prototype, "linkText", void 0);

__decorate([Prop()], MediaOverlay$1.prototype, "isVisible", void 0);

MediaOverlay$1 = __decorate([Component({
  components: {
    Stars: () => Promise.resolve().then(function () { return Stars; })
  }
})], MediaOverlay$1);
var script$O = MediaOverlay$1;

/* script */
const __vue_script__$O = script$O;
/* template */

var __vue_render__$O = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-mediaOverlay",
    class: {
      'oke-mediaOverlay--isSmall': _vm.overlayHeight < 160
    }
  }, [_c('div', {
    staticClass: "oke-mediaOverlay-container",
    on: {
      "click": function ($event) {
        return _vm.onMediaClick();
      }
    }
  }, [_vm.overlayItem.rating ? _c('div', {
    staticClass: "oke-mediaOverlay-rating"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.overlayItem.rating,
      "height": 12
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.overlayItem.body ? _c('div', {
    staticClass: "oke-mediaOverlay-text"
  }, [_vm._v("\n            " + _vm._s(_vm.overlayItem.body) + "\n        ")]) : _vm._e(), _vm._v(" "), _c('button', {
    staticClass: "oke-mediaOverlay-button"
  }, [_vm._v("\n            " + _vm._s(_vm.$tc(_vm.linkText)) + "\n        ")])])]);
};

var __vue_staticRenderFns__$O = [];
/* style */

const __vue_inject_styles__$O = undefined;
/* scoped */

const __vue_scope_id__$O = undefined;
/* module identifier */

const __vue_module_identifier__$O = undefined;
/* functional template */

const __vue_is_functional_template__$O = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$O = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$O,
  staticRenderFns: __vue_staticRenderFns__$O
}, __vue_inject_styles__$O, __vue_script__$O, __vue_scope_id__$O, __vue_is_functional_template__$O, __vue_module_identifier__$O, false, undefined, undefined, undefined);

var MediaOverlay = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$O
});

let MediaThumbnail$1 = class MediaThumbnail extends Vue {
  constructor() {
    super(...arguments);
    this.viewState = 'loading';
  }

  created() {
    var _a, _b;

    this.dynamicImageKey = 'dynamicImageKey' in this.mediaItem ? this.mediaItem.dynamicImageKey : 'dynamicKey' in this.mediaItem ? this.mediaItem.dynamicKey : undefined;
    this.fullSizeUrl = 'fullSizeUrl' in this.mediaItem ? this.mediaItem.fullSizeUrl : 'imageUrls' in this.mediaItem ? (_a = this.mediaItem.imageUrls) === null || _a === void 0 ? void 0 : _a.fullSizeUrl : undefined;
    this.videoPosterUrl = 'videoPosterUrl' in this.mediaItem ? this.mediaItem.videoPosterUrl : 'videoUrls' in this.mediaItem ? (_b = this.mediaItem.videoUrls) === null || _b === void 0 ? void 0 : _b.videoPosterUrl : undefined;
  }

  get mediaUrl() {
    return this.mediaItem.type === 'video' ? this.videoPosterUrl : this.getImageUrl();
  }

  get altLabel() {
    var _a;

    if ((_a = this.alt) === null || _a === void 0 ? void 0 : _a.length) {
      return this.alt;
    } else if (this.mediaItem.type === 'video') {
      return this.linked ? this.$tc('Customer-uploaded video, show more details') : this.$tc('Customer-uploaded video');
    } else {
      return this.linked ? this.$tc('Customer-uploaded image, show more details') : this.$tc('Customer-uploaded image');
    }
  }

  onImageLoaded() {
    this.$emit('imageLoaded');
    this.viewState = 'content';
  }

  onImageError() {
    this.viewState = 'error';
  }

  getImageUrl() {
    return this.dynamicImageKey ? ImageUtils.getTranscodedImageUrl(this.dynamicImageKey, this.transcodedWidth, this.transcodedHeight) : this.fullSizeUrl;
  }

  onThumbnailClick() {
    this.$emit('mediaThumbnailClick');
  }

};

__decorate([Prop()], MediaThumbnail$1.prototype, "mediaItem", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "alt", void 0);

__decorate([Prop({
  default: () => false
})], MediaThumbnail$1.prototype, "linked", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "transcodedHeight", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "transcodedWidth", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "imageClass", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "outerClass", void 0);

__decorate([Prop({
  default: () => 'review'
})], MediaThumbnail$1.prototype, "mediaContext", void 0);

__decorate([Prop()], MediaThumbnail$1.prototype, "productName", void 0);

MediaThumbnail$1 = __decorate([Component], MediaThumbnail$1);
var script$N = MediaThumbnail$1;

/* script */
const __vue_script__$N = script$N;
/* template */

var __vue_render__$N = function () {
  var _obj;

  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.mediaItem ? _c('div', {
    staticClass: "oke-media",
    class: (_obj = {}, _obj[_vm.outerClass] = _vm.outerClass, _obj['oke-media--video'] = _vm.mediaItem.type === 'video', _obj['oke-media--linked'] = _vm.linked, _obj['oke-is-loading'] = _vm.viewState === 'loading', _obj['oke-is-error'] = _vm.viewState === 'error', _obj),
    attrs: {
      "role": "button"
    }
  }, [_vm.linked ? [_c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: (_vm.mediaContext === 'aggregate' ? 'Review Aggregate' : 'Review') + " " + (_vm.mediaItem.type === 'video' ? 'Video' : 'Photo') + " Click",
        label: _vm.productName
      },
      expression: "{\n                action: `${ mediaContext === 'aggregate' ? 'Review Aggregate' : 'Review' } ${ mediaItem.type === 'video' ? 'Video' : 'Photo' } Click`,\n                label: productName\n            }",
      arg: "click"
    }],
    staticClass: "oke-media-link",
    attrs: {
      "tabindex": "0",
      "type": "button"
    },
    on: {
      "click": function ($event) {
        $event.stopPropagation();
        return _vm.onThumbnailClick.apply(null, arguments);
      }
    }
  }, [_c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.mediaUrl,
      expression: "mediaUrl"
    }],
    staticClass: "oke-media-image",
    attrs: {
      "alt": _vm.altLabel,
      "draggable": "false"
    },
    on: {
      "load": function ($event) {
        return _vm.onImageLoaded();
      },
      "error": function ($event) {
        return _vm.onImageError();
      }
    }
  })])] : [_c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.mediaUrl,
      expression: "mediaUrl"
    }],
    staticClass: "oke-media-image",
    attrs: {
      "alt": _vm.altLabel,
      "draggable": "false"
    },
    on: {
      "load": function ($event) {
        return _vm.onImageLoaded();
      },
      "error": function ($event) {
        return _vm.onImageError();
      }
    }
  })]], 2) : _vm._e();
};

var __vue_staticRenderFns__$N = [];
/* style */

const __vue_inject_styles__$N = undefined;
/* scoped */

const __vue_scope_id__$N = undefined;
/* module identifier */

const __vue_module_identifier__$N = undefined;
/* functional template */

const __vue_is_functional_template__$N = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$N = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$N,
  staticRenderFns: __vue_staticRenderFns__$N
}, __vue_inject_styles__$N, __vue_script__$N, __vue_scope_id__$N, __vue_is_functional_template__$N, __vue_module_identifier__$N, false, undefined, undefined, undefined);

var MediaThumbnail = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$N
});

let ShowMore$1 = class ShowMore extends Vue {
  onClick(event) {
    event.preventDefault();
    event.stopImmediatePropagation();
    this.$refs.showMoreButton.blur();
    this.$emit('click', event.target.value);
  } // TODO: Consider widget instances if we have multiples how do we know which next url this applies to.


  get sanitizedNextUrl() {
    if (!this.nextUrl) {
      return;
    }

    const searchParams = new URLSearchParams(window.location.search);
    const contentTypeUrlParamName = this.contentType === 'reviews' ? 'okeReviewsNextUrl' : 'okeQuestionsNextUrl';
    searchParams.set(contentTypeUrlParamName, encodeURIComponent(this.nextUrl));

    if (this.pageNumber) {
      const pageNumUrlParamName = this.contentType === 'reviews' ? 'okeReviewsPageNum' : 'okeQuestionsPageNum';
      searchParams.set(pageNumUrlParamName, (this.pageNumber + 1).toString());
    }

    return `?${searchParams.toString()}`;
  }

};

__decorate([Prop()], ShowMore$1.prototype, "nextUrl", void 0);

__decorate([Prop()], ShowMore$1.prototype, "pageNumber", void 0);

__decorate([Prop({
  default: () => false
})], ShowMore$1.prototype, "isLoading", void 0);

__decorate([Prop({
  default: () => false
})], ShowMore$1.prototype, "allowSearchEnginePagination", void 0);

__decorate([Prop({
  default: () => 'reviews'
})], ShowMore$1.prototype, "contentType", void 0);

ShowMore$1 = __decorate([Component], ShowMore$1);
var script$M = ShowMore$1;

/* script */
const __vue_script__$M = script$M;
/* template */

var __vue_render__$M = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.nextUrl || _vm.isLoading ? _c('div', {
    staticClass: "oke-showMore"
  }, [_c(_vm.allowSearchEnginePagination ? 'a' : 'button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: _vm.contentType + " Load More"
      },
      expression: "{ action: `${contentType} Load More` }",
      arg: "click"
    }],
    ref: "showMoreButton",
    tag: "component",
    staticClass: "oke-showMore-button oke-button",
    class: {
      'oke-is-loading': _vm.isLoading
    },
    attrs: {
      "href": _vm.allowSearchEnginePagination ? _vm.sanitizedNextUrl : undefined,
      "type": !_vm.allowSearchEnginePagination ? 'button' : undefined
    },
    on: {
      "click": function ($event) {
        return _vm.onClick($event);
      }
    }
  }, [_c('span', {
    staticClass: "oke-showMore-button-text oke-button-text"
  }, [_vm._v("\n            " + _vm._s(_vm.isLoading ? _vm.$tc('Loading more') : _vm.$tc('Show More')) + "\n        ")])])], 1) : _vm._e();
};

var __vue_staticRenderFns__$M = [];
/* style */

const __vue_inject_styles__$M = undefined;
/* scoped */

const __vue_scope_id__$M = undefined;
/* module identifier */

const __vue_module_identifier__$M = undefined;
/* functional template */

const __vue_is_functional_template__$M = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$M = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$M,
  staticRenderFns: __vue_staticRenderFns__$M
}, __vue_inject_styles__$M, __vue_script__$M, __vue_scope_id__$M, __vue_is_functional_template__$M, __vue_module_identifier__$M, false, undefined, undefined, undefined);

var ShowMore = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$M
});

let SortSelect = class SortSelect extends Vue {
  mounted() {
    var _a; // Vue ignores [selected] if it's set in the template
    // Set selected attribute with refs so that metafields will start with the right value selected


    const options = (_a = this.$refs.sortSelect) === null || _a === void 0 ? void 0 : _a.querySelectorAll('option');
    const selectedOption = Array.from(options).find(option => option.value === this.value);

    if (selectedOption) {
      selectedOption.setAttribute('selected', 'true');
    }
  }

  onSortChange(event) {
    this.$emit('input', event.target.value);
  }

  get selectId() {
    return `oke-sortSelect--${this.contentType}`;
  }

};

__decorate([Prop()], SortSelect.prototype, "value", void 0);

__decorate([Prop({
  default: () => 'reviews'
})], SortSelect.prototype, "contentType", void 0);

__decorate([Prop({
  default: () => false
})], SortSelect.prototype, "disabled", void 0);

__decorate([Prop()], SortSelect.prototype, "mediaLayout", void 0);

SortSelect = __decorate([Component], SortSelect);
var script$L = SortSelect;

/* script */
const __vue_script__$L = script$L;
/* template */

var __vue_render__$L = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-sortSelect"
  }, [_c('label', {
    staticClass: "oke-sortSelect-label",
    attrs: {
      "for": _vm.selectId
    }
  }, [_vm._v("\n        " + _vm._s(_vm.$tc('Sort')) + "\n    ")]), _vm._v(" "), _c('select', {
    directives: [{
      name: "ga",
      rawName: "v-ga:change",
      value: {
        action: _vm.contentType === 'questions' ? 'Question Sort' : 'Review Sort'
      },
      expression: "{ action: contentType === 'questions' ? 'Question Sort' : 'Review Sort' }",
      arg: "change"
    }],
    ref: "sortSelect",
    staticClass: "oke-sortSelect-sort oke-select",
    attrs: {
      "disabled": _vm.disabled,
      "id": _vm.selectId
    },
    domProps: {
      "value": _vm.value
    },
    on: {
      "change": function ($event) {
        return _vm.onSortChange($event);
      }
    }
  }, [_c('option', {
    attrs: {
      "value": "date desc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Most Recent')))]), _vm._v(" "), _c('option', {
    attrs: {
      "value": "date asc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Oldest')))]), _vm._v(" "), _c('option', {
    attrs: {
      "value": "helpful desc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Most Helpful')))]), _vm._v(" "), _vm.contentType === 'reviews' ? [_vm.mediaLayout !== 'hidden' ? _c('option', {
    attrs: {
      "value": "has_media desc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Photos & Videos')))]) : _vm._e(), _vm._v(" "), _c('option', {
    attrs: {
      "value": "rating desc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Highest Rating')))]), _vm._v(" "), _c('option', {
    attrs: {
      "value": "rating asc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Lowest Rating')))]), _vm._v(" "), _c('option', {
    attrs: {
      "value": "unhelpful desc"
    }
  }, [_vm._v(_vm._s(_vm.$tc('Least Helpful')))])] : _vm._e()], 2)]);
};

var __vue_staticRenderFns__$L = [];
/* style */

const __vue_inject_styles__$L = undefined;
/* scoped */

const __vue_scope_id__$L = undefined;
/* module identifier */

const __vue_module_identifier__$L = undefined;
/* functional template */

const __vue_is_functional_template__$L = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$L = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$L,
  staticRenderFns: __vue_staticRenderFns__$L
}, __vue_inject_styles__$L, __vue_script__$L, __vue_scope_id__$L, __vue_is_functional_template__$L, __vue_module_identifier__$L, false, undefined, undefined, undefined);

let Alert$1 = class Alert extends Vue {
  constructor() {
    super(...arguments);
    this.isVisible = false;
    this.message = i18n.tc('Loading...');
  }

  show(message, timeout = 0) {
    this.isVisible = true;
    this.message = message;

    if (timeout) {
      setTimeout(() => {
        this.isVisible = false;
      }, timeout);
    }
  }

  hide() {
    this.isVisible = false;
  }

};

__decorate([Prop()], Alert$1.prototype, "position", void 0);

Alert$1 = __decorate([Component], Alert$1);
var script$K = Alert$1;

/* script */
const __vue_script__$K = script$K;
/* template */

var __vue_render__$K = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-alert",
    class: {
      'oke-is-visible': _vm.isVisible && _vm.message.length,
      'oke-alert--top': _vm.position === 'top',
      'oke-alert--bottom': _vm.position === 'bottom'
    },
    attrs: {
      "aria-hidden": !_vm.isVisible,
      "role": "alert",
      "aria-live": "assertive",
      "aria-atomic": "true"
    }
  }, [_c('div', {
    staticClass: "oke-alert-inner"
  }, [_vm._v("\n        " + _vm._s(_vm.message) + "\n        "), _vm._t("default")], 2)]);
};

var __vue_staticRenderFns__$K = [];
/* style */

const __vue_inject_styles__$K = undefined;
/* scoped */

const __vue_scope_id__$K = undefined;
/* module identifier */

const __vue_module_identifier__$K = undefined;
/* functional template */

const __vue_is_functional_template__$K = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$K = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$K,
  staticRenderFns: __vue_staticRenderFns__$K
}, __vue_inject_styles__$K, __vue_script__$K, __vue_scope_id__$K, __vue_is_functional_template__$K, __vue_module_identifier__$K, false, undefined, undefined, undefined);

var Alert = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$K
});

let Reviews$1 = class Reviews extends Vue {
  constructor() {
    var _a;

    super(...arguments);
    this.reviews = this.initialReviews;
    this.nextUrl = (_a = this.initialNextUrl) !== null && _a !== void 0 ? _a : null;
    this.selectedSortOption = 'date desc';
    this.activeFilters = [];
    this.areFiltersOpen = false;
    this.filtersState = 'unopened';
    this.activeRatingFilters = [];
    this.viewState = 'loading';
    this.pageNumber = 1;
    this.showResetWidget = false;
    this.searchEnginePaginationActive = false;
  }

  get isLoadingMore() {
    return this.viewState === 'loading-more';
  }

  get isLoadingReviews() {
    return this.viewState === 'loading' || this.viewState === 'empty-filtered-loading';
  }

  get showReviewsList() {
    return this.viewState !== 'empty' && this.viewState !== 'empty-filtered' && this.viewState !== 'empty-filtered-loading';
  }

  get showMainWrapperBorder() {
    return this.reviewsSettings.list.layout.name !== 'carousel';
  }

  created() {
    this.selectedSortOption = this.reviewsSettings.controls.defaultSort || this.selectedSortOption;
    this.updateReviewCount(this.initialReviewCount);
    this.filtersStartOpen = this.filterMode === 'open' || this.filterMode === 'open-always';
    this.areFiltersOpen = this.filtersStartOpen;
    this.filtersState = this.filtersStartOpen ? this.productAttributes ? 'loaded' : 'loading' : 'unopened';
    this.viewState = this.reviewCount > 0 ? 'content' : 'empty';
    this.pageNumber = this.initialPageNumber;
    this.searchEnginePaginationActive = this.hasInitialSearchEnginePaginationUrl;
  }

  mounted() {
    if (this.initialPageNumber > 1 && this.searchEnginePaginationActive) {
      this.showResetWidget = true;
      const alertMessage = `${this.$tc('Showing reviews starting from page {0}', undefined, [this.pageNumber])} - `;
      this.$refs.topAlert.show(alertMessage);
      this.$refs.bottomAlert.show(alertMessage);
    }
  }

  get reviewsSettings() {
    return SharedSettings.widgetSettings.reviewsWidget.reviews;
  }

  get writeReviewButtonEnabled() {
    return this.reviewsSettings.controls.writeReviewButtonEnabled;
  }

  get filtersEnabled() {
    return this.reviewsSettings.controls.filterMode !== 'off' && this.widgetMode !== 'all';
  }

  get filterMode() {
    return this.reviewsSettings.controls.filterMode;
  }

  get freeTextSearchEnabled() {
    return this.reviewsSettings.controls.freeTextSearchEnabled;
  }

  get reviewListComponent() {
    switch (this.reviewsSettings.list.layout.name) {
      case 'carousel':
        return 'ReviewsListCarousel';

      case 'masonry':
        return 'ReviewsListMasonry';

      default:
        return 'ReviewsList';
    }
  }

  get individualReviewSettings() {
    var _a, _b;

    const reviewListSettings = SharedSettings.widgetSettings.reviewsWidget.reviews.list;
    const reviewStyleSettings = SharedSettings.widgetSettings.reviewsWidget.style;
    const baseSettings = {
      showAvatars: reviewStyleSettings.avatar.enabled,
      showDates: reviewStyleSettings.showDates,
      showMedia: reviewListSettings.media.layout !== 'hidden',
      stars: {
        height: reviewStyleSettings.stars.height,
        interspace: (_b = (_a = reviewStyleSettings.stars.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.interspace) !== null && _b !== void 0 ? _b : SharedSettings.widgetSettings.global.stars.interspace
      },
      truncationSettings: reviewListSettings.truncation
    };

    switch (reviewListSettings.layout.name) {
      case 'carousel':
      case 'masonry':
        // WidgetCardSettings
        return { ...baseSettings,
          layout: reviewListSettings.layout.cardLayout,
          media: reviewListSettings.media
        };

      case 'default':
      case 'minimal':
      case 'split':
      default:
        // TODO: Add showProductName customizability
        // ReviewListSettings
        return { ...baseSettings,
          layout: reviewListSettings.layout,
          media: reviewListSettings.media
        };
    }
  }

  get mediaLayout() {
    return this.reviewsSettings.list.media.layout;
  }

  resetReviews() {
    this.pageNumber = 1;
    this.searchEnginePaginationActive = false;
    this.nextUrl = null;
    this.showResetWidget = false;
    this.$refs.topAlert.hide();
    this.$refs.bottomAlert.hide();
  }

  reloadReviews() {
    if (this.searchEnginePaginationActive) {
      this.resetReviews();
    }

    this.loadReviews(this.reviewsSettings.list.initialPageSize, this.selectedSortOption, this.activeFilters, this.activeRatingFilters, this.freeTextSearchFilter);
  }

  onFiltersChange(newFilters) {
    this.activeFilters = newFilters;
    this.reloadReviews();
  }

  onFiltersRatingChange(newRatingFilters) {
    this.activeRatingFilters = newRatingFilters;
    this.reloadReviews();
  }

  onFreeTextSearchChange(searchQuery) {
    this.freeTextSearchFilter = searchQuery;
    this.reloadReviews();
  }

  showMoreReviews() {
    if (this.nextUrl && !this.isLoadingMore) {
      this.pageNumber = this.pageNumber + 1;
      this.viewState = 'loading-more';
      this.addReviewsFromPromise(OkendoApi.getMore(this.nextUrl, this.reviewsSettings.list.loadMorePageSize));
    }
  }

  onFiltersToggle() {
    if (this.filtersState === 'unopened') {
      this.filtersState = 'loading';
    }

    this.areFiltersOpen = !this.areFiltersOpen;
  }

  onFiltersLoad() {
    this.filtersState = 'loaded';
  }

  onFiltersReload() {
    this.filtersState = 'loading';
  }

  updateReviewCount(count) {
    var _a;

    this.reviewCount = count !== null && count !== void 0 ? count : this.initialReviewCount;
    this.prettyReviewCount = (_a = OkendoUtils.getPrettyNumber(this.reviewCount)) !== null && _a !== void 0 ? _a : '0';
  }

  loadReviews(limit, sort, filters, ratingFilters, freeTextSearchFilter) {
    this.viewState = this.viewState === 'empty-filtered' ? 'empty-filtered-loading' : 'loading';
    const loadReviewsPromise = OkendoApi.getReviews(this.productId, this.groupId, limit, sort, filters, ratingFilters, freeTextSearchFilter);
    this.addReviewsFromPromise(loadReviewsPromise, true);
  }

  async addReviewsFromPromise(reviewPromise, replaceExistingReviews) {
    var _a;

    try {
      const reviewResponse = await reviewPromise;
      const {
        reviews,
        nextUrl
      } = reviewResponse;
      this.nextUrl = nextUrl !== null && nextUrl !== void 0 ? nextUrl : null;
      this.reviews = replaceExistingReviews ? reviews : [...this.reviews, ...reviews];
      this.updateReviewCount('total' in reviewResponse ? (_a = reviewResponse.total) === null || _a === void 0 ? void 0 : _a.count : undefined);
    } catch (_b) {
      const alertMessage = this.$tc('Error occurred loading reviews, please try again');
      this.$refs.topAlert.show(alertMessage, 2000);
      this.$refs.bottomAlert.show(alertMessage, 2000);
    } finally {
      this.viewState = this.reviews.length > 0 ? 'content' : this.filtersEnabled ? 'empty-filtered' : 'empty';
    }
  }

};

__decorate([Prop()], Reviews$1.prototype, "productId", void 0);

__decorate([Prop()], Reviews$1.prototype, "groupId", void 0);

__decorate([Prop()], Reviews$1.prototype, "writeReviewProductId", void 0);

__decorate([Prop()], Reviews$1.prototype, "widgetSize", void 0);

__decorate([Prop()], Reviews$1.prototype, "widgetWidth", void 0);

__decorate([Prop()], Reviews$1.prototype, "initialReviews", void 0);

__decorate([Prop()], Reviews$1.prototype, "initialNextUrl", void 0);

__decorate([Prop()], Reviews$1.prototype, "initialReviewCount", void 0);

__decorate([Prop({
  default: () => 1
})], Reviews$1.prototype, "initialPageNumber", void 0);

__decorate([Prop()], Reviews$1.prototype, "widgetId", void 0);

__decorate([Prop()], Reviews$1.prototype, "widgetMode", void 0);

__decorate([Prop()], Reviews$1.prototype, "productAttributes", void 0);

__decorate([Prop({
  default: () => false
})], Reviews$1.prototype, "allowSearchEnginePagination", void 0);

__decorate([Prop({
  default: () => false
})], Reviews$1.prototype, "hasInitialSearchEnginePaginationUrl", void 0);

Reviews$1 = __decorate([Component({
  components: {
    ShowMore: __vue_component__$M,
    ReviewsList: async () => (await Promise.resolve().then(function () { return ReviewsList; })).default,
    ReviewsListMasonry: async () => (await Promise.resolve().then(function () { return ReviewsListMasonry; })).default,
    ReviewsListCarousel: async () => (await Promise.resolve().then(function () { return ReviewsListCarousel; })).default,
    SortSelect: __vue_component__$L,
    WriteReviewButton: async () => (await Promise.resolve().then(function () { return WriteReviewButton; })).default,
    Filters: async () => (await Promise.resolve().then(function () { return Filters; })).default,
    Alert: __vue_component__$K,
    State: async () => (await Promise.resolve().then(function () { return State; })).default
  }
})], Reviews$1);
var script$J = Reviews$1;

/* script */
const __vue_script__$J = script$J;
/* template */

var __vue_render__$J = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviews",
    class: {
      'oke-w-reviews--filtersAlwaysOpen': _vm.filterMode === 'open-always'
    }
  }, [_vm.viewState !== 'empty' ? [_vm.productId || _vm.writeReviewProductId ? _c('div', {
    staticClass: "oke-w-reviews-head"
  }, [_vm.productId && _vm.filtersEnabled ? _c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Filter Toggle Click'
      },
      expression: "{ action: 'Filter Toggle Click' }",
      arg: "click"
    }],
    staticClass: "oke-button oke-w-reviews-filterToggle",
    class: {
      'oke-is-loading': _vm.filtersState === 'loading',
      'oke-is-active': _vm.areFiltersOpen && _vm.filtersState === 'loaded'
    },
    attrs: {
      "aria-expanded": _vm.areFiltersOpen,
      "aria-busy": _vm.filtersState === 'loading',
      "aria-controls": "filter-options",
      "id": "filter-toggle",
      "type": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onFiltersToggle();
      }
    }
  }, [_c('span', {
    staticClass: "oke-icon"
  }), _vm._v(" "), _c('span', {
    staticClass: "oke-button-text"
  }, [_vm._v("\n                    " + _vm._s(_vm.$tc('Filters')) + " "), !_vm.areFiltersOpen && _vm.activeFilters.length ? _c('span', {
    staticClass: "oke-w-reviews-filterToggle-count"
  }, [_vm._v("(" + _vm._s(_vm.activeFilters.length) + ")")]) : _vm._e()])]) : _vm._e(), _vm._v(" "), _vm.productId ? _c('div', {
    staticClass: "oke-w-reviews-filters",
    attrs: {
      "id": "filter-options",
      "aria-labelledby": "filter-toggle",
      "role": "region"
    }
  }, [_vm.filtersEnabled && _vm.filtersState !== 'unopened' ? _c('filters', {
    attrs: {
      "filtersStartOpen": _vm.filtersStartOpen,
      "freeTextSearchEnabled": _vm.freeTextSearchEnabled,
      "isOpen": _vm.areFiltersOpen,
      "productAttributes": _vm.productAttributes,
      "productId": _vm.productId,
      "widgetId": _vm.widgetId
    },
    on: {
      "changeStarRating": function ($event) {
        return _vm.onFiltersRatingChange($event);
      },
      "changeFreeTextSearch": function ($event) {
        return _vm.onFreeTextSearchChange($event);
      },
      "change": function ($event) {
        return _vm.onFiltersChange($event);
      },
      "load": function ($event) {
        return _vm.onFiltersLoad();
      },
      "reload": function ($event) {
        return _vm.onFiltersReload();
      }
    }
  }) : _vm._e()], 1) : _vm._e(), _vm._v(" "), _vm.writeReviewButtonEnabled ? _c('div', {
    staticClass: "oke-w-reviews-writeReview"
  }, [_c('write-review-button', {
    attrs: {
      "productId": _vm.productId || _vm.writeReviewProductId
    }
  })], 1) : _vm._e()]) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviews-controls"
  }, [_c('div', {
    staticClass: "oke-w-reviews-count"
  }, [_vm._v("\n                " + _vm._s(_vm.$tc('{0} reviews', _vm.reviewCount, [_vm.prettyReviewCount])) + "\n            ")]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviews-sort"
  }, [_c('sort-select', {
    attrs: {
      "mediaLayout": _vm.mediaLayout
    },
    on: {
      "input": function ($event) {
        return _vm.reloadReviews();
      }
    },
    model: {
      value: _vm.selectedSortOption,
      callback: function ($$v) {
        _vm.selectedSortOption = $$v;
      },
      expression: "selectedSortOption"
    }
  })], 1)]), _vm._v(" "), _c('div', {
    ref: "reviewsMain",
    staticClass: "oke-w-reviews-main",
    class: {
      'oke-w-reviews-main--nav-divider': _vm.showMainWrapperBorder,
      'oke-is-loading': _vm.isLoadingReviews
    },
    attrs: {
      "aria-busy": _vm.isLoadingReviews
    }
  }, [_vm.showReviewsList ? _c(_vm.reviewListComponent, {
    tag: "component",
    attrs: {
      "reviewSettings": _vm.individualReviewSettings,
      "reviews": _vm.reviews,
      "widgetMode": _vm.widgetMode,
      "widgetSize": _vm.widgetSize,
      "isLoading": _vm.isLoadingReviews,
      "isLoadingMore": _vm.isLoadingMore,
      "widgetWidth": _vm.widgetWidth,
      "canLoadMore": !!_vm.nextUrl
    },
    on: {
      "carouselLoadMore": function ($event) {
        return _vm.showMoreReviews();
      }
    }
  }) : _vm._e(), _vm._v(" "), _vm.viewState === 'empty-filtered' || _vm.viewState === 'empty-filtered-loading' ? _c('div', {
    staticClass: "oke-w-reviews-emptyResults"
  }, [_vm._v("\n                " + _vm._s(_vm.$tc('No Reviews Found')) + "\n            ")]) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviews-alerts"
  }, [_c('alert', {
    ref: "bottomAlert",
    attrs: {
      "position": "bottom"
    }
  }, [_vm.showResetWidget ? _c('button', {
    staticClass: "oke-linkButton",
    attrs: {
      "type": "button",
      "title": _vm.$tc('Reset')
    },
    on: {
      "click": _vm.reloadReviews
    }
  }, [_vm._v(_vm._s(_vm.$t('Reset')))]) : _vm._e()]), _vm._v(" "), _c('alert', {
    ref: "topAlert",
    attrs: {
      "position": "top"
    }
  }, [_vm.showResetWidget ? _c('button', {
    staticClass: "oke-linkButton",
    attrs: {
      "type": "button",
      "title": _vm.$tc('Reset')
    },
    on: {
      "click": _vm.reloadReviews
    }
  }, [_vm._v(_vm._s(_vm.$t('Reset')))]) : _vm._e()])], 1)], 1)] : _vm.viewState === 'empty' || _vm.viewState === 'empty-filtered' ? _c('state', {
    attrs: {
      "productId": _vm.productId || _vm.writeReviewProductId,
      "topBorder": false,
      "state": "empty",
      "contentType": "reviews"
    }
  }) : _vm._e(), _vm._v(" "), (_vm.viewState === 'content' || _vm.viewState === 'loading-more') && _vm.nextUrl ? _c('div', {
    staticClass: "oke-w-reviews-footer"
  }, [_vm.reviewListComponent !== 'ReviewsListCarousel' ? _c('show-more', {
    attrs: {
      "allowSearchEnginePagination": _vm.allowSearchEnginePagination,
      "isLoading": _vm.isLoadingMore,
      "nextUrl": _vm.nextUrl,
      "pageNumber": _vm.pageNumber,
      "contentType": "reviews"
    },
    on: {
      "click": function ($event) {
        return _vm.showMoreReviews();
      }
    }
  }) : _vm._e()], 1) : _vm._e(), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText",
    attrs: {
      "role": "status",
      "aria-live": "polite"
    }
  }, [_vm._v(_vm._s(_vm.isLoadingReviews ? _vm.$tc('Loading Reviews') : _vm.$tc('Reviews Loaded')))]), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText",
    attrs: {
      "role": "status",
      "aria-live": "polite"
    }
  }, [_vm._v(_vm._s(_vm.isLoadingMore ? _vm.$tc('Loading More Reviews') : _vm.$tc('Reviews Added')))])], 2);
};

var __vue_staticRenderFns__$J = [];
/* style */

const __vue_inject_styles__$J = undefined;
/* scoped */

const __vue_scope_id__$J = undefined;
/* module identifier */

const __vue_module_identifier__$J = undefined;
/* functional template */

const __vue_is_functional_template__$J = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$J = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$J,
  staticRenderFns: __vue_staticRenderFns__$J
}, __vue_inject_styles__$J, __vue_script__$J, __vue_scope_id__$J, __vue_is_functional_template__$J, __vue_module_identifier__$J, false, undefined, undefined, undefined);

var Reviews = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$J
});

let WidgetNavBar$1 = class WidgetNavBar extends Vue {
  get prettyReviewCount() {
    return OkendoUtils.getPrettyNumber(this.reviewCount);
  }

  get prettyQuestionCount() {
    return OkendoUtils.getPrettyNumber(this.questionCount);
  }

  onActiveTabChange(newTab) {
    const newTabRefs = this.$refs[newTab];

    if (newTabRefs[0]) {
      newTabRefs[0].focus();
    }

    this.$emit('tabChange', newTab);
  }

  selectFirstTab() {
    const newTab = this.tabs[0];
    this.onActiveTabChange(newTab);
  }

  selectLastTab() {
    const newTab = this.tabs[this.tabs.length - 1];
    this.onActiveTabChange(newTab);
  }

  selectNextTab(index) {
    const nextTab = this.tabs[index + 1];
    const newTab = nextTab || this.tabs[0];
    this.onActiveTabChange(newTab);
  }

  selectPreviousTab(index) {
    const prevTab = this.tabs[index - 1];
    const newTab = prevTab || this.tabs[this.tabs.length - 1];
    this.onActiveTabChange(newTab);
  }

};

__decorate([Prop()], WidgetNavBar$1.prototype, "activeTab", void 0);

__decorate([Prop()], WidgetNavBar$1.prototype, "reviewCount", void 0);

__decorate([Prop()], WidgetNavBar$1.prototype, "questionCount", void 0);

__decorate([Prop()], WidgetNavBar$1.prototype, "tabs", void 0);

__decorate([Prop()], WidgetNavBar$1.prototype, "widgetId", void 0);

WidgetNavBar$1 = __decorate([Component], WidgetNavBar$1);
var script$I = WidgetNavBar$1;

/* script */
const __vue_script__$I = script$I;
/* template */

var __vue_render__$I = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-navBar",
    attrs: {
      "role": "tablist"
    }
  }, _vm._l(_vm.tabs, function (tab, index) {
    return _c('button', {
      directives: [{
        name: "ga",
        rawName: "v-ga:click",
        value: {
          action: tab + " Navbar Click"
        },
        expression: "{ action: `${tab} Navbar Click` }",
        arg: "click"
      }],
      key: tab,
      ref: tab,
      refInFor: true,
      staticClass: "oke-w-navBar-item",
      attrs: {
        "aria-selected": _vm.activeTab === tab,
        "id": tab + "-tab-" + _vm.widgetId,
        "aria-controls": tab + "-panel-" + _vm.widgetId,
        "tabindex": _vm.activeTab === tab ? 0 : -1,
        "role": "tab",
        "type": "button"
      },
      on: {
        "click": function ($event) {
          return _vm.onActiveTabChange(tab);
        },
        "keyup": [function ($event) {
          if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "right", 39, $event.key, ["Right", "ArrowRight"])) {
            return null;
          }

          if ('button' in $event && $event.button !== 2) {
            return null;
          }

          return _vm.selectNextTab(index);
        }, function ($event) {
          if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "left", 37, $event.key, ["Left", "ArrowLeft"])) {
            return null;
          }

          if ('button' in $event && $event.button !== 0) {
            return null;
          }

          return _vm.selectPreviousTab(index);
        }, function ($event) {
          if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "home", undefined, $event.key, undefined)) {
            return null;
          }

          return _vm.selectFirstTab();
        }, function ($event) {
          if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "end", undefined, $event.key, undefined)) {
            return null;
          }

          return _vm.selectLastTab();
        }]
      }
    }, [_vm._v("\n        " + _vm._s(tab === 'reviews' ? _vm.$tc('Reviews') : _vm.$tc('Questions')) + "\n        "), tab === 'reviews' && _vm.reviewCount ? _c('span', {
      staticClass: "oke-w-navBar-item-count"
    }, [_vm._v(_vm._s(_vm.prettyReviewCount))]) : _vm._e(), _vm._v(" "), tab === 'questions' && _vm.questionCount ? _c('span', {
      staticClass: "oke-w-navBar-item-count"
    }, [_vm._v(_vm._s(_vm.prettyQuestionCount))]) : _vm._e()]);
  }), 0);
};

var __vue_staticRenderFns__$I = [];
/* style */

const __vue_inject_styles__$I = undefined;
/* scoped */

const __vue_scope_id__$I = undefined;
/* module identifier */

const __vue_module_identifier__$I = undefined;
/* functional template */

const __vue_is_functional_template__$I = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$I = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$I,
  staticRenderFns: __vue_staticRenderFns__$I
}, __vue_inject_styles__$I, __vue_script__$I, __vue_scope_id__$I, __vue_is_functional_template__$I, __vue_module_identifier__$I, false, undefined, undefined, undefined);

var WidgetNavBar = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$I
});

let WidgetHeader$1 = class WidgetHeader extends Vue {
  get headerSettings() {
    return SharedSettings.widgetSettings.reviewsWidget.header;
  }

  capitalizedClass(string) {
    return StringUtils.capitalize(string);
  }

  kebabToCamelCaseClass(string) {
    return StringUtils.kebabToCamelCase(string);
  }

};

__decorate([Prop()], WidgetHeader$1.prototype, "reviewAggregate", void 0);

__decorate([Prop()], WidgetHeader$1.prototype, "media", void 0);

__decorate([Prop()], WidgetHeader$1.prototype, "mediaNextUrl", void 0);

__decorate([Prop()], WidgetHeader$1.prototype, "widgetMode", void 0);

WidgetHeader$1 = __decorate([Component({
  components: {
    HeaderModuleAttributes: async () => (await Promise.resolve().then(function () { return HeaderModuleAttributes; })).default,
    HeaderModuleMediaGrid: async () => (await Promise.resolve().then(function () { return HeaderModuleMediaGrid; })).default,
    HeaderModuleMediaCarousel: async () => (await Promise.resolve().then(function () { return HeaderModuleMediaCarousel; })).default,
    HeaderModuleRatingBreakdown: async () => (await Promise.resolve().then(function () { return HeaderModuleRatingBreakdown; })).default,
    HeaderModuleRecommends: async () => (await Promise.resolve().then(function () { return HeaderModuleRecommends; })).default,
    HeaderModuleRatingAverage: async () => (await Promise.resolve().then(function () { return HeaderModuleRatingAverage; })).default
  }
})], WidgetHeader$1);
var script$H = WidgetHeader$1;

/* script */
const __vue_script__$H = script$H;
/* template */

var __vue_render__$H = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-header"
  }, [_c('div', {
    staticClass: "oke-w-header-content",
    class: "oke-w-header-content--verticalAlign" + _vm.capitalizedClass(_vm.headerSettings.verticalAlignment) + " oke-w-header-content--" + _vm.kebabToCamelCaseClass(_vm.headerSettings.columnDistribution)
  }, _vm._l(_vm.headerSettings.blocks, function (block, key) {
    return _c('div', {
      key: key,
      staticClass: "oke-w-header-content-block",
      class: "oke-w-header-content-block--" + _vm.kebabToCamelCaseClass(block.columnWidth) + " oke-w-header-content-block--" + block.textAlignment
    }, _vm._l(block.modules, function (module, moduleIndex) {
      return _c('div', {
        key: 'block-' + key + 'module-' + moduleIndex + module.name,
        staticClass: "oke-w-header-content-module",
        class: "oke-w-header-content-module--" + block.textAlignment
      }, [module.name === 'rating-average' ? _c('header-module-rating-average', {
        attrs: {
          "moduleSettings": module,
          "reviewAggregate": _vm.reviewAggregate,
          "moduleAlignment": block.textAlignment
        }
      }) : _vm._e(), _vm._v(" "), module.name === 'rating-breakdown' ? _c('header-module-rating-breakdown', {
        attrs: {
          "moduleSettings": module,
          "reviewAggregate": _vm.reviewAggregate
        }
      }) : _vm._e(), _vm._v(" "), module.name === 'recommended' ? _c('header-module-recommends', {
        attrs: {
          "reviewCount": _vm.reviewAggregate.reviewCount,
          "recommendationCount": _vm.reviewAggregate.recommendationCount,
          "widgetMode": _vm.widgetMode
        }
      }) : _vm._e(), _vm._v(" "), module.name === 'attributes' && _vm.reviewAggregate.attributeRatings ? _c('header-module-attributes', {
        attrs: {
          "attributeRatings": _vm.reviewAggregate.attributeRatings,
          "moduleSettings": module,
          "alignment": block.textAlignment
        }
      }) : _vm._e(), _vm._v(" "), module.name === 'media-grid' && _vm.media ? _c('header-module-media-grid', {
        attrs: {
          "media": _vm.media,
          "nextUrl": _vm.mediaNextUrl,
          "moduleSettings": module,
          "widgetMode": _vm.widgetMode,
          "alignment": block.textAlignment
        }
      }) : _vm._e(), _vm._v(" "), module.name === 'media-carousel' && _vm.media ? _c('header-module-media-carousel', {
        attrs: {
          "media": _vm.media,
          "nextUrl": _vm.mediaNextUrl,
          "moduleSettings": module,
          "widgetMode": _vm.widgetMode,
          "carouselWidth": block.columnWidth
        }
      }) : _vm._e()], 1);
    }), 0);
  }), 0)]);
};

var __vue_staticRenderFns__$H = [];
/* style */

const __vue_inject_styles__$H = undefined;
/* scoped */

const __vue_scope_id__$H = undefined;
/* module identifier */

const __vue_module_identifier__$H = undefined;
/* functional template */

const __vue_is_functional_template__$H = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$H = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$H,
  staticRenderFns: __vue_staticRenderFns__$H
}, __vue_inject_styles__$H, __vue_script__$H, __vue_scope_id__$H, __vue_is_functional_template__$H, __vue_module_identifier__$H, false, undefined, undefined, undefined);

var WidgetHeader = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$H
});

let State$1 = class State extends Vue {
  get emptyStateText() {
    if (this.contentType === 'reviews') {
      return this.productId ? this.$tc('No reviews yet, write one now?') : this.$tc('No reviews yet');
    } else {
      return this.productId ? this.$tc('No questions yet, ask one now?') : this.$tc('No questions yet');
    }
  }

  onRetryClick() {
    this.$emit('retry');
  }

};

__decorate([Prop()], State$1.prototype, "state", void 0);

__decorate([Prop()], State$1.prototype, "contentType", void 0);

__decorate([Prop()], State$1.prototype, "productId", void 0);

__decorate([Prop({
  default: () => true
})], State$1.prototype, "topBorder", void 0);

State$1 = __decorate([Component({
  components: {
    AskQuestionButton: async () => (await Promise.resolve().then(function () { return AskQuestionButton; })).default,
    WriteReviewButton: async () => (await Promise.resolve().then(function () { return WriteReviewButton; })).default
  }
})], State$1);
var script$G = State$1;

/* script */
const __vue_script__$G = script$G;
/* template */

var __vue_render__$G = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-state",
    class: {
      'oke-state--noTopBorder': !_vm.topBorder
    }
  }, [_vm.state === 'loading' ? _c('div', {
    staticClass: "oke-state-loading"
  }, [_c('div', {
    staticClass: "oke-state-loading-text"
  }, [_vm._v("\n            " + _vm._s(_vm.$t('Loading {0}', [_vm.contentType])) + " "), _c('span', {
    staticClass: "oke-loader"
  })])]) : _vm._e(), _vm._v(" "), _vm.state === 'empty' ? _c('div', {
    staticClass: "oke-state-empty"
  }, [_c('div', {
    staticClass: "oke-state-empty-text"
  }, [_vm._v("\n            " + _vm._s(_vm.emptyStateText) + "\n        ")]), _vm._v(" "), _vm.productId ? _c('div', {
    staticClass: "oke-state-empty-button"
  }, [_vm.contentType === 'reviews' ? _c('write-review-button', {
    attrs: {
      "productId": _vm.productId
    }
  }) : _vm._e(), _vm._v(" "), _vm.contentType === 'questions' ? _c('ask-question-button', {
    attrs: {
      "productId": _vm.productId
    }
  }) : _vm._e()], 1) : _vm._e()]) : _vm._e(), _vm._v(" "), _vm.state === 'error' ? _c('div', {
    staticClass: "oke-state-error"
  }, [_c('div', {
    staticClass: "oke-state-error-text"
  }, [_vm._v("\n            " + _vm._s(_vm.$t('Error occurred while loading {0}', [_vm.contentType])) + " 😣\n        ")]), _vm._v(" "), _c('div', {
    staticClass: "oke-state-error-button"
  }, [_c('button', {
    staticClass: "oke-button",
    attrs: {
      "type": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onRetryClick();
      }
    }
  }, [_vm._v("\n                " + _vm._s(_vm.$tc('Retry')) + "\n            ")])])]) : _vm._e()]);
};

var __vue_staticRenderFns__$G = [];
/* style */

const __vue_inject_styles__$G = undefined;
/* scoped */

const __vue_scope_id__$G = undefined;
/* module identifier */

const __vue_module_identifier__$G = undefined;
/* functional template */

const __vue_is_functional_template__$G = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$G = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$G,
  staticRenderFns: __vue_staticRenderFns__$G
}, __vue_inject_styles__$G, __vue_script__$G, __vue_scope_id__$G, __vue_is_functional_template__$G, __vue_module_identifier__$G, false, undefined, undefined, undefined);

var State = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$G
});

let AskQuestionButton$1 = class AskQuestionButton extends Vue {
  get askQuestionUrl() {
    return OkendoApi.askQuestionUrl(this.productId);
  }

};

__decorate([Prop()], AskQuestionButton$1.prototype, "productId", void 0);

AskQuestionButton$1 = __decorate([Component], AskQuestionButton$1);
var script$F = AskQuestionButton$1;

/* script */
const __vue_script__$F = script$F;
/* template */

var __vue_render__$F = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.productId ? _c('a', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Ask Question Click'
      },
      expression: "{ action: 'Ask Question Click' }",
      arg: "click"
    }],
    staticClass: "oke-qw-askQuestion oke-button",
    attrs: {
      "href": _vm.askQuestionUrl,
      "target": "_blank",
      "rel": "noopener"
    }
  }, [_vm._v("\n    " + _vm._s(_vm.$tc('Ask a Question')) + "\n    "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("(" + _vm._s(_vm.$tc('Opens in a new window')) + ")")])]) : _vm._e();
};

var __vue_staticRenderFns__$F = [];
/* style */

const __vue_inject_styles__$F = undefined;
/* scoped */

const __vue_scope_id__$F = undefined;
/* module identifier */

const __vue_module_identifier__$F = undefined;
/* functional template */

const __vue_is_functional_template__$F = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$F = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$F,
  staticRenderFns: __vue_staticRenderFns__$F
}, __vue_inject_styles__$F, __vue_script__$F, __vue_scope_id__$F, __vue_is_functional_template__$F, __vue_module_identifier__$F, false, undefined, undefined, undefined);

var AskQuestionButton = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$F
});

let QuestionsHeader$1 = class QuestionsHeader extends Vue {
  constructor() {
    super(...arguments);
    this.selectedSortOption = 'date desc';
  }

  created() {
    if (this.initialSortOption) {
      this.selectedSortOption = this.initialSortOption;
    }
  }

  onSortChange(sortOption) {
    this.$emit('sortChange', sortOption);
  }

};

__decorate([Prop()], QuestionsHeader$1.prototype, "initialSortOption", void 0);

__decorate([Prop({
  default: () => false
})], QuestionsHeader$1.prototype, "sortDisabled", void 0);

__decorate([Prop()], QuestionsHeader$1.prototype, "productId", void 0);

QuestionsHeader$1 = __decorate([Component({
  components: {
    AskQuestionButton: __vue_component__$F,
    PoweredBy: async () => (await Promise.resolve().then(function () { return PoweredBy; })).default,
    SortSelect: __vue_component__$L
  }
})], QuestionsHeader$1);
var script$E = QuestionsHeader$1;

/* script */
const __vue_script__$E = script$E;
/* template */

var __vue_render__$E = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-qw-header"
  }, [_c('div', {
    staticClass: "oke-qw-header-sort"
  }, [_c('sort-select', {
    attrs: {
      "disabled": _vm.sortDisabled,
      "contentType": "questions"
    },
    on: {
      "input": function ($event) {
        return _vm.onSortChange($event);
      }
    },
    model: {
      value: _vm.selectedSortOption,
      callback: function ($$v) {
        _vm.selectedSortOption = $$v;
      },
      expression: "selectedSortOption"
    }
  })], 1), _vm._v(" "), _vm.productId ? _c('div', {
    staticClass: "oke-qw-header-askQuestion"
  }, [_c('ask-question-button', {
    attrs: {
      "productId": _vm.productId
    }
  })], 1) : _vm._e()]);
};

var __vue_staticRenderFns__$E = [];
/* style */

const __vue_inject_styles__$E = undefined;
/* scoped */

const __vue_scope_id__$E = undefined;
/* module identifier */

const __vue_module_identifier__$E = undefined;
/* functional template */

const __vue_is_functional_template__$E = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$E = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$E,
  staticRenderFns: __vue_staticRenderFns__$E
}, __vue_inject_styles__$E, __vue_script__$E, __vue_scope_id__$E, __vue_is_functional_template__$E, __vue_module_identifier__$E, false, undefined, undefined, undefined);

var QuestionsHeader = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$E
});

let QuestionsList$1 = class QuestionsList extends Vue {};

__decorate([Prop({
  default: () => []
})], QuestionsList$1.prototype, "questions", void 0);

__decorate([Prop()], QuestionsList$1.prototype, "isLoading", void 0);

QuestionsList$1 = __decorate([Component({
  components: {
    Question: async () => (
    /* webpackChunkName: "modules/questions" */
    await Promise.resolve().then(function () { return Question; })).default
  }
})], QuestionsList$1);
var script$D = QuestionsList$1;

/* script */
const __vue_script__$D = script$D;
/* template */

var __vue_render__$D = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.questions.length ? _c('ul', {
    staticClass: "oke-qw-questionList",
    class: {
      'oke-is-loading': _vm.isLoading
    },
    attrs: {
      "aria-busy": _vm.isLoading
    }
  }, _vm._l(_vm.questions, function (question, index) {
    return _c('li', {
      key: question.questionId,
      staticClass: "oke-qw-questionList-item"
    }, [_c('question', {
      attrs: {
        "question": question,
        "index": index
      }
    })], 1);
  }), 0) : _vm._e();
};

var __vue_staticRenderFns__$D = [];
/* style */

const __vue_inject_styles__$D = undefined;
/* scoped */

const __vue_scope_id__$D = undefined;
/* module identifier */

const __vue_module_identifier__$D = undefined;
/* functional template */

const __vue_is_functional_template__$D = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$D = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$D,
  staticRenderFns: __vue_staticRenderFns__$D
}, __vue_inject_styles__$D, __vue_script__$D, __vue_scope_id__$D, __vue_is_functional_template__$D, __vue_module_identifier__$D, false, undefined, undefined, undefined);

var QuestionsList = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$D
});

let ReviewSimple$1 = class ReviewSimple extends Vue {
  get showProductInfo() {
    const showProductDetails = SharedSettings.widgetSettings.reviewsWidget.reviews.list.layout.showProductDetails;
    return showProductDetails === 'always' || showProductDetails === 'only-when-grouped' && (this.widgetMode === 'all' || this.widgetMode === 'group');
  }

  get starHeight() {
    return SharedSettings.widgetSettings.reviewsWidget.style.stars.height;
  }

  get starInterspace() {
    var _a, _b;

    return (_b = (_a = SharedSettings.widgetSettings.reviewsWidget.style.stars.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.interspace) !== null && _b !== void 0 ? _b : SharedSettings.widgetSettings.global.stars.interspace;
  }

};

__decorate([Prop()], ReviewSimple$1.prototype, "review", void 0);

__decorate([Prop()], ReviewSimple$1.prototype, "widgetMode", void 0);

__decorate([Prop({
  default: () => true
})], ReviewSimple$1.prototype, "showHelpfulVoting", void 0);

__decorate([Prop({
  default: () => false
})], ReviewSimple$1.prototype, "hideStars", void 0);

__decorate([Prop({
  default: () => false
})], ReviewSimple$1.prototype, "showPostedOnIg", void 0);

ReviewSimple$1 = __decorate([Component({
  components: {
    Reviewer: async () => (await Promise.resolve().then(function () { return Reviewer; })).default,
    HelpfulVoting: async () => (await Promise.resolve().then(function () { return HelpfulVoting; })).default,
    ReviewBasicContent: async () => (await Promise.resolve().then(function () { return ReviewBasicContent; })).default,
    Product: async () => (await Promise.resolve().then(function () { return Product; })).default
  }
})], ReviewSimple$1);
var script$C = ReviewSimple$1;

/* script */
const __vue_script__$C = script$C;
/* template */

var __vue_render__$C = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewSimple"
  }, [_c('div', {
    staticClass: "oke-w-reviewSimple-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "sourceUrl": _vm.review.sourceUrl
    }
  })], 1), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-w-reviewSimple-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewSimple-content"
  }, [_c('review-basic-content', {
    attrs: {
      "review": _vm.review,
      "hideStars": _vm.hideStars,
      "showPostedOnIg": _vm.showPostedOnIg,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace
    }
  })], 1), _vm._v(" "), _vm.showHelpfulVoting ? _c('div', {
    staticClass: "oke-w-reviewSimple-helpful"
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.parentId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1) : _vm._e()]);
};

var __vue_staticRenderFns__$C = [];
/* style */

const __vue_inject_styles__$C = undefined;
/* scoped */

const __vue_scope_id__$C = undefined;
/* module identifier */

const __vue_module_identifier__$C = undefined;
/* functional template */

const __vue_is_functional_template__$C = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$C = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$C,
  staticRenderFns: __vue_staticRenderFns__$C
}, __vue_inject_styles__$C, __vue_script__$C, __vue_scope_id__$C, __vue_is_functional_template__$C, __vue_module_identifier__$C, false, undefined, undefined, undefined);

var ReviewSimple = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$C
});

let Video = class Video extends Vue {
  get poster() {
    return this.mediaItem.videoPosterUrl;
  }

  get source() {
    return this.mediaItem.fullSizeUrl;
  }

};

__decorate([Prop()], Video.prototype, "mediaItem", void 0);

__decorate([Prop()], Video.prototype, "videoClass", void 0);

__decorate([Prop()], Video.prototype, "tabbable", void 0);

Video = __decorate([Component], Video);
var script$B = Video;

/* script */
const __vue_script__$B = script$B;
/* template */

var __vue_render__$B = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.mediaItem ? _c('video', {
    class: 'oke-video ' + _vm.videoClass,
    attrs: {
      "poster": _vm.poster,
      "tabindex": _vm.tabbable ? 0 : -1,
      "controls": ""
    }
  }, [_c('source', {
    attrs: {
      "src": _vm.source,
      "type": "video/mp4"
    }
  })]) : _vm._e();
};

var __vue_staticRenderFns__$B = [];
/* style */

const __vue_inject_styles__$B = undefined;
/* scoped */

const __vue_scope_id__$B = undefined;
/* module identifier */

const __vue_module_identifier__$B = undefined;
/* functional template */

const __vue_is_functional_template__$B = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$B = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$B,
  staticRenderFns: __vue_staticRenderFns__$B
}, __vue_inject_styles__$B, __vue_script__$B, __vue_scope_id__$B, __vue_is_functional_template__$B, __vue_module_identifier__$B, false, undefined, undefined, undefined);

var FullVideo = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$B
});

var img$1 = "data:image/svg+xml,%3csvg width='24' height='24' viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg'%3e%3cg fill='none' fill-rule='evenodd'%3e%3crect width='24' height='24' rx='2' fill='%23EEE'/%3e%3crect width='24' height='24' rx='2'/%3e%3crect width='24' height='24' rx='2'/%3e%3crect width='24' height='24' rx='2'/%3e%3cg%3e%3cpath d='M19.778 12.125c0-.58-.052-1.135-.15-1.67H11.94v3.158h4.394c-.19 1.02-.765 1.886-1.63 2.465v2.048h2.64c1.543-1.42 2.434-3.514 2.434-6z' fill='%234285F4' fill-rule='nonzero'/%3e%3cpath d='M11.94 20.104c2.204 0 4.052-.73 5.403-1.978l-2.638-2.048c-.732.49-1.667.78-2.765.78-2.127 0-3.927-1.437-4.57-3.367H4.644v2.116c1.344 2.67 4.105 4.498 7.297 4.498z' fill='%2334A853' fill-rule='nonzero'/%3e%3cpath d='M7.37 13.49c-.162-.49-.255-1.012-.255-1.55s.093-1.062.256-1.552V8.273H4.644c-.553 1.102-.868 2.35-.868 3.667 0 1.317.315 2.564.868 3.666L7.37 13.49z' fill='%23FBBC05' fill-rule='nonzero'/%3e%3cpath d='M11.94 7.022c1.198 0 2.275.412 3.12 1.22l2.343-2.34C15.99 4.584 14.14 3.775 11.94 3.775c-3.192 0-5.953 1.83-7.297 4.498l2.728 2.115c.643-1.93 2.443-3.366 4.57-3.366z' fill='%23EA4335' fill-rule='nonzero'/%3e%3cpath d='M3.775 3.775h16.33v16.33H3.774'/%3e%3c/g%3e%3c/g%3e%3c/svg%3e";

var img = "data:image/svg+xml,%3csvg width='24' height='24' viewBox='0 0 24 24' xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink'%3e%3cdefs%3e%3cpath id='a' d='M11.995 23.91H23.99V.01H0v23.9h11.995z'/%3e%3c/defs%3e%3cg fill='none' fill-rule='evenodd'%3e%3cg transform='translate(0 .08)'%3e%3cmask id='b' fill='white'%3e%3cuse xlink:href='%23a'/%3e%3c/mask%3e%3cpath d='M22.666 23.91c.73 0 1.324-.59 1.324-1.32V1.33c0-.73-.593-1.32-1.324-1.32H1.324C.594.01 0 .6 0 1.33v21.26c0 .73.593 1.32 1.324 1.32h21.342z' fill='%233C5999' mask='url(%23b)'/%3e%3c/g%3e%3cpath d='M16.553 23.99v-9.255h3.118l.468-3.607h-3.585V8.825c0-1.045.29-1.756 1.794-1.756l1.918-.002V3.842c-.332-.044-1.47-.143-2.794-.143-2.764 0-4.656 1.68-4.656 4.768v2.66H9.688v3.607h3.126v9.256h3.74z' fill='%23FEFEFE'/%3e%3c/g%3e%3c/svg%3e";

let Avatar$1 = class Avatar extends Vue {
  constructor() {
    super(...arguments);
    this.isError = false;
    this.showAvatar = true;
    this.showSocialConnectionIcon = true;
  }

  get initials() {
    return (this.displayName || '').split(' ').slice(0, 2).map(part => part.substr(0, 1).toLocaleUpperCase()).join('');
  }

  get socialConnectionIcon() {
    switch (this.socialConnection) {
      case 'google':
        return img$1;

      case 'facebook':
        return img;
    }
  } // allow lazy-load of new images


  onAvatarUrlChange() {
    this.showAvatar = false;
    this.$nextTick(() => {
      this.showAvatar = true;
    });
  }

  onSocialConnectionIconChange() {
    this.showSocialConnectionIcon = false;
    this.$nextTick(() => {
      this.showSocialConnectionIcon = true;
    });
  }

  onImageError() {
    this.isError = true;
  }

};

__decorate([Prop()], Avatar$1.prototype, "avatarUrl", void 0);

__decorate([Prop()], Avatar$1.prototype, "displayName", void 0);

__decorate([Prop()], Avatar$1.prototype, "socialConnection", void 0);

__decorate([Watch('avatarUrl')], Avatar$1.prototype, "onAvatarUrlChange", null);

__decorate([Watch('socialConnectionIcon')], Avatar$1.prototype, "onSocialConnectionIconChange", null);

Avatar$1 = __decorate([Component], Avatar$1);
var script$A = Avatar$1;

/* script */
const __vue_script__$A = script$A;
/* template */

var __vue_render__$A = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-avatar"
  }, [_c('span', {
    staticClass: "oke-avatar-placeholder"
  }, [_vm._v("\n        " + _vm._s(_vm.initials) + "\n    ")]), _vm._v(" "), _vm.avatarUrl && _vm.showAvatar ? _c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.avatarUrl,
      expression: "avatarUrl"
    }],
    staticClass: "oke-avatar-image",
    class: {
      'is-error': _vm.isError
    },
    attrs: {
      "alt": _vm.$t('Profile picture for {0}', [_vm.displayName])
    },
    on: {
      "error": function ($event) {
        return _vm.onImageError();
      }
    }
  }) : _vm._e(), _vm._v(" "), _vm.socialConnectionIcon && _vm.showSocialConnectionIcon ? _c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.socialConnectionIcon,
      expression: "socialConnectionIcon"
    }],
    staticClass: "oke-avatar-icon",
    attrs: {
      "alt": _vm.$t('{0} logo', [_vm.socialConnection])
    }
  }) : _vm._e()]);
};

var __vue_staticRenderFns__$A = [];
/* style */

const __vue_inject_styles__$A = undefined;
/* scoped */

const __vue_scope_id__$A = undefined;
/* module identifier */

const __vue_module_identifier__$A = undefined;
/* functional template */

const __vue_is_functional_template__$A = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$A = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$A,
  staticRenderFns: __vue_staticRenderFns__$A
}, __vue_inject_styles__$A, __vue_script__$A, __vue_scope_id__$A, __vue_is_functional_template__$A, __vue_module_identifier__$A, false, undefined, undefined, undefined);

var Avatar = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$A
});

let Reviewer$1 = class Reviewer extends Vue {
  getAvatarUrl() {
    return ImageUtils.getAvatarUrl(this.reviewer);
  }

  getVerifiedStatusLabel() {
    if (!this.reviewer.verifiedStatus) {
      return this.$tc('Verified Buyer');
    }

    switch (this.reviewer.verifiedStatus.toLowerCase()) {
      case 'verified reviewer':
        return this.$tc('Verified Reviewer');

      default:
        return this.reviewer.verifiedStatus;
    }
  }

};

__decorate([Prop()], Reviewer$1.prototype, "reviewer", void 0);

__decorate([Prop()], Reviewer$1.prototype, "selectAttributes", void 0);

__decorate([Prop()], Reviewer$1.prototype, "sourceUrl", void 0);

__decorate([Prop()], Reviewer$1.prototype, "hideAvatar", void 0);

__decorate([Prop({
  default: () => 'side-by-side'
})], Reviewer$1.prototype, "layout", void 0);

Reviewer$1 = __decorate([Component({
  components: {
    Avatar: async () => (await Promise.resolve().then(function () { return Avatar; })).default,
    Flag: async () => (await Promise.resolve().then(function () { return Flag; })).default,
    SelectAttributes: async () => (
    /* webpackChunkName: "modules/attributes" */
    await Promise.resolve().then(function () { return SelectAttributes; })).default
  }
})], Reviewer$1);
var script$z = Reviewer$1;

/* script */
const __vue_script__$z = script$z;
/* template */

var __vue_render__$z = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewer",
    class: {
      'oke-w-reviewer--attributes': _vm.selectAttributes && _vm.selectAttributes.length,
      'oke-w-reviewer--stacked': _vm.layout === 'stacked',
      'oke-w-reviewer--minimal': _vm.layout === 'minimal'
    }
  }, [_vm.layout !== 'minimal' && !_vm.hideAvatar ? _c('div', {
    staticClass: "oke-w-reviewer-avatar"
  }, [_c('avatar', {
    attrs: {
      "avatarUrl": _vm.getAvatarUrl(),
      "displayName": _vm.reviewer.displayName,
      "socialConnection": _vm.reviewer.socialConnection
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', [_c('div', {
    staticClass: "oke-w-reviewer-identity"
  }, [_vm.sourceUrl ? _c('a', {
    attrs: {
      "href": _vm.sourceUrl,
      "rel": "noopener nofollow noreferrer",
      "target": "_blank"
    }
  }, [_vm._v("\n                @" + _vm._s(_vm.reviewer.displayName) + " "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("(" + _vm._s(_vm.$tc('Opens in a new window')) + ")")])]) : _c('span', {
    staticClass: "oke-w-reviewer-name"
  }, [_vm._v("\n                " + _vm._s(_vm.reviewer.displayName) + "\n            ")]), _vm._v(" "), _vm.reviewer.location || _vm.reviewer.country ? _c('span', {
    staticClass: "oke-w-reviewer-flag"
  }, [_c('flag', {
    attrs: {
      "reviewer": _vm.reviewer
    }
  })], 1) : _vm._e()]), _vm._v(" "), _vm.reviewer.isVerified ? _c('div', {
    staticClass: "oke-w-reviewer-verified"
  }, [_vm._v("\n            " + _vm._s(_vm.getVerifiedStatusLabel()) + "\n            "), _c('span', {
    staticClass: "oke-w-reviewer-verified-icon"
  })]) : _vm._e(), _vm._v(" "), _vm.selectAttributes && _vm.selectAttributes.length ? _c('div', {
    staticClass: "oke-w-reviewer-attributes"
  }, [_c('select-attributes', {
    attrs: {
      "attributes": _vm.selectAttributes,
      "layout": "line"
    }
  })], 1) : _vm._e()])]);
};

var __vue_staticRenderFns__$z = [];
/* style */

const __vue_inject_styles__$z = undefined;
/* scoped */

const __vue_scope_id__$z = undefined;
/* module identifier */

const __vue_module_identifier__$z = undefined;
/* functional template */

const __vue_is_functional_template__$z = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$z = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$z,
  staticRenderFns: __vue_staticRenderFns__$z
}, __vue_inject_styles__$z, __vue_script__$z, __vue_scope_id__$z, __vue_is_functional_template__$z, __vue_module_identifier__$z, false, undefined, undefined, undefined);

var Reviewer = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$z
});

let HelpfulVoting$1 = class HelpfulVoting extends Vue {
  constructor() {
    super(...arguments);
    this.currentVote = '';
    this.isVoting = false;
  }

  get helpfulCountDisplay() {
    return this.currentVote === 'upvote' ? this.helpfulCount + 1 : this.helpfulCount;
  }

  get unhelpfulCountDisplay() {
    return this.currentVote === 'downvote' ? this.unhelpfulCount + 1 : this.unhelpfulCount;
  }

  get helpfulLabelText() {
    return this.contentType === 'question' ? this.$tc('I had this question too') : this.$tc('Was this helpful?');
  }

  async onVote(newVote) {
    this.isVoting = true;
    const voteType = this.getVoteType(this.currentVote, newVote);
    AnalyticsUtils.sendGAEvent(`${this.contentType} Vote – ${voteType.replace(/-/g, ' ')}`, this.productName);

    try {
      await this.postVote(voteType);
      this.currentVote = newVote === this.currentVote ? '' : newVote;
    } finally {
      this.isVoting = false;
    }
  }

  getVoteType(currentVote, newVote) {
    if (!currentVote) {
      return newVote;
    } else if (currentVote === newVote) {
      return `${newVote}-cancel`;
    } else {
      return `swap-to-${newVote}`;
    }
  }

  postVote(voteType) {
    switch (this.contentType) {
      case 'review':
        return OkendoApi.postHelpfulVoteReview(this.itemId, voteType);

      case 'question':
        return OkendoApi.postHelpfulVoteQuestion(this.itemId, voteType);

      case 'answer':
        return OkendoApi.postHelpfulVoteAnswer(this.parentId, this.itemId, voteType);
    }
  }

};

__decorate([Prop({
  default: () => 'review'
})], HelpfulVoting$1.prototype, "contentType", void 0);

__decorate([Prop({
  default: () => 0
})], HelpfulVoting$1.prototype, "helpfulCount", void 0);

__decorate([Prop({
  default: () => 0
})], HelpfulVoting$1.prototype, "unhelpfulCount", void 0);

__decorate([Prop()], HelpfulVoting$1.prototype, "itemId", void 0);

__decorate([Prop()], HelpfulVoting$1.prototype, "parentId", void 0);

__decorate([Prop()], HelpfulVoting$1.prototype, "productName", void 0);

HelpfulVoting$1 = __decorate([Component], HelpfulVoting$1);
var script$y = HelpfulVoting$1;

/* script */
const __vue_script__$y = script$y;
/* template */

var __vue_render__$y = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-helpful"
  }, [_c('span', {
    staticClass: "oke-helpful-label"
  }, [_vm._v(_vm._s(_vm.helpfulLabelText))]), _vm._v(" "), _c('div', {
    staticClass: "oke-helpful-vote"
  }, [_c('button', {
    staticClass: "oke-helpful-vote-button oke-helpful-vote-button--positive",
    class: {
      'oke-is-voted': _vm.currentVote === 'upvote',
      'is-oke-disabled': _vm.isVoting
    },
    attrs: {
      "disabled": _vm.isVoting,
      "type": "button",
      "aria-label": _vm.$tc('Yes, this review was helpful')
    },
    on: {
      "click": function ($event) {
        return _vm.onVote('upvote');
      }
    }
  }, [_c('span', {
    staticClass: "oke-helpful-vote-counter",
    attrs: {
      "id": "oke-helpful-vote-counter-positive-" + _vm.itemId
    }
  }, [_vm._v("\n                " + _vm._s(_vm.helpfulCountDisplay) + "\n                "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc("person voted yes", _vm.helpfulCountDisplay)))])])]), _vm._v(" "), _c('button', {
    staticClass: "oke-helpful-vote-button oke-helpful-vote-button--negative",
    class: {
      'oke-is-voted': _vm.currentVote === 'downvote',
      'is-oke-disabled': _vm.isVoting
    },
    attrs: {
      "disabled": _vm.isVoting,
      "type": "button",
      "aria-label": _vm.$tc('No, this review was not helpful')
    },
    on: {
      "click": function ($event) {
        return _vm.onVote('downvote');
      }
    }
  }, [_c('span', {
    staticClass: "oke-helpful-vote-counter",
    attrs: {
      "id": "oke-helpful-vote-counter-negative-" + _vm.itemId
    }
  }, [_vm._v("\n                " + _vm._s(_vm.unhelpfulCountDisplay) + "\n                "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc('person voted no', _vm.unhelpfulCountDisplay)))])])])])]);
};

var __vue_staticRenderFns__$y = [];
/* style */

const __vue_inject_styles__$y = undefined;
/* scoped */

const __vue_scope_id__$y = undefined;
/* module identifier */

const __vue_module_identifier__$y = undefined;
/* functional template */

const __vue_is_functional_template__$y = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$y = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$y,
  staticRenderFns: __vue_staticRenderFns__$y
}, __vue_inject_styles__$y, __vue_script__$y, __vue_scope_id__$y, __vue_is_functional_template__$y, __vue_module_identifier__$y, false, undefined, undefined, undefined);

var HelpfulVoting = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$y
});

let SelectAttributes$1 = class SelectAttributes extends Vue {
  getFormattedDateFromAttribute(date) {
    return DateUtils.getFormattedDateFromAttribute(date);
  }

  isDateComponentWithValue(attribute) {
    if ((attribute === null || attribute === void 0 ? void 0 : attribute.type) !== 'date-components') {
      return false;
    }

    const objectKeys = Object.keys(attribute.value);
    return objectKeys.includes('day') || objectKeys.includes('month') || objectKeys.includes('year');
  }

  isMultiValue(attribute) {
    return Array.isArray(attribute.value);
  }

  isSelectAttribute(attribute) {
    return attribute.type === 'single-value' || attribute.type === 'multi-value' || attribute.type === 'drop-down';
  }

};

__decorate([Prop()], SelectAttributes$1.prototype, "attributes", void 0);

__decorate([Prop({
  default: () => 'side-by-side'
})], SelectAttributes$1.prototype, "layout", void 0);

SelectAttributes$1 = __decorate([Component], SelectAttributes$1);
var script$x = SelectAttributes$1;

/* script */
const __vue_script__$x = script$x;
/* template */

var __vue_render__$x = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-selectAttr",
    class: {
      'oke-w-selectAttr--line': _vm.layout === 'line',
      'oke-w-selectAttr--stacked': _vm.layout === 'stacked'
    }
  }, _vm._l(_vm.attributes, function (attribute, index) {
    return _c('div', {
      key: attribute.title + '-' + index,
      staticClass: "oke-w-selectAttr-item"
    }, [_c('span', {
      staticClass: "oke-w-selectAttr-item-title"
    }, [_vm._v("\n            " + _vm._s(attribute.title) + "\n        ")]), _vm._v(" "), _c('span', {
      staticClass: "oke-w-selectAttr-item-value"
    }, [_vm.isDateComponentWithValue(attribute) ? [_vm._v("\n                " + _vm._s(_vm.getFormattedDateFromAttribute(attribute)) + "\n            ")] : _vm.isSelectAttribute(attribute) ? [_vm.isMultiValue(attribute) ? _vm._l(attribute.value, function (value, valueIndex) {
      return _c('span', {
        key: value + '-' + valueIndex
      }, [_vm._v("\n                        " + _vm._s(value)), valueIndex !== attribute.value.length - 1 ? [_vm._v(",")] : _vm._e()], 2);
    }) : [_vm._v("\n                    " + _vm._s(attribute.value) + "\n                ")]] : _vm._e()], 2)]);
  }), 0);
};

var __vue_staticRenderFns__$x = [];
/* style */

const __vue_inject_styles__$x = undefined;
/* scoped */

const __vue_scope_id__$x = undefined;
/* module identifier */

const __vue_module_identifier__$x = undefined;
/* functional template */

const __vue_is_functional_template__$x = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$x = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$x,
  staticRenderFns: __vue_staticRenderFns__$x
}, __vue_inject_styles__$x, __vue_script__$x, __vue_scope_id__$x, __vue_is_functional_template__$x, __vue_module_identifier__$x, false, undefined, undefined, undefined);

var SelectAttributes = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$x
});

let BarAttributes$1 = class BarAttributes extends Vue {
  get calcBarMaxWidth() {
    var _a;

    const bars = this.attributes.length;
    const gaps = bars - 1;
    const gapSpace = 32;
    const barMaxWidth = 300;
    return this.isBarFullWidth ? '100%' : `${(_a = this.maxWidth) !== null && _a !== void 0 ? _a : barMaxWidth - Math.ceil(gapSpace * gaps / bars)}px`;
  }

};

__decorate([Prop()], BarAttributes$1.prototype, "attributes", void 0);

__decorate([Prop({
  default: () => false
})], BarAttributes$1.prototype, "stacked", void 0);

__decorate([Prop({
  default: () => 'left'
})], BarAttributes$1.prototype, "alignment", void 0);

__decorate([Prop({
  default: () => false
})], BarAttributes$1.prototype, "barHasMinWidth", void 0);

__decorate([Prop({
  default: () => false
})], BarAttributes$1.prototype, "isBarFullWidth", void 0);

__decorate([Prop()], BarAttributes$1.prototype, "maxWidth", void 0);

BarAttributes$1 = __decorate([Component({
  components: {
    AttributeBar: async () => (
    /* webpackChunkName: "modules/attributes" */
    await Promise.resolve().then(function () { return AttributeBar; })).default
  }
})], BarAttributes$1);
var script$w = BarAttributes$1;

/* script */
const __vue_script__$w = script$w;
/* template */

var __vue_render__$w = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.attributes ? _c('div', {
    staticClass: "oke-w-barAttributes",
    class: "oke-w-barAttributes--align-" + _vm.alignment + " oke-w-barAttributes--" + (_vm.stacked ? 'stacked' : 'sideBySide')
  }, _vm._l(_vm.attributes, function (attribute, index) {
    return _c('div', {
      key: attribute.title + '-' + index,
      staticClass: "oke-w-barAttributes-item",
      class: [{
        'oke-w-barAttributes--min-width': _vm.barHasMinWidth
      }],
      style: "max-width: " + _vm.calcBarMaxWidth
    }, [_c('attribute-bar', {
      attrs: {
        "attribute": attribute
      }
    })], 1);
  }), 0) : _vm._e();
};

var __vue_staticRenderFns__$w = [];
/* style */

const __vue_inject_styles__$w = undefined;
/* scoped */

const __vue_scope_id__$w = undefined;
/* module identifier */

const __vue_module_identifier__$w = undefined;
/* functional template */

const __vue_is_functional_template__$w = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$w = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$w,
  staticRenderFns: __vue_staticRenderFns__$w
}, __vue_inject_styles__$w, __vue_script__$w, __vue_scope_id__$w, __vue_is_functional_template__$w, __vue_module_identifier__$w, false, undefined, undefined, undefined);

var BarAttributes = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$w
});

let ReviewerRecommendation$1 = class ReviewerRecommendation extends Vue {};

__decorate([Prop({
  default: () => true
})], ReviewerRecommendation$1.prototype, "isRecommended", void 0);

ReviewerRecommendation$1 = __decorate([Component], ReviewerRecommendation$1);
var script$v = ReviewerRecommendation$1;

/* script */
const __vue_script__$v = script$v;
/* template */

var __vue_render__$v = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewerRecommendation",
    class: {
      'oke-w-reviewerRecommendation--yes': _vm.isRecommended
    }
  }, [_c('span', {
    staticClass: "oke-w-reviewerRecommendation-text"
  }, [_vm._v(_vm._s(_vm.isRecommended ? _vm.$tc('I recommend this product') : _vm.$tc('I do not recommend this product')))])]);
};

var __vue_staticRenderFns__$v = [];
/* style */

const __vue_inject_styles__$v = undefined;
/* scoped */

const __vue_scope_id__$v = undefined;
/* module identifier */

const __vue_module_identifier__$v = undefined;
/* functional template */

const __vue_is_functional_template__$v = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$v = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$v,
  staticRenderFns: __vue_staticRenderFns__$v
}, __vue_inject_styles__$v, __vue_script__$v, __vue_scope_id__$v, __vue_is_functional_template__$v, __vue_module_identifier__$v, false, undefined, undefined, undefined);

var ReviewerRecommendation = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$v
});

let ReviewReply$1 = class ReviewReply extends Vue {
  get replyDateCreated() {
    return DateUtils.formatDate(this.reply.dateCreated, SharedSettings.widgetSettings.global.dateSettings.format);
  }

};

__decorate([Prop()], ReviewReply$1.prototype, "reply", void 0);

ReviewReply$1 = __decorate([Component({
  components: {
    Avatar: async () => (await Promise.resolve().then(function () { return Avatar; })).default
  }
})], ReviewReply$1);
var script$u = ReviewReply$1;

/* script */
const __vue_script__$u = script$u;
/* template */

var __vue_render__$u = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewReply"
  }, [_vm.reply.avatarUrl ? _c('div', {
    staticClass: "oke-w-reviewReply-avatar"
  }, [_c('avatar', {
    attrs: {
      "avatarUrl": _vm.reply.avatarUrl,
      "displayName": _vm.reply.title
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewReply-main"
  }, [_vm._m(0), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewReply-date"
  }, [_vm._v("\n            " + _vm._s(_vm.replyDateCreated) + "\n        ")]), _vm._v(" "), _vm._m(1)])]);
};

var __vue_staticRenderFns__$u = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewReply-title"
  }, [_vm._v("\n            " + _vm._s(_vm.reply.title) + "\n        ")]);
}, function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewReply-body",
    domProps: {
      "innerHTML": _vm._s(_vm.reply.body)
    }
  });
}];
/* style */

const __vue_inject_styles__$u = undefined;
/* scoped */

const __vue_scope_id__$u = undefined;
/* module identifier */

const __vue_module_identifier__$u = undefined;
/* functional template */

const __vue_is_functional_template__$u = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$u = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$u,
  staticRenderFns: __vue_staticRenderFns__$u
}, __vue_inject_styles__$u, __vue_script__$u, __vue_scope_id__$u, __vue_is_functional_template__$u, __vue_module_identifier__$u, false, undefined, undefined, undefined);

var ReviewReply = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$u
});

let MediaStrip$1 = class MediaStrip extends Vue {
  constructor() {
    super(...arguments);
    this.imageHasLoaded = false;
  }

  get maxMediaToDisplay() {
    var _a;

    return (_a = this.maxMediaCount) !== null && _a !== void 0 ? _a : this.media.length;
  }

  get shouldButtonRender() {
    return !!this.maxMediaCount && this.media.length > this.maxMediaCount;
  }

  get mediaToDisplay() {
    return this.maxMediaCount ? this.media.slice(0, this.maxMediaCount) : this.media;
  }

  get mediaStripStyle() {
    const imageGap = this.toPixels(this.imageGap);

    if (this.scale && this.media.length >= this.columns) {
      return {
        display: 'grid',
        'grid-template-columns': `repeat(${Math.min(this.columns, this.media.length)}, 1fr)`,
        'grid-column-gap': `${imageGap}px`,
        'grid-row-gap': `${imageGap}px`
      };
    } else {
      const alignment = this.media.length >= this.columns ? 'left' : this.alignment;
      return {
        display: 'flex',
        'flex-wrap': this.flexWrapImages ? 'wrap' : 'nowrap',
        'column-gap': `${imageGap}px`,
        'row-gap': `${imageGap}px`,
        'justify-content': alignment === 'center' ? 'center' : alignment === 'left' ? 'flex-start' : 'flex-end',
        'margin-bottom': `-${imageGap || 0}px`
      };
    }
  }

  onMediaClick(clickedIndex) {
    this.$emit('click', clickedIndex);
  }

  toPixels(measure) {
    if (!measure) {
      return;
    }

    if (typeof measure === 'number') {
      return measure;
    } else {
      return OkendoUtils.toPixels(measure);
    }
  }

};

__decorate([Prop()], MediaStrip$1.prototype, "media", void 0);

__decorate([Prop({
  default: () => 8
})], MediaStrip$1.prototype, "imageGap", void 0);

__decorate([Prop()], MediaStrip$1.prototype, "imageWidth", void 0);

__decorate([Prop({
  default: () => 160
})], MediaStrip$1.prototype, "imageHeight", void 0);

__decorate([Prop()], MediaStrip$1.prototype, "mediaContext", void 0);

__decorate([Prop()], MediaStrip$1.prototype, "columns", void 0);

__decorate([Prop()], MediaStrip$1.prototype, "productName", void 0);

__decorate([Prop({
  default: () => 'left'
})], MediaStrip$1.prototype, "alignment", void 0);

__decorate([Prop({
  default: () => false
})], MediaStrip$1.prototype, "scale", void 0);

__decorate([Prop()], MediaStrip$1.prototype, "maxMediaCount", void 0);

__decorate([Prop({
  default: () => false
})], MediaStrip$1.prototype, "showAllImagesWhenLarge", void 0);

__decorate([Prop({
  default: () => false
})], MediaStrip$1.prototype, "flexWrapImages", void 0);

MediaStrip$1 = __decorate([Component({
  components: {
    MediaThumbnail: async () => (await Promise.resolve().then(function () { return MediaThumbnail; })).default,
    ShowMoreButton: async () => (await Promise.resolve().then(function () { return ShowMoreButton; })).default
  }
})], MediaStrip$1);
var script$t = MediaStrip$1;

/* script */
const __vue_script__$t = script$t;
/* template */

var __vue_render__$t = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-mediaStrip-container"
  }, [_c('ul', {
    staticClass: "oke-mediaStrip",
    class: ["oke-mediaStrip--maxImages-" + _vm.mediaToDisplay.length, {
      'oke-mediaStrip--maxImagesLarge-all': _vm.showAllImagesWhenLarge
    }],
    style: _vm.mediaStripStyle
  }, _vm._l(_vm.media, function (mediaItem, index) {
    return _c('li', {
      key: mediaItem.streamId,
      style: {
        height: _vm.toPixels(_vm.imageHeight) + "px",
        'max-width': (!!_vm.columns ? 100 : 100 / _vm.mediaToDisplay.length) + '%'
      }
    }, [_c('media-thumbnail', {
      attrs: {
        "mediaItem": mediaItem,
        "linked": true,
        "mediaContext": _vm.mediaContext,
        "transcodedHeight": _vm.toPixels(_vm.imageHeight),
        "transcodedWidth": _vm.toPixels(_vm.imageWidth),
        "productName": _vm.productName
      },
      on: {
        "mediaThumbnailClick": function ($event) {
          return _vm.onMediaClick(index);
        },
        "imageLoaded": function ($event) {
          _vm.imageHasLoaded = true;
        }
      }
    }), _vm._v(" "), _vm.shouldButtonRender && index === _vm.maxMediaToDisplay - 1 ? _c('show-more-button', {
      staticClass: "oke-mediaStrip-showMoreButton",
      style: {
        visibility: _vm.imageHasLoaded ? 'initial' : 'hidden'
      },
      attrs: {
        "moreMediaCount": _vm.media.length - (_vm.maxMediaToDisplay - 1)
      },
      on: {
        "showMoreButtonClick": function ($event) {
          return _vm.onMediaClick(index);
        }
      }
    }) : _vm._e()], 1);
  }), 0)]);
};

var __vue_staticRenderFns__$t = [];
/* style */

const __vue_inject_styles__$t = undefined;
/* scoped */

const __vue_scope_id__$t = "data-v-40d3fa6b";
/* module identifier */

const __vue_module_identifier__$t = undefined;
/* functional template */

const __vue_is_functional_template__$t = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$t = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$t,
  staticRenderFns: __vue_staticRenderFns__$t
}, __vue_inject_styles__$t, __vue_script__$t, __vue_scope_id__$t, __vue_is_functional_template__$t, __vue_module_identifier__$t, false, undefined, undefined, undefined);

var MediaStrip = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$t
});

let ReviewBasicContent$1 = class ReviewBasicContent extends Vue {
  constructor() {
    super(...arguments);
    this.initialLoad = true;
  }

  mounted() {
    var _a;

    const reviewBody = this.$refs.reviewBody; // Check whether review body is long enough to need truncation

    if (reviewBody && ((_a = this.truncationSettings) === null || _a === void 0 ? void 0 : _a.enabled) && this.truncationSettings.bodyMaxLines) {
      this.truncatedHeight = this.getTruncatedHeight(reviewBody, this.truncationSettings.bodyMaxLines);
      this.reviewBodyNeedsTruncation = reviewBody.scrollHeight > this.truncatedHeight;
    } else {
      this.reviewBodyNeedsTruncation = false;
    }

    this.initialLoad = false;
    this.$emit('load', {
      reviewBodyNeedsTruncation: this.reviewBodyNeedsTruncation
    });
  }

  get bodyWithParagraphs() {
    return this.review.body ? StringUtils.addParagraphTags(this.review.body) : undefined;
  }

  get isTruncated() {
    return this.initialLoad || this.isReviewTruncated && (this.truncationSettings.truncateAll || this.reviewBodyNeedsTruncation) || this.isMetafieldTruncated;
  }

  get starHeightPx() {
    return OkendoUtils.toPixels(this.starHeight);
  }

  get truncationLineClamp() {
    if (!this.initialLoad && this.reviewBodyNeedsTruncation && this.isTruncated) {
      return {
        'height': `${this.truncatedHeight}px`
      };
    }
  }

  get reviewDateCreated() {
    return DateUtils.formatDate(this.review.dateCreated, SharedSettings.widgetSettings.global.dateSettings.format);
  }

  onReadMoreClick() {
    this.$emit('readMore', 'reviewId' in this.review ? this.review.reviewId : this.review.parentId);
  }

  getTruncatedHeight(reviewBody, bodyMaxLines) {
    let truncatedHeight = 0;
    let linesVisible = 0;
    const pTags = reviewBody.querySelectorAll('p');
    const lineHeight = parseFloat(window.getComputedStyle(pTags[0]).lineHeight);
    const marginBottom = parseFloat(window.getComputedStyle(pTags[0]).marginBottom); // Loops through paragraphs in the review line by line, adding lineHeight per line, and marginBottom per paragraph

    for (const pTag of pTags) {
      const lineCountInP = Math.round(pTag.scrollHeight / lineHeight);

      for (let i = 0; i < lineCountInP; i++) {
        linesVisible++;
        truncatedHeight += lineHeight;

        if (linesVisible >= bodyMaxLines) {
          break;
        }
      }

      if (linesVisible >= bodyMaxLines) {
        break;
      } else {
        truncatedHeight += marginBottom;
      }
    }

    return Math.round(truncatedHeight);
  }

};

__decorate([Prop()], ReviewBasicContent$1.prototype, "review", void 0);

__decorate([Prop({
  default: () => true
})], ReviewBasicContent$1.prototype, "showDates", void 0);

__decorate([Prop({
  default: () => false
})], ReviewBasicContent$1.prototype, "hideStars", void 0);

__decorate([Prop({
  default: () => false
})], ReviewBasicContent$1.prototype, "showPostedOnIg", void 0);

__decorate([Prop({
  default: () => false
})], ReviewBasicContent$1.prototype, "isReviewTruncated", void 0);

__decorate([Prop({
  default: () => false
})], ReviewBasicContent$1.prototype, "isMetafieldTruncated", void 0);

__decorate([Prop({
  default: () => false
})], ReviewBasicContent$1.prototype, "isLoading", void 0);

__decorate([Prop({
  default: () => ({
    truncateAll: false
  })
})], ReviewBasicContent$1.prototype, "truncationSettings", void 0);

__decorate([Prop({
  default: () => 'left'
})], ReviewBasicContent$1.prototype, "alignment", void 0);

__decorate([Prop()], ReviewBasicContent$1.prototype, "starHeight", void 0);

__decorate([Prop()], ReviewBasicContent$1.prototype, "starInterspace", void 0);

ReviewBasicContent$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], ReviewBasicContent$1);
var script$s = ReviewBasicContent$1;

/* script */
const __vue_script__$s = script$s;
/* template */

var __vue_render__$s = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-reviewContent",
    class: [{
      'oke-is-truncated': _vm.isTruncated
    }, "oke-reviewContent--" + _vm.alignment]
  }, [!_vm.hideStars || _vm.showDates ? _c('div', {
    staticClass: "oke-reviewContent-top"
  }, [!_vm.hideStars ? _c('div', {
    staticClass: "oke-reviewContent-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.review.rating,
      "height": _vm.starHeightPx,
      "interspace": _vm.starInterspace
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.showDates ? _c('div', {
    staticClass: "oke-reviewContent-date"
  }, [_vm.showPostedOnIg ? _c('a', {
    attrs: {
      "href": _vm.review.reviewer.sourceUrl,
      "rel": "noopener nofollow noreferrer",
      "target": "_blank"
    }
  }, [_vm._v("\n                " + _vm._s(_vm.$t('Posted on Instagram {0}', [_vm.reviewDateCreated])) + " "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("(" + _vm._s(_vm.$tc('Opens in a new window')) + ")")])]) : _c('span', [_vm._v(_vm._s(_vm.reviewDateCreated))])]) : _vm._e()]) : _vm._e(), _vm._v(" "), !_vm.showPostedOnIg ? _c('div', {
    staticClass: "oke-reviewContent-title",
    domProps: {
      "innerHTML": _vm._s(_vm.review.title)
    }
  }) : _vm._e(), _vm._v(" "), _vm.bodyWithParagraphs ? _c('div', {
    ref: "reviewBody",
    staticClass: "oke-reviewContent-body",
    style: _vm.truncationLineClamp,
    domProps: {
      "innerHTML": _vm._s(_vm.bodyWithParagraphs)
    }
  }) : _vm._e(), _vm._v(" "), _c('button', {
    staticClass: "oke-reviewContent-readMore",
    class: {
      'oke-is-loading': _vm.isLoading
    },
    on: {
      "click": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  }, [_c('span', {
    staticClass: "oke-reviewContent-readMore-text"
  }, [_vm._v(_vm._s(_vm.$tc('Read More')))]), _vm._v(" "), _vm.isLoading ? _c('span', {
    staticClass: "oke-loader"
  }, [_c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc('Loading...')))])]) : _vm._e()])]);
};

var __vue_staticRenderFns__$s = [];
/* style */

const __vue_inject_styles__$s = undefined;
/* scoped */

const __vue_scope_id__$s = undefined;
/* module identifier */

const __vue_module_identifier__$s = undefined;
/* functional template */

const __vue_is_functional_template__$s = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$s = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$s,
  staticRenderFns: __vue_staticRenderFns__$s
}, __vue_inject_styles__$s, __vue_script__$s, __vue_scope_id__$s, __vue_is_functional_template__$s, __vue_module_identifier__$s, false, undefined, undefined, undefined);

var ReviewBasicContent = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$s
});

let MediaCollage$1 = class MediaCollage extends Vue {
  constructor() {
    super(...arguments);
    this.maxImages = 3;
  }

  get collageHeightPixels() {
    return this.collageWidthPixels * (4 / 3);
  }

  get collageWidthPixels() {
    return OkendoUtils.toPixels(this.collageWidth);
  }

  get collageGapPixels() {
    return OkendoUtils.toPixels(this.imageGap);
  }

  get smallImageSize() {
    return (this.collageWidthPixels - this.collageGapPixels) / 2;
  }

  get totalImages() {
    return this.media.length;
  }

  get collageStyle() {
    return {
      height: this.collageHeightPixels + 'px',
      width: this.collageWidthPixels + 'px',
      display: 'grid',
      'grid-gap': this.totalImages === 1 ? 0 : this.totalImages === 2 ? `${this.collageGapPixels}px 0` : `${this.collageGapPixels}px`,
      'grid-template-columns': this.totalImages > 2 ? `${this.smallImageSize}px ${this.smallImageSize}px` : '1fr'
    };
  }

  created() {
    // Show videos first
    if (this.media.length > 1) {
      this.media.sort((x, y) => {
        return x.type === 'video' ? -1 : y.type === 'video' ? 1 : 0;
      });
    }
  }

  getImageDimensions(index) {
    switch (this.totalImages) {
      case 1:
        return {
          width: this.collageWidthPixels,
          height: this.collageHeightPixels
        };

      case 2:
        return {
          width: this.collageWidthPixels,
          height: (this.collageHeightPixels - this.collageGapPixels) / 2
        };

      default:
        return {
          width: index === 0 ? this.collageWidthPixels : this.smallImageSize,
          height: index === 0 ? this.collageHeightPixels - this.smallImageSize - this.collageGapPixels : this.smallImageSize
        };
    }
  }

  onMediaClick(clickedIndex) {
    this.$emit('click', clickedIndex);
  }

};

__decorate([Prop()], MediaCollage$1.prototype, "media", void 0);

__decorate([Prop({
  default: () => {
    return {
      value: 8,
      unit: 'px'
    };
  }
})], MediaCollage$1.prototype, "imageGap", void 0);

__decorate([Prop()], MediaCollage$1.prototype, "mediaContext", void 0);

__decorate([Prop()], MediaCollage$1.prototype, "collageWidth", void 0);

__decorate([Prop()], MediaCollage$1.prototype, "productName", void 0);

MediaCollage$1 = __decorate([Component({
  components: {
    MediaThumbnail: async () => (await Promise.resolve().then(function () { return MediaThumbnail; })).default,
    ShowMoreButton: async () => (await Promise.resolve().then(function () { return ShowMoreButton; })).default
  }
})], MediaCollage$1);
var script$r = MediaCollage$1;

/* script */
const __vue_script__$r = script$r;
/* template */

var __vue_render__$r = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-mediaCollage",
    style: _vm.collageStyle
  }, [_vm._l(_vm.media.slice(0, _vm.maxImages), function (mediaItem, index) {
    return _c('media-thumbnail', {
      key: mediaItem.streamId,
      attrs: {
        "mediaItem": mediaItem,
        "linked": true,
        "mediaContext": _vm.mediaContext,
        "transcodedWidth": _vm.getImageDimensions(index).width,
        "transcodedHeight": _vm.getImageDimensions(index).height,
        "productName": _vm.productName,
        "outerClass": "oke-mediaCollage-item",
        "imageClass": "oke-mediaCollage-item-media"
      },
      on: {
        "mediaThumbnailClick": function ($event) {
          return _vm.onMediaClick(index);
        }
      }
    });
  }), _vm._v(" "), _vm.media.length > _vm.maxImages ? _c('show-more-button', {
    attrs: {
      "moreMediaCount": _vm.media.length - _vm.maxImages
    },
    on: {
      "showMoreButtonClick": function ($event) {
        return _vm.onMediaClick(_vm.maxImages);
      }
    }
  }) : _vm._e()], 2);
};

var __vue_staticRenderFns__$r = [];
/* style */

const __vue_inject_styles__$r = undefined;
/* scoped */

const __vue_scope_id__$r = undefined;
/* module identifier */

const __vue_module_identifier__$r = undefined;
/* functional template */

const __vue_is_functional_template__$r = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$r = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$r,
  staticRenderFns: __vue_staticRenderFns__$r
}, __vue_inject_styles__$r, __vue_script__$r, __vue_scope_id__$r, __vue_is_functional_template__$r, __vue_module_identifier__$r, false, undefined, undefined, undefined);

var MediaCollage = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$r
});

let Product$1 = class Product extends Vue {
  constructor() {
    super(...arguments);
    this.showProductImage = true;
  } // allow lazy-load of new product image


  get productImageUrl() {
    this.showProductImage = false;
    this.$nextTick(() => {
      this.showProductImage = true;
    });
    return this.review.productImageUrl;
  }

  get productUrl() {
    if (typeof window.okeProductUrlFormatter === 'function' && this.review.productId) {
      return window.okeProductUrlFormatter({
        productHandle: this.review.productHandle,
        productId: this.review.productId.replaceAll('shopify-', ''),
        variantId: this.review.variantId
      });
    }

    return this.review.variantId && this.review.productUrl ? `${this.review.productUrl + '?variant=' + this.review.variantId}` : this.review.productUrl;
  }

};

__decorate([Prop()], Product$1.prototype, "review", void 0);

__decorate([Prop({
  default: () => true
})], Product$1.prototype, "showTitle", void 0);

__decorate([Prop({
  default: () => 'side-by-side'
})], Product$1.prototype, "layout", void 0);

Product$1 = __decorate([Component], Product$1);
var script$q = Product$1;

/* script */
const __vue_script__$q = script$q;
/* template */

var __vue_render__$q = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.review.productName ? _c('div', {
    staticClass: "oke-product",
    class: {
      'oke-product--stacked': _vm.layout === 'stacked',
      'oke-product--imageOnly': _vm.layout === 'image-only'
    }
  }, [_vm.review.productImageUrl ? _c(_vm.productUrl ? 'a' : 'div', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: _vm.productUrl ? {
        action: 'Review Product Click',
        label: _vm.review.productName,
        eventParameters: {
          product_label: _vm.review.productName
        }
      } : undefined,
      expression: "productUrl ? { action: 'Review Product Click', label: review.productName, eventParameters: { product_label: review.productName } } : undefined",
      arg: "click"
    }],
    tag: "component",
    staticClass: "oke-product-thumbnail",
    attrs: {
      "href": _vm.productUrl,
      "aria-label": _vm.$t('View {0}', [_vm.review.productName])
    }
  }, [_vm.showProductImage ? _c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.productImageUrl,
      expression: "productImageUrl"
    }],
    staticClass: "oke-product-thumbnail-image",
    attrs: {
      "alt": _vm.review.productName
    }
  }) : _vm._e()]) : _vm._e(), _vm._v(" "), _vm.layout !== 'image-only' ? _c('div', {
    staticClass: "oke-product-details"
  }, [_vm.review.rating && _vm.showTitle ? _c('div', {
    staticClass: "oke-product-details-title"
  }, [_vm._v("\n            " + _vm._s(_vm.$tc('Reviewing')) + "\n        ")]) : _vm._e(), _vm._v(" "), _c(_vm.productUrl ? 'a' : 'span', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: _vm.productUrl ? {
        action: 'Product Click',
        label: _vm.review.productName,
        eventParameters: {
          product_label: _vm.review.productName
        }
      } : undefined,
      expression: "productUrl ? { action: 'Product Click', label: review.productName, eventParameters: { product_label: review.productName } } : undefined",
      arg: "click"
    }],
    tag: "component",
    staticClass: "oke-product-details-name",
    attrs: {
      "href": _vm.productUrl
    }
  }, [_vm._v("\n            " + _vm._s(_vm.review.productName) + "\n        ")])], 1) : _vm._e()], 1) : _vm._e();
};

var __vue_staticRenderFns__$q = [];
/* style */

const __vue_inject_styles__$q = undefined;
/* scoped */

const __vue_scope_id__$q = undefined;
/* module identifier */

const __vue_module_identifier__$q = undefined;
/* functional template */

const __vue_is_functional_template__$q = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$q = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$q,
  staticRenderFns: __vue_staticRenderFns__$q
}, __vue_inject_styles__$q, __vue_script__$q, __vue_scope_id__$q, __vue_is_functional_template__$q, __vue_module_identifier__$q, false, undefined, undefined, undefined);

var Product = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$q
});

let IncentivizedReview$1 = class IncentivizedReview extends Vue {};
IncentivizedReview$1 = __decorate([Component], IncentivizedReview$1);
var script$p = IncentivizedReview$1;

/* script */
const __vue_script__$p = script$p;
/* template */

var __vue_render__$p = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-incentivized"
  }, [_c('svg', {
    attrs: {
      "viewBox": "0 0 24 24",
      "xmlns": "http://www.w3.org/2000/svg"
    }
  }, [_c('path', {
    attrs: {
      "d": "M15.58,16.8L12,14.5L8.42,16.8L9.5,12.68L6.21,10L10.46,9.74L12,5.8L13.54,9.74L17.79,10L14.5,12.68M20,12C20,10.89 20.9,10 22,10V6C22,4.89 21.1,4 20,4H4A2,2 0 0,0 2,6V10C3.11,10 4,10.9 4,12A2,2 0 0,1 2,14V18A2,2 0 0,0 4,20H20A2,2 0 0,0 22,18V14A2,2 0 0,1 20,12Z"
    }
  })]), _vm._v(" "), _c('span', [_vm._v(_vm._s(_vm.$t('Incentivized review')))]), _vm._v(" "), _c('div', {
    staticClass: "oke-incentivized-tooltip"
  }, [_vm._v("\n        " + _vm._s(_vm.$t('This review was received as part of a promotion or in exchange for an incentive. The incentive was offered to both positive and negative reviews.')) + "\n    ")])]);
};

var __vue_staticRenderFns__$p = [];
/* style */

const __vue_inject_styles__$p = undefined;
/* scoped */

const __vue_scope_id__$p = undefined;
/* module identifier */

const __vue_module_identifier__$p = undefined;
/* functional template */

const __vue_is_functional_template__$p = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$p = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$p,
  staticRenderFns: __vue_staticRenderFns__$p
}, __vue_inject_styles__$p, __vue_script__$p, __vue_scope_id__$p, __vue_is_functional_template__$p, __vue_module_identifier__$p, false, undefined, undefined, undefined);

var IncentivizedReview = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$p
});

let ShowMoreButton$1 = class ShowMoreButton extends Vue {
  showMoreButtonClick() {
    this.$emit('showMoreButtonClick');
  }

};

__decorate([Prop()], ShowMoreButton$1.prototype, "moreMediaCount", void 0);

ShowMoreButton$1 = __decorate([Component], ShowMoreButton$1);
var script$o = ShowMoreButton$1;

/* script */
const __vue_script__$o = script$o;
/* template */

var __vue_render__$o = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "okeReviews",
    attrs: {
      "data-oke-container": ""
    }
  }, [_c('button', {
    staticClass: "oke-showMoreButton",
    on: {
      "click": function ($event) {
        return _vm.showMoreButtonClick();
      }
    }
  }, [_vm._v("\n        " + _vm._s(_vm.$t('+ {0} more', [_vm.moreMediaCount])) + "\n    ")])]);
};

var __vue_staticRenderFns__$o = [];
/* style */

const __vue_inject_styles__$o = undefined;
/* scoped */

const __vue_scope_id__$o = undefined;
/* module identifier */

const __vue_module_identifier__$o = undefined;
/* functional template */

const __vue_is_functional_template__$o = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$o = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$o,
  staticRenderFns: __vue_staticRenderFns__$o
}, __vue_inject_styles__$o, __vue_script__$o, __vue_scope_id__$o, __vue_is_functional_template__$o, __vue_module_identifier__$o, false, undefined, undefined, undefined);

var ShowMoreButton = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$o
});

let ReviewsList$1 = class ReviewsList extends Vue {
  onPropertyChanged() {
    this.updateReviewSearchHighlightFragments();
  }

  get reviewComponent() {
    switch (SharedSettings.widgetSettings.reviewsWidget.reviews.list.layout.name) {
      case 'minimal':
        return 'ReviewMinimal';

      case 'split':
        return 'ReviewSplit';

      case 'default':
      default:
        return 'Review';
    }
  }

  updateReviewSearchHighlightFragments() {
    this.reviews.forEach(review => {
      var _a, _b, _c, _d, _e, _f, _g, _h;

      if ((_b = (_a = review.searchHighlight) === null || _a === void 0 ? void 0 : _a.bodyFragments) === null || _b === void 0 ? void 0 : _b.length) {
        let html = '';
        (_d = (_c = review.searchHighlight) === null || _c === void 0 ? void 0 : _c.bodyFragments) === null || _d === void 0 ? void 0 : _d.forEach(fragment => {
          html += this.buildHighlightedHtml(fragment);
        });
        review.body = html;
      }

      if ((_f = (_e = review.searchHighlight) === null || _e === void 0 ? void 0 : _e.titleFragments) === null || _f === void 0 ? void 0 : _f.length) {
        let html = '';
        (_h = (_g = review.searchHighlight) === null || _g === void 0 ? void 0 : _g.titleFragments) === null || _h === void 0 ? void 0 : _h.forEach(fragment => {
          html += this.buildHighlightedHtml(fragment);
        });
        review.title = html;
      }
    });
  }

  buildHighlightedHtml({
    isHighlight,
    text
  }) {
    return isHighlight ? `<mark class="oke-reviewContent-highlight">${text}</mark>` : text;
  }

};

__decorate([Prop({
  default: () => []
})], ReviewsList$1.prototype, "reviews", void 0);

__decorate([Prop()], ReviewsList$1.prototype, "reviewSettings", void 0);

__decorate([Prop()], ReviewsList$1.prototype, "widgetMode", void 0);

__decorate([Prop()], ReviewsList$1.prototype, "widgetSize", void 0);

__decorate([Watch('reviews')], ReviewsList$1.prototype, "onPropertyChanged", null);

ReviewsList$1 = __decorate([Component({
  components: {
    Review: async () => (await Promise.resolve().then(function () { return Review; })).default,
    ReviewMinimal: async () => (await Promise.resolve().then(function () { return ReviewMinimal; })).default,
    ReviewSplit: async () => (await Promise.resolve().then(function () { return ReviewSplit; })).default
  }
})], ReviewsList$1);
var script$n = ReviewsList$1;

/* script */
const __vue_script__$n = script$n;
/* template */

var __vue_render__$n = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('ul', {
    staticClass: "oke-w-reviews-list"
  }, _vm._l(_vm.reviews, function (review) {
    return _c('li', {
      key: review.reviewId,
      ref: "reviewItem",
      refInFor: true,
      staticClass: "oke-w-reviews-list-item"
    }, [_c(_vm.reviewComponent, {
      tag: "component",
      attrs: {
        "reviewSettings": _vm.reviewSettings,
        "review": review,
        "widgetMode": _vm.widgetMode,
        "widgetSize": _vm.widgetSize
      }
    })], 1);
  }), 0);
};

var __vue_staticRenderFns__$n = [];
/* style */

const __vue_inject_styles__$n = undefined;
/* scoped */

const __vue_scope_id__$n = undefined;
/* module identifier */

const __vue_module_identifier__$n = undefined;
/* functional template */

const __vue_is_functional_template__$n = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$n = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$n,
  staticRenderFns: __vue_staticRenderFns__$n
}, __vue_inject_styles__$n, __vue_script__$n, __vue_scope_id__$n, __vue_is_functional_template__$n, __vue_module_identifier__$n, false, undefined, undefined, undefined);

var ReviewsList = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$n
});

let ReviewsListMasonry$1 = class ReviewsListMasonry extends Vue {
  onPropertyChanged(newReviews, currentReviews) {
    if (newReviews.length > currentReviews.length) {
      this.$emit('loadedReviewsItems');
    }
  }

  get numColumns() {
    var _a;

    return (_a = SharedSettings.widgetSettings.reviewsWidget.reviews.list.layout.columnAmount) !== null && _a !== void 0 ? _a : 4;
  }

  get columnAmount() {
    if (this.widgetSize === 'small') {
      return 1;
    } else if (this.widgetSize === 'medium' && this.numColumns === 4) {
      return 3;
    } else {
      return this.numColumns;
    }
  }

  get reviewCardComponent() {
    switch (this.reviewSettings.layout.name) {
      case 'testimonial':
        return 'TestimonialCard';

      case 'minimal-centered':
        return 'ReviewCardMinimalCentered';

      case 'featured':
        return 'ReviewCardFeaturedMedia';

      case 'default':
      default:
        return 'ReviewCard';
    }
  }

  get isImageFullHeight() {
    return this.reviewSettings.layout.name === 'featured' && !!this.reviewSettings.layout.showFullHeightImages;
  }

  get gridColumnSize() {
    const columnGap = 10;
    const columnAmount = this.columnAmount;
    const columnGapAsPercentage = columnGap * columnAmount / this.widgetWidth * 100;
    const gridItemWidth = this.widgetSize === 'small' ? 100 : (100 - columnGapAsPercentage) / columnAmount;
    return `repeat(auto-fill, minmax(${gridItemWidth}%, 1fr))`;
  }

  onReviewCardMediaClick(initialIndex, initialMedia) {
    ModalService.openMediaModal({
      initialMedia,
      mediaContext: 'review',
      initialIndex,
      widgetMode: this.widgetMode
    });
  }

  cardUpdated(settings) {
    const masonryItems = this.$refs.masonryItem;
    this.resizeGridItem(settings.height, masonryItems[settings.index]);
  }

  resizeGridItem(height, item) {
    if (height === 0) {
      return;
    }

    const extraMarginToAdd = this.reviewSettings.layout.name === 'testimonial' ? 24 : 0;
    item.style.gridRowEnd = `span ${Math.ceil(height + 10 + extraMarginToAdd)}`;

    if (item.style.opacity !== '1') {
      item.style.opacity = '1';
    }
  }

};

__decorate([Prop({
  default: () => []
})], ReviewsListMasonry$1.prototype, "reviews", void 0);

__decorate([Prop()], ReviewsListMasonry$1.prototype, "reviewSettings", void 0);

__decorate([Prop()], ReviewsListMasonry$1.prototype, "widgetMode", void 0);

__decorate([Prop()], ReviewsListMasonry$1.prototype, "index", void 0);

__decorate([Prop()], ReviewsListMasonry$1.prototype, "widgetSize", void 0);

__decorate([Prop()], ReviewsListMasonry$1.prototype, "widgetWidth", void 0);

__decorate([Watch('reviews')], ReviewsListMasonry$1.prototype, "onPropertyChanged", null);

ReviewsListMasonry$1 = __decorate([Component({
  components: {
    ReviewCard: async () => (await Promise.resolve().then(function () { return ReviewCard$2; })).default,
    ReviewCardFeaturedMedia: async () => (await Promise.resolve().then(function () { return ReviewCardFeaturedMedia; })).default,
    ReviewCardMinimalCentered: async () => (await Promise.resolve().then(function () { return ReviewCardMinimalCentered; })).default,
    TestimonialCard: async () => (await Promise.resolve().then(function () { return TestimonialCard; })).default
  }
})], ReviewsListMasonry$1);
var script$m = ReviewsListMasonry$1;

/* script */
const __vue_script__$m = script$m;
/* template */

var __vue_render__$m = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', [_c('div', {
    ref: "reviewList",
    staticClass: "oke-w-reviews-listMasonry",
    style: [{
      'paddingTop': _vm.reviewSettings.layout.name === 'testimonial' ? '34px' : '16px'
    }]
  }, [_c('ul', {
    staticClass: "oke-w-reviews-masonryGrid",
    style: {
      'grid-template-columns': _vm.gridColumnSize
    }
  }, _vm._l(_vm.reviews, function (item, index) {
    return _c('li', {
      key: item.reviewId,
      ref: "masonryItem",
      refInFor: true,
      staticClass: "oke-w-reviews-masonryGrid-item"
    }, [_c(_vm.reviewCardComponent, {
      tag: "component",
      staticClass: "masonryContent oke-w-reviews-js-masonryContent",
      attrs: {
        "review": item,
        "reviewSettings": _vm.reviewSettings,
        "widgetMode": _vm.widgetMode,
        "widgetSize": _vm.widgetSize,
        "showHelpfulVoting": true,
        "shouldStretchVertically": false,
        "index": index,
        "showFullHeightImages": _vm.isImageFullHeight
      },
      on: {
        "cardUpdated": _vm.cardUpdated,
        "reviewCardMediaClick": _vm.onReviewCardMediaClick
      }
    })], 1);
  }), 0)]), _vm._v(" "), _c('span', {
    ref: "endFocusHolder",
    attrs: {
      "tabindex": "-1",
      "aria-hidden": "true"
    }
  })]);
};

var __vue_staticRenderFns__$m = [];
/* style */

const __vue_inject_styles__$m = undefined;
/* scoped */

const __vue_scope_id__$m = undefined;
/* module identifier */

const __vue_module_identifier__$m = undefined;
/* functional template */

const __vue_is_functional_template__$m = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$m = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$m,
  staticRenderFns: __vue_staticRenderFns__$m
}, __vue_inject_styles__$m, __vue_script__$m, __vue_scope_id__$m, __vue_is_functional_template__$m, __vue_module_identifier__$m, false, undefined, undefined, undefined);

var ReviewsListMasonry = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$m
});

let ReviewsListCarousel$1 = class ReviewsListCarousel extends Vue {
  constructor() {
    super(...arguments);
    this.currentPage = 0;
    this.slidesPerPage = 3;
    this.readReviewIds = [];
    this.carouselOptions = {
      itemsToShow: this.slidesPerPage,
      itemsToSlide: this.scrollBehaviour,
      infiniteScroll: false,
      fluidSlide: true,
      wheelControl: false
    };
  }

  mounted() {
    const slidesPerPage = this.getSlidesPerPage(this.widgetSize);
    this.slidesPerPage = slidesPerPage;
    this.carouselOptions.itemsToShow = slidesPerPage;
    this.carouselOptions.itemsToSlide = this.getItemsToSlide(slidesPerPage);
  }

  sizeChanged(newSize) {
    const newSlidesPerPage = this.getSlidesPerPage(newSize);
    this.slidesPerPage = newSlidesPerPage;
    this.$refs.okeReviewsListCarousel.displayConfig.itemsToShow = newSlidesPerPage;
    this.$refs.okeReviewsListCarousel.displayConfig.itemsToSlide = this.getItemsToSlide(newSlidesPerPage);
    this.setTabIndices();
    this.$refs.okeReviewsListCarousel.update();
  }

  get arrowSettings() {
    return this.carouselLayoutSettings.arrows;
  }

  get scrollBehaviour() {
    return this.carouselLayoutSettings.scrollBehaviour === 'page' ? this.slidesPerPage : 1;
  }

  get mediaLayout() {
    return SharedSettings.widgetSettings.reviewsWidget.reviews.list.media.layout;
  }

  get carouselLayoutSettings() {
    return SharedSettings.widgetSettings.reviewsWidget.reviews.list.layout;
  }

  get isCloseToSliderEnd() {
    return this.currentPage >= this.reviews.length - this.slidesPerPage;
  }

  get translatedInstructions() {
    return this.$tc('Press left and right arrows to navigate.');
  }

  get reviewCardComponent() {
    switch (this.reviewSettings.layout.name) {
      case 'testimonial':
        return 'TestimonialCard';

      case 'minimal-centered':
        return 'ReviewCardMinimalCentered';

      case 'featured':
        return 'ReviewCardFeaturedMedia';

      case 'default':
      default:
        return 'ReviewCard';
    }
  }

  onSliderSlide(event) {
    if (event.currentSlide !== this.currentPage) {
      this.currentPage = event.currentSlide;
      this.setTabIndices();

      if (this.isCloseToSliderEnd) {
        this.$emit('carouselLoadMore');
      }
    }
  }

  onReviewCardMediaClick(initialIndex, initialMedia) {
    if (!this.$refs.okeReviewsListCarousel.isSliding) {
      ModalService.openMediaModal({
        initialMedia,
        mediaContext: 'review',
        initialIndex,
        widgetMode: this.widgetMode
      });
    }
  }

  setTabIndices() {
    this.$nextTick(() => {
      var _a;

      for (const [index, reviewCard] of ((_a = this.$refs.reviewCards) !== null && _a !== void 0 ? _a : []).entries()) {
        const focusableElements = HtmlUtils.getFocusableElements(reviewCard.$el, true);

        for (const element of focusableElements !== null && focusableElements !== void 0 ? focusableElements : []) {
          element.tabIndex = this.isSlideVisible(index) ? 0 : -1;
        }
      }
    });
  }

  getItemsToSlide(slidesPerPage) {
    return this.carouselLayoutSettings.scrollBehaviour === 'page' ? slidesPerPage : 1;
  }

  getSlidesPerPage(size) {
    if (size === 'small') {
      this.slidesPerPage = 1;
      return 1;
    } else if (this.carouselLayoutSettings.slidesPerPage[size] < this.carouselLayoutSettings.slidesPerPage.large) {
      this.slidesPerPage = this.carouselLayoutSettings.slidesPerPage[size];
      return this.carouselLayoutSettings.slidesPerPage[size];
    } else {
      this.slidesPerPage = this.carouselLayoutSettings.slidesPerPage.large;
      return this.carouselLayoutSettings.slidesPerPage.large;
    }
  }

  nextSlide() {
    this.$refs.okeReviewsListCarousel.slideNext();
  }

  prevSlide() {
    this.$refs.okeReviewsListCarousel.slidePrev();
  }

  isSlideVisible(index) {
    return index >= this.currentPage && index < this.currentPage + this.slidesPerPage;
  }

  updateReadReviewId(reviewId) {
    this.readReviewIds.push(reviewId);
  }

};

__decorate([Prop({
  default: () => []
})], ReviewsListCarousel$1.prototype, "reviews", void 0);

__decorate([Prop()], ReviewsListCarousel$1.prototype, "reviewSettings", void 0);

__decorate([Prop()], ReviewsListCarousel$1.prototype, "isLoadingMore", void 0);

__decorate([Prop()], ReviewsListCarousel$1.prototype, "widgetMode", void 0);

__decorate([Prop()], ReviewsListCarousel$1.prototype, "widgetSize", void 0);

__decorate([Prop()], ReviewsListCarousel$1.prototype, "canLoadMore", void 0);

__decorate([Watch('widgetSize')], ReviewsListCarousel$1.prototype, "sizeChanged", null);

ReviewsListCarousel$1 = __decorate([Component({
  components: {
    Hooper: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Hooper,
    Slide: async () => (await Promise.resolve().then(function () { return hooper_esm; })).Slide,
    PrevNextButton: async () => (await Promise.resolve().then(function () { return PrevNextButton; })).default,
    ReviewCard: async () => (await Promise.resolve().then(function () { return ReviewCard$2; })).default,
    ReviewCardFeaturedMedia: async () => (await Promise.resolve().then(function () { return ReviewCardFeaturedMedia; })).default,
    ReviewCardMinimalCentered: async () => (await Promise.resolve().then(function () { return ReviewCardMinimalCentered; })).default,
    TestimonialCard: async () => (await Promise.resolve().then(function () { return TestimonialCard; })).default
  }
})], ReviewsListCarousel$1);
var script$l = ReviewsListCarousel$1;

/* script */
const __vue_script__$l = script$l;
/* template */

var __vue_render__$l = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-reviewsListCarousel",
    class: {
      'oke-is-small': _vm.widgetSize === 'small',
      'oke-is-medium': _vm.widgetSize === 'medium',
      'oke-is-large': _vm.widgetSize === 'large'
    },
    attrs: {
      "role": "region",
      "aria-label": _vm.$t('Review Carousel')
    }
  }, [_vm.arrowSettings.enabled ? _c('prev-next-button', {
    attrs: {
      "isDisabled": _vm.currentPage === 0,
      "arrowSize": _vm.arrowSettings.size,
      "arrowColor": _vm.arrowSettings.color,
      "arrowDirection": "left",
      "buttonClass": "oke-reviewsListCarousel-prev"
    },
    on: {
      "click": _vm.prevSlide
    }
  }) : _vm._e(), _vm._v(" "), _c('hooper', {
    ref: "okeReviewsListCarousel",
    staticClass: "oke-reviewsListCarousel-reviews",
    attrs: {
      "settings": _vm.carouselOptions,
      "instructionsText": _vm.translatedInstructions,
      "role": _vm.$t('group')
    },
    on: {
      "slide": _vm.onSliderSlide
    }
  }, _vm._l(_vm.reviews, function (review, index) {
    return _c('slide', {
      key: review.reviewId,
      ref: "reviewCards",
      refInFor: true,
      staticClass: "oke-reviewsListCarousel-reviews-review",
      class: {
        'oke-reviewsListCarousel-reviews-review--testimonial': _vm.reviewSettings.layout.name === 'testimonial'
      },
      style: {
        width: 100 / _vm.slidesPerPage + '%'
      },
      attrs: {
        "aria-label": _vm.$t('Slide {0}', [index + 1])
      }
    }, [_c(_vm.reviewCardComponent, {
      tag: "component",
      attrs: {
        "review": review,
        "reviewSettings": _vm.reviewSettings,
        "widgetSize": _vm.widgetSize,
        "widgetMode": _vm.widgetMode,
        "readReviewIds": _vm.readReviewIds,
        "showHelpfulVoting": true
      },
      on: {
        "readReviewId": _vm.updateReadReviewId,
        "reviewCardMediaClick": _vm.onReviewCardMediaClick
      }
    })], 1);
  }), 1), _vm._v(" "), _vm.arrowSettings.enabled ? _c('prev-next-button', {
    attrs: {
      "isDisabled": _vm.currentPage >= _vm.reviews.length - _vm.slidesPerPage && !_vm.canLoadMore,
      "arrowSize": _vm.arrowSettings.size,
      "arrowColor": _vm.arrowSettings.color,
      "arrowDirection": "right",
      "buttonClass": "oke-reviewsListCarousel-next",
      "isLoadingMore": _vm.isLoadingMore
    },
    on: {
      "click": _vm.nextSlide
    }
  }) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-a11yText",
    attrs: {
      "aria-live": "polite"
    }
  }, [_vm._v("\n        " + _vm._s(_vm.$t('Viewing Slides {0} to {1} of {2}', [_vm.currentPage + 1, _vm.currentPage + _vm.slidesPerPage, _vm.reviews.length])) + "\n    ")])], 1);
};

var __vue_staticRenderFns__$l = [];
/* style */

const __vue_inject_styles__$l = undefined;
/* scoped */

const __vue_scope_id__$l = undefined;
/* module identifier */

const __vue_module_identifier__$l = undefined;
/* functional template */

const __vue_is_functional_template__$l = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$l = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$l,
  staticRenderFns: __vue_staticRenderFns__$l
}, __vue_inject_styles__$l, __vue_script__$l, __vue_scope_id__$l, __vue_is_functional_template__$l, __vue_module_identifier__$l, false, undefined, undefined, undefined);

var ReviewsListCarousel = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$l
});

let WriteReviewButton$1 = class WriteReviewButton extends Vue {
  get writeReviewUrl() {
    return OkendoApi.writeReviewUrl(this.productId);
  }

};

__decorate([Prop()], WriteReviewButton$1.prototype, "productId", void 0);

WriteReviewButton$1 = __decorate([Component], WriteReviewButton$1);
var script$k = WriteReviewButton$1;

/* script */
const __vue_script__$k = script$k;
/* template */

var __vue_render__$k = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.productId ? _c('a', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Write Review Click'
      },
      expression: "{ action: 'Write Review Click' }",
      arg: "click"
    }],
    staticClass: "oke-w-writeReview oke-button",
    attrs: {
      "href": _vm.writeReviewUrl,
      "target": "_blank",
      "rel": "noopener"
    }
  }, [_vm._v("\n    " + _vm._s(_vm.$tc('Write a Review')) + " "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("(" + _vm._s(_vm.$tc('Opens in a new window')) + ")")])]) : _vm._e();
};

var __vue_staticRenderFns__$k = [];
/* style */

const __vue_inject_styles__$k = undefined;
/* scoped */

const __vue_scope_id__$k = undefined;
/* module identifier */

const __vue_module_identifier__$k = undefined;
/* functional template */

const __vue_is_functional_template__$k = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$k = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$k,
  staticRenderFns: __vue_staticRenderFns__$k
}, __vue_inject_styles__$k, __vue_script__$k, __vue_scope_id__$k, __vue_is_functional_template__$k, __vue_module_identifier__$k, false, undefined, undefined, undefined);

var WriteReviewButton = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$k
});

let Filters$1 = class Filters extends Vue {
  constructor() {
    super(...arguments);
    this.filters = [];
    this.viewState = 'loading';
    this.filterContentHeight = this.filtersStartOpen ? 'auto' : 0;
    this.ratingsFilters = [{
      rating: 1,
      isSelected: false
    }, {
      rating: 2,
      isSelected: false
    }, {
      rating: 3,
      isSelected: false
    }, {
      rating: 4,
      isSelected: false
    }, {
      rating: 5,
      isSelected: false
    }];
  }

  created() {
    var _a;

    if (!this.productId) {
      this.viewState = 'error';
      return;
    }

    if (!this.attributeFiltersEnabled) {
      this.updateFilterContentHeight(this.isOpen);
      this.$emit('load');
      return;
    }

    if ((_a = this.productAttributes) === null || _a === void 0 ? void 0 : _a.length) {
      this.filters = this.buildFiltersFromAttributes(this.productAttributes);
      this.viewState = this.filters.length ? 'content' : 'empty';

      if (this.filters.length) {
        this.updateFilterContentHeight(this.isOpen);
      }

      this.$emit('load');
    } else {
      this.loadFilters();
    }
  }

  onPropertyChanged(isOpen) {
    this.updateFilterContentHeight(isOpen);
  }

  get attributeFiltersEnabled() {
    var _a;

    return !!((_a = SharedSettings.features) === null || _a === void 0 ? void 0 : _a.attributeFiltersEnabled);
  }

  isFilterActive(filter) {
    return !!filter.options.find(option => option.isSelected);
  }

  onFilterChange() {
    const filtersWithSelectedOptions = [];

    for (const filter of this.filters) {
      const selectedFilterOptions = filter.options.filter(option => option.isSelected).map(option => option.name);

      if (selectedFilterOptions.length) {
        filtersWithSelectedOptions.push({ ...filter,
          options: selectedFilterOptions
        });
      }
    }

    this.$emit('change', filtersWithSelectedOptions);
  }

  onFreeTextSearchChange(searchQuery) {
    this.$emit('changeFreeTextSearch', searchQuery);
  }

  onFilterClear(filter) {
    for (const option of filter.options) {
      option.isSelected = false;
    }

    this.onFilterChange();
  }

  onFilterReload() {
    this.$emit('reload');
    this.loadFilters();
  }

  isRatingsFilterActive() {
    return this.ratingsFilters.find(rating => rating.isSelected);
  }

  onRatingsFilterClear() {
    for (const elem of this.ratingsFilters) {
      elem.isSelected = false;
    }

    this.filterByRatings([]);
  }

  onRatingsFilterChange() {
    const ratingsToFilter = this.ratingsFilters.filter(ratingFilter => ratingFilter.isSelected).map(ratingFilter => ratingFilter.rating);
    this.filterByRatings(ratingsToFilter);
  }

  filterByRatings(ratingsToFilter) {
    this.$emit('changeStarRating', ratingsToFilter);
  }

  updateFilterContentHeight(isOpen) {
    const animationDuration = 200;

    if (isOpen) {
      setTimeout(() => {
        this.filterContentHeight = 'auto';
      }, animationDuration);
    } else {
      this.filterContentHeight = `${this.$refs.filtersContainer.scrollHeight}px`;
    } // Wait for dom to catch up before setting the height


    setTimeout(() => {
      this.filterContentHeight = isOpen ? `${this.$refs.filtersContainer.scrollHeight}px` : 0;
    }, 0);
  }

  async loadFilters() {
    var _a;

    try {
      let result = (_a = this.productAttributes) !== null && _a !== void 0 ? _a : [];

      if (!result.length) {
        const {
          productAttributes
        } = await OkendoApi.getFiltersProduct(this.productId);

        if (productAttributes === null || productAttributes === void 0 ? void 0 : productAttributes.length) {
          result = productAttributes;
        }
      }

      this.filters = this.buildFiltersFromAttributes(result);
      this.viewState = this.filters.length ? 'content' : 'empty';
    } catch (_b) {
      this.viewState = 'error';
    } finally {
      this.updateFilterContentHeight(this.isOpen);
      this.$emit('load');
    }
  }

  buildFiltersFromAttributes(productAttributes) {
    return productAttributes.length ? productAttributes.map(attribute => ({ ...attribute,
      options: attribute.options.map(option => ({
        name: option,
        isSelected: false
      }))
    })) : [];
  }

};

__decorate([Prop()], Filters$1.prototype, "productId", void 0);

__decorate([Prop()], Filters$1.prototype, "isOpen", void 0);

__decorate([Prop()], Filters$1.prototype, "filtersStartOpen", void 0);

__decorate([Prop()], Filters$1.prototype, "freeTextSearchEnabled", void 0);

__decorate([Prop()], Filters$1.prototype, "productAttributes", void 0);

__decorate([Prop()], Filters$1.prototype, "widgetId", void 0);

__decorate([Watch('isOpen')], Filters$1.prototype, "onPropertyChanged", null);

Filters$1 = __decorate([Component({
  components: {
    FiltersFreeTextSearch: () => Promise.resolve().then(function () { return FiltersFreeTextSearch; })
  }
})], Filters$1);
var script$j = Filters$1;

/* script */
const __vue_script__$j = script$j;
/* template */

var __vue_render__$j = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "filtersContainer",
    staticClass: "oke-w-filters",
    style: {
      'height': _vm.filterContentHeight
    }
  }, [_vm.freeTextSearchEnabled ? _c('filters-free-text-search', {
    attrs: {
      "aria-hidden": !_vm.isOpen,
      "isFocusable": _vm.isOpen
    },
    on: {
      "change": _vm.onFreeTextSearchChange
    }
  }) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-filter"
  }, [_c('div', {
    staticClass: "oke-w-filter-title"
  }, [_vm._v("\n            " + _vm._s(_vm.$tc('Rating')) + "\n            "), _vm.isRatingsFilterActive() ? _c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Filter Clear Click',
        label: 'Star Rating',
        eventParameters: {
          filter_value: 'Star Rating'
        }
      },
      expression: "{ action: 'Filter Clear Click', label: 'Star Rating', eventParameters: { filter_value: 'Star Rating' } }",
      arg: "click"
    }],
    staticClass: "oke-w-filter-clear",
    attrs: {
      "type": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onRatingsFilterClear();
      }
    }
  }, [_vm._v("\n                " + _vm._s(_vm.$tc('Clear')) + " "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$tc('Rating filter')))])]) : _vm._e()]), _vm._v(" "), _c('fieldset', {
    staticClass: "oke-w-filter-options"
  }, [_c('legend', {
    staticClass: "oke-a11yText"
  }, [_vm._v("Ratings")]), _vm._v(" "), _vm._l(_vm.ratingsFilters, function (filter, index) {
    return _c('div', {
      key: filter.rating,
      staticClass: "oke-w-filterOption"
    }, [_c('input', {
      directives: [{
        name: "model",
        rawName: "v-model",
        value: filter.isSelected,
        expression: "filter.isSelected"
      }, {
        name: "ga",
        rawName: "v-ga:click",
        value: {
          action: 'Filter Option Click',
          label: "Rating " + filter.rating,
          eventParameters: {
            filter_value: "Rating " + filter.rating
          }
        },
        expression: "{ action: 'Filter Option Click', label: `Rating ${filter.rating}`, eventParameters: { filter_value: `Rating ${filter.rating}` } }",
        arg: "click"
      }],
      staticClass: "oke-w-filterOption-checkbox oke-a11yText",
      attrs: {
        "id": "inputRating" + filter.rating + "-" + _vm.widgetId,
        "tabindex": _vm.isOpen ? 0 : -1,
        "name": "Rating " + filter.rating,
        "type": "checkbox"
      },
      domProps: {
        "checked": Array.isArray(filter.isSelected) ? _vm._i(filter.isSelected, null) > -1 : filter.isSelected
      },
      on: {
        "change": [function ($event) {
          var $$a = filter.isSelected,
              $$el = $event.target,
              $$c = $$el.checked ? true : false;

          if (Array.isArray($$a)) {
            var $$v = null,
                $$i = _vm._i($$a, $$v);

            if ($$el.checked) {
              $$i < 0 && _vm.$set(filter, "isSelected", $$a.concat([$$v]));
            } else {
              $$i > -1 && _vm.$set(filter, "isSelected", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
            }
          } else {
            _vm.$set(filter, "isSelected", $$c);
          }
        }, function ($event) {
          return _vm.onRatingsFilterChange();
        }]
      }
    }), _vm._v(" "), _c('label', {
      staticClass: "oke-w-filterOption-label",
      attrs: {
        "for": "inputRating" + filter.rating + "-" + _vm.widgetId
      }
    }, [_vm._l(filter.rating, function (value, ratingIndex) {
      return _c('div', {
        key: 'filter-rating-' + index + '-' + ratingIndex + '-' + value,
        staticClass: "oke-w-filterOption-label-star"
      });
    }), _vm._v(" "), _c('span', {
      staticClass: "oke-a11yText"
    }, [_vm._v(_vm._s(filter.rating) + " stars")])], 2)]);
  })], 2)]), _vm._v(" "), _vm.viewState === 'content' ? _vm._l(_vm.filters, function (filter) {
    return _c('div', {
      key: filter.title,
      staticClass: "oke-w-filter"
    }, [_c('div', {
      staticClass: "oke-w-filter-title"
    }, [_vm._v("\n                " + _vm._s(filter.title) + "\n                "), _vm.isFilterActive(filter) ? _c('button', {
      directives: [{
        name: "ga",
        rawName: "v-ga:click",
        value: {
          action: 'Filter Clear Click',
          label: filter.title,
          eventParameters: {
            filter_value: filter.title
          }
        },
        expression: "{ action: 'Filter Clear Click', label: filter.title, eventParameters: { filter_value: filter.title } }",
        arg: "click"
      }],
      staticClass: "oke-w-filter-clear",
      attrs: {
        "tabindex": _vm.isOpen ? 0 : -1,
        "type": "button"
      },
      on: {
        "click": function ($event) {
          return _vm.onFilterClear(filter);
        }
      }
    }, [_vm._v("\n                    " + _vm._s(_vm.$tc('Clear')) + " "), _c('span', {
      staticClass: "oke-a11yText"
    }, [_vm._v(_vm._s(_vm.$t('{0} filter', [filter.title])))])]) : _vm._e()]), _vm._v(" "), _c('fieldset', {
      staticClass: "oke-w-filter-options"
    }, [_c('legend', {
      staticClass: "oke-a11yText"
    }, [_vm._v(_vm._s(filter.title))]), _vm._v(" "), _vm._l(filter.options, function (option) {
      return _c('div', {
        key: option.name,
        staticClass: "oke-w-filterOption"
      }, [_c('input', {
        directives: [{
          name: "model",
          rawName: "v-model",
          value: option.isSelected,
          expression: "option.isSelected"
        }, {
          name: "ga",
          rawName: "v-ga:click",
          value: {
            action: 'Filter Option Click',
            label: filter.title + " - " + option.name,
            eventParameters: {
              filter_value: filter.title + " - " + option.name
            }
          },
          expression: "{ action: 'Filter Option Click', label: `${filter.title} - ${option.name}`, eventParameters: { filter_value: `${filter.title} - ${option.name}` } }",
          arg: "click"
        }],
        staticClass: "oke-w-filterOption-checkbox oke-a11yText",
        attrs: {
          "id": filter.title + "-" + option.name + "-" + _vm.widgetId,
          "tabindex": _vm.isOpen ? 0 : -1,
          "name": filter.title,
          "type": "checkbox"
        },
        domProps: {
          "value": option.name,
          "checked": Array.isArray(option.isSelected) ? _vm._i(option.isSelected, option.name) > -1 : option.isSelected
        },
        on: {
          "change": [function ($event) {
            var $$a = option.isSelected,
                $$el = $event.target,
                $$c = $$el.checked ? true : false;

            if (Array.isArray($$a)) {
              var $$v = option.name,
                  $$i = _vm._i($$a, $$v);

              if ($$el.checked) {
                $$i < 0 && _vm.$set(option, "isSelected", $$a.concat([$$v]));
              } else {
                $$i > -1 && _vm.$set(option, "isSelected", $$a.slice(0, $$i).concat($$a.slice($$i + 1)));
              }
            } else {
              _vm.$set(option, "isSelected", $$c);
            }
          }, function ($event) {
            return _vm.onFilterChange();
          }]
        }
      }), _vm._v(" "), _c('label', {
        staticClass: "oke-w-filterOption-label",
        attrs: {
          "for": filter.title + "-" + option.name + "-" + _vm.widgetId
        }
      }, [_vm._v("\n                        " + _vm._s(option.name) + "\n                    ")])]);
    })], 2)]);
  }) : _vm._e(), _vm._v(" "), _vm.viewState === 'error' ? _c('div', {
    staticClass: "oke-w-filters-message"
  }, [_vm.viewState === 'error' ? [_vm._v(_vm._s(_vm.$tc('Error Loading Filters')) + "\n            "), _c('button', {
    staticClass: "oke-w-filters-message-retry",
    on: {
      "click": function ($event) {
        return _vm.onFilterReload();
      }
    }
  }, [_vm._v(_vm._s(_vm.$tc('Retry')))])] : _vm._e()], 2) : _vm._e()], 2);
};

var __vue_staticRenderFns__$j = [];
/* style */

const __vue_inject_styles__$j = undefined;
/* scoped */

const __vue_scope_id__$j = undefined;
/* module identifier */

const __vue_module_identifier__$j = undefined;
/* functional template */

const __vue_is_functional_template__$j = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$j = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$j,
  staticRenderFns: __vue_staticRenderFns__$j
}, __vue_inject_styles__$j, __vue_script__$j, __vue_scope_id__$j, __vue_is_functional_template__$j, __vue_module_identifier__$j, false, undefined, undefined, undefined);

var Filters = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$j
});

let HeaderModuleAttributes$1 = class HeaderModuleAttributes extends Vue {
  get attributeBarLayout() {
    return this.moduleSettings.layout;
  }

  get hasMaxWidth() {
    return this.attributeBarLayout === 'stacked';
  }

  get stretchMode() {
    return this.attributeBarLayout === 'side-by-side' ? 'stretch' : this.moduleSettings.stretchMode;
  }

};

__decorate([Prop()], HeaderModuleAttributes$1.prototype, "attributeRatings", void 0);

__decorate([Prop()], HeaderModuleAttributes$1.prototype, "moduleSettings", void 0);

__decorate([Prop()], HeaderModuleAttributes$1.prototype, "alignment", void 0);

HeaderModuleAttributes$1 = __decorate([Component({
  components: {
    BarAttributes: async () => (await Promise.resolve().then(function () { return BarAttributes; })).default
  }
})], HeaderModuleAttributes$1);
var script$i = HeaderModuleAttributes$1;

/* script */
const __vue_script__$i = script$i;
/* template */

var __vue_render__$i = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-attrModule",
    class: "oke-w-attrModule--" + _vm.stretchMode
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.attributeRatings,
      "stacked": _vm.attributeBarLayout === 'stacked',
      "alignment": _vm.alignment,
      "barHasMinWidth": true,
      "isBarFullWidth": _vm.hasMaxWidth,
      "maxWidth": _vm.attributeBarLayout === 'side-by-side' ? 250 : undefined
    }
  })], 1);
};

var __vue_staticRenderFns__$i = [];
/* style */

const __vue_inject_styles__$i = undefined;
/* scoped */

const __vue_scope_id__$i = "data-v-52e59696";
/* module identifier */

const __vue_module_identifier__$i = undefined;
/* functional template */

const __vue_is_functional_template__$i = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$i = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$i,
  staticRenderFns: __vue_staticRenderFns__$i
}, __vue_inject_styles__$i, __vue_script__$i, __vue_scope_id__$i, __vue_is_functional_template__$i, __vue_module_identifier__$i, false, undefined, undefined, undefined);

var HeaderModuleAttributes = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$i
});

let HeaderModuleMedia$1 = class HeaderModuleMedia extends Vue {
  constructor() {
    super(...arguments);
    this.imageDimension = 0;
    this.observer = new ResizeObserver(this.updateImageSize);
  }

  mounted() {
    if (this.$refs.mediaGridModule) {
      this.observer.observe(this.$refs.mediaGridModule);
    }
  }

  destroyed() {
    if (this.$refs.mediaGridModule) {
      this.observer.unobserve(this.$refs.mediaGridModule);
    }
  }

  updateImageSize() {
    var _a;

    this.containerSize = ((_a = this.$refs.mediaGridModule) === null || _a === void 0 ? void 0 : _a.clientWidth) || 0;

    if (this.containerSize) {
      this.cappedImageSize(this.containerSize);
    }
  }

  onMediaClick(clickedIndex) {
    const initialMedia = OkendoUtils.convertMediaToMediaReviews(this.media);
    ModalService.openMediaModal({
      initialMedia,
      initialNextUrl: this.nextUrl,
      mediaContext: 'aggregate',
      initialIndex: clickedIndex,
      widgetMode: this.widgetMode
    });
  }

  cappedImageSize(size) {
    const imageGap = OkendoUtils.toPixels(this.moduleSettings.imageGap) || 8;
    const columns = this.moduleSettings.columns || 4;
    let maxImageWidth = 0;

    if (this.moduleSettings.scaleToFill === true && this.media.length < columns) {
      maxImageWidth = this.media.length > 1 ? (size - (this.media.length - 1) * imageGap) / this.media.length : 150;
    } else {
      maxImageWidth = (size - (columns - 1) * imageGap) / columns;
    }

    this.imageDimension = maxImageWidth;
  }

};

__decorate([Prop()], HeaderModuleMedia$1.prototype, "media", void 0);

__decorate([Prop()], HeaderModuleMedia$1.prototype, "nextUrl", void 0);

__decorate([Prop()], HeaderModuleMedia$1.prototype, "moduleSettings", void 0);

__decorate([Prop()], HeaderModuleMedia$1.prototype, "widgetMode", void 0);

__decorate([Prop()], HeaderModuleMedia$1.prototype, "alignment", void 0);

HeaderModuleMedia$1 = __decorate([Component({
  components: {
    MediaStrip: async () => (await Promise.resolve().then(function () { return MediaStrip; })).default
  }
})], HeaderModuleMedia$1);
var script$h = HeaderModuleMedia$1;

/* script */
const __vue_script__$h = script$h;
/* template */

var __vue_render__$h = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.media.length ? _c('div', {
    ref: "mediaGridModule",
    staticClass: "oke-w-mediaGridModule"
  }, [_vm.imageDimension ? _c('media-strip', {
    staticClass: "oke-w-mediaStrip",
    attrs: {
      "media": _vm.media.slice(0, _vm.moduleSettings.columns * _vm.moduleSettings.rows),
      "columns": _vm.moduleSettings.columns,
      "imageGap": _vm.moduleSettings.imageGap,
      "imageWidth": _vm.imageDimension,
      "imageHeight": _vm.imageDimension,
      "alignment": _vm.alignment,
      "scale": true,
      "mediaContext": "aggregate",
      "role": "button"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  }) : _vm._e()], 1) : _vm._e();
};

var __vue_staticRenderFns__$h = [];
/* style */

const __vue_inject_styles__$h = undefined;
/* scoped */

const __vue_scope_id__$h = undefined;
/* module identifier */

const __vue_module_identifier__$h = undefined;
/* functional template */

const __vue_is_functional_template__$h = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$h = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$h,
  staticRenderFns: __vue_staticRenderFns__$h
}, __vue_inject_styles__$h, __vue_script__$h, __vue_scope_id__$h, __vue_is_functional_template__$h, __vue_module_identifier__$h, false, undefined, undefined, undefined);

var HeaderModuleMediaGrid = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$h
});

let HeaderModuleMedia = class HeaderModuleMedia extends Vue {
  get imageGap() {
    return OkendoUtils.toPixels(this.moduleSettings.imageGap);
  }

  get imageHeight() {
    return OkendoUtils.toPixels(this.moduleSettings.imageHeight);
  }

};

__decorate([Prop()], HeaderModuleMedia.prototype, "media", void 0);

__decorate([Prop()], HeaderModuleMedia.prototype, "nextUrl", void 0);

__decorate([Prop()], HeaderModuleMedia.prototype, "moduleSettings", void 0);

__decorate([Prop()], HeaderModuleMedia.prototype, "widgetMode", void 0);

__decorate([Prop()], HeaderModuleMedia.prototype, "carouselWidth", void 0);

HeaderModuleMedia = __decorate([Component({
  components: {
    MediaCarousel: async () => (await Promise.resolve().then(function () { return MediaCarousel; })).default
  }
})], HeaderModuleMedia);
var script$g = HeaderModuleMedia;

/* script */
const __vue_script__$g = script$g;
/* template */

var __vue_render__$g = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.media.length ? _c('div', {
    staticClass: "oke-w-mediaCarouselModule"
  }, [_c('media-carousel', {
    attrs: {
      "initialMedia": _vm.media,
      "initialNextUrl": _vm.nextUrl,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.imageHeight,
      "widgetMode": _vm.widgetMode,
      "carouselWidth": _vm.carouselWidth
    }
  })], 1) : _vm._e();
};

var __vue_staticRenderFns__$g = [];
/* style */

const __vue_inject_styles__$g = undefined;
/* scoped */

const __vue_scope_id__$g = undefined;
/* module identifier */

const __vue_module_identifier__$g = undefined;
/* functional template */

const __vue_is_functional_template__$g = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$g = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$g,
  staticRenderFns: __vue_staticRenderFns__$g
}, __vue_inject_styles__$g, __vue_script__$g, __vue_scope_id__$g, __vue_is_functional_template__$g, __vue_module_identifier__$g, false, undefined, undefined, undefined);

var HeaderModuleMediaCarousel = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$g
});

let HeaderModuleRatingBreakdown$1 = class HeaderModuleRatingBreakdown extends Vue {
  get reviewCountData() {
    const reviewCountByLevel = this.reviewAggregate.ratingAndReviewCountByLevel;
    return {
      level5Count: (reviewCountByLevel === null || reviewCountByLevel === void 0 ? void 0 : reviewCountByLevel.level5Count) || 0,
      level4Count: (reviewCountByLevel === null || reviewCountByLevel === void 0 ? void 0 : reviewCountByLevel.level4Count) || 0,
      level3Count: (reviewCountByLevel === null || reviewCountByLevel === void 0 ? void 0 : reviewCountByLevel.level3Count) || 0,
      level2Count: (reviewCountByLevel === null || reviewCountByLevel === void 0 ? void 0 : reviewCountByLevel.level2Count) || 0,
      level1Count: (reviewCountByLevel === null || reviewCountByLevel === void 0 ? void 0 : reviewCountByLevel.level1Count) || 0
    };
  }

  getPrettyNumber(count) {
    return OkendoUtils.getPrettyNumber(count, true);
  }

  reviewCountPercentage(count) {
    return count / this.reviewAggregate.ratingAndReviewCount * 100 + '%';
  }

  transformIndex(index) {
    return 5 - index;
  }

  get barFillColor() {
    return this.moduleSettings.shadingColor;
  }

  get barBackgroundColor() {
    return this.moduleSettings.backgroundColor;
  }

  get starHeight() {
    return OkendoUtils.toPixels(SharedSettings.widgetSettings.reviewsWidget.style.text.fontSizeSmall);
  }

};

__decorate([Prop()], HeaderModuleRatingBreakdown$1.prototype, "reviewAggregate", void 0);

__decorate([Prop()], HeaderModuleRatingBreakdown$1.prototype, "moduleSettings", void 0);

HeaderModuleRatingBreakdown$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], HeaderModuleRatingBreakdown$1);
var script$f = HeaderModuleRatingBreakdown$1;

/* script */
const __vue_script__$f = script$f;
/* template */

var __vue_render__$f = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.reviewAggregate ? _c('div', {
    staticClass: "oke-w-breakdownModule",
    class: "oke-w-breakdownModule--" + _vm.moduleSettings.stretchMode
  }, [_c('div', {
    staticClass: "oke-w-breakdownModule-distribution"
  }, [_vm._l(_vm.reviewCountData, function (count, key, index) {
    return [_c('div', {
      key: key + '-label',
      staticClass: "oke-w-breakdownModule-distribution-label",
      attrs: {
        "aria-hidden": "true"
      }
    }, [_c('span', {
      staticClass: "oke-w-breakdownModule-distribution-label-number"
    }, [_vm._v("\n                    " + _vm._s(_vm.transformIndex(index)) + "\n                ")]), _vm._v(" "), _c('span', {
      staticClass: "oke-w-breakdownModule-distribution-label-star"
    }, [_c('stars', {
      attrs: {
        "singleStar": true,
        "height": _vm.starHeight
      }
    })], 1)]), _vm._v(" "), _c('div', {
      key: key + '-bar',
      staticClass: "oke-w-breakdownModule-distribution-bar",
      style: {
        'background-color': _vm.barBackgroundColor
      },
      attrs: {
        "aria-hidden": "true"
      }
    }, [_c('div', {
      staticClass: "oke-w-breakdownModule-distribution-bar-fill",
      style: {
        width: _vm.reviewCountPercentage(count),
        'min-width': count === 0 ? 0 : undefined,
        'background-color': _vm.barFillColor
      }
    })]), _vm._v(" "), _c('div', {
      key: key + '-count',
      staticClass: "oke-w-breakdownModule-distribution-count",
      attrs: {
        "aria-hidden": "true"
      }
    }, [_vm._v("\n                " + _vm._s(_vm.getPrettyNumber(count)) + "\n            ")]), _vm._v(" "), _c('span', {
      key: key + '-a11y',
      staticClass: "oke-a11yText"
    }, [_vm._v("\n                " + _vm._s(_vm.$t('Total {0} star reviews: {1}', [_vm.transformIndex(index), _vm.getPrettyNumber(count)])) + "\n            ")])];
  })], 2)]) : _vm._e();
};

var __vue_staticRenderFns__$f = [];
/* style */

const __vue_inject_styles__$f = undefined;
/* scoped */

const __vue_scope_id__$f = undefined;
/* module identifier */

const __vue_module_identifier__$f = undefined;
/* functional template */

const __vue_is_functional_template__$f = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$f = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$f,
  staticRenderFns: __vue_staticRenderFns__$f
}, __vue_inject_styles__$f, __vue_script__$f, __vue_scope_id__$f, __vue_is_functional_template__$f, __vue_module_identifier__$f, false, undefined, undefined, undefined);

var HeaderModuleRatingBreakdown = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$f
});

let HeaderModuleRecommends$1 = class HeaderModuleRecommends extends Vue {
  get percentageRecommended() {
    if (this.reviewCount) {
      return ((this.recommendationCount || 0) / this.reviewCount * 100).toFixed(0);
    }
  }

  get recommendsText() {
    return this.widgetMode === 'product' ? this.$tc('would recommend this product') : this.$tc('would recommend these products');
  }

};

__decorate([Prop()], HeaderModuleRecommends$1.prototype, "recommendationCount", void 0);

__decorate([Prop()], HeaderModuleRecommends$1.prototype, "reviewCount", void 0);

__decorate([Prop()], HeaderModuleRecommends$1.prototype, "widgetMode", void 0);

HeaderModuleRecommends$1 = __decorate([Component], HeaderModuleRecommends$1);
var script$e = HeaderModuleRecommends$1;

/* script */
const __vue_script__$e = script$e;
/* template */

var __vue_render__$e = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.percentageRecommended ? _c('div', {
    staticClass: "oke-w-recommendsModule"
  }, [_c('span', {
    staticClass: "oke-w-recommendsModule-value"
  }, [_vm._v(_vm._s(_vm.percentageRecommended) + "%")]), _vm._v(" "), _c('span', {
    staticClass: "oke-w-recommendsModule-text"
  }, [_vm._v(_vm._s(_vm.recommendsText))])]) : _vm._e();
};

var __vue_staticRenderFns__$e = [];
/* style */

const __vue_inject_styles__$e = undefined;
/* scoped */

const __vue_scope_id__$e = undefined;
/* module identifier */

const __vue_module_identifier__$e = undefined;
/* functional template */

const __vue_is_functional_template__$e = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$e = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$e,
  staticRenderFns: __vue_staticRenderFns__$e
}, __vue_inject_styles__$e, __vue_script__$e, __vue_scope_id__$e, __vue_is_functional_template__$e, __vue_module_identifier__$e, false, undefined, undefined, undefined);

var HeaderModuleRecommends = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$e
});

let HeaderModuleRatingAverage$1 = class HeaderModuleRatingAverage extends Vue {
  get averageRating() {
    return (this.reviewAggregate.ratingAndReviewValuesTotal / this.reviewAggregate.ratingAndReviewCount).toFixed(1);
  }

  get numericReviewCount() {
    var _a;

    return (_a = this.reviewAggregate.ratingAndReviewCount) !== null && _a !== void 0 ? _a : 0;
  }

  get prettyReviewCount() {
    var _a;

    const count = (_a = this.reviewAggregate.ratingAndReviewCount) === null || _a === void 0 ? void 0 : _a.toString();
    return OkendoUtils.getPrettyNumber(count) || '0';
  }

  get starInterspace() {
    var _a, _b;

    return (_b = (_a = SharedSettings.widgetSettings.reviewsWidget.style.stars.globalOverrideSettings) === null || _a === void 0 ? void 0 : _a.interspace) !== null && _b !== void 0 ? _b : SharedSettings.widgetSettings.global.stars.interspace;
  }

  kebabToCamelCaseClass(string) {
    return StringUtils.kebabToCamelCase(string);
  }

};

__decorate([Prop()], HeaderModuleRatingAverage$1.prototype, "reviewAggregate", void 0);

__decorate([Prop()], HeaderModuleRatingAverage$1.prototype, "moduleSettings", void 0);

__decorate([Prop()], HeaderModuleRatingAverage$1.prototype, "moduleAlignment", void 0);

HeaderModuleRatingAverage$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], HeaderModuleRatingAverage$1);
var script$d = HeaderModuleRatingAverage$1;

/* script */
const __vue_script__$d = script$d;
/* template */

var __vue_render__$d = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.reviewAggregate ? _c('div', {
    staticClass: "oke-w-ratingAverageModule",
    class: "oke-w-ratingAverageModule--" + _vm.kebabToCamelCaseClass(_vm.moduleSettings.layout) + " oke-w-ratingAverageModule--" + _vm.moduleAlignment
  }, [_c('div', {
    staticClass: "oke-w-ratingAverageModule-rating"
  }, [_c('span', {
    staticClass: "oke-w-ratingAverageModule-rating-average"
  }, [_vm._v("\n            " + _vm._s(_vm.averageRating) + "\n        ")]), _vm._v(" "), _c('span', {
    staticClass: "oke-w-ratingAverageModule-rating-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.averageRating,
      "interspace": _vm.starInterspace
    }
  })], 1)]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-ratingAverageModule-count"
  }, [_vm._v("\n        " + _vm._s(_vm.$tc('Based on {0} reviews', _vm.numericReviewCount, [_vm.prettyReviewCount])) + "\n    ")])]) : _vm._e();
};

var __vue_staticRenderFns__$d = [];
/* style */

const __vue_inject_styles__$d = undefined;
/* scoped */

const __vue_scope_id__$d = undefined;
/* module identifier */

const __vue_module_identifier__$d = undefined;
/* functional template */

const __vue_is_functional_template__$d = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$d = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$d,
  staticRenderFns: __vue_staticRenderFns__$d
}, __vue_inject_styles__$d, __vue_script__$d, __vue_scope_id__$d, __vue_is_functional_template__$d, __vue_module_identifier__$d, false, undefined, undefined, undefined);

var HeaderModuleRatingAverage = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$d
});

let Question$1 = class Question extends Vue {
  formatDate(date) {
    return DateUtils.formatDate(date, SharedSettings.widgetSettings.global.dateSettings.format);
  }

};

__decorate([Prop()], Question$1.prototype, "question", void 0);

__decorate([Prop()], Question$1.prototype, "index", void 0);

Question$1 = __decorate([Component({
  components: {
    Avatar: async () => (await Promise.resolve().then(function () { return Avatar; })).default,
    HelpfulVoting: async () => (await Promise.resolve().then(function () { return HelpfulVoting; })).default
  }
})], Question$1);
var script$c = Question$1;

/* script */
const __vue_script__$c = script$c;
/* template */

var __vue_render__$c = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.question ? _c('div', [_c('div', {
    staticClass: "oke-qw-question"
  }, [_c('div', {
    staticClass: "oke-qw-question-avatar"
  }, [_c('avatar', {
    attrs: {
      "avatarUrl": _vm.question.author.avatarUrl,
      "displayName": _vm.question.author.displayName
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-qw-question-main"
  }, [_vm._m(0), _vm._v(" "), _c('div', {
    staticClass: "oke-qw-question-main-date"
  }, [_vm._v("\n                " + _vm._s(_vm.formatDate(_vm.question.dateCreated)) + "\n            ")]), _vm._v(" "), _vm._m(1), _vm._v(" "), _c('div', {
    staticClass: "oke-qw-question-main-helpful"
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.question.questionId,
      "helpfulCount": _vm.question.helpfulCount,
      "unhelpfulCount": _vm.question.unhelpfulCount,
      "contentType": "question"
    }
  })], 1)])]), _vm._v(" "), _vm._l(_vm.question.answers, function (answer) {
    return _c('div', {
      key: answer.answerId,
      staticClass: "oke-qw-answer"
    }, [_c('div', {
      staticClass: "oke-qw-answer-avatar"
    }, [_c('avatar', {
      attrs: {
        "avatarUrl": answer.author.avatarUrl,
        "displayName": answer.author.displayName
      }
    })], 1), _vm._v(" "), _c('div', {
      staticClass: "oke-qw-answer-main"
    }, [_vm._o(_c('div', {
      staticClass: "oke-qw-answer-main-author"
    }, [_vm._v("\n                " + _vm._s(answer.author.displayName) + "\n            ")]), 0, answer.answerId), _vm._v(" "), _c('div', {
      staticClass: "oke-qw-answer-main-date"
    }, [_vm._v("\n                " + _vm._s(_vm.formatDate(answer.dateCreated)) + "\n            ")]), _vm._v(" "), _vm._o(_c('div', {
      staticClass: "oke-qw-answer-main-body",
      domProps: {
        "innerHTML": _vm._s(answer.body)
      }
    }), 1, answer.answerId), _vm._v(" "), _c('div', {
      staticClass: "oke-qw-answer-main-helpful"
    }, [_c('helpful-voting', {
      attrs: {
        "itemId": answer.answerId,
        "parentId": _vm.question.questionId,
        "helpfulCount": answer.helpfulCount,
        "unhelpfulCount": answer.unhelpfulCount,
        "contentType": "answer"
      }
    })], 1)])]);
  })], 2) : _vm._e();
};

var __vue_staticRenderFns__$c = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-qw-question-main-author"
  }, [_vm._v("\n                " + _vm._s(_vm.question.author.displayName) + "\n            ")]);
}, function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-qw-question-main-body"
  }, [_vm._v("\n                " + _vm._s(_vm.question.body) + "\n            ")]);
}];
/* style */

const __vue_inject_styles__$c = undefined;
/* scoped */

const __vue_scope_id__$c = undefined;
/* module identifier */

const __vue_module_identifier__$c = undefined;
/* functional template */

const __vue_is_functional_template__$c = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$c = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$c,
  staticRenderFns: __vue_staticRenderFns__$c
}, __vue_inject_styles__$c, __vue_script__$c, __vue_scope_id__$c, __vue_is_functional_template__$c, __vue_module_identifier__$c, false, undefined, undefined, undefined);

var Question = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$c
});

let Flag$1 = class Flag extends Vue {
  constructor() {
    super(...arguments);
    this.flags = {};
  }

  created() {
    this.importAllFlags(require.context('./assets/images/flags/', true, /\.svg$/));
  }

  get flagBackgroundUrl() {
    var _a, _b, _c;

    const countryCode = ((_a = this.reviewer.location) === null || _a === void 0 ? void 0 : _a.country.code) || ((_b = this.reviewer.country) === null || _b === void 0 ? void 0 : _b.code);
    return ((_c = this.reviewer.location) === null || _c === void 0 ? void 0 : _c.zoneCode) || !countryCode ? undefined : this.flags[countryCode.toLowerCase()];
  }

  get location() {
    var _a;

    if (this.reviewer.location) {
      return this.reviewer.location.zoneCode ? `${this.reviewer.location.zoneCode}, ${this.reviewer.location.country.name}` : this.reviewer.location.country.name;
    } else {
      (_a = this.reviewer.country) === null || _a === void 0 ? void 0 : _a.name;
    }
  }

  importAllFlags(req) {
    for (const key of req.keys()) {
      this.flags[key.substring(2, 4)] = req(key);
    }
  }

};

__decorate([Prop()], Flag$1.prototype, "reviewer", void 0);

Flag$1 = __decorate([Component], Flag$1);
var script$b = Flag$1;

/* script */
const __vue_script__$b = script$b;
/* template */

var __vue_render__$b = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _vm.location ? _c('div', {
    staticClass: "oke-flag",
    attrs: {
      "title": _vm.$t('from {0}', [_vm.location])
    }
  }, [_vm.reviewer.location && _vm.reviewer.location.zoneCode ? [_vm._v(_vm._s(_vm.location))] : _c('img', {
    directives: [{
      name: "lazySrc",
      rawName: "v-lazySrc",
      value: _vm.flagBackgroundUrl,
      expression: "flagBackgroundUrl"
    }],
    staticClass: "oke-flag-image",
    attrs: {
      "alt": _vm.$t('Flag of {0}', [_vm.location]),
      "height": "10",
      "width": "13"
    }
  })], 2) : _vm._e();
};

var __vue_staticRenderFns__$b = [];
/* style */

const __vue_inject_styles__$b = undefined;
/* scoped */

const __vue_scope_id__$b = undefined;
/* module identifier */

const __vue_module_identifier__$b = undefined;
/* functional template */

const __vue_is_functional_template__$b = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$b = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$b,
  staticRenderFns: __vue_staticRenderFns__$b
}, __vue_inject_styles__$b, __vue_script__$b, __vue_scope_id__$b, __vue_is_functional_template__$b, __vue_module_identifier__$b, false, undefined, undefined, undefined);

var Flag = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$b
});

let AttributeBar$1 = class AttributeBar extends Vue {
  get attributeDisplayValue() {
    return (this.attribute.value * (this.attribute.type === 'centered-range' ? 2 : 1)).toFixed(1);
  }

  get attributePercentageValue() {
    return this.standardiseAttributeValue(this.attribute);
  }

  get attributeBarComponentName() {
    return `bar-${SharedSettings.widgetSettings.reviewsWidget.style.attributeBar.style || 'default'}`;
  }

  get attributeBarType() {
    return SharedSettings.widgetSettings.reviewsWidget.style.attributeBar.style;
  }

  standardiseAttributeValue(attribute) {
    // Centered range is on a scale from -1 to 1, transform to match 1-5 ranged scale
    if (attribute.type === 'centered-range') {
      return this.attributeValueToPercentage(attribute.value * 2 + 3);
    } else {
      return this.attributeValueToPercentage(attribute.value);
    }
  }

  attributeValueToPercentage(value) {
    return (value - 1) * 25;
  }

};

__decorate([Prop()], AttributeBar$1.prototype, "attribute", void 0);

AttributeBar$1 = __decorate([Component({
  components: {
    BarDefault: async () => (await Promise.resolve().then(function () { return BarDefault; })).default,
    BarRounded: async () => (await Promise.resolve().then(function () { return BarRounded; })).default,
    BarOutlined: async () => (await Promise.resolve().then(function () { return BarOutlined; })).default,
    BarClassic: async () => (await Promise.resolve().then(function () { return BarClassic; })).default,
    BarBlocks: async () => (await Promise.resolve().then(function () { return BarBlocks; })).default
  }
})], AttributeBar$1);
var script$a = AttributeBar$1;

/* script */
const __vue_script__$a = script$a;
/* template */

var __vue_render__$a = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-attrBar",
    class: {
      'oke-attrBar--ranged': _vm.attribute.type === 'range',
      'oke-attrBar--centered': _vm.attribute.type === 'centered-range'
    }
  }, [_c('div', {
    staticClass: "oke-attrBar-title"
  }, [_c('span', {
    staticClass: "oke-attrBar-title-text"
  }, [_vm._v(_vm._s(_vm.attribute.title))]), _vm._v(" "), _vm.attribute.type === 'range' ? _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$t('Rated {0} on a scale of 1 to 5', [_vm.attributeDisplayValue])))]) : _vm._e(), _vm._v(" "), _vm.attribute.type === 'centered-range' ? _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v(_vm._s(_vm.$t('Rated {0} on a scale of minus 2 to 2', [_vm.attributeDisplayValue])))]) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-attrBar-body",
    attrs: {
      "role": "presentation"
    }
  }, [_c('div', {
    staticClass: "oke-attrBar-bar"
  }, [_c(_vm.attributeBarComponentName, {
    tag: "component",
    attrs: {
      "attributePercentage": _vm.attributePercentageValue,
      "type": _vm.attribute.type
    }
  })], 1), _vm._v(" "), _vm._m(0)])]);
};

var __vue_staticRenderFns__$a = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-attrBar-labels",
    attrs: {
      "aria-hidden": "true"
    }
  }, [_vm.attribute.minLabel ? _c('span', {
    staticClass: "oke-attrBar-labels-label oke-attrBar-labels-label--min"
  }, [_vm._v("\n                " + _vm._s(_vm.attribute.minLabel) + "\n            ")]) : _vm._e(), _vm._v(" "), _vm.attribute.midLabel ? _c('span', {
    staticClass: "oke-attrBar-labels-label oke-attrBar-labels-label--mid"
  }, [_vm._v("\n                " + _vm._s(_vm.attribute.midLabel) + "\n            ")]) : _vm._e(), _vm._v(" "), _vm.attribute.maxLabel ? _c('span', {
    staticClass: "oke-attrBar-labels-label oke-attrBar-labels-label--max"
  }, [_vm._v("\n                " + _vm._s(_vm.attribute.maxLabel) + "\n            ")]) : _vm._e()]);
}];
/* style */

const __vue_inject_styles__$a = undefined;
/* scoped */

const __vue_scope_id__$a = undefined;
/* module identifier */

const __vue_module_identifier__$a = undefined;
/* functional template */

const __vue_is_functional_template__$a = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$a = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$a,
  staticRenderFns: __vue_staticRenderFns__$a
}, __vue_inject_styles__$a, __vue_script__$a, __vue_scope_id__$a, __vue_is_functional_template__$a, __vue_module_identifier__$a, false, undefined, undefined, undefined);

var AttributeBar = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$a
});

let ReviewListBase = class ReviewListBase extends ReviewBase$1 {
  get isMediaVisible() {
    return (!this.isTruncated || !this.mediaNeedsTruncation) && this.showMedia || this.mediaLayout === 'featured';
  }

  get mediaLayout() {
    return this.reviewSettings.media.layout;
  }

  get reviewLayoutSettings() {
    return this.reviewSettings.layout;
  }

  get reviewStyle() {
    if (this.mediaLayout === 'featured') {
      return {
        'grid-template-columns': `1fr ${OkendoUtils.toPixels(this.mediaSize) + 48}px`
      };
    }
  }

  get mediaNeedsTruncation() {
    var _a;

    const hasMedia = !!((_a = this.review.media) === null || _a === void 0 ? void 0 : _a.length);
    return this.truncationSettings.truncateAll && hasMedia && this.showMedia && !(this.mediaLayout === 'featured');
  }

  onMediaClick(clickedIndex) {
    const mediaReview = OkendoUtils.convertReviewsToMediaReviews([this.review]);
    ModalService.openMediaModal({
      initialMedia: mediaReview,
      mediaContext: 'review',
      initialIndex: clickedIndex,
      widgetMode: this.widgetMode
    });
  }

};

__decorate([Prop()], ReviewListBase.prototype, "reviewSettings", void 0);

ReviewListBase = __decorate([Component], ReviewListBase);
var ReviewListBase$1 = ReviewListBase;

let Review$1 = class Review extends mixins(ReviewListBase$1) {
  constructor() {
    super(...arguments);
    this.isSidebarCollapsed = true;
  }

  get collapseSidebar() {
    return this.widgetSize === 'small' && this.isSidebarCollapsed && !!this.reviewLayoutSettings.collapseReviewerDetails;
  }

  onSidebarCollapseToggle() {
    this.isSidebarCollapsed = !this.isSidebarCollapsed;
  }

};
Review$1 = __decorate([Component], Review$1);
var script$9 = Review$1;

/* script */
const __vue_script__$9 = script$9;
/* template */

var __vue_render__$9 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-review",
    class: {
      'oke-w-review--featuredMedia': _vm.mediaLayout === 'featured' && _vm.review.media && _vm.showMedia,
      'oke-w-review--minimalBorders': _vm.reviewLayoutSettings.borderStyle === 'minimal'
    }
  }, [_c('div', {
    staticClass: "oke-w-review-side",
    class: {
      'oke-is-collapsed': _vm.collapseSidebar
    }
  }, [_c('div', {
    staticClass: "oke-w-review-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars
    }
  })], 1), _vm._v(" "), _vm.reviewLayoutSettings.collapseReviewerDetails ? _c('button', {
    directives: [{
      name: "ga",
      rawName: "v-ga:click",
      value: {
        action: 'Expand Reviewer Details Click',
        label: _vm.review.productName
      },
      expression: "{ action: 'Expand Reviewer Details Click', label: review.productName }",
      arg: "click"
    }],
    staticClass: "oke-w-review-side-expand",
    attrs: {
      "aria-expanded": !_vm.collapseSidebar,
      "title": "More details"
    },
    on: {
      "click": function ($event) {
        return _vm.onSidebarCollapseToggle();
      }
    }
  }) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-side-expandContent"
  }, [_vm.showProductInfo ? _c('div', {
    staticClass: "oke-w-review-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-recommendation"
  }, [_c('reviewer-recommendation', {
    attrs: {
      "isRecommended": _vm.review.isRecommended
    }
  })], 1), _vm._v(" "), _vm.selectAttributes.length ? _c('div', {
    staticClass: "oke-w-review-selectAttributes"
  }, [_c('select-attributes', {
    attrs: {
      "attributes": _vm.selectAttributes
    }
  })], 1) : _vm._e()])]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-main",
    style: _vm.reviewStyle
  }, [_c('div', {
    staticClass: "oke-w-review-content"
  }, [_c('review-basic-content', {
    attrs: {
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": _vm.showDates,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _vm.showAttributeBars && _vm.review.attributesWithRating && _vm.review.attributesWithRating.length ? _c('div', {
    staticClass: "oke-w-review-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating,
      "barHasMinWidth": true
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.showMedia && _vm.review.media && _vm.review.media.length ? _c('div', {
    staticClass: "oke-w-review-media",
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_vm.mediaLayout === 'featured' ? _c('div', {
    staticClass: "oke-w-review-media-featured"
  }, [_c('media-collage', {
    attrs: {
      "media": _vm.review.media,
      "collageWidth": _vm.mediaSize,
      "imageGap": _vm.imageGap,
      "productName": _vm.review.productName,
      "mediaContext": "review"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-media-thumbnail"
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "mediaContext": "review",
      "maxMediaCount": 2,
      "showAllImagesWhenLarge": _vm.mediaLayout !== 'featured',
      "flexWrapImages": _vm.widgetSize === 'large'
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1)]) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-review-helpful"
  }, [_c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)], 1), _vm._v(" "), _vm.review.reply ? _c('div', {
    staticClass: "oke-w-review-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()])]);
};

var __vue_staticRenderFns__$9 = [];
/* style */

const __vue_inject_styles__$9 = undefined;
/* scoped */

const __vue_scope_id__$9 = undefined;
/* module identifier */

const __vue_module_identifier__$9 = undefined;
/* functional template */

const __vue_is_functional_template__$9 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$9 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$9,
  staticRenderFns: __vue_staticRenderFns__$9
}, __vue_inject_styles__$9, __vue_script__$9, __vue_scope_id__$9, __vue_is_functional_template__$9, __vue_module_identifier__$9, false, undefined, undefined, undefined);

var Review = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$9
});

let ReviewMinimal$1 = class ReviewMinimal extends mixins(ReviewListBase$1) {};
ReviewMinimal$1 = __decorate([Component({
  components: {
    SelectAttributes: async () => (await Promise.resolve().then(function () { return SelectAttributes; })).default
  }
})], ReviewMinimal$1);
var script$8 = ReviewMinimal$1;

/* script */
const __vue_script__$8 = script$8;
/* template */

var __vue_render__$8 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewMinimal",
    class: {
      'oke-w-reviewMinimal--featuredMedia': _vm.mediaLayout === 'featured' && _vm.review.media && _vm.showMedia
    },
    style: _vm.reviewStyle
  }, [_c('div', {
    staticClass: "oke-w-reviewMinimal-head"
  }, [_c('div', {
    staticClass: "oke-w-reviewMinimal-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "selectAttributes": _vm.selectAttributes
    }
  })], 1), _vm._v(" "), _vm.showDates ? _c('div', {
    staticClass: "oke-w-reviewMinimal-date"
  }, [_vm._v("\n            " + _vm._s(_vm.reviewDateCreated) + "\n        ")]) : _vm._e()]), _vm._v(" "), _vm.selectAttributes.length ? _c('div', {
    staticClass: "oke-w-reviewMinimal-reviewerAttributes"
  }, [_c('select-attributes', {
    attrs: {
      "attributes": _vm.selectAttributes,
      "layout": "line"
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-w-reviewMinimal-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewMinimal-content"
  }, [_c('review-basic-content', {
    attrs: {
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": false,
      "starHeight": _vm.starHeight,
      "starInterspace": _vm.starInterspace,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _vm.showAttributeBars && _vm.review.attributesWithRating && _vm.review.attributesWithRating.length ? _c('div', {
    staticClass: "oke-w-reviewMinimal-attributes",
    attrs: {
      "hidden": !_vm.isAttributesVisible
    }
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating,
      "barHasMinWidth": true
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.showMedia && _vm.review.media && _vm.review.media.length ? _c('div', {
    staticClass: "oke-w-reviewMinimal-media",
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_vm.mediaLayout === 'featured' ? _c('div', {
    staticClass: "oke-w-reviewMinimal-media-featured"
  }, [_c('media-collage', {
    attrs: {
      "media": _vm.review.media,
      "collageWidth": _vm.mediaSize,
      "imageGap": _vm.imageGap,
      "productName": _vm.review.productName,
      "mediaContext": "review"
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewMinimal-media-thumbnail"
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "mediaContext": "review",
      "maxMediaCount": 2,
      "showAllImagesWhenLarge": _vm.mediaLayout !== 'featured',
      "flexWrapImages": _vm.widgetSize === 'large'
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1)]) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewMinimal-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1), _vm._v(" "), _vm.review.reply ? _c('div', {
    staticClass: "oke-w-reviewMinimal-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()]);
};

var __vue_staticRenderFns__$8 = [];
/* style */

const __vue_inject_styles__$8 = undefined;
/* scoped */

const __vue_scope_id__$8 = undefined;
/* module identifier */

const __vue_module_identifier__$8 = undefined;
/* functional template */

const __vue_is_functional_template__$8 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$8 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$8,
  staticRenderFns: __vue_staticRenderFns__$8
}, __vue_inject_styles__$8, __vue_script__$8, __vue_scope_id__$8, __vue_is_functional_template__$8, __vue_module_identifier__$8, false, undefined, undefined, undefined);

var ReviewMinimal = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$8
});

let ReviewSplit$1 = class ReviewSplit extends mixins(ReviewListBase$1) {
  get starHeightPx() {
    return OkendoUtils.toPixels(this.starHeight);
  }

};
ReviewSplit$1 = __decorate([Component({
  components: {
    Stars: async () => (await Promise.resolve().then(function () { return Stars; })).default
  }
})], ReviewSplit$1);
var script$7 = ReviewSplit$1;

/* script */
const __vue_script__$7 = script$7;
/* template */

var __vue_render__$7 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-reviewSplit"
  }, [_c('div', {
    staticClass: "oke-w-reviewSplit-main"
  }, [_c('div', {
    staticClass: "oke-w-reviewSplit-left"
  }, [_c('div', {
    staticClass: "oke-w-reviewSplit-reviewer"
  }, [_c('reviewer', {
    attrs: {
      "reviewer": _vm.review.reviewer,
      "hideAvatar": _vm.hideAvatars,
      "layout": _vm.widgetSize === 'small' ? 'side-by-side' : 'stacked'
    }
  })], 1), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewSplit-stars"
  }, [_c('stars', {
    attrs: {
      "rating": _vm.review.rating,
      "height": _vm.starHeightPx,
      "interspace": _vm.starInterspace
    }
  })], 1), _vm._v(" "), _vm.showDates ? _c('div', {
    staticClass: "oke-w-reviewSplit-date"
  }, [_vm._v("\n                " + _vm._s(_vm.reviewDateCreated) + "\n            ")]) : _vm._e(), _vm._v(" "), _vm.showProductInfo ? _c('div', {
    staticClass: "oke-w-reviewSplit-product"
  }, [_c('product', {
    attrs: {
      "review": _vm.review,
      "layout": _vm.widgetSize === 'small' ? 'side-by-side' : 'stacked'
    }
  })], 1) : _vm._e()]), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewSplit-mid"
  }, [_c('div', {
    staticClass: "oke-w-reviewSplit-content"
  }, [_c('review-basic-content', {
    attrs: {
      "hideStars": true,
      "isLoading": _vm.isFullReviewLoading,
      "isMetafieldTruncated": _vm.isMetafieldTruncated,
      "isReviewTruncated": _vm.isTruncated,
      "review": _vm.review,
      "showDates": false,
      "truncationSettings": _vm.truncationSettings
    },
    on: {
      "load": function ($event) {
        return _vm.setReviewTruncation($event);
      },
      "readMore": function ($event) {
        return _vm.onReadMoreClick();
      }
    }
  })], 1), _vm._v(" "), _vm.showMedia && _vm.review.media && _vm.review.media.length ? _c('div', {
    staticClass: "oke-w-reviewSplit-media",
    attrs: {
      "hidden": !_vm.isMediaVisible
    }
  }, [_c('media-strip', {
    attrs: {
      "media": _vm.review.media,
      "imageGap": _vm.imageGap,
      "imageHeight": _vm.mediaSize,
      "productName": _vm.review.productName,
      "alignment": _vm.widgetSize === 'small' ? 'center' : 'left',
      "mediaContext": "review",
      "maxMediaCount": 2,
      "showAllImagesWhenLarge": true,
      "flexWrapImages": _vm.widgetSize === 'large'
    },
    on: {
      "click": function ($event) {
        return _vm.onMediaClick($event);
      }
    }
  })], 1) : _vm._e(), _vm._v(" "), _c('div', {
    staticClass: "oke-w-reviewSplit-footer"
  }, [_vm.showIncentivizedReviewsBadge ? _c('incentivized-review') : _vm._e(), _vm._v(" "), _c('helpful-voting', {
    attrs: {
      "itemId": _vm.review.reviewId,
      "helpfulCount": _vm.review.helpfulCount,
      "unhelpfulCount": _vm.review.unhelpfulCount,
      "productName": _vm.review.productName,
      "contentType": "review"
    }
  })], 1)]), _vm._v(" "), _vm.selectAttributes.length || _vm.review.attributesWithRating ? _c('div', {
    staticClass: "oke-w-reviewSplit-right"
  }, [_vm.selectAttributes.length ? _c('div', {
    staticClass: "oke-w-review-selectAttributes"
  }, [_c('select-attributes', {
    attrs: {
      "attributes": _vm.selectAttributes,
      "layout": _vm.widgetSize === 'large' ? 'side-by-side' : 'stacked'
    }
  })], 1) : _vm._e(), _vm._v(" "), _vm.showAttributeBars && _vm.review.attributesWithRating ? _c('div', {
    staticClass: "oke-w-reviewSplit-attributes"
  }, [_c('bar-attributes', {
    attrs: {
      "attributes": _vm.review.attributesWithRating,
      "barHasMinWidth": true
    }
  })], 1) : _vm._e()]) : _vm._e()]), _vm._v(" "), _vm.review.reply ? _c('div', {
    staticClass: "oke-w-reviewSplit-reply"
  }, [_c('review-reply', {
    attrs: {
      "reply": _vm.review.reply
    }
  })], 1) : _vm._e()]);
};

var __vue_staticRenderFns__$7 = [];
/* style */

const __vue_inject_styles__$7 = undefined;
/* scoped */

const __vue_scope_id__$7 = undefined;
/* module identifier */

const __vue_module_identifier__$7 = undefined;
/* functional template */

const __vue_is_functional_template__$7 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$7 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$7,
  staticRenderFns: __vue_staticRenderFns__$7
}, __vue_inject_styles__$7, __vue_script__$7, __vue_scope_id__$7, __vue_is_functional_template__$7, __vue_module_identifier__$7, false, undefined, undefined, undefined);

var ReviewSplit = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$7
});

let FiltersFreeTextSearch$1 = class FiltersFreeTextSearch extends Vue {
  constructor() {
    super();
    this.debounce = undefined;
    this.searchQuery = '';
    this.maxCharacterLength = 3;
  }

  onSearchQueryInput() {
    if (this.searchQuery.length < this.maxCharacterLength) {
      this.$emit('change', undefined);
      return;
    }

    if (this.debounce) {
      clearTimeout(this.debounce);
    }

    this.debounce = window.setTimeout(() => {
      this.$emit('change', this.searchQuery);
      AnalyticsUtils.sendGAEvent('Filter Text Search', this.searchQuery, undefined, {
        search_query: this.searchQuery
      });
    }, 250);
  }

};

__decorate([Prop()], FiltersFreeTextSearch$1.prototype, "isFocusable", void 0);

FiltersFreeTextSearch$1 = __decorate([Component], FiltersFreeTextSearch$1);
var script$6 = FiltersFreeTextSearch$1;

/* script */
const __vue_script__$6 = script$6;
/* template */

var __vue_render__$6 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-w-filter oke-w-filter--text-search"
  }, [_c('div', {
    staticClass: "oke-w-filter-title"
  }, [_vm._v("\n        Search\n    ")]), _vm._v(" "), _c('fieldset', {
    staticClass: "oke-w-textSearchFilter"
  }, [_c('legend', {
    staticClass: "oke-a11yText"
  }, [_vm._v("Search Reviews")]), _vm._v(" "), _c('input', {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.searchQuery,
      expression: "searchQuery"
    }],
    staticClass: "oke-w-textSearchFilter-input",
    attrs: {
      "type": "text",
      "placeholder": "Search reviews",
      "aria-label": "Search Reviews",
      "tabindex": _vm.isFocusable ? 0 : -1
    },
    domProps: {
      "value": _vm.searchQuery
    },
    on: {
      "input": [function ($event) {
        if ($event.target.composing) {
          return;
        }

        _vm.searchQuery = $event.target.value;
      }, _vm.onSearchQueryInput]
    }
  })])]);
};

var __vue_staticRenderFns__$6 = [];
/* style */

const __vue_inject_styles__$6 = undefined;
/* scoped */

const __vue_scope_id__$6 = undefined;
/* module identifier */

const __vue_module_identifier__$6 = undefined;
/* functional template */

const __vue_is_functional_template__$6 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$6 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$6,
  staticRenderFns: __vue_staticRenderFns__$6
}, __vue_inject_styles__$6, __vue_script__$6, __vue_scope_id__$6, __vue_is_functional_template__$6, __vue_module_identifier__$6, false, undefined, undefined, undefined);

var FiltersFreeTextSearch = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$6
});

let MediaCarousel$1 = class MediaCarousel extends mixins(WidgetBase$1) {
  constructor() {
    super(...arguments);
    this.media = [];
    this.isLoadingMore = false;
    this.currentSlide = 0;
    this.loadMoreThreshold = 8;
    this.slidesPerPage = 10; // Can also be a fractional unit for half slides

    this.carouselOptions = {
      itemsToShow: this.slidesPerPage,
      itemsToSlide: 1,
      initialSlide: 0,
      infiniteScroll: false,
      fluidSlide: true,
      wheelControl: false
    };
  }

  created() {
    this.nextUrl = this.initialNextUrl;
    this.media = [...OkendoUtils.convertMediaToMediaReviews(this.initialMedia)];

    if (this.isCloseToSliderEnd) {
      this.loadMoreMedia();
    }
  }

  mounted() {
    this.setItemsToSlide(this.widgetSize);
    this.setSlidesPerPage(this.$refs.okeHeaderCarouselContainer.clientWidth);
  }

  onWidgetSizeChange(newSize) {
    this.setItemsToSlide(newSize);
  }

  onWidgetWidthChange(newSize) {
    this.setSlidesPerPage(newSize);
  }

  get isNextArrowDisabled() {
    return this.currentSlide >= this.media.length - this.slidesPerPage && !this.nextUrl;
  }

  get isCloseToSliderEnd() {
    return this.currentSlide >= this.media.length - this.loadMoreThreshold;
  }

  onSliderSlide(event) {
    if (event.currentSlide !== this.currentSlide) {
      AnalyticsUtils.sendGAEvent('Media Carousel Scroll');
      this.currentSlide = event.currentSlide;

      if (this.isCloseToSliderEnd) {
        this.loadMoreMedia();
      }
    }
  }

  onMediaClick(index) {
    if (!this.$refs.okeMediaCarousel.isSliding) {
      const mediaType = this.media[index].type;
      AnalyticsUtils.sendGAEvent(`Media Carousel ${mediaType === 'image' ? 'Photo' : StringUtils.toTitleCase(mediaType)} Click`);
      ModalService.openMediaModal({
        initialMedia: this.media,
        initialNextUrl: this.nextUrl,
        mediaContext: 'aggregate',
        initialIndex: index,
        widgetMode: this.widgetMode
      });
    }
  }

  nextSlide() {
    this.$refs.okeMediaCarousel.slideNext();
  }

  prevSlide() {
    this.$refs.okeMediaCarousel.slidePrev();
  }

  async loadMoreMedia() {
    if (this.nextUrl && !this.isLoadingMore) {
      this.isLoadingMore = true;

      try {
        const {
          media,
          nextUrl
        } = await OkendoApi.getMore(this.nextUrl);
        this.nextUrl = nextUrl;
        this.media.push(...OkendoUtils.convertMediaToMediaReviews(media));
      } finally {
        this.isLoadingMore = false;
      }
    }
  }

  setItemsToSlide(widgetSize) {
    this.$refs.okeMediaCarousel.displayConfig.itemsToSlide = widgetSize === 'large' && this.carouselWidth === 'full' ? 3 : 1;
  }

  setSlidesPerPage(size) {
    const itemsCount = size / (this.imageHeight + this.imageGap);
    this.slidesPerPage = itemsCount;
    this.$refs.okeMediaCarousel.displayConfig.itemsToShow = this.slidesPerPage;
    this.$refs.okeMediaCarousel.update();
  }

};

__decorate([Prop()], MediaCarousel$1.prototype, "initialMedia", void 0);

__decorate([Prop()], MediaCarousel$1.prototype, "initialNextUrl", void 0);

__decorate([Prop({
  default: () => 120
})], MediaCarousel$1.prototype, "imageHeight", void 0);

__decorate([Prop({
  default: () => 8
})], MediaCarousel$1.prototype, "imageGap", void 0);

__decorate([Prop()], MediaCarousel$1.prototype, "widgetMode", void 0);

__decorate([Prop()], MediaCarousel$1.prototype, "carouselWidth", void 0);

__decorate([Watch('widgetSize')], MediaCarousel$1.prototype, "onWidgetSizeChange", null);

__decorate([Watch('widgetWidth')], MediaCarousel$1.prototype, "onWidgetWidthChange", null);

MediaCarousel$1 = __decorate([Component({
  components: {
    MediaThumbnail: async () => (await Promise.resolve().then(function () { return MediaThumbnail; })).default,
    Hooper: Carousel,
    Slide
  }
})], MediaCarousel$1);
var script$5 = MediaCarousel$1;

/* script */
const __vue_script__$5 = script$5;
/* template */

var __vue_render__$5 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    ref: "okeHeaderCarouselContainer",
    staticClass: "oke-mediaCarousel",
    style: {
      height: _vm.imageHeight + 'px'
    },
    attrs: {
      "tabindex": "0",
      "role": "region"
    },
    on: {
      "keydown": [function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) {
          return null;
        }

        return _vm.onMediaClick(_vm.currentSlide);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "space", 32, $event.key, [" ", "Spacebar"])) {
          return null;
        }

        return _vm.onMediaClick(_vm.currentSlide);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "right", 39, $event.key, ["Right", "ArrowRight"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 2) {
          return null;
        }

        return _vm.nextSlide.apply(null, arguments);
      }, function ($event) {
        if (!$event.type.indexOf('key') && _vm._k($event.keyCode, "left", 37, $event.key, ["Left", "ArrowLeft"])) {
          return null;
        }

        if ('button' in $event && $event.button !== 0) {
          return null;
        }

        return _vm.prevSlide.apply(null, arguments);
      }]
    }
  }, [_c('div', [_c('button', {
    staticClass: "oke-mediaCarousel-prev",
    attrs: {
      "disabled": _vm.currentSlide === 0,
      "type": "button",
      "title": _vm.$tc('Previous Slide'),
      "tabindex": "-1"
    },
    on: {
      "click": _vm.prevSlide
    }
  }), _vm._v(" "), _c('hooper', {
    ref: "okeMediaCarousel",
    attrs: {
      "settings": _vm.carouselOptions,
      "role": _vm.$t('group')
    },
    on: {
      "slide": _vm.onSliderSlide
    }
  }, _vm._l(_vm.media, function (mediaItem, index) {
    return _c('slide', {
      key: mediaItem.id,
      staticClass: "oke-mediaCarousel-slide",
      style: {
        width: _vm.imageHeight + "px",
        height: _vm.imageHeight + "px",
        marginRight: _vm.imageGap + "px"
      },
      attrs: {
        "aria-label": _vm.$t('Slide {0}', [index + 1])
      }
    }, [_c('media-thumbnail', {
      attrs: {
        "linked": true,
        "mediaItem": mediaItem,
        "transcodedHeight": _vm.imageHeight,
        "transcodedWidth": _vm.imageHeight,
        "alt": _vm.$tc('Customer-uploaded image'),
        "mediaContext": "aggregate"
      },
      on: {
        "mediaThumbnailClick": function ($event) {
          return _vm.onMediaClick(index);
        }
      }
    })], 1);
  }), 1), _vm._v(" "), _c('button', {
    staticClass: "oke-mediaCarousel-next",
    class: {
      'oke-is-loading': _vm.isLoadingMore
    },
    attrs: {
      "disabled": _vm.isNextArrowDisabled,
      "aria-busy": _vm.isLoadingMore,
      "type": "button",
      "title": _vm.$tc('Next Slide'),
      "tabindex": "-1"
    },
    on: {
      "click": _vm.nextSlide
    }
  })], 1), _vm._v(" "), _c('span', {
    staticClass: "oke-a11yText"
  }, [_vm._v("\n        " + _vm._s(_vm.$tc('Customer-uploaded media carousel. Press left and right arrows to navigate. Press space or enter to open more details.')) + "\n    ")]), _vm._v(" "), _c('div', {
    staticClass: "oke-a11yText",
    attrs: {
      "aria-live": "polite"
    }
  }, [_vm._v("\n        " + _vm._s(_vm.$t('Slide {0} selected', [_vm.currentSlide + 1])) + "\n    ")])]);
};

var __vue_staticRenderFns__$5 = [];
/* style */

const __vue_inject_styles__$5 = undefined;
/* scoped */

const __vue_scope_id__$5 = undefined;
/* module identifier */

const __vue_module_identifier__$5 = undefined;
/* functional template */

const __vue_is_functional_template__$5 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$5 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$5,
  staticRenderFns: __vue_staticRenderFns__$5
}, __vue_inject_styles__$5, __vue_script__$5, __vue_scope_id__$5, __vue_is_functional_template__$5, __vue_module_identifier__$5, false, undefined, undefined, undefined);

var MediaCarousel = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$5
});

let BarBase = class BarBase extends Vue {
  get shadedWidth() {
    return this.type === 'range' ? `${this.attributePercentage}%` : `${this.getAbsoluteValue(this.attributePercentage - 50)}%`;
  }

  get shadedMarginLeft() {
    return this.type === 'range' ? '0' : `${this.getMinimumValue(this.attributePercentage, 50)}%`;
  }

  getAbsoluteValue(value) {
    return Math.abs(value);
  }

  getMinimumValue(value1, value2) {
    return Math.min(value1, value2);
  }

};

__decorate([Prop()], BarBase.prototype, "attributePercentage", void 0);

__decorate([Prop()], BarBase.prototype, "type", void 0);

BarBase = __decorate([Component], BarBase);
var BarBase$1 = BarBase;

let BarDefault$1 = class BarDefault extends mixins(BarBase$1) {};
BarDefault$1 = __decorate([Component], BarDefault$1);
var script$4 = BarDefault$1;

/* script */
const __vue_script__$4 = script$4;
/* template */

var __vue_render__$4 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  _vm._self._c || _h;

  return _vm._m(0);
};

var __vue_staticRenderFns__$4 = [function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-barDefault",
    class: {
      'oke-barDefault--centered': _vm.type === 'centered-range',
      'oke-barDefault--centeredMiddle': _vm.type === 'centered-range' && _vm.attributePercentage === 50,
      'oke-barDefault--leftPadding': _vm.attributePercentage === 0,
      'oke-barDefault--rightPadding': _vm.attributePercentage === 100
    }
  }, [_c('div', {
    staticClass: "oke-barDefault-marker"
  }, [_c('div', {
    staticClass: "oke-barDefault-dot",
    style: {
      left: _vm.attributePercentage + "%"
    }
  })]), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-dots"
  }, [_c('div', {
    staticClass: "oke-barDefault-dot",
    class: {
      'oke-barDefault-dot--dark': _vm.type === 'range' && _vm.attributePercentage > 0
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-dot",
    class: {
      'oke-barDefault-dot--dark': _vm.type === 'range' && _vm.attributePercentage > 25 || _vm.type === 'centered-range' && _vm.attributePercentage < 25
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-dot oke-barDefault-dot--center",
    class: {
      'oke-barDefault-dot--dark': _vm.type === 'range' && _vm.attributePercentage > 50
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-dot",
    class: {
      'oke-barDefault-dot--dark': _vm.attributePercentage > 75
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-dot"
  })]), _vm._v(" "), _c('div', {
    staticClass: "oke-barDefault-background"
  }, [_c('div', {
    staticClass: "oke-barDefault-background-shading",
    style: {
      width: _vm.shadedWidth,
      'margin-left': _vm.shadedMarginLeft
    }
  })])]);
}];
/* style */

const __vue_inject_styles__$4 = undefined;
/* scoped */

const __vue_scope_id__$4 = undefined;
/* module identifier */

const __vue_module_identifier__$4 = undefined;
/* functional template */

const __vue_is_functional_template__$4 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$4 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$4,
  staticRenderFns: __vue_staticRenderFns__$4
}, __vue_inject_styles__$4, __vue_script__$4, __vue_scope_id__$4, __vue_is_functional_template__$4, __vue_module_identifier__$4, false, undefined, undefined, undefined);

var BarDefault = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$4
});

let BarRounded$1 = class BarRounded extends mixins(BarBase$1) {};
BarRounded$1 = __decorate([Component], BarRounded$1);
var script$3 = BarRounded$1;

/* script */
const __vue_script__$3 = script$3;
/* template */

var __vue_render__$3 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-barRounded",
    class: {
      'oke-barRounded--centeredLeft': _vm.type === 'centered-range' && _vm.attributePercentage < 50,
      'oke-barRounded--centeredRight': _vm.type === 'centered-range' && _vm.attributePercentage > 50,
      'oke-barRounded--centeredMiddle': _vm.type === 'centered-range' && _vm.attributePercentage === 50
    }
  }, [_c('div', {
    staticClass: "oke-barRounded-bg"
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barRounded-shading",
    style: {
      width: _vm.shadedWidth,
      'margin-left': _vm.shadedMarginLeft
    }
  })]);
};

var __vue_staticRenderFns__$3 = [];
/* style */

const __vue_inject_styles__$3 = undefined;
/* scoped */

const __vue_scope_id__$3 = undefined;
/* module identifier */

const __vue_module_identifier__$3 = undefined;
/* functional template */

const __vue_is_functional_template__$3 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$3 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$3,
  staticRenderFns: __vue_staticRenderFns__$3
}, __vue_inject_styles__$3, __vue_script__$3, __vue_scope_id__$3, __vue_is_functional_template__$3, __vue_module_identifier__$3, false, undefined, undefined, undefined);

var BarRounded = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$3
});

let BarOutlined$1 = class BarOutlined extends mixins(BarBase$1) {};
BarOutlined$1 = __decorate([Component], BarOutlined$1);
var script$2 = BarOutlined$1;

/* script */
const __vue_script__$2 = script$2;
/* template */

var __vue_render__$2 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-barOutlined",
    class: {
      'oke-barOutlined--centeredLeft': _vm.type === 'centered-range' && _vm.attributePercentage < 50,
      'oke-barOutlined--centeredRight': _vm.type === 'centered-range' && _vm.attributePercentage > 50,
      'oke-barOutlined--centeredMiddle': _vm.type === 'centered-range' && _vm.attributePercentage === 50
    }
  }, [_c('div', {
    staticClass: "oke-barOutlined-bg"
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barOutlined-shading",
    style: {
      width: _vm.shadedWidth,
      'margin-left': _vm.shadedMarginLeft
    }
  })]);
};

var __vue_staticRenderFns__$2 = [];
/* style */

const __vue_inject_styles__$2 = undefined;
/* scoped */

const __vue_scope_id__$2 = undefined;
/* module identifier */

const __vue_module_identifier__$2 = undefined;
/* functional template */

const __vue_is_functional_template__$2 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$2 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$2,
  staticRenderFns: __vue_staticRenderFns__$2
}, __vue_inject_styles__$2, __vue_script__$2, __vue_scope_id__$2, __vue_is_functional_template__$2, __vue_module_identifier__$2, false, undefined, undefined, undefined);

var BarOutlined = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$2
});

let BarClassic$1 = class BarClassic extends mixins(BarBase$1) {};
BarClassic$1 = __decorate([Component], BarClassic$1);
var script$1 = BarClassic$1;

/* script */
const __vue_script__$1 = script$1;
/* template */

var __vue_render__$1 = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-barClassic",
    class: {
      'oke-barClassic--centered': _vm.type === 'centered-range',
      'oke-barClassic--leftPadding': _vm.attributePercentage === 0,
      'oke-barClassic--rightPadding': _vm.attributePercentage === 100
    }
  }, [_c('div', {
    staticClass: "oke-barClassic-bg"
  }, [_c('div', {
    staticClass: "oke-barClassic-bg-shading",
    style: {
      width: _vm.shadedWidth,
      'margin-left': _vm.shadedMarginLeft
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barClassic-bg-centerLine"
  })]), _vm._v(" "), _c('div', {
    staticClass: "oke-barClassic-marker"
  }, [_c('div', {
    staticClass: "oke-barClassic-marker-dot",
    style: {
      left: _vm.attributePercentage + "%"
    }
  })])]);
};

var __vue_staticRenderFns__$1 = [];
/* style */

const __vue_inject_styles__$1 = undefined;
/* scoped */

const __vue_scope_id__$1 = undefined;
/* module identifier */

const __vue_module_identifier__$1 = undefined;
/* functional template */

const __vue_is_functional_template__$1 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__$1 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, undefined, undefined, undefined);

var BarClassic = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__$1
});

let BarBlocks$1 = class BarBlocks extends mixins(BarBase$1) {};
BarBlocks$1 = __decorate([Component], BarBlocks$1);
var script = BarBlocks$1;

/* script */
const __vue_script__ = script;
/* template */

var __vue_render__ = function () {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "oke-barBlocks",
    class: {
      'oke-barBlocks--centered': _vm.type === 'centered-range',
      'oke-barBlocks--centeredMiddle': _vm.type === 'centered-range' && _vm.attributePercentage === 50
    }
  }, [_c('div', {
    staticClass: "oke-barBlocks-bg"
  }, [_c('div', {
    staticClass: "oke-barBlocks-bg-shading",
    style: {
      width: _vm.shadedWidth,
      'margin-left': _vm.shadedMarginLeft
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "oke-barBlocks-bg-centerLine"
  })])]);
};

var __vue_staticRenderFns__ = [];
/* style */

const __vue_inject_styles__ = undefined;
/* scoped */

const __vue_scope_id__ = undefined;
/* module identifier */

const __vue_module_identifier__ = undefined;
/* functional template */

const __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

const __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

var BarBlocks = /*#__PURE__*/Object.freeze({
    __proto__: null,
    'default': __vue_component__
});

export { __vue_component__$14 as OkendoHomepageCarousel, __vue_component__$11 as OkendoMediaCarousel, __vue_component__$12 as OkendoMediaGrid, __vue_component__$15 as OkendoQuestionsWidget, __vue_component__$13 as OkendoReviewsBadge, __vue_component__$16 as OkendoStarRating, OkendoVueI18nPlugin, __vue_component__$10 as OkendoWidget, install as default, okendoConfigure };
